(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3475217,      96636]*)
(*NotebookOutlinePosition[   3475909,      96660]*)
(*  CellTagsIndexPosition[   3475865,      96656]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Random numbers and random matrices:", "Title"],

Cell["where quantum chaos meets number theory", "Subtitle"],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "This is a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook to accompany the article \"Random Numbers and Random Matrices: \
quantum chaos meets number theory\", which has been submitted to the American \
Journal of Physics.  All of the calculations discussed and presented in the \
article can be carried out using this notebook.  I do not include much \
description of the physical relevance of the various calculations since that \
is covered in depth in the article (so please consult the article for that \
information).  Instead I provide here a brief description of the calculations \
and the code to implement them in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  I have tried to make each section self-contained, although the plots of \
the theoretical distributions are not redone in each section.  Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Help feature for descriptions of the individual commands.  If you have \
any questions about this material feel free to contact me at \
ttimberlake@berry.edu."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of the Theoretical Distrubutions", "Section"],

Cell["\<\
In this section we create plots of the various Wigner distributions \
and the Poisson distrubution, as well as the Wigner semicircle law.  These \
will be used later to compare calculated distributions to these theoretical \
predictions.  The actual limiting distributions for random matrices are \
slightly different from the Wigner distributions.\
\>", "Text"],

Cell["Here's a plot of the Poisson distribution.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Poisson = 
      Plot[Exp[\(-s\)], {s, 0, 5}, 
        PlotStyle \[Rule] {Thickness[0.015]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0147151 0.588604 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(1)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(2)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(3)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(4)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.015 w
.02381 .60332 m
.06244 .49526 L
.10458 .39989 L
.14415 .32764 L
.18221 .27097 L
.22272 .22187 L
.26171 .18353 L
.30316 .15052 L
.34309 .12483 L
.3815 .10472 L
.42237 .08734 L
.46172 .07379 L
.49955 .06314 L
.53984 .05391 L
.57861 .04669 L
.61984 .04047 L
.65954 .03562 L
.69774 .03182 L
.73838 .02854 L
.77751 .02597 L
.81909 .02376 L
.85916 .02205 L
.89771 .0207 L
.93871 .01954 L
.97619 .01868 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool003cooooo0ol0000Uooooo`Go00009_ooool3o`0002Sooooo0ol0000Uoooo
o`?o00001_ooool003gooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool0000Uoooo
o`05o`000?ooooooooooooooool00000:?ooool00ol0003oooooooooo`0Sooooo`05o`000?oooooo
ooooooooool000001Oooool003gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo02?ooooo1Ol0000Xooooo`03o`000?oooooooooo00?ooooo000moooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool2o`0002Kooooo00Co0000oooo
oooooooo0000:Oooool00ol0003oooooooooo`03ooooo`00?Oooool00ol0003oooooooooo`0Toooo
o`05o`000?ooooooooooooooool00000:Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
000002Gooooo1?l00006ooooo`00??ooool2o`0002Kooooo00Go0000ooooooooooooooooo`00000U
ooooo`05o`000?ooooooooooooooool000009oooool2o`0002Gooooo00?o0000ooooooooool01ooo
ool003gooooo00?o0000ooooooooool09Oooool3o`0002Oooooo0ol0000Yooooo`03o`000?oooooo
oooo02?ooooo1Ol00005ooooo`00joooool001Cooooo00?o0000ooooooooool0e?ooool001Cooooo
00?o0000ooooooooool0e?ooool001Cooooo00?o0000ooooooooool0e?ooool000oooooog?l00000
01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00000ao`0000Gooooo000Dooooo`03
o`000?oooooooooo09Cooooo>ol00005ooooo`005?ooool00ol0003oooooooooo`23ooooobko0000
8oooool001Cooooo00?o0000ooooooooool0O?oooolSo`0003Gooooo000Dooooo`03o`000?oooooo
oooo07Oooooo7ol0000nooooo`005?ooool2o`0007;ooooo5?l0001?ooooo`005?ooool00ol0003o
ooooooooo`1[oooooa?o0000E_ooool001Cooooo00?o0000ooooooooool0I_oooolCo`0005_ooooo
000Dooooo`03o`000?oooooooooo06?ooooo4?l0001Qooooo`005?ooool00ol0003oooooooooo`1P
ooooo`go0000Ioooool001Cooooo00?o0000ooooooooool0GOooool;o`0006cooooo000Dooooo`03
o`000?oooooooooo05_ooooo2_l0001_ooooo`005?ooool2o`0005Wooooo2_l0001booooo`005?oo
ool00ol0003oooooooooo`1Eooooo`[o0000MOooool001Cooooo00?o0000ooooooooool0D_ooool;
o`0007Oooooo000Dooooo`03o`000?oooooooooo04oooooo2ol0001jooooo`005?ooool00ol0003o
ooooooooo`1<ooooo`_o0000OOooool001Cooooo00?o0000ooooooooool0BOooool;o`00083ooooo
000Dooooo`;o0000BOooool9o`0008?ooooo000Dooooo`03o`000?oooooooooo04Kooooo2?l00026
ooooo`005?ooool00ol0003oooooooooo`14ooooo`Oo0000ROooool001Cooooo00?o0000oooooooo
ool0@oooool7o`0008[ooooo0002ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000?o
oooo00?o0000ooooooooool0@Oooool7o`0008cooooo00001Ooooooo0000oooooooooooo000000So
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0oooooo`Oo0000S_ooool00005
ooooool0003oooooooooool000002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
03gooooo2?l0002?ooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oooooooooo
00;ooooo0ol0000looooo`Oo0000TOooool00005ooooool0003oooooooooool000001oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0>_ooool7o`0009?ooooo00001Ooo
oooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo03Sooooo1ol0002Eooooo`000_ooool2o`0000Wooooo0ol00004ooooo`03o`000?oooooo
oooo03Oooooo1ol0002Fooooo`005?ooool00ol0003oooooooooo`0fooooo`Ko0000V?ooool001Co
oooo00?o0000ooooooooool0=Oooool5o`0009[ooooo000Dooooo`;o0000=Oooool5o`0009_ooooo
000Dooooo`03o`000?oooooooooo03?ooooo1Ol0002Looooo`005?ooool00ol0003oooooooooo`0b
ooooo`Go0000WOooool001Cooooo00?o0000ooooooooool0<Oooool5o`0009kooooo000Dooooo`03
o`000?oooooooooo033ooooo1Ol0002Oooooo`005?ooool00ol0003oooooooooo`0_ooooo`Go0000
X?ooool001Cooooo0_l0000_ooooo`Go0000XOooool001Cooooo00?o0000ooooooooool0;Oooool5
o`000:;ooooo000Dooooo`03o`000?oooooooooo02cooooo1Ol0002Sooooo`005?ooool00ol0003o
ooooooooo`0[ooooo`Go0000Y?ooool001Cooooo00?o0000ooooooooool0:_ooool5o`000:Gooooo
000Dooooo`03o`000?oooooooooo02Wooooo1Ol0002Vooooo`005?ooool00ol0003oooooooooo`0X
ooooo`Go0000Yoooool001Cooooo0_l0000Yooooo`Co0000Z?ooool001Cooooo00?o0000oooooooo
ool09oooool4o`000:Wooooo000Dooooo`03o`000?oooooooooo02Kooooo1Ol0002Yooooo`005?oo
ool00ol0003oooooooooo`0Uooooo`Go0000Z_ooool000;ooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo0ol00003ooooo`03o`000?oooooooooo02Cooooo1Ol0002[ooooo`0000Goooooo`00
0?ooooooooooo`00000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool5
o`000:cooooo00001Ooooooo0000oooooooooooo000000Oooooo1Ol00003ooooo`?o00008oooool4
o`000:gooooo00001Ooooooo0000oooooooooooo000000Oooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0Rooooo`Co0000[_ooool00005ooooool0003oooooooooool000002?oo
ool00ol0003oooooo`000004ooooo`03o`000?oooooooooo027ooooo1Ol0002^ooooo`0000Gooooo
o`000?ooooooooooo`000009ooooo`;o00001?ooool00ol0003oooooooooo`0Pooooo`Go0000[ooo
ool000;ooooo0_l0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool5
o`000;3ooooo000Dooooo`03o`000?oooooooooo01oooooo1?l0002aooooo`005?ooool00ol0003o
ooooooooo`0Nooooo`Co0000/_ooool001Cooooo0_l0000Nooooo`Go0000/_ooool001Cooooo00?o
0000ooooooooool07Oooool4o`000;?ooooo000Dooooo`03o`000?oooooooooo01cooooo1?l0002d
ooooo`005?ooool00ol0003oooooooooo`0Kooooo`Go0000]?ooool001Cooooo00?o0000oooooooo
ool06oooool4o`000;Gooooo000Dooooo`03o`000?oooooooooo01[ooooo1?l0002fooooo`005?oo
ool2o`0001[ooooo1Ol0002fooooo`005?ooool00ol0003oooooooooo`0Iooooo`Co0000]oooool0
01Cooooo00?o0000ooooooooool06?ooool4o`000;Sooooo000Dooooo`03o`000?oooooooooo01Oo
oooo1Ol0002hooooo`005?ooool00ol0003oooooooooo`0Gooooo`Co0000^Oooool001Cooooo00?o
0000ooooooooool05_ooool4o`000;[ooooo000Dooooo`03o`000?oooooooooo01Kooooo1?l0002j
ooooo`005?ooool2o`0001Kooooo1?l0002kooooo`005?ooool00ol0003oooooooooo`0Dooooo`Go
0000^oooool001Cooooo00?o0000ooooooooool05?ooool4o`000;cooooo0002ooooo`;o00001?oo
ool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`0Cooooo`Co0000_Ooo
ool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool04oooool4o`000;gooooo00001Ooooooo0000oooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01;ooooo1?l0002nooooo`00
00Goooooo`000?ooooooooooo`000007ooooo`Co00001?ooool3o`0001;ooooo1?l0002nooooo`00
00Goooooo`000?ooooooooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04Oooool4o`000;oooooo00001Ooooooo0000oooooooooooo000000Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Aooooo`Co0000_oooool000;ooooo0_l0000:ooooo`;o0000
1?ooool00ol0003oooooooooo`0@ooooo`Co0000`?ooool001Cooooo00?o0000ooooooooool03ooo
ool5o`000<3ooooo000Dooooo`03o`000?oooooooooo00oooooo1?l00031ooooo`005?ooool2o`00
00oooooo1?l00032ooooo`005?ooool00ol0003oooooooooo`0>ooooo`Co0000`_ooool001Cooooo
00?o0000ooooooooool03Oooool4o`000<?ooooo000Dooooo`03o`000?oooooooooo00gooooo1?l0
0033ooooo`005?ooool00ol0003oooooooooo`0<ooooo`Co0000a?ooool001Cooooo00?o0000oooo
ooooool03?ooool4o`000<Cooooo000Dooooo`03o`000?oooooooooo00cooooo0ol00035ooooo`00
5?ooool2o`0000cooooo1?l00035ooooo`005?ooool00ol0003oooooooooo`0;ooooo`Co0000aOoo
ool001Cooooo00?o0000ooooooooool02_ooool4o`000<Kooooo000Dooooo`03o`000?oooooooooo
00[ooooo1?l00036ooooo`005?ooool00ol0003oooooooooo`09ooooo`Co0000aoooool001Cooooo
00?o0000ooooooooool02Oooool4o`000<Oooooo000Dooooo`;o00002_ooool3o`000<Sooooo000D
ooooo`03o`000?oooooooooo00Sooooo1?l00038ooooo`005?ooool00ol0003oooooooooo`08oooo
o`Co0000b?ooool001Cooooo00?o0000ooooooooool01oooool4o`000<Wooooo0002ooooo`;o0000
1?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`07ooooo`Co0000
bOooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01_ooool4o`000<[ooooo00001Ooooooo0000oooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo1?l0003:oooo
o`0000Goooooo`000?ooooooooooo`000008ooooo`?o00001?ooool3o`0000Kooooo0ol0003;oooo
o`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`05ooooo`Co0000boooool00005ooooool0003oooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool4o`000<_ooooo0002
ooooo`;o00002Oooool3o`0000Cooooo00?o0000ooooooooool01?ooool4o`000<cooooo000Doooo
o`03o`000?oooooooooo00Cooooo1?l0003<ooooo`005?ooool00ol0003oooooooooo`04ooooo`?o
0000cOooool001Cooooo0_l00004ooooo`Co0000cOooool001Cooooo00?o0000ooooooooool00ooo
ool4o`000<gooooo000Dooooo`03o`000?oooooooooo00;ooooo1?l0003>ooooo`005?ooool00ol0
003oooooooooo`02ooooo`Co0000c_ooool001Cooooo00?o0000ooooooooool00_ooool3o`000<oo
oooo000Dooooo`04o`000?ooooooooooooooo`Co0000coooool001Cooooo00Co0000oooooooooooo
oooo1?l0003?ooooo`005?ooool2o`000003ooooool0003o000000;o0000d?ooool001Cooooo00?o
0000ooooooooool01?l0003@ooooo`005?ooool00ol0003oooooooooo`03o`000=7ooooo000Doooo
o`03o`000?oooooo000000?o0000dOooool001Cooooo00?o0000ooooool000000ol0003Aooooo`00
5?ooool00ol0003oooooo`000002o`000=;ooooo000Dooooo`Go0000d_ooool001Cooooo1Ol0003B
ooooo`005?ooool4o`000=?ooooo000Dooooo`Co0000doooool000gooooo0ol00004ooooo`?o0000
e?ooool000kooooo00?o0000ooooooooool00_ooool4o`000=Cooooo000>ooooo`03o`000?oooooo
oooo00;ooooo1?l0003Dooooo`003_ooool00ol0003oooooooooo`02ooooo`?o0000eOooool000ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Dooooo`003Oooool2o`0000Gooooo
00?o0000ooooooooool0e?ooool000kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`3Dooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-0.498205, -0.437968, 0.0240309, \
0.00777656}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Below we plot the theoretical density of eigenvalues known as Wigner's \
semicircle law (because the curve takes the shape of a semicircle centered at \
zero with radius ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\@\(2  N\)\)\(,\)\)\)]],
  "where N is the dimension of the random matrix (and hence the number of \
eigenvalues)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(WSC = 
      Plot[Sqrt[2*n - x^2]/\((Pi)\), {x, \(-Sqrt[2*n]\), Sqrt[2*n]}, 
        PlotStyle \[Rule] {Thickness[0.02]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00614759 0.0147151 0.0238725 [
[.03893 .00222 -9 -9 ]
[.03893 .00222 9 0 ]
[.19262 .00222 -9 -9 ]
[.19262 .00222 9 0 ]
[.34631 .00222 -9 -9 ]
[.34631 .00222 9 0 ]
[.65369 .00222 -6 -9 ]
[.65369 .00222 6 0 ]
[.80738 .00222 -6 -9 ]
[.80738 .00222 6 0 ]
[.96107 .00222 -6 -9 ]
[.96107 .00222 6 0 ]
[.4875 .13408 -6 -4.5 ]
[.4875 .13408 0 4.5 ]
[.4875 .25344 -12 -4.5 ]
[.4875 .25344 0 4.5 ]
[.4875 .3728 -12 -4.5 ]
[.4875 .3728 0 4.5 ]
[.4875 .49216 -12 -4.5 ]
[.4875 .49216 0 4.5 ]
[.4875 .61153 -12 -4.5 ]
[.4875 .61153 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03893 .01472 m
.03893 .02097 L
s
[(-75)] .03893 .00222 0 1 Mshowa
.19262 .01472 m
.19262 .02097 L
s
[(-50)] .19262 .00222 0 1 Mshowa
.34631 .01472 m
.34631 .02097 L
s
[(-25)] .34631 .00222 0 1 Mshowa
.65369 .01472 m
.65369 .02097 L
s
[(25)] .65369 .00222 0 1 Mshowa
.80738 .01472 m
.80738 .02097 L
s
[(50)] .80738 .00222 0 1 Mshowa
.96107 .01472 m
.96107 .02097 L
s
[(75)] .96107 .00222 0 1 Mshowa
.125 Mabswid
.06967 .01472 m
.06967 .01847 L
s
.10041 .01472 m
.10041 .01847 L
s
.13114 .01472 m
.13114 .01847 L
s
.16188 .01472 m
.16188 .01847 L
s
.22336 .01472 m
.22336 .01847 L
s
.2541 .01472 m
.2541 .01847 L
s
.28483 .01472 m
.28483 .01847 L
s
.31557 .01472 m
.31557 .01847 L
s
.37705 .01472 m
.37705 .01847 L
s
.40779 .01472 m
.40779 .01847 L
s
.43852 .01472 m
.43852 .01847 L
s
.46926 .01472 m
.46926 .01847 L
s
.53074 .01472 m
.53074 .01847 L
s
.56148 .01472 m
.56148 .01847 L
s
.59221 .01472 m
.59221 .01847 L
s
.62295 .01472 m
.62295 .01847 L
s
.68443 .01472 m
.68443 .01847 L
s
.71517 .01472 m
.71517 .01847 L
s
.7459 .01472 m
.7459 .01847 L
s
.77664 .01472 m
.77664 .01847 L
s
.83812 .01472 m
.83812 .01847 L
s
.86886 .01472 m
.86886 .01847 L
s
.89959 .01472 m
.89959 .01847 L
s
.93033 .01472 m
.93033 .01847 L
s
.00819 .01472 m
.00819 .01847 L
s
.99181 .01472 m
.99181 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .13408 m
.50625 .13408 L
s
[(5)] .4875 .13408 1 0 Mshowa
.5 .25344 m
.50625 .25344 L
s
[(10)] .4875 .25344 1 0 Mshowa
.5 .3728 m
.50625 .3728 L
s
[(15)] .4875 .3728 1 0 Mshowa
.5 .49216 m
.50625 .49216 L
s
[(20)] .4875 .49216 1 0 Mshowa
.5 .61153 m
.50625 .61153 L
s
[(25)] .4875 .61153 1 0 Mshowa
.125 Mabswid
.5 .03859 m
.50375 .03859 L
s
.5 .06246 m
.50375 .06246 L
s
.5 .08633 m
.50375 .08633 L
s
.5 .1102 m
.50375 .1102 L
s
.5 .15795 m
.50375 .15795 L
s
.5 .18182 m
.50375 .18182 L
s
.5 .20569 m
.50375 .20569 L
s
.5 .22957 m
.50375 .22957 L
s
.5 .27731 m
.50375 .27731 L
s
.5 .30118 m
.50375 .30118 L
s
.5 .32506 m
.50375 .32506 L
s
.5 .34893 m
.50375 .34893 L
s
.5 .39667 m
.50375 .39667 L
s
.5 .42055 m
.50375 .42055 L
s
.5 .44442 m
.50375 .44442 L
s
.5 .46829 m
.50375 .46829 L
s
.5 .51604 m
.50375 .51604 L
s
.5 .53991 m
.50375 .53991 L
s
.5 .56378 m
.50375 .56378 L
s
.5 .58765 m
.50375 .58765 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.02 w
.02381 .01496 m
.02499 .05605 L
.02605 .07181 L
.02846 .09674 L
.03279 .12846 L
.03784 .15654 L
.04262 .1785 L
.06244 .24696 L
.08265 .29814 L
.10458 .34268 L
.14545 .40764 L
.1848 .45591 L
.22263 .49316 L
.26292 .52518 L
.30169 .54985 L
.34292 .57037 L
.36351 .57862 L
.38262 .58516 L
.40229 .59079 L
.42082 .59512 L
.44134 .59884 L
.45995 .60123 L
.46971 .60213 L
.47505 .60251 L
.48003 .6028 L
.48428 .603 L
.48883 .60316 L
.49143 .60322 L
.49271 .60325 L
.49389 .60327 L
.49494 .60329 L
.4961 .6033 L
.49726 .60331 L
.4985 .60332 L
.49971 .60332 L
.50085 .60332 L
.50209 .60331 L
.50278 .60331 L
.50341 .6033 L
.50469 .60329 L
.50608 .60327 L
.50859 .60322 L
.51093 .60316 L
.51341 .60309 L
.51785 .60291 L
.52298 .60263 L
.52778 .60232 L
.5387 .60137 L
.54911 .60018 L
.55899 .59879 L
Mistroke
.57753 .59547 L
.59737 .59088 L
.61577 .58566 L
.65495 .57129 L
.69659 .55082 L
.73671 .52545 L
.77531 .49498 L
.81636 .45464 L
.8559 .40577 L
.89393 .34541 L
.91511 .30312 L
.9344 .25583 L
.944 .22745 L
.95442 .19064 L
.9592 .17054 L
.96427 .1456 L
.9686 .11942 L
.97089 .10228 L
.97336 .07874 L
.97408 .07002 L
.97484 .05902 L
.97549 .04674 L
.97619 .01496 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool000Sooooo00?o0000ooooooooool00_ooool3
o`0001_ooooo0ol00004ooooo`;o00006_ooool5o`0000;ooooo0ol0000jooooo`Go00000_ooool3
o`0001_ooooo0ol00004ooooo`;o00007?ooool00ol0003oooooooooo`02ooooo`?o00001oooool0
00Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Oooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001[ooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`03o`000?oooooooooo03Sooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0001_ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Cooooo0005o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`Go
00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo017ooooo1Ol00003oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool000Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo000:
ooooo`03o`000?oooooo000000?o00006_ooool4o`0000?ooooo00Co0000oooooooooooo00006Ooo
ool01_l0003ooooooooooooooooo0000ooooo`Co0000>_ooool01_l0003ooooooooooooooooo0000
ooooo`Co00006_ooool4o`0000?ooooo00Co0000oooooooooooo00007Oooool00ol0003oooooo`00
0003o`0000Oooooo0006ooooo`07o`000?ooooooooooooooool0003oooooo`00000Mooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo00006Oooool01ol0003ooooooooooooooooo0000
ooooool00000?Oooool01ol0003ooooooooooooooooo0000ooooool000007Oooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0001Wooooo00Oo0000ooooooooooooooooo`000?oooooo
000000[ooooo0006ooooo`Go000000?oooooo`000?l000000ol0000Iooooo`Go00000oooool2o`00
01_ooooo0ol00002ooooo`Go0000>_ooool3o`0000;ooooo1Ol0000Iooooo`Go00000oooool2o`00
01[ooooo1Ol000000ooooooo0000o`000003o`0000Kooooo003[ooooo`00MOooool00ol0003ooooo
ooooo`1cooooo`00MOooool00ol0003oooooooooo`1cooooo`000oooool4o`0006kooooo00?o0000
ooooooooool0J_ooool4o`0000Gooooo003[o`00000000?oooooo`000?ooool01?l00002ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooo000000?o00000_ooool1o`00007ooooo0Oooool000?ooooo1?l00002ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooo000000?o00001Oooool000?ooooo1?l0001^ooooo`03o`000?oooooooooo06[ooooo1?l0
0005ooooo`000oooool4o`0006kooooo00?o0000ooooooooool0J_ooool4o`0000Gooooo0003oooo
o`Co0000K_ooool00ol0003oooooooooo`1Zooooo`Co00001Oooool000?ooooo1?l0001^ooooo`03
o`000?oooooooooo06[ooooo1?l00005ooooo`000oooool4o`0006kooooo00?o0000ooooooooool0
J_ooool4o`0000Gooooo0003ooooo`Co0000K_ooool00ol0003oooooooooo`1Zooooo`Co00001Ooo
ool000?ooooo1?l0001^ooooo`03o`000?oooooooooo06[ooooo1?l00005ooooo`000oooool4o`00
06kooooo00?o0000ooooooooool0J_ooool4o`0000Gooooo0003ooooo`Co0000K_ooool00ol0003o
ooooooooo`1Zooooo`Co00001Oooool000?ooooo1Ol0001]ooooo`03o`000?oooooooooo06Wooooo
1Ol00005ooooo`000oooool5o`0006gooooo00?o0000ooooooooool0JOooool5o`0000Gooooo0003
ooooo`Go0000KOooool00ol0003oooooooooo`1Yooooo`Go00001Oooool000Cooooo1?l0001]oooo
o`03o`000?oooooooooo06Wooooo1?l00006ooooo`001?ooool4o`0006gooooo00?o0000oooooooo
ool0JOooool4o`0000Kooooo0004ooooo`Co0000KOooool00ol0003oooooooooo`1Yooooo`Co0000
1_ooool000Cooooo1?l0001]ooooo`03o`000?oooooooooo06Wooooo1?l00006ooooo`001?ooool4
o`0006gooooo00?o0000ooooooooool0JOooool4o`0000Kooooo0004ooooo`Co0000KOooool00ol0
003oooooooooo`1Yooooo`Co00001_ooool000Cooooo1?l0001]ooooo`03o`000?oooooooooo06Wo
oooo1?l00006ooooo`001?ooool4o`0006gooooo00?o0000ooooooooool0JOooool4o`0000Kooooo
0004ooooo`Go0000K?ooool00ol0003oooooooooo`1Xooooo`Go00001_ooool000Cooooo1Ol0001/
ooooo`03o`000?oooooooooo06Sooooo1Ol00006ooooo`001?ooool5o`0006cooooo00?o0000oooo
ooooool0J?ooool5o`0000Kooooo0005ooooo`Co0000I?ooool3o`0000Gooooo00?o0000oooooooo
ool0J?ooool4o`0000Oooooo0005ooooo`Co0000Hoooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0J?ooool4o`0000Oooooo0005ooooo`Co0000Ioooool00ol0003ooooo
ooooo`02ooooo`;o0000J?ooool5o`0000Oooooo0005ooooo`Co0000Ioooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06Oooooo1Ol00007ooooo`001Oooool5o`0006;ooooo1?l00005
ooooo`03o`000?oooooooooo06Oooooo1Ol00007ooooo`001Oooool5o`0006;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Wooooo`Co00002?ooool000Gooooo1Ol0001Rooooo`Go
00001?ooool00ol0003oooooooooo`1Wooooo`Co00002?ooool000Kooooo1?l0001[ooooo`03o`00
0?oooooooooo06Oooooo1?l00008ooooo`001_ooool4o`0006_ooooo00?o0000ooooooooool0I_oo
ool5o`0000Sooooo0006ooooo`Co0000Joooool00ol0003oooooooooo`1Vooooo`Go00002?ooool0
00Kooooo1Ol0001Zooooo`03o`000?oooooooooo06Kooooo1Ol00008ooooo`001_ooool5o`0006[o
oooo00?o0000ooooooooool0I_ooool4o`0000Wooooo0006ooooo`Go0000J_ooool00ol0003ooooo
ooooo`1Vooooo`Co00002Oooool000Oooooo1?l0001Zooooo`03o`000?oooooooooo06Gooooo1Ol0
0009ooooo`001oooool4o`0006[ooooo00?o0000ooooooooool0IOooool5o`0000Wooooo0007oooo
o`Go0000JOooool00ol0003oooooooooo`1Uooooo`Go00002Oooool000Oooooo1Ol0001Yooooo`03
o`000?oooooooooo06Gooooo1?l0000:ooooo`001oooool5o`0006Wooooo00?o0000ooooooooool0
I?ooool5o`0000[ooooo0008ooooo`Go0000J?ooool00ol0003oooooooooo`1Tooooo`Go00002_oo
ool000Sooooo1Ol0001Xooooo`03o`000?oooooooooo06Cooooo1Ol0000:ooooo`002?ooool5o`00
06Sooooo00?o0000ooooooooool0Hoooool5o`0000_ooooo0009ooooo`Go0000Ioooool00ol0003o
ooooooooo`1Sooooo`Go00002oooool000Wooooo1Ol0001Wooooo`03o`000?oooooooooo06?ooooo
1Ol0000;ooooo`002Oooool5o`0006Oooooo00?o0000ooooooooool0H_ooool5o`0000cooooo000:
ooooo`Go0000I_ooool00ol0003oooooooooo`1Rooooo`Go00003?ooool000[ooooo1Ol0001Voooo
o`03o`000?oooooooooo06;ooooo1Ol0000<ooooo`002_ooool5o`0006Kooooo00?o0000oooooooo
ool0HOooool5o`0000gooooo000;ooooo`Go0000IOooool00ol0003oooooooooo`1Qooooo`Go0000
3Oooool000_ooooo1Ol0001Gooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0HOoo
ool5o`0000gooooo000;ooooo`Go0000F?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0H?ooool5o`0000kooooo000<ooooo`Go0000Eoooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo0_l0001Qooooo`Go00003_oo
ool000cooooo1Ol0001Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`1Pooooo`Go00003_ooool000cooooo1Ol0001Gooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Oooooo`Go00003ooo
ool000gooooo1Ol0001Eooooo`;o00001?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo05oooooo1Ol0000?ooooo`003Oooool5o`0005Kooooo00?o0000ooooooooool00oooool2
o`0000Gooooo00?o0000ooooooooool0Goooool5o`0000oooooo000=ooooo`Ko0000H_ooool00ol0
003oooooooooo`1Nooooo`Go00004?ooool000kooooo1Ol0001Rooooo`03o`000?oooooooooo05ko
oooo1Ol0000@ooooo`003_ooool6o`00067ooooo00?o0000ooooooooool0G_ooool5o`00013ooooo
000?ooooo`Go0000HOooool00ol0003oooooooooo`1Mooooo`Go00004Oooool000oooooo1Ol0001Q
ooooo`03o`000?oooooooooo05gooooo1Ol0000Aooooo`004?ooool5o`00063ooooo00?o0000oooo
ooooool0GOooool5o`00017ooooo000@ooooo`Go0000H?ooool00ol0003oooooooooo`1Looooo`Go
00004_ooool0013ooooo1_l0001Oooooo`03o`000?oooooooooo05cooooo1Ol0000Booooo`004Ooo
ool5o`0005oooooo00?o0000ooooooooool0Foooool6o`0001;ooooo000Aooooo`Ko0000G_ooool0
0ol0003oooooooooo`1Kooooo`Go00004oooool001;ooooo1Ol0001Nooooo`03o`000?oooooooooo
05[ooooo1_l0000Cooooo`004_ooool6o`0005gooooo00?o0000ooooooooool0F_ooool5o`0001Co
oooo000Cooooo`Go0000GOooool00ol0003oooooooooo`1Iooooo`Ko00005?ooool001?ooooo1_l0
001Looooo`03o`000?oooooooooo05Wooooo1Ol0000Eooooo`005?ooool5o`0005cooooo00?o0000
ooooooooool0F?ooool6o`0001Gooooo000Dooooo`Ko0000Foooool00ol0003oooooooooo`1Hoooo
o`Go00005_ooool001Gooooo1Ol0001Kooooo`03o`000?oooooooooo05Oooooo1_l0000Fooooo`00
5Oooool6o`0005[ooooo00?o0000ooooooooool0Eoooool5o`0001Oooooo000Fooooo`Ko0000FOoo
ool00ol0003oooooooooo`1Fooooo`Ko00005oooool001Kooooo1_l0001Iooooo`03o`000?oooooo
oooo05Gooooo1_l0000Hooooo`005oooool6o`0005Sooooo00?o0000ooooooooool0EOooool6o`00
01Sooooo000Hooooo`Ko0000BOooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo05Co
oooo1_l0000Iooooo`006?ooool6o`0004[ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0Doooool6o`0001[ooooo000Iooooo`Ko0000
BOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l0001Dooooo`Ko0000
6_ooool001[ooooo1_l00018ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Booooo`Ko00006oooool001[ooooo1_l00018ooooo`04o`000?oooooo
ooooooooo`Co00001Oooool00ol0003oooooooooo`1Booooo`Go00007?ooool001_ooooo1_l00016
ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo057ooooo1_l0000L
ooooo`007?ooool6o`0004Kooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooo
oooo053ooooo1_l0000Mooooo`007?ooool6o`0005?ooooo00?o0000ooooooooool0D?ooool6o`00
01gooooo000Mooooo`Ko0000D_ooool00ol0003oooooooooo`1?ooooo`Ko00007_ooool001kooooo
1_l0001Aooooo`03o`000?oooooooooo04kooooo1_l0000Oooooo`007_ooool6o`00057ooooo00?o
0000ooooooooool0C_ooool6o`0001oooooo000Oooooo`Ko0000D?ooool00ol0003oooooooooo`1=
ooooo`Ko00008?ooool0023ooooo1_l0001?ooooo`03o`000?oooooooooo04cooooo1_l0000Qoooo
o`008?ooool7o`0004kooooo00?o0000ooooooooool0Boooool7o`00027ooooo000Qooooo`Ko0000
C_ooool00ol0003oooooooooo`1:ooooo`Oo00008_ooool002;ooooo1_l0001=ooooo`03o`000?oo
oooooooo04Wooooo1ol0000Sooooo`008oooool6o`0004cooooo00?o0000ooooooooool0BOooool6
o`0002Cooooo000Sooooo`Oo0000Boooool00ol0003oooooooooo`18ooooo`Ko00009Oooool002Co
oooo1_l0001;ooooo`03o`000?oooooooooo04Oooooo1_l0000Vooooo`009Oooool6o`0004[ooooo
00?o0000ooooooooool0A_ooool7o`0002Kooooo000Vooooo`Ko0000BOooool00ol0003ooooooooo
o`15ooooo`Oo00009oooool002Kooooo2?l00017ooooo`03o`000?oooooooooo04Cooooo1ol0000X
ooooo`009oooool8o`0004Kooooo00?o0000ooooooooool0@oooool7o`0002Wooooo000Xooooo`So
0000AOooool00ol0003oooooooooo`12ooooo`Oo0000:_ooool002Wooooo2?l00014ooooo`03o`00
0?oooooooooo047ooooo1ol0000[ooooo`00:oooool7o`0004?ooooo00?o0000ooooooooool0@?oo
ool7o`0002cooooo000/ooooo`Oo0000@_ooool00ol0003oooooooooo`0oooooo`Oo0000;Oooool0
02gooooo1ol00011ooooo`03o`000?oooooooooo03kooooo1ol0000^ooooo`00;_ooool7o`00037o
oooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0mooooo`Oo0000;oooool002oooooo
2?l0000`ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0looooo`Oo0000<?ooool0033ooooo2?l0000`ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001?ooool2o`0003_ooooo2?l0000aooooo`00<Oooool8o`00033o
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0>Oooool8o`0003;ooooo000booooo`So0000;?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0hooooo`So0000<oooool0
03Cooooo1ol0000[ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo03Kooooo2Ol0000dooooo`00=Oooool7o`0002_ooooo0ol00004
ooooo`;o00001Oooool00ol0003oooooooooo`0eooooo`So0000=_ooool003Kooooo1ol0000hoooo
o`03o`000?oooooooooo03Cooooo2?l0000gooooo`00=oooool7o`0003Oooooo00?o0000oooooooo
ool0<oooool8o`0003Sooooo000hooooo`So0000=Oooool00ol0003oooooooooo`0aooooo`So0000
>_ooool003Wooooo2?l0000dooooo`03o`000?oooooooooo033ooooo2?l0000kooooo`00>_ooool9
o`0003;ooooo00?o0000ooooooooool0;_ooool9o`0003cooooo000kooooo`Wo0000<Oooool00ol0
003oooooooooo`0]ooooo`Wo0000?Oooool003gooooo2Ol0000_ooooo`03o`000?oooooooooo02_o
oooo2Ol0000oooooo`00?_ooool9o`0002kooooo00?o0000ooooooooool0:_ooool9o`00043ooooo
0010ooooo`Wo0000;?ooool00ol0003oooooooooo`0Xooooo`Wo0000@_ooool0047ooooo2ol0000Y
ooooo`03o`000?oooooooooo02Kooooo2_l00013ooooo`00@oooool;o`0002Oooooo00?o0000oooo
ooooool09?ooool:o`0004Gooooo0014ooooo`go00009?ooool00ol0003oooooooooo`0Rooooo`_o
0000A_ooool004Kooooo3Ol0000Rooooo`03o`000?oooooooooo023ooooo2ol00018ooooo`00BOoo
ool=o`0001oooooo00?o0000ooooooooool07_ooool;o`0004[ooooo001;ooooo`go00007Oooool0
0ol0003oooooooooo`0Kooooo`co0000C?ooool004kooooo3?l0000Kooooo`03o`000?oooooooooo
01Sooooo3Ol0001>ooooo`00D?ooool>o`0001Oooooo00?o0000ooooooooool05?ooool?o`00053o
oooo001Cooooo`oo00004oooool00ol0003oooooooooo`0?oooooa;o0000D_ooool005Gooooo4_l0
000>ooooo`03o`000?oooooooooo00_ooooo4ol0001Eooooo`00EooooolDo`0000[ooooo00?o0000
ooooooooool01OoooolFo`0005Sooooo001KooooocCo0000G?ooool005oooooo:ol0001Qooooo`00
I?oooolRo`0006Gooooo001XoooooaSo0000Joooool006Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo07?ooooo001Vooooo`06o`000?oooooooooo
ooooool0003ooooo1?l00005ooooo`03o`000?oooooooooo07?ooooo001Vooooo`07o`000?oooooo
ooooooooool0003oooooo`00001nooooo`00Ioooool3o`0000;ooooo1Ol0001jooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-81.3335, -9.10925, 0.695158, \
0.179015}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Here's the Wigner distribution for random real symmetric matrices \
(which is very close to the Gaussian Orthogonal Ensemble distribution).\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GOE = 
      Plot[Pi*s*Exp[\(-Pi\)*s^2/4]/2, {s, 0, 5}, 
        PlotStyle \[Rule] {Thickness[0.01]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0147151 0.774302 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .09215 -18 -4.5 ]
[.01131 .09215 0 4.5 ]
[.01131 .16958 -18 -4.5 ]
[.01131 .16958 0 4.5 ]
[.01131 .24701 -18 -4.5 ]
[.01131 .24701 0 4.5 ]
[.01131 .32444 -18 -4.5 ]
[.01131 .32444 0 4.5 ]
[.01131 .40187 -18 -4.5 ]
[.01131 .40187 0 4.5 ]
[.01131 .4793 -18 -4.5 ]
[.01131 .4793 0 4.5 ]
[.01131 .55673 -18 -4.5 ]
[.01131 .55673 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(1)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(2)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(3)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(4)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09215 m
.03006 .09215 L
s
[(0.1)] .01131 .09215 1 0 Mshowa
.02381 .16958 m
.03006 .16958 L
s
[(0.2)] .01131 .16958 1 0 Mshowa
.02381 .24701 m
.03006 .24701 L
s
[(0.3)] .01131 .24701 1 0 Mshowa
.02381 .32444 m
.03006 .32444 L
s
[(0.4)] .01131 .32444 1 0 Mshowa
.02381 .40187 m
.03006 .40187 L
s
[(0.5)] .01131 .40187 1 0 Mshowa
.02381 .4793 m
.03006 .4793 L
s
[(0.6)] .01131 .4793 1 0 Mshowa
.02381 .55673 m
.03006 .55673 L
s
[(0.7)] .01131 .55673 1 0 Mshowa
.125 Mabswid
.02381 .0302 m
.02756 .0302 L
s
.02381 .04569 m
.02756 .04569 L
s
.02381 .06117 m
.02756 .06117 L
s
.02381 .07666 m
.02756 .07666 L
s
.02381 .10763 m
.02756 .10763 L
s
.02381 .12312 m
.02756 .12312 L
s
.02381 .1386 m
.02756 .1386 L
s
.02381 .15409 m
.02756 .15409 L
s
.02381 .18506 m
.02756 .18506 L
s
.02381 .20055 m
.02756 .20055 L
s
.02381 .21603 m
.02756 .21603 L
s
.02381 .23152 m
.02756 .23152 L
s
.02381 .26249 m
.02756 .26249 L
s
.02381 .27798 m
.02756 .27798 L
s
.02381 .29346 m
.02756 .29346 L
s
.02381 .30895 m
.02756 .30895 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35541 m
.02756 .35541 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38638 m
.02756 .38638 L
s
.02381 .41735 m
.02756 .41735 L
s
.02381 .43284 m
.02756 .43284 L
s
.02381 .44832 m
.02756 .44832 L
s
.02381 .46381 m
.02756 .46381 L
s
.02381 .49478 m
.02756 .49478 L
s
.02381 .51027 m
.02756 .51027 L
s
.02381 .52575 m
.02756 .52575 L
s
.02381 .54124 m
.02756 .54124 L
s
.02381 .57221 m
.02756 .57221 L
s
.02381 .5877 m
.02756 .5877 L
s
.02381 .60318 m
.02756 .60318 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.02381 .01472 m
.06244 .25357 L
.08255 .36282 L
.10458 .46254 L
.11448 .49929 L
.12507 .53259 L
.13499 .55797 L
.14415 .57635 L
.14901 .58413 L
.15437 .59114 L
.15975 .59655 L
.1627 .59884 L
.16546 .60054 L
.16805 .60177 L
.16934 .60224 L
.17052 .6026 L
.17169 .60289 L
.17274 .60308 L
.17391 .60323 L
.17516 .60331 L
.17581 .60332 L
.1765 .60331 L
.17774 .60322 L
.17843 .60314 L
.17907 .60305 L
.18053 .60275 L
.18181 .60241 L
.18298 .60202 L
.1856 .60092 L
.1904 .59806 L
.19551 .59387 L
.20468 .58356 L
.21455 .56882 L
.22544 .5487 L
.26565 .4501 L
.30433 .3408 L
.34547 .23342 L
.3851 .15145 L
.42321 .09542 L
.44282 .07453 L
.46377 .05726 L
.48511 .04413 L
.50526 .03506 L
.52528 .02856 L
.54373 .02426 L
.56249 .02115 L
.57316 .01982 L
.58313 .0188 L
.59354 .01795 L
.60342 .01729 L
Mistroke
.62196 .01637 L
.63157 .01602 L
.6418 .01573 L
.6602 .01535 L
.67051 .0152 L
.68165 .01507 L
.69217 .01498 L
.70184 .01492 L
.7116 .01487 L
.7207 .01484 L
.73069 .01481 L
.74138 .01478 L
.75158 .01476 L
.76266 .01475 L
.77312 .01474 L
.78279 .01473 L
.79244 .01473 L
.80149 .01473 L
.81142 .01472 L
.82211 .01472 L
.83171 .01472 L
.84219 .01472 L
.84748 .01472 L
.85313 .01472 L
.8633 .01472 L
.87357 .01472 L
.87936 .01472 L
.88469 .01472 L
.89449 .01472 L
.89943 .01472 L
.90485 .01472 L
.91008 .01472 L
.91504 .01472 L
.92434 .01472 L
.92953 .01472 L
.93435 .01472 L
.94524 .01472 L
.95282 .01472 L
.95995 .01472 L
.96776 .01472 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo000looooo`?o00009Oooool5o`0002Kooooo0ol0000Xooooo`?o
00009Oooool3o`0000Kooooo000mooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo
00009Oooool01Ol0003ooooooooooooooooo000002Sooooo00?o0000ooooooooool08oooool01Ol0
003ooooooooooooooooo000000Gooooo000mooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Sooooo`Go0000:?ooool00ol0003oooooooooo`03oooo
o`00?Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo0_l0000Vooooo`04
o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool00oooool003gooooo00?o0000oooooooo
ool09?ooool01Ol0003ooooooooooooooooo000002Wooooo00?o0000ooooooooool09?ooool00ol0
003oooooo`00000Uooooo`Co00001_ooool003cooooo0_l0000Vooooo`05o`000?oooooooooooooo
ool000009Oooool01Ol0003ooooooooooooooooo000002Oooooo0_l0000Uooooo`03o`000?oooooo
oooo00Oooooo000mooooo`03o`000?oooooooooo02Gooooo0ol0000Wooooo`?o0000:Oooool00ol0
003oooooooooo`0Sooooo`Go00001Oooool001Cooooo00?o0000ooooooooool0e?ooool001Cooooo
00?o0000ooooooooool0e?ooool001Cooooo00?o0000ooooooooool0e?ooool000oooooog?l00000
01?ooooo0_l00008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0FOl00006oooo
o`004oooool2o`0002Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Mooooob;o
00004_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo000Cooooo`;o0000
Joooool=o`0005kooooo000Cooooo`?o0000Ioooool;o`0006?ooooo000Dooooo`;o0000IOooool6
o`0006[ooooo000Dooooo`;o0000Hoooool5o`0006gooooo000Dooooo`;o0000HOooool5o`0006oo
oooo000Dooooo`;o0000Goooool5o`00077ooooo000Dooooo`;o0000G_ooool4o`0007?ooooo000D
ooooo`?o0000G?ooool3o`0007Gooooo000Dooooo`?o0000Foooool3o`0007Kooooo000Dooooo`?o
0000F_ooool3o`0007Oooooo000Dooooo`?o0000FOooool3o`0007Sooooo000Dooooo`?o0000Eooo
ool4o`0007Wooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool3
o`0005Kooooo1?l0001jooooo`0000Goooooo`000?ooooooooooo`000009ooooo`03o`000?oooooo
oooo00?ooooo1?l0001Dooooo`?o0000O?ooool00005ooooool0003oooooooooool000002Oooool0
0ol0003oooooooooo`03ooooo`Co0000Doooool3o`0007gooooo00001Ooooooo0000oooooooooooo
000000Wooooo00?o0000ooooooooool00oooool01?l0003oooooo`000?l0001Booooo`?o0000O_oo
ool00005ooooool0003oooooooooool000002Oooool00ol0003oooooooooo`03ooooo`04o`000?oo
oooo0000o`0005;ooooo0_l0001oooooo`0000Goooooo`000?ooooooooooo`000008ooooo`;o0000
1Oooool01?l0003oooooo`000?l0001Aooooo`?o0000Ooooool000;ooooo0_l0000:ooooo`03o`00
0?oooooooooo00?ooooo1?l0001@ooooo`?o0000P?ooool001Cooooo00?o0000ooooool000000_l0
001?ooooo`;o0000POooool001Cooooo00?o0000ooooooooool00_l0001>ooooo`?o0000POooool0
01Cooooo0_l000000ooooooo0000o`00001=ooooo`?o0000P_ooool001Cooooo00?o0000oooooooo
ool00_l0001=ooooo`;o0000Poooool001Cooooo00?o0000ooooooooool00_l0001<ooooo`?o0000
Poooool001Cooooo00?o0000ooooooooool00ol0001:ooooo`?o0000Q?ooool001Cooooo0_l00002
ooooo`;o0000B_ooool2o`0008Gooooo000Dooooo`04o`000?ooooooooooooooo`;o0000BOooool3
o`0008Gooooo000Dooooo`04o`000?ooooooooooooooo`;o0000B?ooool3o`0008Kooooo000Doooo
o`;o00000_ooool2o`0004Sooooo0_l00027ooooo`000_ooool2o`0000Cooooo00Co0000oooooooo
oooooooo1Ol00003ooooo`04o`000?ooooooooooooooo`;o0000Aoooool3o`0008Oooooo00001Ooo
oooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo00000oooool01?l0003ooooooooo
ooooool3o`0004Kooooo0_l00028ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`03o`00
0?oooooooooo00?ooooo0ol00002ooooo`;o0000AOooool3o`0008Sooooo00001Ooooooo0000oooo
oooooooo000000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o0000
AOooool2o`0008Wooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00;ooooo0_l00015ooooo`;o0000ROooool00005oooo
ool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00_ooool2o`0004Cooooo0ol00029ooooo`000_ooool2o`0000Wooooo0ol00004ooooo`;o
00000oooool2o`0004Cooooo0_l0002:ooooo`005?ooool00ol0003oooooooooo`02ooooo`?o0000
@_ooool3o`0008[ooooo000Dooooo`03o`000?oooooooooo00?ooooo0_l00012ooooo`;o0000Rooo
ool001Cooooo0_l00004ooooo`;o0000@Oooool3o`0008_ooooo000Dooooo`03o`000?oooooooooo
00?ooooo0_l00011ooooo`;o0000S?ooool001Cooooo00?o0000ooooooooool00oooool2o`00043o
oooo0ol0002<ooooo`005?ooool2o`0000Cooooo0_l00010ooooo`;o0000SOooool001Cooooo00?o
0000ooooooooool00oooool3o`0003oooooo0_l0002=ooooo`005?ooool00ol0003oooooooooo`04
ooooo`;o0000?_ooool3o`0008gooooo000Dooooo`03o`000?oooooooooo00Cooooo0_l0000noooo
o`;o0000S_ooool001Cooooo0_l00005ooooo`;o0000?Oooool3o`0008kooooo0002ooooo`;o0000
1?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`;o0000
?Oooool2o`0008oooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Cooooo0_l0000looooo`?o0000Soooool00005oooo
ool0003oooooooooool000002oooool01?l0003oooooooooooooool3o`0000Cooooo0ol0000koooo
o`;o0000T?ooool00005ooooool0003oooooooooool000002Oooool2o`0000Cooooo00?o0000oooo
ooooool01Oooool2o`0003_ooooo0_l0002@ooooo`0000Goooooo`000?ooooooooooo`00000;oooo
o`05o`000?ooooooooooooooool000001oooool2o`0003[ooooo0ol0002@ooooo`0000Goooooo`00
0?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`05ooooo`;o0000>_ooool2o`00097ooooo0002ooooo`;o00002Oooool3o`0000Cooooo0_l00006
ooooo`;o0000>_ooool2o`00097ooooo000Dooooo`03o`000?oooooooooo00Gooooo0_l0000ioooo
o`?o0000TOooool001Cooooo00?o0000ooooooooool01Oooool3o`0003Sooooo0_l0002Booooo`00
5?ooool2o`0000Oooooo0_l0000gooooo`?o0000T_ooool001Cooooo00?o0000ooooooooool01_oo
ool2o`0003Oooooo0_l0002Cooooo`005?ooool00ol0003oooooooooo`06ooooo`;o0000=oooool2
o`0009?ooooo000Dooooo`;o00001oooool2o`0003Kooooo0ol0002Cooooo`005?ooool00ol0003o
ooooooooo`06ooooo`;o0000=_ooool2o`0009Cooooo000Dooooo`03o`000?oooooooooo00Kooooo
0ol0000eooooo`;o0000U?ooool001Cooooo00?o0000ooooooooool01oooool2o`0003Cooooo0ol0
002Dooooo`005?ooool2o`0000Sooooo0_l0000dooooo`;o0000UOooool000;ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00Oooooo0_l0000coooo
o`?o0000UOooool00005ooooool0003oooooooooool000002_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo0_l0000cooooo`;o0000U_ooool00005ooooool0003ooooooooo
ool000001oooool5o`0000?ooooo0ol00007ooooo`;o0000<oooool2o`0009Kooooo00001Ooooooo
0000oooooooooooo000000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`07
ooooo`?o0000<Oooool3o`0009Kooooo00001Ooooooo0000oooooooooooo000000Sooooo00?o0000
ooooool000001?ooool00ol0003oooooooooo`08ooooo`;o0000<Oooool2o`0009Oooooo00001Ooo
oooo0000oooooooooooo000000Wooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo0_l0000a
ooooo`;o0000Uoooool000;ooooo0_l0000;ooooo`03o`000?oooooooooo00;ooooo0_l00009oooo
o`;o0000<?ooool3o`0009Oooooo000Dooooo`03o`000?oooooooooo00Sooooo0_l0000`ooooo`;o
0000V?ooool001Cooooo00?o0000ooooooooool02?ooool2o`0002oooooo0ol0002Hooooo`005?oo
ool2o`0000Wooooo0ol0000^ooooo`;o0000VOooool001Cooooo00?o0000ooooooooool02Oooool2
o`0002kooooo0_l0002Iooooo`005?ooool00ol0003oooooooooo`09ooooo`;o0000;Oooool3o`00
09Wooooo000Dooooo`;o00002_ooool2o`0002gooooo0_l0002Jooooo`005?ooool00ol0003ooooo
ooooo`09ooooo`;o0000;Oooool2o`0009[ooooo000Dooooo`03o`000?oooooooooo00Wooooo0ol0
000[ooooo`?o0000V_ooool001Cooooo00?o0000ooooooooool02_ooool2o`0002_ooooo0_l0002K
ooooo`005?ooool2o`0000_ooooo0_l0000Zooooo`?o0000Voooool000;ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00004ooooo`03o`000?oooooooooo00[ooooo0_l0000Zooooo`;o
0000W?ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool02_ooool3o`0002Wooooo0_l0002Looooo`0000Goooooo`000?oo
ooooooooo`00000;ooooo`04o`000?ooooooooooooooo`?o00002oooool2o`0002Sooooo0ol0002L
ooooo`0000Goooooo`000?ooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000003Ooo
ool2o`0002Sooooo0_l0002Mooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Co00001?oo
ool00ol0003oooooooooo`0;ooooo`;o0000:?ooool2o`0009gooooo00001Ooooooo0000oooooooo
oooo000000Oooooo00?o0000ooooooooool01Oooool2o`0000cooooo0ol0000Vooooo`?o0000WOoo
ool000;ooooo0_l00008ooooo`Go00000oooool00ol0003oooooooooo`0<ooooo`;o00009_ooool2
o`0009kooooo000Dooooo`03o`000?oooooooooo00cooooo0_l0000Uooooo`?o0000W_ooool001Co
oooo00?o0000ooooooooool03?ooool2o`0002Gooooo0_l0002Oooooo`005?ooool2o`0000gooooo
0_l0000Uooooo`;o0000Woooool001Cooooo00?o0000ooooooooool03?ooool3o`0002?ooooo0ol0
002Oooooo`005?ooool00ol0003oooooooooo`0=ooooo`;o00008oooool2o`000:3ooooo000Doooo
o`;o00003_ooool2o`0002?ooooo0_l0002Pooooo`005?ooool00ol0003oooooooooo`0=ooooo`;o
00008_ooool3o`000:3ooooo000Dooooo`03o`000?oooooooooo00gooooo0ol0000Qooooo`;o0000
XOooool001Cooooo00?o0000ooooooooool03_ooool2o`00023ooooo0ol0002Qooooo`000_ooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0000?ooooo`;o00008?ooool2
o`000:;ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00kooooo0_l0000Oooooo`?o0000X_ooool00005ooooool0003o
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
3_ooool3o`0001kooooo0_l0002Sooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Co0000
1?ooool3o`0000oooooo0_l0000Nooooo`;o0000Xoooool00005ooooool0003oooooooooool00000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo0_l0000Mooooo`?o0000
Xoooool00005ooooool0003oooooooooool000002?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00oooooo0_l0000Mooooo`;o0000Y?ooool000;ooooo0_l0000:ooooo`;o00001?oo
ool2o`00013ooooo0ol0000Kooooo`?o0000Y?ooool001Cooooo00?o0000ooooooooool04?ooool2
o`0001_ooooo0_l0002Uooooo`005?ooool00ol0003oooooooooo`0@ooooo`;o00006_ooool3o`00
0:Gooooo000Dooooo`03o`000?oooooooooo013ooooo0_l0000Jooooo`;o0000Y_ooool001Cooooo
0_l0000Aooooo`?o00006Oooool2o`000:Kooooo000Dooooo`03o`000?oooooooooo017ooooo0_l0
000Hooooo`?o0000Y_ooool001Cooooo00?o0000ooooooooool04Oooool2o`0001Sooooo0_l0002W
ooooo`005?ooool2o`0001;ooooo0_l0000Gooooo`?o0000Yoooool001Cooooo00?o0000oooooooo
ool04Oooool3o`0001Kooooo0_l0002Xooooo`005?ooool00ol0003oooooooooo`0Booooo`;o0000
5Oooool3o`000:Sooooo000Dooooo`;o00004oooool2o`0001Gooooo0_l0002Yooooo`000_ooool2
o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01;ooooo0ol0000Dooooo`;o0000ZOooool00005ooooool0003oooooooooool000002Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo0ol0000Booooo`?o0000ZOooool0
0005ooooool0003oooooooooool000002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Cooooo0_l0000Booooo`;o0000Z_ooool00005ooooool0003oooooooooool000002_ooool0
0ol0003oooooooooo`02ooooo`?o00005?ooool3o`00013ooooo0ol0002Zooooo`0000Goooooo`00
0?ooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000005oooool2o`00013ooooo0_l0
002[ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Eooooo`?o00003oooool2o`000:_ooooo0002ooooo`;o00002?oo
ool5o`0000?ooooo0_l0000Gooooo`;o00003_ooool3o`000:_ooooo000Dooooo`03o`000?oooooo
oooo01Kooooo0ol0000=ooooo`;o0000[?ooool001Cooooo00?o0000ooooooooool05oooool2o`00
00cooooo0ol0002/ooooo`005?ooool00ol0003oooooooooo`0Gooooo`?o00002_ooool3o`000:go
oooo000Dooooo`;o00006Oooool3o`0000Sooooo0ol0002^ooooo`005?ooool00ol0003ooooooooo
o`0Iooooo`;o00001oooool3o`000:oooooo000Dooooo`03o`000?oooooooooo01Wooooo1?l00004
ooooo`?o0000/?ooool001Cooooo0_l0000Kooooo`Wo0000/Oooool001Cooooo00?o0000oooooooo
ool07?ooool6o`000;;ooooo000Dooooo`03o`000?oooooooooo0=Cooooo000Dooooo`03o`000?oo
oooooooo0=Cooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-0.498205, -0.336734, 0.0240309, \
0.00591154}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Here's the distribution for a combination of two GOE data \
sets.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GOE2 = 
      Plot[Exp[\(-Pi\)*s^2/8]/2\  + \ 
          Pi*s*Exp[\(-Pi\)*s^2/16]*Erfc[Sqrt[Pi]*s/4]/8, {s, 0, 5}, 
        PlotStyle \[Rule] {Thickness[0.01]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0147151 0.990392 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .11375 -18 -4.5 ]
[.01131 .11375 0 4.5 ]
[.01131 .21279 -18 -4.5 ]
[.01131 .21279 0 4.5 ]
[.01131 .31183 -18 -4.5 ]
[.01131 .31183 0 4.5 ]
[.01131 .41087 -18 -4.5 ]
[.01131 .41087 0 4.5 ]
[.01131 .50991 -18 -4.5 ]
[.01131 .50991 0 4.5 ]
[.01131 .60895 -18 -4.5 ]
[.01131 .60895 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(1)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(2)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(3)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(4)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11375 m
.03006 .11375 L
s
[(0.1)] .01131 .11375 1 0 Mshowa
.02381 .21279 m
.03006 .21279 L
s
[(0.2)] .01131 .21279 1 0 Mshowa
.02381 .31183 m
.03006 .31183 L
s
[(0.3)] .01131 .31183 1 0 Mshowa
.02381 .41087 m
.03006 .41087 L
s
[(0.4)] .01131 .41087 1 0 Mshowa
.02381 .50991 m
.03006 .50991 L
s
[(0.5)] .01131 .50991 1 0 Mshowa
.02381 .60895 m
.03006 .60895 L
s
[(0.6)] .01131 .60895 1 0 Mshowa
.125 Mabswid
.02381 .03452 m
.02756 .03452 L
s
.02381 .05433 m
.02756 .05433 L
s
.02381 .07414 m
.02756 .07414 L
s
.02381 .09395 m
.02756 .09395 L
s
.02381 .13356 m
.02756 .13356 L
s
.02381 .15337 m
.02756 .15337 L
s
.02381 .17318 m
.02756 .17318 L
s
.02381 .19299 m
.02756 .19299 L
s
.02381 .2326 m
.02756 .2326 L
s
.02381 .25241 m
.02756 .25241 L
s
.02381 .27222 m
.02756 .27222 L
s
.02381 .29202 m
.02756 .29202 L
s
.02381 .33164 m
.02756 .33164 L
s
.02381 .35145 m
.02756 .35145 L
s
.02381 .37126 m
.02756 .37126 L
s
.02381 .39106 m
.02756 .39106 L
s
.02381 .43068 m
.02756 .43068 L
s
.02381 .45049 m
.02756 .45049 L
s
.02381 .4703 m
.02756 .4703 L
s
.02381 .4901 m
.02756 .4901 L
s
.02381 .52972 m
.02756 .52972 L
s
.02381 .54953 m
.02756 .54953 L
s
.02381 .56933 m
.02756 .56933 L
s
.02381 .58914 m
.02756 .58914 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.02381 .50991 m
.04262 .54446 L
.06244 .57231 L
.07286 .58336 L
.08255 .59144 L
.08802 .59507 L
.0932 .59788 L
.09916 .60038 L
.10196 .60129 L
.10458 .60199 L
.10699 .6025 L
.10919 .60286 L
.11045 .60302 L
.11164 .60314 L
.1129 .60323 L
.11361 .60327 L
.11428 .60329 L
.11492 .60331 L
.11562 .60332 L
.11688 .60331 L
.11812 .60327 L
.11925 .6032 L
.12048 .6031 L
.12183 .60295 L
.12455 .60254 L
.12696 .60205 L
.12916 .60151 L
.13409 .59995 L
.14299 .59595 L
.15291 .58981 L
.16208 .58261 L
.18284 .56147 L
.22211 .50654 L
.25986 .44159 L
.30006 .36715 L
.33875 .29681 L
.37989 .22862 L
.41951 .17247 L
.45762 .12841 L
.49818 .09206 L
.53723 .06623 L
.55857 .05537 L
.57872 .04692 L
.61719 .03485 L
.63707 .0303 L
.65811 .02649 L
.67791 .02368 L
.696 .02165 L
.71544 .01994 L
.73634 .01853 L
Mistroke
.75536 .01755 L
.7761 .01675 L
.79581 .01619 L
.81679 .01575 L
.83825 .01543 L
.85843 .01522 L
.87855 .01506 L
.89703 .01496 L
.91589 .01489 L
.92659 .01485 L
.93657 .01483 L
.94705 .01481 L
.95696 .01479 L
.97553 .01477 L
.97619 .01477 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00??ooool3o`0002Gooooo1Ol0000Vooooo`?o0000:?ooool3o`0002Gooooo0ol00006
ooooo`00?Oooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0002Gooooo00Go0000
ooooooooooooooooo`00000Xooooo`03o`000?oooooooooo02?ooooo00Go0000oooooooooooooooo
o`000005ooooo`00?Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool08oooool5o`0002Sooooo00?o0000ooooooooool00oooool003gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Vooooo`;o00009_ooool01?l0003oooooooooool0
000Yooooo`03o`000?oooooooooo00?ooooo000mooooo`03o`000?oooooooooo02Cooooo00Go0000
ooooooooooooooooo`00000Yooooo`03o`000?oooooooooo02Cooooo00?o0000ooooool000009Ooo
ool4o`0000Kooooo000looooo`;o00009_ooool01Ol0003ooooooooooooooooo000002Gooooo00Go
0000ooooooooooooooooo`00000Wooooo`;o00009Oooool00ol0003oooooooooo`07ooooo`00?Ooo
ool00ol0003oooooooooo`0Uooooo`?o00009oooool3o`0002Wooooo00?o0000ooooooooool08ooo
ool5o`0000Gooooo003[ooooo`005?ooool00ol0003oooooooooo`3Dooooo`005?ooool00ol0003o
ooooooooo`3Dooooo`005?ooool00ol0003oooooooooo`3Dooooo`003ooooooLo`0000005?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooooolm
o`0000Kooooo000Dooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00cooooo7ol0000Uooooo`03o`000?oooooooooo
00Cooooo000Dooooo`03o`000?oooooooooo08Gooooo3Ol00012ooooo`005?ooool00ol0003ooooo
ooooo`20ooooo`[o0000B_ooool001Cooooo0_l0001mooooo`[o0000C_ooool001Cooooo00?o0000
ooooooooool0Moooool:o`0005?ooooo000Dooooo`03o`000?oooooooooo07Cooooo2Ol0001Goooo
o`005?ooool00ol0003oooooooooo`1booooo`Ko0000G?ooool001Cooooo0_l0001aooooo`Go0000
Goooool001Cooooo00?o0000ooooooooool0KOooool6o`00067ooooo000Dooooo`03o`000?oooooo
oooo06_ooooo1_l0001Sooooo`005?ooool00ol0003oooooooooo`1Zooooo`Co0000I_ooool001Co
oooo0_l0001Zooooo`?o0000J?ooool001Cooooo00?o0000ooooooooool0Ioooool4o`0006Wooooo
000Dooooo`03o`000?oooooooooo06Kooooo1?l0001Zooooo`005?ooool00ol0003oooooooooo`1U
ooooo`?o0000K?ooool001Cooooo00?o0000ooooooooool0Hoooool4o`0006gooooo000Dooooo`;o
0000Hoooool4o`0006kooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1?ooool00ol0003oooooooooo`1Qooooo`?o0000L?ooool00005ooooool0003oooooooooool00000
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo063ooooo0ol0001aooooo`0000Go
ooooo`000?ooooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Goooool3o`0007;ooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool0
0oooool3o`0005kooooo0ol0001cooooo`0000Goooooo`000?ooooooooooo`000009ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0GOooool3o`0007Cooooo00001Ooooooo0000oooo
oooooooo000000Sooooo0_l00005ooooo`03o`000?oooooooooo05cooooo0ol0001eooooo`000_oo
ool2o`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Kooooo`?o0000M_oo
ool001Cooooo0_l0001Looooo`;o0000Moooool001Cooooo00?o0000ooooooooool0F_ooool3o`00
07Oooooo000Dooooo`03o`000?oooooooooo05Wooooo0ol0001hooooo`005?ooool00ol0003ooooo
ooooo`1Hooooo`?o0000NOooool001Cooooo0_l0001Hooooo`?o0000N_ooool001Cooooo00?o0000
ooooooooool0Eoooool2o`0007_ooooo000Dooooo`03o`000?oooooooooo05Kooooo0ol0001koooo
o`005?ooool00ol0003oooooooooo`1Eooooo`?o0000O?ooool001Cooooo00?o0000ooooooooool0
E?ooool3o`0007gooooo000Dooooo`;o0000E?ooool3o`0007kooooo000Dooooo`03o`000?oooooo
oooo05?ooooo0_l0001oooooo`005?ooool00ol0003oooooooooo`1Booooo`?o0000Ooooool001Co
oooo00?o0000ooooooooool0DOooool3o`00083ooooo000Dooooo`;o0000DOooool3o`00087ooooo
000Dooooo`03o`000?oooooooooo053ooooo0_l00022ooooo`000_ooool2o`0000Cooooo00Co0000
oooooooooooooooo1Ol00003ooooo`03o`000?oooooooooo04oooooo0ol00022ooooo`0000Gooooo
o`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
C_ooool3o`0008?ooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool0
0oooool3o`0004gooooo0ol00024ooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0COooool2o`0008Gooooo00001Ooooooo0000oooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo04co
oooo0ol00025ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`1;ooooo`?o0000Q_ooool000;ooooo0_l00009ooooo`?o
00001?ooool00ol0003oooooooooo`1:ooooo`?o0000Qoooool001Cooooo0_l0001;ooooo`;o0000
R?ooool001Cooooo00?o0000ooooooooool0BOooool3o`0008Sooooo000Dooooo`03o`000?oooooo
oooo04Sooooo0ol00029ooooo`005?ooool00ol0003oooooooooo`18ooooo`;o0000R_ooool001Co
oooo0_l00018ooooo`?o0000R_ooool001Cooooo00?o0000ooooooooool0Aoooool2o`0008_ooooo
000Dooooo`03o`000?oooooooooo04Kooooo0ol0002;ooooo`005?ooool00ol0003oooooooooo`15
ooooo`?o0000S?ooool001Cooooo0_l00016ooooo`;o0000SOooool001Cooooo00?o0000oooooooo
ool0A?ooool3o`0008gooooo000Dooooo`03o`000?oooooooooo04Cooooo0_l0002>ooooo`005?oo
ool00ol0003oooooooooo`13ooooo`?o0000S_ooool001Cooooo00?o0000ooooooooool0@_ooool3
o`0008oooooo000Dooooo`;o0000@oooool2o`00093ooooo000Dooooo`03o`000?oooooooooo047o
oooo0ol0002@ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo
00?o0000ooooooooool0@Oooool2o`00097ooooo00001Ooooooo0000oooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo043ooooo0ol0002Aooooo`00
00Goooooo`000?ooooooooooo`00000;ooooo`04o`000?ooooooooooooooo`?o0000@?ooool2o`00
09;ooooo00001Ooooooo0000oooooooooooo000000Wooooo0_l00004ooooo`03o`000?oooooooooo
03oooooo0ol0002Booooo`0000Goooooo`000?ooooooooooo`00000;ooooo`05o`000?oooooooooo
ooooool00000@Oooool2o`0009?ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo03kooooo0ol0002Cooooo`000_ooool2
o`0000Wooooo0ol00004ooooo`;o0000?oooool2o`0009Cooooo000Dooooo`03o`000?oooooooooo
03gooooo0ol0002Dooooo`005?ooool00ol0003oooooooooo`0looooo`?o0000UOooool001Cooooo
00?o0000ooooooooool0??ooool2o`0009Kooooo000Dooooo`03o`000?oooooooooo03_ooooo0ol0
002Fooooo`005?ooool2o`0003cooooo0_l0002Gooooo`005?ooool00ol0003oooooooooo`0joooo
o`?o0000Uoooool001Cooooo00?o0000ooooooooool0>_ooool2o`0009Sooooo000Dooooo`03o`00
0?oooooooooo03Wooooo0ol0002Hooooo`005?ooool2o`0003[ooooo0_l0002Iooooo`005?ooool0
0ol0003oooooooooo`0hooooo`?o0000VOooool001Cooooo00?o0000ooooooooool0>?ooool2o`00
09[ooooo000Dooooo`03o`000?oooooooooo03Oooooo0ol0002Jooooo`005?ooool2o`0003Oooooo
0ol0002Kooooo`005?ooool00ol0003oooooooooo`0fooooo`;o0000W?ooool000;ooooo0_l00004
ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo03Gooooo0ol0002L
ooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0=Oooool2o`0009gooooo00001Ooooooo0000oooooooooooo000000Oooooo1Ol00003
ooooo`03o`000?oooooooooo03Cooooo0ol0002Mooooo`0000Goooooo`000?ooooooooooo`000007
ooooo`04o`000?ooooooooooo`0000Cooooo0ol0000dooooo`;o0000W_ooool00005ooooool0003o
ooooooooool000002?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo03?ooooo0ol0
002Nooooo`0000Goooooo`000?ooooooooooo`000009ooooo`;o00001?ooool00ol0003ooooooooo
o`0cooooo`;o0000Woooool000;ooooo0_l0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0<_ooool3o`0009oooooo000Dooooo`;o0000<_ooool3o`000:3ooooo000Dooooo`03
o`000?oooooooooo037ooooo0_l0002Qooooo`005?ooool00ol0003oooooooooo`0`ooooo`?o0000
XOooool001Cooooo00?o0000ooooooooool0<?ooool2o`000:;ooooo000Dooooo`;o0000<?ooool3
o`000:;ooooo000Dooooo`03o`000?oooooooooo02oooooo0_l0002Sooooo`005?ooool00ol0003o
ooooooooo`0^ooooo`?o0000Xoooool001Cooooo00?o0000ooooooooool0;_ooool2o`000:Cooooo
000Dooooo`03o`000?oooooooooo02gooooo0ol0002Tooooo`005?ooool2o`0002kooooo0_l0002U
ooooo`005?ooool00ol0003oooooooooo`0/ooooo`?o0000YOooool001Cooooo00?o0000oooooooo
ool0:oooool3o`000:Kooooo000Dooooo`03o`000?oooooooooo02_ooooo0_l0002Wooooo`005?oo
ool2o`0002_ooooo0ol0002Wooooo`005?ooool00ol0003oooooooooo`0Zooooo`;o0000Z?ooool0
00;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03o`000?oooooooooo
02Wooooo0ol0002Xooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`0Yooooo`;o0000ZOooool00005ooooool0003ooooo
ooooool000002oooool00ol0003oooooooooo`04o`0002Sooooo0ol0002Yooooo`0000Goooooo`00
0?ooooooooooo`00000;ooooo`03o`000?oooooooooo00;o0000:_ooool2o`000:[ooooo00001Ooo
oooo0000oooooooooooo000000Oooooo1?l00003ooooo`?o0000:?ooool3o`000:[ooooo00001Ooo
oooo0000oooooooooooo000000Oooooo00?o0000ooooooooool01Oooool2o`0002Oooooo0ol0002[
ooooo`000_ooool2o`0000Sooooo1Ol00003ooooo`?o00009Oooool3o`000:cooooo000Dooooo`?o
00009Oooool2o`000:gooooo000Dooooo`Co00008oooool3o`000:gooooo000Dooooo`04o`000?oo
oooo0000o`0002;ooooo0ol0002^ooooo`005?ooool00ol0003oooooo`000002o`00023ooooo0ol0
002_ooooo`005?ooool2o`000003ooooool0003o0000023ooooo0_l0002`ooooo`005?ooool00ol0
003oooooooooo`03o`0001kooooo0ol0002`ooooo`005?ooool01?l0003oooooooooooooool3o`00
01cooooo0ol0002aooooo`005?ooool00ol0003oooooooooo`02ooooo`?o00006Oooool4o`000;;o
oooo000Dooooo`;o00001?ooool3o`0001Oooooo1?l0002cooooo`005?ooool00ol0003ooooooooo
o`04ooooo`?o00005Oooool3o`000;Gooooo000Dooooo`03o`000?oooooooooo00Gooooo0ol0000C
ooooo`?o0000]_ooool001Cooooo00?o0000ooooooooool01_ooool3o`00017ooooo0ol0002goooo
o`005?ooool00ol0003oooooooooo`07ooooo`?o00003oooool3o`000;Sooooo000Dooooo`;o0000
2Oooool3o`0000cooooo1?l0002iooooo`005?ooool00ol0003oooooooooo`09ooooo`?o00002Ooo
ool5o`000;[ooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool0
0ol0003oooooooooo`0:ooooo`Go00001?ooool5o`000;cooooo00001Ooooooo0000oooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00_ooooo2ol0
002nooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
0oooool3o`0000kooooo1ol0002oooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Co0000
1?ooool00ol0003oooooooooo`3Dooooo`0000Goooooo`000?ooooooooooo`000007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0e?ooool00005ooooool0003oooooooooool00000
2?ooool00ol0003oooooooooo`3Kooooo`000_ooool2o`0000[ooooo0_l0003Kooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-0.498205, -0.257448, 0.0240309, \
0.00462172}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Next we plot both the Poisson distribution (dashed) and the GOE or \
2 GOE distribution (solid) together.  This will help to illustrate the \
transition from random to random-matrix statistics in our quantum map.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Curves1 = 
      Plot[{Exp[\(-s\)], Pi*s*Exp[\(-Pi\)*s^2/4]/2}, {s, 0, 5}, 
        PlotStyle \[Rule] {{Thickness[0.01], Dashing[{0.02, 0.02}]}, 
            Thickness[0.01]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0147151 0.588604 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(1)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(2)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(3)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(4)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
[ .02 .02 ] 0 setdash
.02381 .60332 m
.06244 .49526 L
.10458 .39989 L
.14415 .32764 L
.18221 .27097 L
.22272 .22187 L
.26171 .18353 L
.30316 .15052 L
.34309 .12483 L
.3815 .10472 L
.42237 .08734 L
.46172 .07379 L
.49955 .06314 L
.53984 .05391 L
.57861 .04669 L
.61984 .04047 L
.65954 .03562 L
.69774 .03182 L
.73838 .02854 L
.77751 .02597 L
.81909 .02376 L
.85916 .02205 L
.89771 .0207 L
.93871 .01954 L
.97619 .01868 L
s
[ ] 0 setdash
.02381 .01472 m
.06244 .19629 L
.08255 .27934 L
.10458 .35514 L
.11448 .38307 L
.12507 .40839 L
.13499 .42769 L
.14415 .44166 L
.14901 .44757 L
.15437 .4529 L
.15975 .45701 L
.1627 .45875 L
.16546 .46004 L
.16805 .46098 L
.16934 .46134 L
.17052 .46161 L
.17169 .46183 L
.17274 .46198 L
.17391 .46209 L
.17516 .46215 L
.17581 .46216 L
.1765 .46215 L
.17774 .46208 L
.17843 .46202 L
.17907 .46195 L
.18053 .46172 L
.18181 .46146 L
.18298 .46117 L
.1856 .46033 L
.1904 .45816 L
.19551 .45498 L
.20468 .44714 L
.21455 .43593 L
.22544 .42064 L
.26565 .34568 L
.30433 .2626 L
.34547 .18097 L
.3851 .11866 L
.42321 .07607 L
.44282 .06019 L
.46377 .04706 L
.48511 .03707 L
.50526 .03018 L
.52528 .02524 L
.54373 .02197 L
.56249 .01961 L
.57316 .01859 L
.58313 .01782 L
.59354 .01717 L
.60342 .01667 L
Mistroke
.62196 .01597 L
.63157 .01571 L
.6418 .01549 L
.6602 .0152 L
.67051 .01508 L
.68165 .01499 L
.69217 .01492 L
.70184 .01487 L
.7116 .01483 L
.7207 .01481 L
.73069 .01478 L
.74138 .01477 L
.75158 .01475 L
.76266 .01474 L
.77312 .01473 L
.78279 .01473 L
.79244 .01473 L
.80149 .01472 L
.81142 .01472 L
.82211 .01472 L
.83171 .01472 L
.84219 .01472 L
.84748 .01472 L
.85313 .01472 L
.8633 .01472 L
.87357 .01472 L
.87936 .01472 L
.88469 .01472 L
.89449 .01472 L
.89943 .01472 L
.90485 .01472 L
.91008 .01472 L
.91504 .01472 L
.92434 .01472 L
.92953 .01472 L
.93435 .01472 L
.94524 .01472 L
.95282 .01472 L
.95995 .01472 L
.96776 .01472 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool003cooooo0ol0000Uooooo`Go00009_ooool3o`0002Sooooo0ol0000Uoooo
o`?o00001_ooool003gooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool0000Uoooo
o`05o`000?ooooooooooooooool00000:?ooool00ol0003oooooooooo`0Sooooo`05o`000?oooooo
ooooooooool000001Oooool003gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo02?ooooo1Ol0000Xooooo`03o`000?oooooooooo00?ooooo000moooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool2o`0002Kooooo00Co0000oooo
oooooooo0000:Oooool00ol0003oooooooooo`03ooooo`00?Oooool00ol0003oooooooooo`0Toooo
o`05o`000?ooooooooooooooool00000:Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
000002Gooooo1?l00006ooooo`00??ooool2o`0002Kooooo00Go0000ooooooooooooooooo`00000U
ooooo`05o`000?ooooooooooooooool000009oooool2o`0002Gooooo00?o0000ooooooooool01ooo
ool003gooooo00?o0000ooooooooool09Oooool3o`0002Oooooo0ol0000Yooooo`03o`000?oooooo
oooo02?ooooo1Ol00005ooooo`00joooool001Cooooo00?o0000ooooooooool0e?ooool001Cooooo
00?o0000ooooooooool0e?ooool001Cooooo00?o0000ooooooooool0e?ooool000oooooog?l00000
01?ooooo0_l00008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo06;o00001_ooool001?ooooo0_l0001Zooooo`ko
0000:oooool7o`0000;ooooo1_l00003ooooo`Ko00000_ooool7o`0000;ooooo1ol00009ooooo`00
4oooool3o`0006Gooooo2Ol0000Uooooo`Co00000oooool6o`0000;ooooo1ol00002ooooo`Ko0000
9?ooool001Cooooo0_l0001Sooooo`Oo00007_ooool7o`0000;ooooo1_l00003ooooo`Ko0000=Ooo
ool001Cooooo0_l0001Qooooo`Go00006_ooool6o`0000;ooooo1ol00002ooooo`?o0000@Oooool0
01Cooooo0_l0001Nooooo`Ko00005Oooool4o`0000?ooooo1_l0001?ooooo`005?ooool3o`0005_o
oooo1_l0000Eooooo`Ko0000F?ooool001Cooooo0ol0001Jooooo`Co00003oooool7o`0000;ooooo
0ol0001Kooooo`005?ooool3o`0005Wooooo0ol0000;ooooo`Co00000_ooool7o`00063ooooo000D
ooooo`?o0000Eoooool4o`0000[ooooo1_l0001Yooooo`005?ooool3o`0005Gooooo1Ol00006oooo
o`?o00000_ooool3o`0006cooooo000Dooooo`Co0000Doooool4o`0000Gooooo1_l0001aooooo`00
5?ooool4o`0005;ooooo0ol00006ooooo`Go0000Loooool001Cooooo00Co0000ooooool0003o0000
D_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0007Kooooo000Dooooo`04o`000?oo
oooo0000o`00057ooooo2?l0001jooooo`005?ooool00ol0003oooooo`000002o`0004oooooo1_l0
001mooooo`005?ooool00ol0003oooooooooo`02o`0004gooooo1?l00021ooooo`005?ooool00ol0
003oooooooooo`02o`0004_ooooo1Ol00022ooooo`005?ooool2o`000003ooooool0003o000004[o
oooo1Ol00023ooooo`005?ooool00ol0003oooooooooo`03o`0004Wooooo1Ol00023ooooo`005?oo
ool01?l0003oooooooooooooool2o`0004Cooooo0ol00003ooooo`?o0000Q?ooool001Cooooo00Co
0000oooooooooooooooo0_l00012ooooo`Go00000_ooool3o`0008Gooooo0002ooooo`;o00001?oo
ool01?l0003oooooooooooooool5o`0000?ooooo00Co0000oooooooooooooooo0_l00011ooooo`Co
00000oooool3o`0008Kooooo00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooooooool2o`00047ooooo0_l00005ooooo`;o0000Qoooool0
0005ooooool0003oooooooooool000002Oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooooooo`?o0000>oooool3o`0000Sooooo0ol00027ooooo`0000Goooooo`000?ooooooooooo`00
000:ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`;o0000>_ooool4o`0000Oooooo0ol0
0028ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`02ooooo`;o0000>Oooool3o`0000Wooooo0_l00029ooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`02ooooo`;o0000>Oooool2o`0000Wooooo0ol00029ooooo`000_ooool2o`0000Wooooo
0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00013ooooo`;o0000R_ooool001Cooooo00?o
0000ooooooooool00oooool2o`0003?ooooo0ol0000<ooooo`?o0000R_ooool001Cooooo00?o0000
ooooooooool00oooool2o`0003;ooooo1?l0000;ooooo`?o0000Roooool001Cooooo0_l00004oooo
o`;o0000<Oooool3o`0000gooooo0_l0002<ooooo`005?ooool00ol0003oooooooooo`03ooooo`?o
0000<?ooool2o`0000gooooo0ol0002<ooooo`005?ooool00ol0003oooooooooo`04ooooo`;o0000
?oooool2o`0008gooooo000Dooooo`03o`000?oooooooooo00Cooooo0_l0000/ooooo`;o00004?oo
ool3o`0008gooooo000Dooooo`03o`000?oooooooooo00Cooooo0_l0000[ooooo`?o00003oooool3
o`0008kooooo000Dooooo`03o`000?oooooooooo00Cooooo0_l0000Zooooo`?o00004?ooool2o`00
08oooooo000Dooooo`;o00001Oooool3o`0002Sooooo0ol0000@ooooo`?o0000Soooool001Cooooo
00?o0000ooooooooool01Oooool2o`0002Sooooo0_l0000Aooooo`;o0000T?ooool001Cooooo00?o
0000ooooooooool01Oooool2o`0003[ooooo0ol0002@ooooo`005?ooool00ol0003oooooooooo`05
ooooo`;o00009Oooool2o`0001?ooooo0_l0002Aooooo`005?ooool00ol0003oooooooooo`05oooo
o`?o00008oooool3o`0001;ooooo0ol0002Aooooo`005?ooool00ol0003oooooooooo`06ooooo`;o
00008_ooool3o`0001?ooooo0_l0002Booooo`005?ooool00ol0003oooooooooo`06ooooo`;o0000
8Oooool3o`0001?ooooo0ol0002Booooo`005?ooool2o`0000Oooooo0_l0000Qooooo`;o00005?oo
ool2o`0009?ooooo000Dooooo`03o`000?oooooooooo00Kooooo0_l0000fooooo`?o0000Toooool0
01Cooooo00?o0000ooooooooool01_ooool3o`0001gooooo0_l0000Fooooo`;o0000U?ooool001Co
oooo00?o0000ooooooooool01oooool2o`0001gooooo0_l0000Eooooo`?o0000U?ooool000;ooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00Oooooo
0_l0000Looooo`?o00005Oooool2o`0009Gooooo00001Ooooooo0000oooooooooooo000000[ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`;o00006oooool3o`0001Gooooo
0ol0002Eooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Go00000oooool3o`0000Oooooo
0_l0000Jooooo`?o00005_ooool2o`0009Kooooo00001Ooooooo0000oooooooooooo000000Oooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`07ooooo`?o00006Oooool2o`0001Ko
oooo0ol0002Fooooo`0000Goooooo`000?ooooooooooo`000008ooooo`03o`000?oooooo000000Co
oooo00?o0000ooooooooool02?ooool2o`00037ooooo0_l0002Gooooo`0000Goooooo`000?oooooo
ooooo`000009ooooo`;o00001?ooool00ol0003oooooooooo`08ooooo`;o00005_ooool2o`0001So
oooo0ol0002Gooooo`000_ooool2o`0000_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`;o00005_ooool2o`0001Sooooo0_l0002Hooooo`005?ooool00ol0003ooooooooo
o`08ooooo`;o00005Oooool3o`0001Oooooo0ol0002Hooooo`005?ooool00ol0003oooooooooo`08
ooooo`?o00005?ooool2o`0001Sooooo0_l0002Iooooo`005?ooool2o`0000[ooooo0_l0000Coooo
o`?o00005oooool3o`0009Wooooo000Dooooo`03o`000?oooooooooo00Wooooo0_l0000Cooooo`;o
00006?ooool2o`0009[ooooo000Dooooo`03o`000?oooooooooo00Wooooo0_l0000/ooooo`?o0000
V_ooool001Cooooo00?o0000ooooooooool02Oooool3o`0000oooooo0_l0000Jooooo`;o0000Vooo
ool001Cooooo00?o0000ooooooooool02_ooool2o`0000oooooo0_l0000Iooooo`?o0000Voooool0
01Cooooo00?o0000ooooooooool02_ooool2o`0000kooooo0ol0000Iooooo`;o0000W?ooool001Co
oooo0_l0000;ooooo`?o00003Oooool2o`0001Wooooo0ol0002Looooo`005?ooool00ol0003ooooo
ooooo`0;ooooo`;o00003?ooool3o`0001Wooooo0_l0002Mooooo`005?ooool00ol0003ooooooooo
o`0;ooooo`;o00003?ooool2o`0001Wooooo0ol0002Mooooo`005?ooool00ol0003oooooooooo`0;
ooooo`?o00009_ooool2o`0009kooooo000Dooooo`03o`000?oooooooooo00cooooo0_l00008oooo
o`;o00006oooool3o`0009kooooo000Dooooo`03o`000?oooooooooo00cooooo0_l00008ooooo`;o
00006oooool2o`0009oooooo000Dooooo`03o`000?oooooooooo00cooooo0ol00006ooooo`?o0000
6_ooool3o`0009oooooo000Dooooo`;o00003_ooool2o`0000Kooooo0_l0000Kooooo`;o0000X?oo
ool001Cooooo00?o0000ooooooooool03Oooool2o`0000Gooooo0ol0000Jooooo`?o0000X?ooool0
01Cooooo00?o0000ooooooooool03Oooool3o`0000Cooooo0_l0000Kooooo`;o0000XOooool000;o
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03o`000?oooooooooo00ko
oooo0_l0000Pooooo`?o0000XOooool00005ooooool0003oooooooooool000001oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool03_ooool2o`00023ooooo0_l0002Roooo
o`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`0>ooooo`?o000000?oooooo`000?l000006oooool3o`000:;ooooo00001Ooo
oooo0000oooooooooooo000000Oooooo1?l00004ooooo`?o00003oooool2o`000003ooooool0003o
000001[ooooo0ol0002Sooooo`0000Goooooo`000?ooooooooooo`000007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool03oooool5o`0001[ooooo0_l0002Tooooo`0000Goooooo`00
0?ooooooooooo`000008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool4
o`0001[ooooo0ol0002Tooooo`000_ooool2o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo
013ooooo0ol0000Jooooo`;o0000YOooool001Cooooo00?o0000ooooooooool04?ooool2o`0001[o
oooo0ol0002Uooooo`005?ooool00ol0003oooooooooo`0@ooooo`?o00006Oooool2o`000:Kooooo
000Dooooo`;o00004_ooool2o`0001Sooooo0ol0002Vooooo`005?ooool00ol0003oooooooooo`0>
ooooo`;o000000?oooooo`000?l000006?ooool2o`000:Oooooo000Dooooo`03o`000?oooooooooo
00kooooo0_l000001?oooooo0000o`000?l0000Fooooo`?o0000Yoooool001Cooooo00?o0000oooo
ooooool03Oooool3o`0000;ooooo0_l0000Eooooo`?o0000Z?ooool001Cooooo00?o0000oooooooo
ool03Oooool2o`0000?ooooo0_l0000Eooooo`;o0000ZOooool001Cooooo00?o0000ooooooooool0
3?ooool3o`0000?ooooo0ol0000Cooooo`?o0000ZOooool001Cooooo00?o0000ooooooooool03?oo
ool2o`0000Gooooo0ol0000Booooo`;o0000Z_ooool001Cooooo0_l0000Eooooo`?o00004?ooool3
o`000:[ooooo000Dooooo`03o`000?oooooooooo01Gooooo0_l0000@ooooo`;o0000Zoooool001Co
oooo00?o0000ooooooooool02_ooool2o`0000Wooooo0ol0000>ooooo`?o0000Zoooool001Cooooo
00?o0000ooooooooool02_ooool2o`0000[ooooo0ol0000<ooooo`?o0000[?ooool001Cooooo00?o
0000ooooooooool02_ooool2o`0000_ooooo0ol0000:ooooo`?o0000[Oooool001Cooooo00?o0000
ooooooooool02Oooool3o`0000cooooo0_l00009ooooo`?o0000[_ooool001Cooooo0_l0000:oooo
o`;o00003Oooool4o`0000Kooooo0ol0002_ooooo`005?ooool00ol0003oooooooooo`09ooooo`;o
00003_ooool;o`000;3ooooo000Dooooo`03o`000?oooooooooo01_ooooo2?l0002aooooo`005?oo
ool00ol0003oooooooooo`0Mooooo`?o0000]?ooool000;ooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00004ooooo`03o`000?oooooooooo00Oooooo0_l0003;ooooo`0000Goooooo`00
0?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`07ooooo`;o0000boooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool01_ooool3o`000<_ooooo00001Ooooooo0000oooo
oooooooo000000Sooooo0ol00004ooooo`?o00001_ooool2o`000<cooooo00001Ooooooo0000oooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Go
oooo0ol0003<ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`05ooooo`;o0000cOooool000;ooooo0_l00009ooooo`?o
00001?ooool00ol0003oooooooooo`3Dooooo`005?ooool00ol0003oooooooooo`3Dooooo`005?oo
ool00ol0003oooooooooo`04ooooo`;o0000c_ooool001Cooooo0_l00005ooooo`;o0000c_ooool0
01Cooooo00?o0000ooooooooool00oooool3o`000<kooooo000Dooooo`03o`000?oooooooooo00?o
oooo0_l0003?ooooo`005?ooool00ol0003oooooooooo`02ooooo`?o0000coooool001Cooooo00?o
0000ooooooooool00_ooool2o`000=3ooooo000Dooooo`03o`000?oooooooooo0=Cooooo000Doooo
o`03o`000?oooooooooo0=Cooooo000Dooooo`;o00000_ooool2o`000=7ooooo000Dooooo`04o`00
0?ooooooooooooooo`;o0000dOooool001Cooooo00?o0000ooooooooool00ol0003Aooooo`005?oo
ool00ol0003oooooooooo`02o`000=;ooooo000Dooooo`03o`000?oooooo000000;o0000d_ooool0
01Cooooo00Co0000ooooool0003o0000doooool001Cooooo0_l0003Eooooo`005?ooool00ol0003o
ooooooooo`3Dooooo`005?ooool3o`000=Cooooo000Dooooo`?o0000e?ooool000gooooo0ol00004
ooooo`?o0000e?ooool000kooooo00?o0000ooooooooool00oooool2o`000=Gooooo000>ooooo`03
o`000?oooooooooo00;ooooo1?l0003Dooooo`003_ooool00ol0003oooooooooo`02ooooo`;o0000
e_ooool000kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Dooooo`003Oooool2
o`0000Gooooo00?o0000ooooooooool0e?ooool000kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`3Dooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-0.498205, -0.437968, 0.0240309, \
0.00777656}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Curves2 = 
      Plot[{Exp[\(-s\)], 
          Exp[\(-Pi\)*s^2/8]/2\  + \ 
            Pi*s*Exp[\(-Pi\)*s^2/16]*Erfc[Sqrt[Pi]*s/4]/8}, {s, 0, 5}, 
        PlotStyle \[Rule] {{Thickness[0.01], Dashing[{0.02, 0.02}]}, 
            Thickness[0.01]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0147151 0.588604 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(1)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(2)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(3)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(4)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
[ .02 .02 ] 0 setdash
.02381 .60332 m
.06244 .49526 L
.10458 .39989 L
.14415 .32764 L
.18221 .27097 L
.22272 .22187 L
.26171 .18353 L
.30316 .15052 L
.34309 .12483 L
.3815 .10472 L
.42237 .08734 L
.46172 .07379 L
.49955 .06314 L
.53984 .05391 L
.57861 .04669 L
.61984 .04047 L
.65954 .03562 L
.69774 .03182 L
.73838 .02854 L
.77751 .02597 L
.81909 .02376 L
.85916 .02205 L
.89771 .0207 L
.93871 .01954 L
.97619 .01868 L
s
[ ] 0 setdash
.02381 .30902 m
.04262 .32955 L
.06244 .3461 L
.07286 .35267 L
.08255 .35747 L
.08802 .35963 L
.0932 .3613 L
.09916 .36279 L
.10196 .36333 L
.10458 .36374 L
.10699 .36404 L
.10919 .36426 L
.11045 .36435 L
.11164 .36442 L
.1129 .36448 L
.11361 .3645 L
.11428 .36452 L
.11492 .36453 L
.11562 .36453 L
.11688 .36452 L
.11812 .3645 L
.11925 .36446 L
.12048 .3644 L
.12183 .36431 L
.12455 .36407 L
.12696 .36378 L
.12916 .36346 L
.13409 .36253 L
.14299 .36015 L
.15291 .3565 L
.16208 .35222 L
.18284 .33966 L
.22211 .30701 L
.25986 .26841 L
.30006 .22417 L
.33875 .18237 L
.37989 .14184 L
.41951 .10847 L
.45762 .08229 L
.49818 .06068 L
.53723 .04533 L
.55857 .03888 L
.57872 .03386 L
.61719 .02668 L
.63707 .02398 L
.65811 .02172 L
.67791 .02004 L
.696 .01884 L
.71544 .01782 L
.73634 .01698 L
Mistroke
.75536 .0164 L
.7761 .01593 L
.79581 .01559 L
.81679 .01533 L
.83825 .01514 L
.85843 .01501 L
.87855 .01492 L
.89703 .01486 L
.91589 .01482 L
.92659 .0148 L
.93657 .01478 L
.94705 .01477 L
.95696 .01476 L
.97553 .01475 L
.97619 .01475 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool003cooooo0ol0000Uooooo`Go00009_ooool3o`0002Sooooo0ol0000Uoooo
o`?o00001_ooool003gooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool0000Uoooo
o`05o`000?ooooooooooooooool00000:?ooool00ol0003oooooooooo`0Sooooo`05o`000?oooooo
ooooooooool000001Oooool003gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo02?ooooo1Ol0000Xooooo`03o`000?oooooooooo00?ooooo000moooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool2o`0002Kooooo00Co0000oooo
oooooooo0000:Oooool00ol0003oooooooooo`03ooooo`00?Oooool00ol0003oooooooooo`0Toooo
o`05o`000?ooooooooooooooool00000:Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
000002Gooooo1?l00006ooooo`00??ooool2o`0002Kooooo00Go0000ooooooooooooooooo`00000U
ooooo`05o`000?ooooooooooooooool000009oooool2o`0002Gooooo00?o0000ooooooooool01ooo
ool003gooooo00?o0000ooooooooool09Oooool3o`0002Oooooo0ol0000Yooooo`03o`000?oooooo
oooo02?ooooo1Ol00005ooooo`00joooool001Cooooo00?o0000ooooooooool0e?ooool001Cooooo
00?o0000ooooooooool0e?ooool001Cooooo00?o0000ooooooooool0e?ooool000oooooog?l00000
01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`19o`0000Kooooo000Dooooo`03
o`000?oooooooooo07cooooo5_l0000?ooooo`Oo00000_ooool6o`0000?ooooo1_l00002ooooo`Oo
00000_ooool7o`0000Wooooo000Dooooo`03o`000?oooooooooo07Oooooo3ol0000<ooooo`Co0000
0oooool6o`0000;ooooo1ol00002ooooo`Ko00009?ooool001Cooooo00?o0000ooooooooool0Looo
ool:o`0000[ooooo1ol00002ooooo`Ko00000oooool6o`0003Gooooo000Dooooo`03o`000?oooooo
oooo073ooooo2?l00007ooooo`Ko00000_ooool7o`0000;ooooo0ol00011ooooo`005?ooool2o`00
06kooooo1ol00004ooooo`Co00000oooool6o`0004oooooo000Dooooo`03o`000?oooooooooo06_o
oooo1_l00005ooooo`Ko0000F?ooool001Cooooo00?o0000ooooooooool0J?ooool<o`0000;ooooo
0ol0001Kooooo`005?ooool00ol0003oooooooooo`1Uooooo`Oo000000?oooooo`000?l000001Ol0
001Pooooo`005?ooool00ol0003oooooooooo`1Sooooo`So0000JOooool001Cooooo00?o0000oooo
ooooool0H?ooool8o`0006cooooo000Dooooo`03o`000?oooooooooo05gooooo1ol0001`ooooo`00
5?ooool2o`0005gooooo1_l0001booooo`005?ooool00ol0003oooooooooo`1Fooooo`Co00000_oo
ool4o`0007Cooooo000Dooooo`03o`000?oooooooooo05Cooooo2ol0001eooooo`005?ooool00ol0
003oooooooooo`1Dooooo`?o00000_ooool4o`0007Oooooo000Dooooo`03o`000?oooooooooo04oo
oooo0ol00005ooooo`Co0000NOooool001Cooooo00?o0000ooooooooool0COooool5o`0000?ooooo
1Ol0001jooooo`005?ooool2o`0004gooooo1?l00004ooooo`Co0000O?ooool001Cooooo00?o0000
ooooooooool0C?ooool2o`0000Cooooo1?l0001nooooo`005?ooool00ol0003oooooooooo`17oooo
o`?o00001oooool4o`0007oooooo000Dooooo`03o`000?oooooooooo04Gooooo1Ol00006ooooo`?o
0000POooool000;ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00000oooool00ol0003o
ooooooooo`14ooooo`Co00001oooool3o`0008;ooooo00001Ooooooo0000oooooooooooo000000So
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`14ooooo`;o00002?ooool3o`00
08?ooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0oooooo`?o00002oooool3o`0008Cooooo00001Ooooooo0000oooooooooooo0000
00[ooooo00?o0000ooooooooool00_ooool3o`0003kooooo1?l0000:ooooo`?o0000QOooool00005
ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool0?Oooool3o`0000_ooooo0ol00026ooooo`0000Goooooo`000?ooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0mooooo`;o00002_oo
ool4o`0008Oooooo0002ooooo`;o00002Oooool3o`0000Cooooo00?o0000ooooooooool0B?ooool4
o`0008Sooooo000Dooooo`03o`000?oooooooooo03Sooooo0ol0000<ooooo`?o0000R_ooool001Co
oooo00?o0000ooooooooool0=oooool4o`0000_ooooo0ol0002;ooooo`005?ooool2o`0003Oooooo
0ol0000<ooooo`?o0000S?ooool001Cooooo00?o0000ooooooooool0=_ooool2o`0000cooooo0ol0
002=ooooo`005?ooool00ol0003oooooooooo`13ooooo`?o0000S_ooool001Cooooo00?o0000oooo
ooooool0<_ooool2o`0000kooooo0ol0002?ooooo`005?ooool00ol0003oooooooooo`0aooooo`?o
00003Oooool3o`00093ooooo000Dooooo`03o`000?oooooooooo033ooooo0ol0000>ooooo`;o0000
TOooool001Cooooo0_l0000`ooooo`?o00003_ooool3o`00097ooooo000Dooooo`03o`000?oooooo
oooo02oooooo0_l0000>ooooo`?o0000T_ooool001Cooooo00?o0000ooooooooool0?_ooool3o`00
09?ooooo000Dooooo`03o`000?oooooooooo02cooooo0_l0000?ooooo`?o0000U?ooool001Cooooo
00?o0000ooooooooool0:oooool3o`0000oooooo0_l0002Eooooo`005?ooool00ol0003ooooooooo
o`0Zooooo`?o00003oooool3o`0009Gooooo000Dooooo`03o`000?oooooooooo02Wooooo0ol0000?
ooooo`?o0000U_ooool001Cooooo0_l0000Zooooo`;o00003oooool3o`0009Oooooo000Dooooo`03
o`000?oooooooooo03Wooooo0ol0002Hooooo`005?ooool00ol0003oooooooooo`0Vooooo`;o0000
4?ooool3o`0009Wooooo000Dooooo`03o`000?oooooooooo02Kooooo0_l0000?ooooo`?o0000V_oo
ool000;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooo
oooo02Gooooo0ol0000>ooooo`?o0000Voooool00005ooooool0003oooooooooool000002_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo0ol0000>ooooo`?o0000W?ooool0
0005ooooool0003oooooooooool000001oooool5o`0000?ooooo0ol0000Sooooo`?o00003_ooool3
o`0009gooooo00001Ooooooo0000oooooooooooo000000Oooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0Sooooo`;o00003_ooool3o`0009kooooo00001Ooooooo0000oooooooo
oooo000000Sooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`0booooo`?o0000Wooo
ool00005ooooool0003oooooooooool000002Oooool2o`0000Cooooo00?o0000ooooooooool08?oo
ool2o`0000oooooo0ol0002Pooooo`000_ooool2o`0000_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Pooooo`;o00003_ooool3o`000:7ooooo000Dooooo`03o`000?oooooooooo
01oooooo0ol0000>ooooo`;o0000X_ooool001Cooooo00?o0000ooooooooool07oooool2o`0000ko
oooo0ol0002Rooooo`005?ooool2o`0001oooooo0ol0000=ooooo`?o0000Xoooool001Cooooo00?o
0000ooooooooool07_ooool2o`0000gooooo0ol0002Tooooo`005?ooool00ol0003oooooooooo`0/
ooooo`?o0000YOooool001Cooooo00?o0000ooooooooool06oooool2o`0000kooooo0ol0002Voooo
o`005?ooool00ol0003oooooooooo`0Kooooo`;o00003Oooool3o`000:Oooooo000Dooooo`03o`00
0?oooooooooo01[ooooo0ol0000<ooooo`?o0000Z?ooool001?ooooo0ol0000Kooooo`;o00002ooo
ool4o`000:Wooooo000Cooooo`;o00006oooool3o`0000[ooooo1?l0002Zooooo`004oooool3o`00
01[ooooo0_l0000:ooooo`?o0000[?ooool001Cooooo0ol0000Sooooo`Co0000[Oooool001Cooooo
1?l0000Eooooo`;o00002_ooool4o`000:kooooo000Dooooo`03o`000?oooooo000000?o00004ooo
ool2o`0000Wooooo0ol0002`ooooo`005?ooool00ol0003oooooooooo`05o`00013ooooo0ol00008
ooooo`?o0000/Oooool001Cooooo0_l00003ooooo`Co00003oooool2o`0000Oooooo1?l0002boooo
o`005?ooool00ol0003oooooooooo`04ooooo`?o00003Oooool3o`0000Gooooo1Ol0002cooooo`00
5?ooool00ol0003oooooooooo`05ooooo`?o00003?ooool2o`0000Gooooo1?l0002eooooo`000_oo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool01_oo
ool4o`0000gooooo1_l0002gooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`07ooooo`Go00002Oooool7o`000;Sooooo
00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00Wooooo3ol0002looooo`0000Goooooo`000?ooooooooooo`000007ooooo`Co
00001?ooool3o`0000_ooooo2ol0002nooooo`0000Goooooo`000?ooooooooooo`000007ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool3o`000<3ooooo00001Ooooooo0000
oooooooooooo000000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`;o
0000`Oooool000;ooooo0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`0@ooooo`?o0000
`Oooool001Cooooo00?o0000ooooooooool04?ooool2o`000<;ooooo000Dooooo`03o`000?oooooo
oooo0=Cooooo000Dooooo`;o0000eOooool001Cooooo00?o0000ooooooooool03_ooool2o`000<Co
oooo000Dooooo`03o`000?oooooooooo00kooooo0_l00034ooooo`005?ooool00ol0003ooooooooo
o`0=ooooo`?o0000a?ooool001Cooooo00?o0000ooooooooool03Oooool2o`000<Gooooo000Doooo
o`03o`000?oooooooooo00cooooo0ol00035ooooo`005?ooool00ol0003oooooooooo`0<ooooo`;o
0000a_ooool001Cooooo0_l0003Eooooo`005?ooool00ol0003oooooooooo`3Dooooo`005?ooool0
0ol0003oooooooooo`0:ooooo`;o0000b?ooool001Cooooo00?o0000ooooooooool02_ooool2o`00
0<Sooooo000Dooooo`03o`000?oooooooooo00[ooooo0_l00038ooooo`005?ooool00ol0003ooooo
ooooo`09ooooo`?o0000b?ooool001Cooooo0_l0000:ooooo`;o0000bOooool001Cooooo00?o0000
ooooooooool02Oooool2o`000<Wooooo000Dooooo`03o`000?oooooooooo0=Cooooo000Dooooo`03
o`000?oooooooooo0=Cooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1?ooool00ol0003oooooooooo`07ooooo`;o0000boooool00005ooooool0003oooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01oooool2o`000<_o
oooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Kooooo0ol0003;ooooo`0000Goooooo`000?ooooooooooo`000008oooo
o`?o00001?ooool3o`0000Kooooo0_l0003<ooooo`0000Goooooo`000?ooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`?o0000c?ooool0
0005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01Oooool2o`000<gooooo0002ooooo`;o00002Oooool3o`0000Cooooo00?o0000
ooooooooool0e?ooool001Cooooo00?o0000ooooooooool0e?ooool001Cooooo00?o0000oooooooo
ool01?ooool2o`000<kooooo000Dooooo`;o00001Oooool2o`000<kooooo000Dooooo`03o`000?oo
oooooooo00?ooooo0ol0003>ooooo`005?ooool00ol0003oooooooooo`03ooooo`;o0000coooool0
01Cooooo00?o0000ooooooooool00_ooool3o`000<oooooo000Dooooo`03o`000?oooooooooo00;o
oooo0_l0003@ooooo`005?ooool00ol0003oooooooooo`3Dooooo`005?ooool00ol0003ooooooooo
o`3Dooooo`005?ooool2o`0000;ooooo0_l0003Aooooo`005?ooool01?l0003oooooooooooooool2
o`000=7ooooo000Dooooo`03o`000?oooooooooo00?o0000dOooool001Cooooo00?o0000oooooooo
ool00_l0003Booooo`005?ooool00ol0003oooooo`000002o`000=;ooooo000Dooooo`04o`000?oo
oooo0000o`000=?ooooo000Dooooo`;o0000eOooool001Cooooo00?o0000ooooooooool0e?ooool0
01Cooooo0ol0003Dooooo`005?ooool3o`000=Cooooo000=ooooo`?o00001?ooool3o`000=Cooooo
000>ooooo`03o`000?oooooooooo00?ooooo0_l0003Eooooo`003_ooool00ol0003oooooooooo`02
ooooo`Co0000e?ooool000kooooo00?o0000ooooooooool00_ooool2o`000=Kooooo000>ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0e?ooool000gooooo0_l00005ooooo`03o`00
0?oooooooooo0=Cooooo000>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0e?oo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00001\
\>"],
  ImageRangeCache->{{{73.4375, 260.438}, {536.188, 349.188}} -> {-2.70723, \
2.96021, 0.0240588, 0.00778557}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Finally we plot the Wigner distribution for random complex \
Hermitian matrices (which is very close to the Gaussian Unitary Ensemble \
distribution).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GUE = 
      Plot[32*s^2*Exp[\(-4\)*s^2/Pi]/Pi^2, {s, 0, 5}, 
        PlotStyle \[Rule] {Thickness[0.015]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0147151 0.628319 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .14038 -18 -4.5 ]
[.01131 .14038 0 4.5 ]
[.01131 .26604 -18 -4.5 ]
[.01131 .26604 0 4.5 ]
[.01131 .39171 -18 -4.5 ]
[.01131 .39171 0 4.5 ]
[.01131 .51737 -18 -4.5 ]
[.01131 .51737 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(1)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(2)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(3)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(4)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .14038 m
.03006 .14038 L
s
[(0.2)] .01131 .14038 1 0 Mshowa
.02381 .26604 m
.03006 .26604 L
s
[(0.4)] .01131 .26604 1 0 Mshowa
.02381 .39171 m
.03006 .39171 L
s
[(0.6)] .01131 .39171 1 0 Mshowa
.02381 .51737 m
.03006 .51737 L
s
[(0.8)] .01131 .51737 1 0 Mshowa
.125 Mabswid
.02381 .04613 m
.02756 .04613 L
s
.02381 .07755 m
.02756 .07755 L
s
.02381 .10896 m
.02756 .10896 L
s
.02381 .17179 m
.02756 .17179 L
s
.02381 .20321 m
.02756 .20321 L
s
.02381 .23463 m
.02756 .23463 L
s
.02381 .29746 m
.02756 .29746 L
s
.02381 .32887 m
.02756 .32887 L
s
.02381 .36029 m
.02756 .36029 L
s
.02381 .42312 m
.02756 .42312 L
s
.02381 .45454 m
.02756 .45454 L
s
.02381 .48595 m
.02756 .48595 L
s
.02381 .54879 m
.02756 .54879 L
s
.02381 .5802 m
.02756 .5802 L
s
.02381 .61162 m
.02756 .61162 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.015 w
.02381 .01472 m
.02499 .01479 L
.02605 .015 L
.02729 .01539 L
.02846 .01593 L
.03053 .01725 L
.03279 .01923 L
.03527 .02205 L
.0379 .02578 L
.04262 .03433 L
.05205 .05827 L
.06244 .09425 L
.0842 .19489 L
.10458 .30607 L
.12312 .40646 L
.14335 .50067 L
.15431 .54075 L
.16449 .56956 L
.16949 .58056 L
.17421 .58895 L
.17682 .59277 L
.17965 .59623 L
.18203 .59861 L
.18458 .60062 L
.1859 .60144 L
.18715 .60208 L
.18827 .60254 L
.18949 .60292 L
.19065 .60316 L
.19188 .6033 L
.19292 .60332 L
.19408 .60323 L
.19474 .60314 L
.19543 .603 L
.19667 .60265 L
.198 .60214 L
.19946 .60141 L
.20208 .5997 L
.20451 .59763 L
.20985 .59156 L
.2147 .58429 L
.22558 .56247 L
.24476 .50888 L
.26556 .43675 L
.30648 .28643 L
.32684 .22021 L
.34588 .16757 L
.36532 .12401 L
.38377 .09182 L
.40406 .06551 L
Mistroke
.42259 .04837 L
.43221 .0416 L
.44244 .0357 L
.46084 .02788 L
.47115 .02473 L
.48229 .0221 L
.49281 .0202 L
.50247 .01886 L
.51224 .01781 L
.52134 .01706 L
.53132 .01643 L
.54201 .01593 L
.55221 .01559 L
.56329 .01531 L
.57376 .01513 L
.58343 .01501 L
.59308 .01492 L
.60213 .01487 L
.61206 .01482 L
.61764 .0148 L
.62275 .01478 L
.6275 .01477 L
.63257 .01476 L
.64171 .01475 L
.6473 .01474 L
.65257 .01474 L
.65726 .01473 L
.66242 .01473 L
.67217 .01472 L
.6775 .01472 L
.68248 .01472 L
.69138 .01472 L
.69638 .01472 L
.70094 .01472 L
.70574 .01472 L
.71084 .01472 L
.72 .01472 L
.72509 .01472 L
.72986 .01472 L
.73506 .01472 L
.74075 .01472 L
.74584 .01472 L
.75057 .01472 L
.75599 .01472 L
.76091 .01472 L
.76985 .01472 L
.77477 .01472 L
.77941 .01472 L
.78442 .01472 L
.78911 .01472 L
Mistroke
.79401 .01472 L
.7994 .01472 L
.80404 .01472 L
.80829 .01472 L
.8133 .01472 L
.81784 .01472 L
.82261 .01472 L
.8277 .01472 L
.83241 .01472 L
.83684 .01472 L
.84203 .01472 L
.8468 .01472 L
.85204 .01472 L
.85757 .01472 L
.86253 .01472 L
.86706 .01472 L
.87228 .01472 L
.87722 .01472 L
.88179 .01472 L
.88601 .01472 L
.89064 .01472 L
.89556 .01472 L
.90046 .01472 L
.90494 .01472 L
.90987 .01472 L
.91505 .01472 L
.91957 .01472 L
.92378 .01472 L
.9284 .01472 L
.93333 .01472 L
.93867 .01472 L
.94359 .01472 L
.94898 .01472 L
.95469 .01472 L
.95966 .01472 L
.9643 .01472 L
.96939 .01472 L
.97485 .01472 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo000looooo`?o00009Oooool5o`0002Kooooo0ol0000Xooooo`?o
00009Oooool3o`0000Kooooo000mooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo
00009Oooool01Ol0003ooooooooooooooooo000002Sooooo00?o0000ooooooooool08oooool01Ol0
003ooooooooooooooooo000000Gooooo000mooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Sooooo`Go0000:?ooool00ol0003oooooooooo`03oooo
o`00?Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo0_l0000Vooooo`04
o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool00oooool003gooooo00?o0000oooooooo
ool09?ooool01Ol0003ooooooooooooooooo000002Wooooo00?o0000ooooooooool09?ooool00ol0
003oooooo`00000Uooooo`Co00001_ooool003cooooo0_l0000Vooooo`05o`000?oooooooooooooo
ool000009Oooool01Ol0003ooooooooooooooooo000002Oooooo0_l0000Uooooo`03o`000?oooooo
oooo00Oooooo000mooooo`03o`000?oooooooooo02Gooooo0ol0000Wooooo`?o0000:Oooool00ol0
003oooooooooo`0Sooooo`Go00001Oooool001Cooooo00?o0000ooooooooool0e?ooool001Cooooo
00?o0000ooooooooool0e?ooool001?ooooo0ol0001koooooeGo00001Oooool000oooooog?l00000
01?ooooo1_l00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooooom`o`00
00Gooooo000Dooooo`Go00009Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00So
oooo8Ol0000Xooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01?ooool001Cooooo
00?o0000ooooool000000_l0001Gooooo`go0000K_ooool001Cooooo00?o0000ooooool000000ol0
001Dooooo`[o0000Loooool001Cooooo00?o0000ooooool000000ol0001Booooo`So0000Moooool0
01Cooooo00?o0000ooooooooool01?l0001@ooooo`Oo0000NOooool001Cooooo0_l000000ooooooo
0000o`000002o`0004oooooo1_l0001kooooo`005?ooool01?l0003oooooooooooooool3o`0004ko
oooo1Ol0001mooooo`005?ooool01?l0003oooooooooooooool4o`0004cooooo1Ol0001nooooo`00
5?ooool01?l0003oooooooooooooool4o`0004_ooooo1Ol0001oooooo`005?ooool00ol0003ooooo
ooooo`02ooooo`Co0000BOooool5o`00083ooooo000Dooooo`03o`000?oooooooooo00;ooooo1?l0
0019ooooo`Co0000POooool001Cooooo00?o0000ooooooooool00oooool3o`0004Sooooo1?l00022
ooooo`005?ooool2o`0000Cooooo1?l00016ooooo`Go0000P_ooool001Cooooo00?o0000oooooooo
ool00oooool4o`0004Gooooo1Ol00023ooooo`005?ooool00ol0003oooooooooo`04ooooo`?o0000
A?ooool5o`0008Cooooo000Dooooo`03o`000?oooooooooo00Cooooo1?l00013ooooo`Co0000QOoo
ool001Cooooo00?o0000ooooooooool01?ooool4o`0004;ooooo1?l00026ooooo`005?ooool00ol0
003oooooooooo`05ooooo`?o0000@_ooool4o`0008Kooooo000Dooooo`03o`000?oooooooooo00Go
oooo0ol00011ooooo`Co0000Qoooool001Cooooo0_l00006ooooo`Co0000?oooool5o`0008Oooooo
000Dooooo`03o`000?oooooooooo00Gooooo1?l0000oooooo`Co0000R?ooool001Cooooo00?o0000
ooooooooool01_ooool3o`0003kooooo1?l00029ooooo`005?ooool00ol0003oooooooooo`06oooo
o`?o0000?_ooool4o`0008Wooooo0002ooooo`;o00001?ooool01?l0003oooooooooooooool5o`00
00?ooooo00?o0000ooooooooool01_ooool3o`0003gooooo1?l0002:ooooo`0000Goooooo`000?oo
ooooooooo`000008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01_ooool4
o`0003cooooo1?l0002:ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01_ooool4o`0003cooooo0ol0002;ooooo`0000Goooooo`00
0?ooooooooooo`00000:ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`?o0000>oooool4
o`0008_ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00Oooooo0ol0000kooooo`Co0000Roooool00005ooooool0003o
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1oooool3o`0003[ooooo1?l0002<ooooo`000_ooool2o`0000Wooooo0ol00004ooooo`03o`000?oo
oooooooo00Oooooo0ol0000jooooo`Co0000S?ooool001Cooooo00?o0000ooooooooool01oooool4
o`0003Wooooo0ol0002=ooooo`005?ooool00ol0003oooooooooo`07ooooo`Co0000>?ooool4o`00
08gooooo000Dooooo`03o`000?oooooooooo00Sooooo0ol0000hooooo`Co0000SOooool001Cooooo
0_l00009ooooo`?o0000=oooool4o`0008kooooo000Dooooo`03o`000?oooooooooo00Sooooo0ol0
000gooooo`Co0000S_ooool001Cooooo00?o0000ooooooooool02?ooool4o`0003Gooooo1?l0002?
ooooo`005?ooool00ol0003oooooooooo`08ooooo`Co0000=Oooool4o`0008oooooo000Dooooo`03
o`000?oooooooooo00Wooooo0ol0000dooooo`Co0000T?ooool001Cooooo00?o0000ooooooooool0
2Oooool3o`0003Cooooo1?l0002@ooooo`005?ooool00ol0003oooooooooo`09ooooo`?o0000=?oo
ool3o`00097ooooo000Dooooo`;o00002_ooool4o`0003;ooooo1?l0002Aooooo`005?ooool00ol0
003oooooooooo`09ooooo`Co0000<_ooool4o`00097ooooo000Dooooo`03o`000?oooooooooo00[o
oooo0ol0000aooooo`Co0000T_ooool001Cooooo00?o0000ooooooooool02_ooool3o`00037ooooo
1?l0002Booooo`005?ooool00ol0003oooooooooo`0:ooooo`?o0000<Oooool3o`0009?ooooo000D
ooooo`03o`000?oooooooooo00[ooooo1?l0000_ooooo`Co0000Toooool001Cooooo00?o0000oooo
ooooool02_ooool4o`0002oooooo1?l0002Cooooo`005?ooool2o`0000cooooo0ol0000_ooooo`?o
0000U?ooool001Cooooo00?o0000ooooooooool02oooool3o`0002oooooo0ol0002Dooooo`005?oo
ool00ol0003oooooooooo`0;ooooo`?o0000;_ooool4o`0009Cooooo000Dooooo`03o`000?oooooo
oooo00_ooooo1?l0000]ooooo`Co0000U?ooool000;ooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo0ol00003ooooo`03o`000?oooooooooo00_ooooo1?l0000]ooooo`?o0000UOooool00005
ooooool0003oooooooooool000002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00cooooo0ol0000/ooooo`Co0000UOooool00005ooooool0003oooooooooool000001oooool5o`00
00?ooooo0ol0000<ooooo`?o0000;?ooool4o`0009Gooooo00001Ooooooo0000oooooooooooo0000
00Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0<ooooo`?o0000;?ooool3
o`0009Kooooo00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooool000001?ooool0
0ol0003oooooooooo`0<ooooo`Co0000:oooool3o`0009Kooooo00001Ooooooo0000oooooooooooo
000000Wooooo0_l00004ooooo`03o`000?oooooooooo00cooooo1?l0000Zooooo`Co0000U_ooool0
00;ooooo0_l0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool3o`00
02[ooooo1?l0002Fooooo`005?ooool00ol0003oooooooooo`0=ooooo`?o0000:_ooool3o`0009Oo
oooo000Dooooo`03o`000?oooooooooo00gooooo0ol0000Zooooo`?o0000Uoooool001Cooooo0_l0
000>ooooo`Co0000:?ooool4o`0009Oooooo000Dooooo`03o`000?oooooooooo00gooooo1?l0000X
ooooo`Co0000Uoooool001Cooooo00?o0000ooooooooool03_ooool3o`0002Sooooo0ol0002Hoooo
o`005?ooool00ol0003oooooooooo`0>ooooo`?o00009oooool4o`0009Sooooo000Dooooo`03o`00
0?oooooooooo00kooooo0ol0000Wooooo`Co0000V?ooool001Cooooo00?o0000ooooooooool03_oo
ool4o`0002Kooooo0ol0002Iooooo`005?ooool00ol0003oooooooooo`0>ooooo`Co00009_ooool3
o`0009Wooooo000Dooooo`;o00004?ooool3o`0002Gooooo1?l0002Iooooo`005?ooool00ol0003o
ooooooooo`0?ooooo`?o00009Oooool4o`0009Wooooo000Dooooo`03o`000?oooooooooo00oooooo
0ol0000Uooooo`?o0000V_ooool001Cooooo00?o0000ooooooooool03oooool4o`0002Cooooo0ol0
002Jooooo`005?ooool00ol0003oooooooooo`0?ooooo`Co00008oooool4o`0009[ooooo000Doooo
o`03o`000?oooooooooo013ooooo0ol0000Sooooo`Co0000V_ooool001Cooooo00?o0000oooooooo
ool04?ooool3o`0002?ooooo0ol0002Kooooo`005?ooool2o`00017ooooo0ol0000Rooooo`Co0000
Voooool001Cooooo00?o0000ooooooooool04?ooool3o`0002;ooooo1?l0002Kooooo`005?ooool0
0ol0003oooooooooo`0@ooooo`Co00008Oooool3o`0009cooooo000Dooooo`03o`000?oooooooooo
013ooooo1?l0000Qooooo`?o0000W?ooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0ol00004ooooo`03o`000?oooooooooo017ooooo0ol0000Pooooo`Co0000W?ooool00005oooo
ool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool04Oooool3o`00023ooooo1?l0002Looooo`0000Goooooo`000?ooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Aooooo`?o00008?ooool3
o`0009gooooo00001Ooooooo0000oooooooooooo000000Oooooo1?l00004ooooo`?o00004Oooool4
o`0001oooooo0ol0002Mooooo`0000Goooooo`000?ooooooooooo`000007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04Oooool4o`0001kooooo1?l0002Mooooo`0000Goooooo`00
0?ooooooooooo`000008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool3
o`0001kooooo1?l0002Mooooo`000_ooool2o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo
01;ooooo0ol0000Nooooo`?o0000W_ooool001Cooooo00?o0000ooooooooool04_ooool3o`0001go
oooo1?l0002Nooooo`005?ooool00ol0003oooooooooo`0Booooo`?o00007Oooool4o`0009kooooo
000Dooooo`03o`000?oooooooooo01;ooooo1?l0000Looooo`?o0000Woooool001Cooooo0_l0000C
ooooo`Co00007?ooool3o`0009oooooo000Dooooo`03o`000?oooooooooo01?ooooo0ol0000Koooo
o`Co0000Woooool001Cooooo00?o0000ooooooooool04oooool3o`0001_ooooo1?l0002Oooooo`00
5?ooool00ol0003oooooooooo`0Cooooo`?o00006oooool3o`000:3ooooo000Dooooo`03o`000?oo
oooooooo01?ooooo1?l0000Jooooo`?o0000X?ooool001Cooooo00?o0000ooooooooool04oooool4
o`0001Wooooo1?l0002Pooooo`005?ooool00ol0003oooooooooo`0Dooooo`?o00006Oooool4o`00
0:3ooooo000Dooooo`;o00005Oooool3o`0001Wooooo0ol0002Qooooo`005?ooool00ol0003ooooo
ooooo`0Dooooo`?o00006Oooool3o`000:7ooooo000Dooooo`03o`000?oooooooooo01Cooooo1?l0
000Gooooo`Co0000XOooool001Cooooo00?o0000ooooooooool05?ooool4o`0001Oooooo1?l0002Q
ooooo`005?ooool00ol0003oooooooooo`0Eooooo`?o00005oooool3o`000:;ooooo000Dooooo`03
o`000?oooooooooo01Gooooo0ol0000Fooooo`Co0000X_ooool001Cooooo0_l0000Fooooo`?o0000
5_ooool4o`000:;ooooo000Dooooo`03o`000?oooooooooo01Gooooo1?l0000Eooooo`?o0000Xooo
ool001Cooooo00?o0000ooooooooool05Oooool4o`0001Gooooo0ol0002Sooooo`005?ooool00ol0
003oooooooooo`0Fooooo`?o00005?ooool4o`000:?ooooo000Dooooo`03o`000?oooooooooo01Ko
oooo0ol0000Dooooo`Co0000Xoooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol00004ooooo`03o`000?oooooooooo01Kooooo1?l0000Cooooo`?o0000Y?ooool00005ooooool0
003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool05_ooool4o`0001;ooooo1?l0002Tooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000000oooool3o`0001Oooooo0ol0000Booooo`Co0000Y?ooool00005
ooooool0003oooooooooool000002?ooool3o`0000Cooooo00?o0000ooooooooool05oooool4o`00
017ooooo0ol0002Uooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`0Gooooo`Co00004?ooool4o`000:Gooooo00001Ooo
oooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo01Sooooo0ol0000@ooooo`Co0000YOooool000;ooooo0_l00009ooooo`?o00001?ooool0
0ol0003oooooooooo`0Hooooo`Co00003_ooool4o`000:Kooooo000Dooooo`03o`000?oooooooooo
01Sooooo1?l0000>ooooo`Co0000Y_ooool001Cooooo00?o0000ooooooooool06Oooool3o`0000go
oooo1?l0002Wooooo`005?ooool2o`0001[ooooo1?l0000<ooooo`Co0000Yoooool001Cooooo00?o
0000ooooooooool06Oooool4o`0000cooooo0ol0002Xooooo`005?ooool00ol0003oooooooooo`0J
ooooo`?o00002oooool4o`000:Sooooo000Dooooo`03o`000?oooooooooo01[ooooo1?l0000:oooo
o`Co0000Z?ooool001Cooooo00?o0000ooooooooool06_ooool4o`0000Wooooo1?l0002Yooooo`00
5?ooool00ol0003oooooooooo`0Kooooo`?o00002Oooool4o`000:Wooooo000Dooooo`03o`000?oo
oooooooo01_ooooo1?l00008ooooo`?o0000Z_ooool001Cooooo0_l0000Looooo`Co00001oooool4
o`000:[ooooo000Dooooo`03o`000?oooooooooo01cooooo1?l00005ooooo`Go0000Z_ooool001Co
oooo00?o0000ooooooooool07?ooool5o`0000Cooooo1?l0002[ooooo`005?ooool00ol0003ooooo
ooooo`0Mooooo`Go000000?oooooo`000?l000000ol0002/ooooo`005?ooool00ol0003ooooooooo
o`0Nooooo`[o0000[?ooool001Cooooo00?o0000ooooooooool07_ooool9o`000:gooooo000Doooo
o`03o`000?oooooooooo023ooooo1_l0002^ooooo`005?ooool2o`000=Gooooo000Dooooo`03o`00
0?oooooooooo0=Cooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo0000\
\>"],
  ImageRangeCache->{{{73.4375, 260.438}, {266.062, 79.0625}} -> {-2.70723, \
0.305714, 0.0240588, 0.00729346}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Random Numbers", "Section"],

Cell[TextData[{
  "In this section we look at the spacing distribution for random numbers, to \
see that is follows the Poisson distribution.  The code below generates a \
list of 10,000 random numbers (all between 0 and 1), sorts them, rescales \
them so that the means spacing between consecutive numbers is 1, and then \
generates a histogram of the frequencies of different level spacings.  To \
generate the histogram you need to load the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Graphics package first."
}], "Text"],

Cell[BoxData[
    \(<< Graphics`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n = 10000;\)\), "\n", 
    \(\(R = Sort[Table[Random[], {i, 1, n + 1}]];\)\), "\n", 
    \(\(RSpacing = Table[R[\([i + 1]\)] - R[\([i]\)], {i, 1, n}];\)\), "\n", 
    \(\(RSpacingNorm = RSpacing/Mean[RSpacing];\)\), "\n", 
    \(\(int\  = \ Table[0 + i/8, {i, 0, 40}];\)\), "\n", 
    \(RHist = 
      Histogram[RSpacingNorm, HistogramCategories \[Rule] int, 
        HistogramScale \[Rule] 1, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<s\>", "\<P(s)\>"}, 
        RotateLabel \[Rule] False]\)}], "Input"],

Cell[BoxData[
    \(Histogram::"rtail" \(\(:\)\(\ \)\) 
      "Warning: \!\(76\) points from the right tail of the data, greater than \
or equal to \!\(5\), are not included in histogram."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.2 0.0147151 0.619833 [
[.2 -0.0125 -6.78125 -18 ]
[.2 -0.0125 6.78125 0 ]
[.4 -0.0125 -6.78125 -18 ]
[.4 -0.0125 6.78125 0 ]
[.6 -0.0125 -6.78125 -18 ]
[.6 -0.0125 6.78125 0 ]
[.8 -0.0125 -6.78125 -18 ]
[.8 -0.0125 6.78125 0 ]
[1 -0.0125 -6.78125 -18 ]
[1 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .13868 -32.6875 -9 ]
[-0.0125 .13868 0 9 ]
[-0.0125 .26265 -32.6875 -9 ]
[-0.0125 .26265 0 9 ]
[-0.0125 .38661 -32.6875 -9 ]
[-0.0125 .38661 0 9 ]
[-0.0125 .51058 -32.6875 -9 ]
[-0.0125 .51058 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -74.9375 -9 ]
[-0.01875 .30902 -32.6875 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
gsave
.2 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.4 0 m
.4 .00625 L
s
gsave
.4 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.6 0 m
.6 .00625 L
s
gsave
.6 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.8 0 m
.8 .00625 L
s
gsave
.8 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13868 m
.00625 .13868 L
s
gsave
-0.0125 .13868 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .26265 m
.00625 .26265 L
s
gsave
-0.0125 .26265 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .38661 m
.00625 .38661 L
s
gsave
-0.0125 .38661 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .51058 m
.00625 .51058 L
s
gsave
-0.0125 .51058 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04571 m
.00375 .04571 L
s
0 .0767 m
.00375 .0767 L
s
0 .10769 m
.00375 .10769 L
s
0 .16967 m
.00375 .16967 L
s
0 .20066 m
.00375 .20066 L
s
0 .23166 m
.00375 .23166 L
s
0 .29364 m
.00375 .29364 L
s
0 .32463 m
.00375 .32463 L
s
0 .35562 m
.00375 .35562 L
s
0 .41761 m
.00375 .41761 L
s
0 .4486 m
.00375 .4486 L
s
0 .47959 m
.00375 .47959 L
s
0 .54157 m
.00375 .54157 L
s
0 .57256 m
.00375 .57256 L
s
0 .60356 m
.00375 .60356 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.04 .61428 m
.04 .61803 L
s
.08 .61428 m
.08 .61803 L
s
.12 .61428 m
.12 .61803 L
s
.16 .61428 m
.16 .61803 L
s
.24 .61428 m
.24 .61803 L
s
.28 .61428 m
.28 .61803 L
s
.32 .61428 m
.32 .61803 L
s
.36 .61428 m
.36 .61803 L
s
.44 .61428 m
.44 .61803 L
s
.48 .61428 m
.48 .61803 L
s
.52 .61428 m
.52 .61803 L
s
.56 .61428 m
.56 .61803 L
s
.64 .61428 m
.64 .61803 L
s
.68 .61428 m
.68 .61803 L
s
.72 .61428 m
.72 .61803 L
s
.76 .61428 m
.76 .61803 L
s
.84 .61428 m
.84 .61803 L
s
.88 .61428 m
.88 .61803 L
s
.92 .61428 m
.92 .61803 L
s
.96 .61428 m
.96 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13868 m
1 .13868 L
s
.99375 .26265 m
1 .26265 L
s
.99375 .38661 m
1 .38661 L
s
.99375 .51058 m
1 .51058 L
s
.125 Mabswid
.99625 .04571 m
1 .04571 L
s
.99625 .0767 m
1 .0767 L
s
.99625 .10769 m
1 .10769 L
s
.99625 .16967 m
1 .16967 L
s
.99625 .20066 m
1 .20066 L
s
.99625 .23166 m
1 .23166 L
s
.99625 .29364 m
1 .29364 L
s
.99625 .32463 m
1 .32463 L
s
.99625 .35562 m
1 .35562 L
s
.99625 .41761 m
1 .41761 L
s
.99625 .4486 m
1 .4486 L
s
.99625 .47959 m
1 .47959 L
s
.99625 .54157 m
1 .54157 L
s
.99625 .57256 m
1 .57256 L
s
.99625 .60356 m
1 .60356 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .60332 L
.025 .60332 L
.025 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .60332 L
.025 .60332 L
.025 .01472 L
0 .01472 L
s
1 0 0 r
.025 .01472 m
.025 .52337 L
.05 .52337 L
.05 .01472 L
F
0 g
.025 .01472 m
.025 .52337 L
.05 .52337 L
.05 .01472 L
.025 .01472 L
s
1 0 0 r
.05 .01472 m
.05 .49339 L
.075 .49339 L
.075 .01472 L
F
0 g
.05 .01472 m
.05 .49339 L
.075 .49339 L
.075 .01472 L
.05 .01472 L
s
1 0 0 r
.075 .01472 m
.075 .40695 L
.1 .40695 L
.1 .01472 L
F
0 g
.075 .01472 m
.075 .40695 L
.1 .40695 L
.1 .01472 L
.075 .01472 L
s
1 0 0 r
.1 .01472 m
.1 .37247 L
.125 .37247 L
.125 .01472 L
F
0 g
.1 .01472 m
.1 .37247 L
.125 .37247 L
.125 .01472 L
.1 .01472 L
s
1 0 0 r
.125 .01472 m
.125 .335 L
.15 .335 L
.15 .01472 L
F
0 g
.125 .01472 m
.125 .335 L
.15 .335 L
.15 .01472 L
.125 .01472 L
s
1 0 0 r
.15 .01472 m
.15 .29403 L
.175 .29403 L
.175 .01472 L
F
0 g
.15 .01472 m
.15 .29403 L
.175 .29403 L
.175 .01472 L
.15 .01472 L
s
1 0 0 r
.175 .01472 m
.175 .26205 L
.2 .26205 L
.2 .01472 L
F
0 g
.175 .01472 m
.175 .26205 L
.2 .26205 L
.2 .01472 L
.175 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .22008 L
.225 .22008 L
.225 .01472 L
F
0 g
.2 .01472 m
.2 .22008 L
.225 .22008 L
.225 .01472 L
.2 .01472 L
s
1 0 0 r
.225 .01472 m
.225 .21308 L
.25 .21308 L
.25 .01472 L
F
0 g
.225 .01472 m
.225 .21308 L
.25 .21308 L
.25 .01472 L
.225 .01472 L
s
1 0 0 r
.25 .01472 m
.25 .17411 L
.275 .17411 L
.275 .01472 L
F
0 g
.25 .01472 m
.25 .17411 L
.275 .17411 L
.275 .01472 L
.25 .01472 L
s
1 0 0 r
.275 .01472 m
.275 .17061 L
.3 .17061 L
.3 .01472 L
F
0 g
.275 .01472 m
.275 .17061 L
.3 .17061 L
.3 .01472 L
.275 .01472 L
s
1 0 0 r
.3 .01472 m
.3 .14613 L
.325 .14613 L
.325 .01472 L
F
0 g
.3 .01472 m
.3 .14613 L
.325 .14613 L
.325 .01472 L
.3 .01472 L
s
1 0 0 r
.325 .01472 m
.325 .12314 L
.35 .12314 L
.35 .01472 L
F
0 g
.325 .01472 m
.325 .12314 L
.35 .12314 L
.35 .01472 L
.325 .01472 L
s
1 0 0 r
.35 .01472 m
.35 .11315 L
.375 .11315 L
.375 .01472 L
F
0 g
.35 .01472 m
.35 .11315 L
.375 .11315 L
.375 .01472 L
.35 .01472 L
s
1 0 0 r
.375 .01472 m
.375 .09916 L
.4 .09916 L
.4 .01472 L
F
0 g
.375 .01472 m
.375 .09916 L
.4 .09916 L
.4 .01472 L
.375 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .10965 L
.425 .10965 L
.425 .01472 L
F
0 g
.4 .01472 m
.4 .10965 L
.425 .10965 L
.425 .01472 L
.4 .01472 L
s
1 0 0 r
.425 .01472 m
.425 .08317 L
.45 .08317 L
.45 .01472 L
F
0 g
.425 .01472 m
.425 .08317 L
.45 .08317 L
.45 .01472 L
.425 .01472 L
s
1 0 0 r
.45 .01472 m
.45 .06968 L
.475 .06968 L
.475 .01472 L
F
0 g
.45 .01472 m
.45 .06968 L
.475 .06968 L
.475 .01472 L
.45 .01472 L
s
1 0 0 r
.475 .01472 m
.475 .06918 L
.5 .06918 L
.5 .01472 L
F
0 g
.475 .01472 m
.475 .06918 L
.5 .06918 L
.5 .01472 L
.475 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .06418 L
.525 .06418 L
.525 .01472 L
F
0 g
.5 .01472 m
.5 .06418 L
.525 .06418 L
.525 .01472 L
.5 .01472 L
s
1 0 0 r
.525 .01472 m
.525 .05719 L
.55 .05719 L
.55 .01472 L
F
0 g
.525 .01472 m
.525 .05719 L
.55 .05719 L
.55 .01472 L
.525 .01472 L
s
1 0 0 r
.55 .01472 m
.55 .0442 L
.575 .0442 L
.575 .01472 L
F
0 g
.55 .01472 m
.55 .0442 L
.575 .0442 L
.575 .01472 L
.55 .01472 L
s
1 0 0 r
.575 .01472 m
.575 .05619 L
.6 .05619 L
.6 .01472 L
F
0 g
.575 .01472 m
.575 .05619 L
.6 .05619 L
.6 .01472 L
.575 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .04619 L
.625 .04619 L
.625 .01472 L
F
0 g
.6 .01472 m
.6 .04619 L
.625 .04619 L
.625 .01472 L
.6 .01472 L
s
1 0 0 r
.625 .01472 m
.625 .0362 L
.65 .0362 L
.65 .01472 L
F
0 g
.625 .01472 m
.625 .0362 L
.65 .0362 L
.65 .01472 L
.625 .01472 L
s
1 0 0 r
.65 .01472 m
.65 .0302 L
.675 .0302 L
.675 .01472 L
F
0 g
.65 .01472 m
.65 .0302 L
.675 .0302 L
.675 .01472 L
.65 .01472 L
s
1 0 0 r
.675 .01472 m
.675 .0337 L
.7 .0337 L
.7 .01472 L
F
0 g
.675 .01472 m
.675 .0337 L
.7 .0337 L
.7 .01472 L
.675 .01472 L
s
1 0 0 r
.7 .01472 m
.7 .0382 L
.725 .0382 L
.725 .01472 L
F
0 g
.7 .01472 m
.7 .0382 L
.725 .0382 L
.725 .01472 L
.7 .01472 L
s
1 0 0 r
.725 .01472 m
.725 .0307 L
.75 .0307 L
.75 .01472 L
F
0 g
.725 .01472 m
.725 .0307 L
.75 .0307 L
.75 .01472 L
.725 .01472 L
s
1 0 0 r
.75 .01472 m
.75 .0307 L
.775 .0307 L
.775 .01472 L
F
0 g
.75 .01472 m
.75 .0307 L
.775 .0307 L
.775 .01472 L
.75 .01472 L
s
1 0 0 r
.775 .01472 m
.775 .02821 L
.8 .02821 L
.8 .01472 L
F
0 g
.775 .01472 m
.775 .02821 L
.8 .02821 L
.8 .01472 L
.775 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .01971 L
.825 .01971 L
.825 .01472 L
F
0 g
.8 .01472 m
.8 .01971 L
.825 .01971 L
.825 .01472 L
.8 .01472 L
s
1 0 0 r
.825 .01472 m
.825 .02421 L
.85 .02421 L
.85 .01472 L
F
0 g
.825 .01472 m
.825 .02421 L
.85 .02421 L
.85 .01472 L
.825 .01472 L
s
1 0 0 r
.85 .01472 m
.85 .02121 L
.875 .02121 L
.875 .01472 L
F
0 g
.85 .01472 m
.85 .02121 L
.875 .02121 L
.875 .01472 L
.85 .01472 L
s
1 0 0 r
.875 .01472 m
.875 .02571 L
.9 .02571 L
.9 .01472 L
F
0 g
.875 .01472 m
.875 .02571 L
.9 .02571 L
.9 .01472 L
.875 .01472 L
s
1 0 0 r
.9 .01472 m
.9 .02221 L
.925 .02221 L
.925 .01472 L
F
0 g
.9 .01472 m
.9 .02221 L
.925 .02221 L
.925 .01472 L
.9 .01472 L
s
1 0 0 r
.925 .01472 m
.925 .01771 L
.95 .01771 L
.95 .01472 L
F
0 g
.925 .01472 m
.925 .01771 L
.95 .01771 L
.95 .01472 L
.925 .01472 L
s
1 0 0 r
.95 .01472 m
.95 .01821 L
.975 .01821 L
.975 .01472 L
F
0 g
.95 .01472 m
.95 .01821 L
.975 .01821 L
.975 .01472 L
.95 .01472 L
s
1 0 0 r
.975 .01472 m
.975 .02071 L
1 .02071 L
1 .01472 L
F
0 g
.975 .01472 m
.975 .02071 L
1 .02071 L
1 .01472 L
.975 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool009Cooooo00?o410@oc8b<_l@4100
0_l000000om4A4Coc<c<ooooo`1?ooooo`00U?ooool00ol0003oV9RHonk^kP02ooooo`03ohN7Qol@
413ooooo04oooooo002Iooooo`03okZj^_l0003ooooo04oooooo002Dooooo`03olc<c?m4A4Co0000
00?o000000?oV9RHooooooooool0C_ooool009Cooooo00Go0000ohN7Qonj^[[o^[Zjolc<c01Boooo
o`00U?ooool00ol0003oV9RHooooo`02ooooo`03olc<c?l@413ooooo04oooooo002Dooooo`07olc<
c?m4A4Co0000o`000?l@413o<S8bo`00001@ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo001Xooooo`Co0000
00?o410@ooooooooool05_ooool6o`0001Wooooo00GoZJVYob4Q8Ol0003o0000ofIVIP0Looooo`;o
000000?o410@ooooooooool05_ooool01OnHV9So410@o`000?l0003oIVIV00Kooooo001Zooooo`03
o`000?oooooooooo01Sooooo00?oV9RHo`000?oMgMd00_ooool00ol@413oooooooooo`0Gooooo`06
oa0@4?o<c<cooooooooooomgMgOoIVIV7?ooool00ol0003oooooooooo`0Gooooo`06oa0@4?n7QhOo
oooooooooomgMgOoIVIV1Oooool006[ooooo00?o0000ooooooooool06Oooool00on7QhOo8B4Qonk^
kP0Pooooo`03o`000?oooooooooo01Kooooo1_l0000Mooooo`03o`000?oooooooooo00?ooooo001Z
ooooo`03o`000?oooooooooo01[ooooo00?oZJVYob4Q8Oo^k^h07oooool00ol0003oooooooooo`0F
ooooo`05odA4A?nj^[[oooooooooool000007Oooool00oo^k^ko0000ooooo`04ooooo`00J_ooool0
0ol0003oooooooooo`0Kooooo`03oiRHV?lb<S;ooooo01gooooo00?oZJVYodA4A?ooool05oooool0
1OoMgMgo8B4Qoooooooooooo000001Wooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH5ooooo`00
J_ooool00ol0003oooooooooo`0Looooo`03odA4A?mgMgOooooo01[ooooo00Co8B4Qo`000?l0003o
gMgM6Oooool01?mgMgOoV9RHooooool0000Iooooo`05o`000?lQ8B7o0000o`000?mVIVH01_ooool0
06[ooooo00?o0000ooooooooool07?ooool00ooMgMgo410@ooooo`0Looooo`03ojVYZOlb<S;ooooo
01Sooooo00Cok^k^ob4Q8Ooooooo00006Oooool00ol0003oooooooooo`08ooooo`00J_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06?ooool00omg
MgOoV9RHo`00000Iooooo`03o`000?oooooooooo00Sooooo001Xooooo`03o`000?m4A4Co000001[o
oooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEEDIooooo`06ob4Q8Onj^[[ooooooooooomVIVKo<S8b
6_ooool00oo^k^ko<S8bo`00000Iooooo`03o`000?oooooooooo00Sooooo001Xooooo`03olc<c?mE
EEGo000001[ooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^hIooooo`06okZj^_m4A4Co0000o`00
0?m4A4Cok^k^6oooool00onHV9So410@ooooo`0Hooooo`Go00001_ooool00>_ooooo003[ooooo`00
joooool004?ooooo00CoV9RHo`000?l0003oV9RHY?ooool004;ooooo00Ko^[Zjob4Q8OoMgMgogMgM
ob4Q8Onj^[X5oooooiOo00001oooool004;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool004;ooooo00Ko0000onk^k_oo
ooooooooonk^k_l00005oooooiOo00001oooool004;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l0
0003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005
o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003o
o`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l0
00000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000_oo0000
1Ol0003oo`00ool00?oo003o000000?oo`0000Go0000ool00?oo003oo`00o`000002ool00005o`00
0?oo003oo`00ool00?l000000ooo00001Ol0003oo`00ool00?oo003o000000;oo`0000Go0000ool0
0?oo003oo`00o`000003ool000Go00000_oo0005o`0000?oo`0000Co0000ool00?oo003oo`003?l0
0007ooooo`00@_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003o
o`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003
ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`00
0?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00
o`0000?oo`0000Go0000ool00?oo003oo`00o`000002ool00005o`000?oo003oo`00ool00?l00000
0ooo00001Ol0003oo`00ool00?oo003o000000;oo`0000Go0000ool00?oo003oo`00o`000003ool0
0005o`000?oo003oo`00ool00?l000000_oo00001?l0003oo`00ool00?oo0005o`0000?ooooo1?l0
0003ooooo`Wo00002_ooool00ol0003oooooooooo`05ooooo`00@_ooool01_l0003ok^k^oooooooo
ooook^k^o`0000Gooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`00
00?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go
0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo
003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`00
0003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000002ool00005
o`000?oo003oo`00ool00?l000000ooo00001Ol0003oo`00ool00?oo003o000000;oo`002Ol00003
ool000So00008Oooool00ol0003oooooooooo`05ooooo`00@_ooool01_m4A4CoV9RHoooooooooooo
V9RHodA4A0Gooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?o
o`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000
ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003o
o`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003
ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000002ool00005o`00
0?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?oo0004o`0000Oooooo1Ol0000Xoooo
o`03o`000?oooooooooo00Gooooo0012ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool0
1Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00
ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o
000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`00
00Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool0
0?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000;oo`001Ol00003ool000Go0000=_oo
ool2o`0000Oooooo0013ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00Go0000ool00?oo003oo`00
o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool0
0004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo
003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`00
00?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go
0000ool00?oo003oo`00o`000002ool00005o`000?ooooooooooooooool000000ooo00000ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo00Gooooo001=ooooo`05o`000?oo003oo`00ool00?l0
00000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo0000
1?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00
ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003
ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00004o`00
0?oo003oo`00ool000Co00000oooool5o`0003_ooooo00?o0000ooooooooool01Oooool004gooooo
00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool0
0?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00
o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool0
0004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo
003oo`00o`0000?oo`001Ol00016ooooo`03o`000?oooooooooo00Gooooo001=ooooo`05o`000?oo
003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool0
0?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo
00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003o
o`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo0008o`0004[ooooo00?o0000
ooooooooool01Oooool004gooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003o
o`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?o
o`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000
ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003o
o`00o`000003ool00003o`000?oooooooooo04kooooo0_l00007ooooo`00COooool01Ol0003oo`00
ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o
000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`00
00Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool0
0?oo003o00000ooo00001?l0003oo`00ool00?oo0005o`00057ooooo00?o0000ooooooooool01Ooo
ool004gooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`00
00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool0
0?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00
o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`00001Eoooo
o`03o`000?oooooooooo00Gooooo001=ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0
003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool0
0?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool0
0005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00005o`0000?oo`0000?o0000
ooooooooool0Doooool00ol0003oooooooooo`05ooooo`00COooool01Ol0003oo`00ool00?oo003o
000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`00
00Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool0
0?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o0000
0oooool01Ol0003oo`00ool00?oo003o000005Cooooo0_l00007ooooo`00COooool01Ol0003oo`00
ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o
000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`00
00Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`001?l00003oooo
o`Go0000EOooool00ol0003oooooooooo`05ooooo`00<?ooool01?nHV9So0000o`000?nHV9P6oooo
o`03oeEEEOl0003oEEEE00Gooooo1_l00005ooooo`05o`000?oo003oo`00ool00?l000000ooo0000
1?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00
ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003
ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oooooooooo`1Nooooo`03o`000?oo
oooooooo00Gooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Gooooo
00?oV9RHo`000?oMgMd00_ooool00ol@413oooooooooo`03ooooo`05o`000?oo003oo`00ool00?l0
00000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo0000
1?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00
ool00?l00003ool00004o`000?oo003oo`00ool000Go0000H?ooool00ol0003oooooooooo`05oooo
o`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool0
0on7QhOo8B4Qonk^kP07ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool0
0?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool0
0005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo
003oo`00ool00?l00000I?ooool00ol0003oooooooooo`05ooooo`00;oooool01_l0003ok^k^oooo
ooooooook^k^o`0000oooooo00?oZJVYob4Q8Oo^k^h01_ooool01Ol0003oo`00ool00?oo003o0000
00?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co
0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo
003o00000ooo00001Ol0003oo`00ool00?oo003o000006?ooooo0_l00007ooooo`00;oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?oV9RHoc8b<_ooool01Oooool01Ol0
003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool0
0?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o0000
00?oo`0000Co0000ool00?oo003o00000ooo0005o`0006Cooooo00?o0000ooooooooool01Oooool0
02oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03odA4A?mgMgOooooo
00Cooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go
0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo
003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000?o0000ooooooooool0I_ooool0
0ol0003oooooooooo`05ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`00017ooooo00?o
gMgMoa0@4?ooool01?ooool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o
00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo0000
1Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00000ol0003ooooo
ooooo`1Vooooo`03o`000?oooooooooo00Gooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9So
A4A44_ooool00ol0003oooooooooo`03ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0
003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool0
0?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool0
0003o`000?oooooooooo06Kooooo00?o0000ooooooooool01Oooool002oooooo00Ko^[Zjob4Q8OoM
gMgogMgMob4Q8Onj^[X=ooooo`06o`000?n7QhOok^k^oooooonHV9SoEEEE1Oooool01Ol0003oo`00
ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o
000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`00
2?l0001Wooooo`;o00001oooool0033ooooo00CoV9RHo`000?l0003oV9RH3_ooool01_nYZJWo<S8b
o`000?l0003oEEEEonk^kPGooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003o
o`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?o
o`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oooooooooo06gooooo00?o0000oooo
ooooool01Oooool004gooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00
o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`00
00Go0000ool00?oo003oo`00o`000003ool00003o`000?oooooooooo06gooooo00?o0000oooooooo
ool01Oooool004gooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`00
00?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go
0000ool00?oo003oo`00o`000003ool00003o`000?oooooooooo06gooooo00?o0000ooooooooool0
1Oooool004gooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?o
o`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000
ool00?oo003oo`00o`000003ool00003o`000?oooooooooo06cooooo0_l00007ooooo`00COooool0
1Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00
ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o
000000?oo`0000?o0000ooooooooool0KOooool00ol0003oooooooooo`05ooooo`00COooool01Ol0
003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool0
0?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001?l0003oo`00ool00?oo0005o`00
06oooooo00?o0000ooooooooool01Oooool004gooooo00Go0000ool00?oo003oo`00o`000003ool0
0004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo
003oo`00o`0000?oo`001Ol0001cooooo`03o`000?oooooooooo00Gooooo001=ooooo`05o`000?oo
003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool0
0?l000000ooo00001?l0003oo`00ool00?l00003ool00003o`000?oooooooooo07Gooooo00?o0000
ooooooooool01Oooool004gooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003o
o`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?o
o`0000?o0000ooooooooool0M?ooool2o`0000Oooooo001=ooooo`05o`000?oo003oo`00ool00?l0
00000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo0000
1?l0003oo`00ool00?l00003ool00003o`000?oooooooooo07Gooooo00?o0000ooooooooool01Ooo
ool0033ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@09ooooo`;o000000?o
410@ooooooooool00_ooool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o
00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo0000
0ol0003oooooooooo`1eooooo`03o`000?oooooooooo00Gooooo000_ooooo`06okZj^_lQ8B7ogMgM
omgMgOlQ8B7o^[Zj1Oooool3o`0000[ooooo00?o0000ooooooooool00oooool01Ol0003oo`00ool0
0?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o0000
00?oo`0000Co0000ool00?oo003o00000ooo00000ol0003oooooooooo`1eooooo`03o`000?oooooo
oooo00Gooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEE
E@06ooooo`Ko00001?ooool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o
00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00001Ol0001goooo
o`03o`000?oooooooooo00Gooooo000@ooooo`03okZj^_lb<S;ooooo00kooooo00?o<S8bokZj^_oo
ool02oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00GoA4A4okZj^_ooooooooooo`00
0005ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005
o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l0001jooooo`;o00001oooool0
013ooooo00?o<S8bokZj^_ooool03_ooool00onj^[[o<S8booooo`0;ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03?ooool01OoMgMgo8B4Qoooooooooooo000000Gooooo00Go0000
ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003o
o`00o`000003ool00004o`000?oo003oo`00o`0007_ooooo00?o0000ooooooooool01Oooool000oo
oooo00?oc<c<oc8b<_ooool04?ooool00olb<S;oc<c<ooooo`0:ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03Oooool01?mgMgOoV9RHooooool00005ooooo`05o`000?oo003oo`00
ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l00000
0ooo00001?l0003oo`00ool00?l0001kooooo`03o`000?oooooooooo00Gooooo0002ooooo`05oa0@
4?l0003o0000o`000?l@41002?ooool00omVIVKoZJVYooooo`04ooooo`03oa0@4?lb<S;o410@00;o
000000?oA4A4olc<c?ooool01?ooool00onHV9SoIVIVooooo`0:ooooo`06o`000?o^k^kooooooooo
ooo^k^ko00003oooool01?o^k^ko8B4Qooooool00005ooooo`05o`000?oo003oo`00ool00?l00000
0ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0
003oo`00ool00?l0001kooooo`03o`000?oooooooooo00Gooooo0004ooooo`03o`000?oooooooooo
00Sooooo00?o<S8booooooooool01?ooool00ol0003oV9RHonk^kP02ooooo`03ohN7Qol@413ooooo
00Cooooo00?ok^k^oc8b<_ooool02_ooool01_m4A4CoV9RHooooooooooooV9RHodA4A13ooooo00?o
MgMgoiRHV?l000001Oooool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o
00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`001?l0001jooooo`;o00001oooool000Co
oooo00?o0000ooooooooool02?ooool00olb<S;oooooooooo`09ooooo`03okZj^_l0003ooooo00Go
oooo00?o0000ooooooooool02Oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Q3ooooo00?ok^k^
oc8b<_l000001Oooool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o0000
0ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ooooooooool0O?ooool00ol0003o
ooooooooo`05ooooo`001?ooool3o`000003oa0@4?mgMgOok^k^00Gooooo00?o<S8booooooooool0
1?ooool00oo<c<coA4A4o`000003o`000003oiRHV?oooooooooo00Cooooo00?o0000ooooooooool0
2_ooool01?nHV9So0000o`000?nHV9PBooooo`03oiRHV?l@413ooooo00Cooooo00Go0000ool00?oo
003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`00
0003ool00003o`000?oooooooooo07cooooo00?o0000ooooooooool01Oooool000Cooooo00Ko0000
ooooooooooook^k^ogMgMomEEED5ooooo`03ob4Q8Ooooooooooo00Cooooo00Go0000ohN7Qonj^[[o
^[Zjolc<c008ooooo`03o`000?oooooooooo02Oooooo00Go0000ool00?oo003oo`00o`000003ool0
0004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo
oooooooo07cooooo00?o0000ooooooooool01Oooool000Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03oc8b<_o^k^kooooo00Cooooo00?o0000oiRHV?ooool00_ooool0
0oo<c<co410@ooooo`04ooooo`03omgMgOlb<S;ooooo02Sooooo00Go0000ool00?oo003oo`00o`00
0003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00003
o`000?oooooooooo07cooooo00?o0000ooooooooool01Oooool000Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03ofIVI_nHV9Sooooo00Cooooo00Ooc<c<odA4A?l0003o
0000oa0@4?lb<S;o000000Gooooo00?oV9RHofIVI_ooool0:?ooool01Ol0003oo`00ool00?oo003o
000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`00
00?o0000ooooooooool0Noooool2o`0000Oooooo0004ooooo`06o`000?ooooooooooonk^k_mgMgOo
EEEE1Oooool00ooMgMgo8B4Qooooo`0@ooooo`03oa0@4?o<c<cooooo02Sooooo00Go0000ool00?oo
003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Co0000ool00?oo003oo`001Ol0
001nooooo`03o`000?oooooooooo00Gooooo0002ooooo`03oa0@4?l0003o000000;o000000?o410@
ogMgMoo^k^h01_ooool00olb<S;o^[Zjooooo`0>ooooo`03okZj^_lb<S;ooooo02Wooooo00Go0000
ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003o
o`00o`000022ooooo`03o`000?oooooooooo00Gooooo000@ooooo`03okZj^_lb<S;ooooo00kooooo
00?o<S8bokZj^_ooool0:Oooool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo
003o00000ooo00001Ol0003oo`00ool00?oo003o000008;ooooo00?o0000ooooooooool01Oooool0
04gooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go
0000ool00?oo003oo`00o`000021ooooo`;o00001oooool004gooooo00Go0000ool00?oo003oo`00
o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000022oooo
o`03o`000?oooooooooo00Gooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`00
0?mEEED01_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPCooooo00Go0000ool00?oo003oo`00
o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000022oooo
o`03o`000?oooooooooo00Gooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3
o`0000Kooooo0_mgMgL2ooooo`03ogMgMomEEEGooooo00?ooooo00Go0000ool00?oo003oo`00o`00
0003ool00004o`000?oo003oo`00o`0000?oo`001Ol00022ooooo`03o`000?oooooooooo00Gooooo
000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`03
ob4Q8Ooooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003oo`00ool00?oo003o0000
00?oo`0000Co0000ool00?oo003o00000ooo00000ol0003oooooooooo`24ooooo`03o`000?oooooo
oooo00Gooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00003_ooool00ol0003ok^k^oooo
o`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ool00?oo003oo`00o`000003ool00004o`00
0?oo003oo`00o`0000?oo`0000?o0000ooooooooool0Poooool2o`0000Oooooo000_ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01_l0003oEEEEonk^k_ooooooMgMgoeEE
E@Cooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000?o
0000ooooooooool0Q?ooool00ol0003oooooooooo`05ooooo`00;oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00cooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^h4ooooo`05o`00
0?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00003o`000?oooooooooo
08Cooooo00?o0000ooooooooool01Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>
ooooo`03odA4A?nHV9Sooooo00Oooooo00Go0000ool00?oo003oo`00o`000003ool00003o`000?oo
003oo`0000Go0000Q_ooool00ol0003oooooooooo`05ooooo`00;oooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A0kooooo00?o^[Zjob4Q8Oooool01oooool01Ol0003oo`00ool00?oo003o000000?o
o`0000Co0000ool00?oo003o0000R_ooool00ol0003oooooooooo`05ooooo`00;oooool01_nj^[[o
8B4QomgMgOoMgMgo8B4QokZj^Poooooo00?oEEEEoc8b<_oMgMd01_ooool01Ol0003oo`00ool00?oo
003o000000?oo`0000Co0000ool00?oo003o0000ROooool2o`0000Oooooo000`ooooo`04oiRHV?l0
003o0000oiRHV17ooooo00CoV9RHob4Q8Ol0003o8B4Q1?ooool01Ol0003oo`00ool00?oo003o0000
00?oo`0000Co0000ool00?oo003o0000R_ooool00ol0003oooooooooo`05ooooo`00COooool01Ol0
003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o0000R_ooool00ol0003ooooooooo
o`05ooooo`00COooool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o0000
R_ooool00ol0003oooooooooo`05ooooo`00COooool01Ol0003oo`00ool00?oo003o000000?oo`00
00Co0000ool00?oo003o0000ROooool2o`0000Oooooo001=ooooo`05o`000?oo003oo`00ool00?l0
00000ooo00001?l0003oo`00ool00?l0002:ooooo`03o`000?oooooooooo00Gooooo001=ooooo`05
o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l0002:ooooo`03o`000?oooooo
oooo00Gooooo001=ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l0
002:ooooo`03o`000?oooooooooo00Gooooo001=ooooo`05o`000?oo003oo`00ool00?l000000ooo
00001?l0003oo`00ool00?l0002:ooooo`03o`000?oooooooooo00Gooooo001=ooooo`05o`000?oo
003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00029ooooo`;o00001oooool004gooooo
00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0008[ooooo00?o0000oooo
ooooool01Oooool0033ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@06oooo
o`06onk^k_mEEEGo0000o`000?mEEEGok^k^1?ooool01Ol0003oo`00ool00?oo003o000000?oo`00
1?l0002:ooooo`03o`000?oooooooooo00Gooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o
^[Zj1Oooool3o`0000Kooooo00KoEEEEogMgMoooooooooooogMgMomEEED4ooooo`05o`000?oo003o
o`00ool00?l000000ooo00000ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Gooooo000_
ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003oo`00ool00?oo003o000000?o
o`0000?o0000ooooooooool0Roooool00ol0003oooooooooo`05ooooo`00;oooool01_l0003ok^k^
ooooooooooook^k^o`0000kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`05o`000?oo003oo`00ool00?l000000ooo00000ol0003oooooooooo`2:ooooo`;o00001oooool0
02oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`06oeEEEOmgMgOooooo
oooooomgMgOoEEEE1?ooool01?l0003oo`00ool00?oo0005o`0008gooooo00?o0000ooooooooool0
1Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03omgMgOl0
003o000000;o000000?ogMgMooooooooool00_ooool01Ol0003oo`00ool00?oo003o0000097ooooo
00?o0000ooooooooool01Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`06
oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b1?ooool01Ol0003oo`00ool00?oo003o0000097ooooo00?o
0000ooooooooool01Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@>ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003oo`00ool00?oo003o0000093o
oooo0_l00007ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00Ko<S8bofIV
I_o^k^kok^k^ofIVI_lb<S84ooooo`05o`000?oo003oo`00ool00?l00000TOooool00ol0003ooooo
ooooo`05ooooo`00<?ooool01?nHV9So0000o`000?nHV9P?ooooo`06onk^k_m4A4Co0000o`000?m4
A4Cok^k^1?ooool01Ol0003oo`00ool00?oo003o0000097ooooo00?o0000ooooooooool01Oooool0
04gooooo00Go0000ool00?oo003oo`00o`00002Aooooo`03o`000?oooooooooo00Gooooo001=oooo
o`05o`000?oo003oo`00ool00?l00000TOooool00ol0003oooooooooo`05ooooo`00COooool01Ol0
003oo`00ool00?oo003o0000093ooooo0_l00007ooooo`00COooool01Ol0003oo`00ool00?oo003o
0000097ooooo00?o0000ooooooooool01Oooool004gooooo00Go0000ool00?oo003oo`00o`00002A
ooooo`03o`000?oooooooooo00Gooooo001=ooooo`05o`000?oo003oo`00ool00?l00000TOooool0
0ol0003oooooooooo`05ooooo`00COooool5o`00093ooooo0_l00007ooooo`00COooool00ol0003o
ooooooooo`2Cooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool004goooooUol00007ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-2.60043, -0.992362, 0.03345, \
0.0107932}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Next we show the level spacing histogram along with a plot of the \
Poisson distribution. It is clear from the results that random numbers have a \
Poisson level spacing distribution. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[RHist, Poisson, AspectRatio \[Rule] 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.2 0.0238095 0.952381 [
[.2 -0.0125 -6.78125 -18 ]
[.2 -0.0125 6.78125 0 ]
[.4 -0.0125 -6.78125 -18 ]
[.4 -0.0125 6.78125 0 ]
[.6 -0.0125 -6.78125 -18 ]
[.6 -0.0125 6.78125 0 ]
[.8 -0.0125 -6.78125 -18 ]
[.8 -0.0125 6.78125 0 ]
[1 -0.0125 -6.78125 -18 ]
[1 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .02381 -13.5625 -9 ]
[-0.0125 .02381 0 9 ]
[-0.0125 .21429 -32.6875 -9 ]
[-0.0125 .21429 0 9 ]
[-0.0125 .40476 -32.6875 -9 ]
[-0.0125 .40476 0 9 ]
[-0.0125 .59524 -32.6875 -9 ]
[-0.0125 .59524 0 9 ]
[-0.0125 .78571 -32.6875 -9 ]
[-0.0125 .78571 0 9 ]
[-0.0125 .97619 -13.5625 -9 ]
[-0.0125 .97619 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -74.9375 -9 ]
[-0.01875 .5 -32.6875 9 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
gsave
.2 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.4 0 m
.4 .00625 L
s
gsave
.4 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.6 0 m
.6 .00625 L
s
gsave
.6 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.8 0 m
.8 .00625 L
s
gsave
.8 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02381 m
.00625 .02381 L
s
gsave
-0.0125 .02381 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .21429 m
.00625 .21429 L
s
gsave
-0.0125 .21429 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .40476 m
.00625 .40476 L
s
gsave
-0.0125 .40476 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .59524 m
.00625 .59524 L
s
gsave
-0.0125 .59524 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .78571 m
.00625 .78571 L
s
gsave
-0.0125 .78571 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .97619 m
.00625 .97619 L
s
gsave
-0.0125 .97619 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07143 m
.00375 .07143 L
s
0 .11905 m
.00375 .11905 L
s
0 .16667 m
.00375 .16667 L
s
0 .2619 m
.00375 .2619 L
s
0 .30952 m
.00375 .30952 L
s
0 .35714 m
.00375 .35714 L
s
0 .45238 m
.00375 .45238 L
s
0 .5 m
.00375 .5 L
s
0 .54762 m
.00375 .54762 L
s
0 .64286 m
.00375 .64286 L
s
0 .69048 m
.00375 .69048 L
s
0 .7381 m
.00375 .7381 L
s
0 .83333 m
.00375 .83333 L
s
0 .88095 m
.00375 .88095 L
s
0 .92857 m
.00375 .92857 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.2 .99375 m
.2 1 L
s
.4 .99375 m
.4 1 L
s
.6 .99375 m
.6 1 L
s
.8 .99375 m
.8 1 L
s
.125 Mabswid
.04 .99625 m
.04 1 L
s
.08 .99625 m
.08 1 L
s
.12 .99625 m
.12 1 L
s
.16 .99625 m
.16 1 L
s
.24 .99625 m
.24 1 L
s
.28 .99625 m
.28 1 L
s
.32 .99625 m
.32 1 L
s
.36 .99625 m
.36 1 L
s
.44 .99625 m
.44 1 L
s
.48 .99625 m
.48 1 L
s
.52 .99625 m
.52 1 L
s
.56 .99625 m
.56 1 L
s
.64 .99625 m
.64 1 L
s
.68 .99625 m
.68 1 L
s
.72 .99625 m
.72 1 L
s
.76 .99625 m
.76 1 L
s
.84 .99625 m
.84 1 L
s
.88 .99625 m
.88 1 L
s
.92 .99625 m
.92 1 L
s
.96 .99625 m
.96 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .21429 m
1 .21429 L
s
.99375 .40476 m
1 .40476 L
s
.99375 .59524 m
1 .59524 L
s
.99375 .78571 m
1 .78571 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .07143 m
1 .07143 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .30952 m
1 .30952 L
s
.99625 .35714 m
1 .35714 L
s
.99625 .45238 m
1 .45238 L
s
.99625 .5 m
1 .5 L
s
.99625 .54762 m
1 .54762 L
s
.99625 .64286 m
1 .64286 L
s
.99625 .69048 m
1 .69048 L
s
.99625 .7381 m
1 .7381 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .88095 m
1 .88095 L
s
.99625 .92857 m
1 .92857 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .02381 m
1 .02381 L
s
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
0 .02381 m
0 .92821 L
.025 .92821 L
.025 .02381 L
F
0 g
.5 Mabswid
0 .02381 m
0 .92821 L
.025 .92821 L
.025 .02381 L
0 .02381 L
s
1 0 0 r
.025 .02381 m
.025 .80537 L
.05 .80537 L
.05 .02381 L
F
0 g
.025 .02381 m
.025 .80537 L
.05 .80537 L
.05 .02381 L
.025 .02381 L
s
1 0 0 r
.05 .02381 m
.05 .7593 L
.075 .7593 L
.075 .02381 L
F
0 g
.05 .02381 m
.05 .7593 L
.075 .7593 L
.075 .02381 L
.05 .02381 L
s
1 0 0 r
.075 .02381 m
.075 .62649 L
.1 .62649 L
.1 .02381 L
F
0 g
.075 .02381 m
.075 .62649 L
.1 .62649 L
.1 .02381 L
.075 .02381 L
s
1 0 0 r
.1 .02381 m
.1 .57351 L
.125 .57351 L
.125 .02381 L
F
0 g
.1 .02381 m
.1 .57351 L
.125 .57351 L
.125 .02381 L
.1 .02381 L
s
1 0 0 r
.125 .02381 m
.125 .51593 L
.15 .51593 L
.15 .02381 L
F
0 g
.125 .02381 m
.125 .51593 L
.15 .51593 L
.15 .02381 L
.125 .02381 L
s
1 0 0 r
.15 .02381 m
.15 .45298 L
.175 .45298 L
.175 .02381 L
F
0 g
.15 .02381 m
.15 .45298 L
.175 .45298 L
.175 .02381 L
.15 .02381 L
s
1 0 0 r
.175 .02381 m
.175 .40384 L
.2 .40384 L
.2 .02381 L
F
0 g
.175 .02381 m
.175 .40384 L
.2 .40384 L
.2 .02381 L
.175 .02381 L
s
1 0 0 r
.2 .02381 m
.2 .33935 L
.225 .33935 L
.225 .02381 L
F
0 g
.2 .02381 m
.2 .33935 L
.225 .33935 L
.225 .02381 L
.2 .02381 L
s
1 0 0 r
.225 .02381 m
.225 .3286 L
.25 .3286 L
.25 .02381 L
F
0 g
.225 .02381 m
.225 .3286 L
.25 .3286 L
.25 .02381 L
.225 .02381 L
s
1 0 0 r
.25 .02381 m
.25 .26872 L
.275 .26872 L
.275 .02381 L
F
0 g
.25 .02381 m
.25 .26872 L
.275 .26872 L
.275 .02381 L
.25 .02381 L
s
1 0 0 r
.275 .02381 m
.275 .26334 L
.3 .26334 L
.3 .02381 L
F
0 g
.275 .02381 m
.275 .26334 L
.3 .26334 L
.3 .02381 L
.275 .02381 L
s
1 0 0 r
.3 .02381 m
.3 .22573 L
.325 .22573 L
.325 .02381 L
F
0 g
.3 .02381 m
.3 .22573 L
.325 .22573 L
.325 .02381 L
.3 .02381 L
s
1 0 0 r
.325 .02381 m
.325 .19041 L
.35 .19041 L
.35 .02381 L
F
0 g
.325 .02381 m
.325 .19041 L
.35 .19041 L
.35 .02381 L
.325 .02381 L
s
1 0 0 r
.35 .02381 m
.35 .17505 L
.375 .17505 L
.375 .02381 L
F
0 g
.35 .02381 m
.35 .17505 L
.375 .17505 L
.375 .02381 L
.35 .02381 L
s
1 0 0 r
.375 .02381 m
.375 .15356 L
.4 .15356 L
.4 .02381 L
F
0 g
.375 .02381 m
.375 .15356 L
.4 .15356 L
.4 .02381 L
.375 .02381 L
s
1 0 0 r
.4 .02381 m
.4 .16968 L
.425 .16968 L
.425 .02381 L
F
0 g
.4 .02381 m
.4 .16968 L
.425 .16968 L
.425 .02381 L
.4 .02381 L
s
1 0 0 r
.425 .02381 m
.425 .12899 L
.45 .12899 L
.45 .02381 L
F
0 g
.425 .02381 m
.425 .12899 L
.45 .12899 L
.45 .02381 L
.425 .02381 L
s
1 0 0 r
.45 .02381 m
.45 .10826 L
.475 .10826 L
.475 .02381 L
F
0 g
.45 .02381 m
.45 .10826 L
.475 .10826 L
.475 .02381 L
.45 .02381 L
s
1 0 0 r
.475 .02381 m
.475 .10749 L
.5 .10749 L
.5 .02381 L
F
0 g
.475 .02381 m
.475 .10749 L
.5 .10749 L
.5 .02381 L
.475 .02381 L
s
1 0 0 r
.5 .02381 m
.5 .09982 L
.525 .09982 L
.525 .02381 L
F
0 g
.5 .02381 m
.5 .09982 L
.525 .09982 L
.525 .02381 L
.5 .02381 L
s
1 0 0 r
.525 .02381 m
.525 .08907 L
.55 .08907 L
.55 .02381 L
F
0 g
.525 .02381 m
.525 .08907 L
.55 .08907 L
.55 .02381 L
.525 .02381 L
s
1 0 0 r
.55 .02381 m
.55 .06911 L
.575 .06911 L
.575 .02381 L
F
0 g
.55 .02381 m
.55 .06911 L
.575 .06911 L
.575 .02381 L
.55 .02381 L
s
1 0 0 r
.575 .02381 m
.575 .08753 L
.6 .08753 L
.6 .02381 L
F
0 g
.575 .02381 m
.575 .08753 L
.6 .08753 L
.6 .02381 L
.575 .02381 L
s
1 0 0 r
.6 .02381 m
.6 .07218 L
.625 .07218 L
.625 .02381 L
F
0 g
.6 .02381 m
.6 .07218 L
.625 .07218 L
.625 .02381 L
.6 .02381 L
s
1 0 0 r
.625 .02381 m
.625 .05682 L
.65 .05682 L
.65 .02381 L
F
0 g
.625 .02381 m
.625 .05682 L
.65 .05682 L
.65 .02381 L
.625 .02381 L
s
1 0 0 r
.65 .02381 m
.65 .04761 L
.675 .04761 L
.675 .02381 L
F
0 g
.65 .02381 m
.65 .04761 L
.675 .04761 L
.675 .02381 L
.65 .02381 L
s
1 0 0 r
.675 .02381 m
.675 .05298 L
.7 .05298 L
.7 .02381 L
F
0 g
.675 .02381 m
.675 .05298 L
.7 .05298 L
.7 .02381 L
.675 .02381 L
s
1 0 0 r
.7 .02381 m
.7 .05989 L
.725 .05989 L
.725 .02381 L
F
0 g
.7 .02381 m
.7 .05989 L
.725 .05989 L
.725 .02381 L
.7 .02381 L
s
1 0 0 r
.725 .02381 m
.725 .04838 L
.75 .04838 L
.75 .02381 L
F
0 g
.725 .02381 m
.725 .04838 L
.75 .04838 L
.75 .02381 L
.725 .02381 L
s
1 0 0 r
.75 .02381 m
.75 .04838 L
.775 .04838 L
.775 .02381 L
F
0 g
.75 .02381 m
.75 .04838 L
.775 .04838 L
.775 .02381 L
.75 .02381 L
s
1 0 0 r
.775 .02381 m
.775 .04454 L
.8 .04454 L
.8 .02381 L
F
0 g
.775 .02381 m
.775 .04454 L
.8 .04454 L
.8 .02381 L
.775 .02381 L
s
1 0 0 r
.8 .02381 m
.8 .03149 L
.825 .03149 L
.825 .02381 L
F
0 g
.8 .02381 m
.8 .03149 L
.825 .03149 L
.825 .02381 L
.8 .02381 L
s
1 0 0 r
.825 .02381 m
.825 .0384 L
.85 .0384 L
.85 .02381 L
F
0 g
.825 .02381 m
.825 .0384 L
.85 .0384 L
.85 .02381 L
.825 .02381 L
s
1 0 0 r
.85 .02381 m
.85 .03379 L
.875 .03379 L
.875 .02381 L
F
0 g
.85 .02381 m
.85 .03379 L
.875 .03379 L
.875 .02381 L
.85 .02381 L
s
1 0 0 r
.875 .02381 m
.875 .0407 L
.9 .0407 L
.9 .02381 L
F
0 g
.875 .02381 m
.875 .0407 L
.9 .0407 L
.9 .02381 L
.875 .02381 L
s
1 0 0 r
.9 .02381 m
.9 .03533 L
.925 .03533 L
.925 .02381 L
F
0 g
.9 .02381 m
.9 .03533 L
.925 .03533 L
.925 .02381 L
.9 .02381 L
s
1 0 0 r
.925 .02381 m
.925 .02842 L
.95 .02842 L
.95 .02381 L
F
0 g
.925 .02381 m
.925 .02842 L
.95 .02842 L
.95 .02381 L
.925 .02381 L
s
1 0 0 r
.95 .02381 m
.95 .02918 L
.975 .02918 L
.975 .02381 L
F
0 g
.95 .02381 m
.95 .02918 L
.975 .02918 L
.975 .02381 L
.95 .02381 L
s
1 0 0 r
.975 .02381 m
.975 .03302 L
1 .03302 L
1 .02381 L
F
0 g
.975 .02381 m
.975 .03302 L
1 .03302 L
1 .02381 L
.975 .02381 L
s
.015 w
0 .97619 m
.04057 .80135 L
.08481 .64704 L
.12636 .53013 L
.16632 .43843 L
.20885 .359 L
.2498 .29695 L
.29331 .24354 L
.33524 .20198 L
.37557 .16944 L
.41848 .14132 L
.4598 .11939 L
.49953 .10217 L
.54183 .08723 L
.58254 .07555 L
.62583 .06548 L
.66752 .05764 L
.70762 .05149 L
.7503 .04617 L
.79139 .04202 L
.83505 .03845 L
.87712 .03567 L
.9176 .0335 L
.96065 .03162 L
1 .03023 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00U?ooool00ol@413o<S8boa0@4002o`000003odA4A?o<c<cooooo04oooooo002Dooooo`03o`00
0?nHV9Sok^k^00;ooooo00?oQhN7oa0@4?ooool0Coooool009Wooooo00?o^[Zjo`000?ooool0Cooo
ool009Cooooo00?oc<c<odA4A?l000000ol000000onHV9Soooooooooo`1>ooooo`00U?ooool01Ol0
003oQhN7okZj^_nj^[[oc<c<05;ooooo002Dooooo`03o`000?nHV9Sooooo00;ooooo00?oc<c<oa0@
4?ooool0Coooool009Cooooo00Ooc<c<odA4A?l0003o0000oa0@4?lb<S;o0000053ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool006Sooooo1?l000000ol@413oooooooooo`0Fooooo`Ko00006Oooool01OnYZJWo
8B4Qo`000?l0003oIVIV01cooooo0_l000000ol@413oooooooooo`0Fooooo`05oiRHV?l@413o0000
o`000?mVIVH01_ooool006[ooooo00?o0000ooooooooool06?ooool00onHV9So0000omgMg@02oooo
o`03oa0@4?oooooooooo01Oooooo00Ko410@olc<c?ooooooooooogMgMomVIVHLooooo`03o`000?oo
oooooooo01Oooooo00Ko410@ohN7QoooooooooooogMgMomVIVH5ooooo`00J_ooool00ol0003ooooo
ooooo`0Iooooo`03ohN7QolQ8B7ok^k^023ooooo00?o0000ooooooooool05_ooool6o`0001gooooo
00?o0000ooooooooool00oooool006[ooooo00?o0000ooooooooool06_ooool00onYZJWo8B4Qonk^
kP0Oooooo`03o`000?oooooooooo01Kooooo00GoA4A4okZj^_ooooooooooo`00000Mooooo`03onk^
k_l0003ooooo00Cooooo001Zooooo`03o`000?oooooooooo01_ooooo00?oV9RHoc8b<_ooool07Ooo
ool00onYZJWoA4A4ooooo`0Gooooo`05omgMgOlQ8B7oooooooooool000006Oooool01_l@413oV9RH
ooooooooooooMgMgofIVIPGooooo001Zooooo`03o`000?oooooooooo01cooooo00?oA4A4ogMgMooo
ool06_ooool01?lQ8B7o0000o`000?oMgMdIooooo`04ogMgMonHV9Soooooo`0001Wooooo00Go0000
ob4Q8Ol0003o0000ofIVIP06ooooo`00J_ooool00ol0003oooooooooo`0Looooo`03omgMgOl@413o
oooo01cooooo00?oZJVYoc8b<_ooool06?ooool01?o^k^ko8B4Qooooool0000Iooooo`03o`000?oo
oooooooo00Sooooo001Zooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Hooooo`03ogMgMonHV9So000001Wooooo00?o0000ooooooooool02?ooool0
06Sooooo00?o0000odA4A?l000006_ooool01_l0003oQhN7onk^k_ooooooV9RHoeEEEAWooooo00Ko
8B4QokZj^_ooooooooooofIVI_lb<S8Jooooo`03onk^k_lb<S;o000001Wooooo00?o0000oooooooo
ool02?ooool006Sooooo00?oc<c<oeEEEOl000006_ooool01_nYZJWo<S8bo`000?l0003oEEEEonk^
kQWooooo00Ko^[ZjodA4A?l0003o0000odA4A?o^k^hKooooo`03oiRHV?l@413ooooo01Sooooo1Ol0
0006ooooo`00joooool00>_ooooo003[ooooo`00joooool004goooooUol00007ooooo`00@oooool0
1?nHV9So0000o`000?nHV9P6ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool004;ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`03o`000?oooooooooo09?ooooo
00?o0000ooooooooool01Oooool004;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03
o`000?oooooooooo09?ooooo00?o0000ooooooooool01Oooool004;ooooo00Ko0000onk^k_oooooo
ooooonk^k_l00005oooooiOo00001oooool004;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003
ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`00
0?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00
ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l00000
0ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000_oo00001Ol0
003oo`00ool00?oo003o000000?oo`0000Go0000ool00?oo003oo`00o`000002ool00005o`000?oo
003oo`00ool00?l000000ooo00001Ol0003oo`00ool00?oo003o000000;oo`0000Go0000ool00?oo
003oo`00o`000003ool000Go00000_oo000Ho`0000Oooooo0012ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool0
0?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o0000
0ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0
003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool0
0?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o0000
00;oo`0000Go0000ool00?oo003oo`00o`000003ool00005o`000?oo003oo`00ool00?l000000_oo
00001Ol0003oo`00ool00?oo003o000000?oo`0000Go0000ool00?oo003oo`00o`000002ool00003
o`000?oo003oo`00023o00000oooool00ol0003oooooooooo`05ooooo`00@_ooool01_l0003ok^k^
ooooooooooook^k^o`0000Gooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003o
o`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?o
o`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000
ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003o
o`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000002
ool00005o`000?oo003oo`00ool00?l000000ooo00001Ol0003oo`00ool00?oo003o000000;oo`00
1Ol00003ool00003o`000?oo003oo`0001Co00005_ooool00ol0003oooooooooo`05ooooo`00@_oo
ool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00Go0000ool00?oo003oo`00o`000003ool0
0004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo
003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`00
00?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go
0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo
003oo`00o`000002ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?oo
0004o`0000?ooooo3ol0000Rooooo`03o`000?oooooooooo00Gooooo0012ooooo`06okZj^_lQ8B7o
gMgMomgMgOlQ8B7o^[Zj1Oooool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo
003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo
00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003o
o`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo
003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000;o
o`0000Go0000ool00?oo003oo`00o`000003ool00006o`000?oo003oo`00ool00?l0003ooooo3_l0
000Xooooo`03o`000?oooooooooo00Gooooo0013ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00Go
0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo
003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`00
0003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004
o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003o
o`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000002ool000Go00000ooo000=o`0002oooooo
00?o0000ooooooooool01Oooool004gooooo00Go0000ool00?oo003oo`00o`000003ool00004o`00
0?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00
o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`00
00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool0
0?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00
o`000002ool00003o`000?oooooooooo00co0000=?ooool2o`0000Oooooo001=ooooo`05o`000?oo
003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool0
0?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo
00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003o
o`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l0
0003ool00005o`000?oo003oo`00ool00?l000000_oo0009o`0003_ooooo00?o0000ooooooooool0
1Oooool004gooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?o
o`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000
ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003o
o`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003
ool00004o`000?oo003oo`00o`0000?oo`0000Co0000ool00?oo003oo`003?l0000kooooo`03o`00
0?oooooooooo00Gooooo001=ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00
ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003
ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`00
0?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00
ool00?l000000ooo00001?l0003oo`00ool00?l00003ool000So0000@oooool00ol0003ooooooooo
o`05ooooo`00COooool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o0000
0ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0
003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool0
0?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o0000
00?oo`0000Go0000ool00?oo003o0000ool00007o`0004Kooooo00?o0000ooooooooool01Oooool0
04gooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go
0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo
003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`00
0003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool000Wo
0000BOooool00ol0003oooooooooo`05ooooo`00COooool01Ol0003oo`00ool00?oo003o000000?o
o`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000
ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o
00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo0000
1Ol0003oo`00ool00?oo003o000000?oo`001_l0001<ooooo`03o`000?oooooooooo00Gooooo001=
ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`00
0?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00
ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l00000
0ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000_oo0005o`00
04gooooo0_l00007ooooo`00COooool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool0
0?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o0000
0ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0
003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001?l0003oo`00ool0
0?oo0006o`00053ooooo00?o0000ooooooooool01Oooool004gooooo00Go0000ool00?oo003oo`00
o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool0
0004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo
003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`00
00?oo`0000?o0000ool00?oo00001Ol0001Booooo`03o`000?oooooooooo00Gooooo001=ooooo`05
o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003o
o`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l0
00000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo0000
1?l0003oo`00ool00?l00003ool000Ko0000E?ooool00ol0003oooooooooo`05ooooo`00COooool0
1Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00
ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o
000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`00
00Co0000ool00?oo003o00000_oo0006o`0005Gooooo00?o0000ooooooooool01Oooool004gooooo
00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool0
0?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00
o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool0
0003o`000?oo003oo`0000Ko00000_oo00000ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
00Gooooo001=ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003
ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`00
0?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00
ool00?l000000ooo00000ol0003oo`00ool00005o`0000?oo`0000?o0000ooooooooool0Doooool0
0ol0003oooooooooo`05ooooo`00COooool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000
ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o
00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo0000
1Ol0003oo`00ool00?oo003o000000?oo`001_l000000ooooooo0000o`000003o`0005Cooooo0_l0
0007ooooo`00COooool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o0000
0ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0
003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool0
0?oo003o000000?oo`001?l0001Mooooo`03o`000?oooooooooo00Gooooo001=ooooo`05o`000?oo
003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool0
0?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo
00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000_oo0003o`0005oo
oooo00?o0000ooooooooool01Oooool004gooooo00Go0000ool00?oo003oo`00o`000003ool00004
o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003o
o`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?o
o`0000Co0000ool00?oo003oo`001Ol0001Pooooo`03o`000?oooooooooo00Gooooo000`ooooo`04
oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01Oooool6o`0000Gooooo00Go0000ool0
0?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00
o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool0
0004o`000?oo003oo`00o`0000?oo`0000Co0000ool00?oo003oo`001?l0001Qooooo`03o`000?oo
oooooooo00Gooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Gooooo
00?oV9RHo`000?oMgMd00_ooool00ol@413oooooooooo`03ooooo`05o`000?oo003oo`00ool00?l0
00000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo0000
1?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00
ool00?l00003ool00004o`000?oo003oo`00ool000?o0000H_ooool00ol0003oooooooooo`05oooo
o`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool0
0on7QhOo8B4Qonk^kP07ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool0
0?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool0
0005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00003o`000?oo
003oo`0000?o0000Hoooool00ol0003oooooooooo`05ooooo`00;oooool01_l0003ok^k^oooooooo
ooook^k^o`0000oooooo00?oZJVYob4Q8Oo^k^h01_ooool01Ol0003oo`00ool00?oo003o000000?o
o`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000
ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o
00000ooo00000ol0003oo`00o`000002o`0006?ooooo0_l00007ooooo`00;oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00kooooo00?oV9RHoc8b<_ooool01Oooool01Ol0003oo`00
ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o
000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`00
00Co0000ool00?oo003o00000ooo0005o`0006Cooooo00?o0000ooooooooool01Oooool002oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03odA4A?mgMgOooooo00Cooooo
00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool0
0?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00
o`000003ool00004o`000?oo003oo`00o`0000?oo`001Ol0001Tooooo`03o`000?oooooooooo00Go
oooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00004Oooool00ooMgMgo410@ooooo`04oooo
o`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo
003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool0
0?l000000ooo00001?l0003oo`00ool00?l00002ool000?o0000Ioooool00ol0003oooooooooo`05
ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A1;ooooo00?o0000ooooooooool00ooo
ool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003o
o`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo
003o000000?oo`0000Go0000ool00?oo003o0000ool00003o`0006Sooooo00?o0000ooooooooool0
1Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X=ooooo`06o`000?n7QhOok^k^oooo
oonHV9SoEEEE1Oooool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o0000
0ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0
003oo`00ool00?oo003o000000?oo`0000Go0000ool00?oo003o0000ool00003o`0006Sooooo00?o
0000ooooooooool01Oooool0033ooooo00CoV9RHo`000?l0003oV9RH3_ooool01_nYZJWo<S8bo`00
0?l0003oEEEEonk^kPGooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00
o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`00
00Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000Go0000J?ooool00ol0003o
ooooooooo`05ooooo`00COooool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo
003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo
00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00001Ol0001Wooooo`;o0000
1oooool004gooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?o
o`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000
ool00?oo003oo`00o`000003ool000Go0000Joooool00ol0003oooooooooo`05ooooo`00COooool0
1Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00
ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o
000000?oo`0000Co0000ooooool0003o0000K?ooool00ol0003oooooooooo`05ooooo`00COooool0
1Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00
ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o
000000?oo`001?l0001/ooooo`03o`000?oooooooooo00Gooooo001=ooooo`05o`000?oo003oo`00
ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l00000
0ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo0003o`00
06gooooo00?o0000ooooooooool01Oooool004gooooo00Go0000ool00?oo003oo`00o`000003ool0
0004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo
003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000002ool000?o0000K_ooool00ol0003o
ooooooooo`05ooooo`00COooool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo
003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo
00001Ol0003oo`00ool00?oo003o000000;oo`000_l0001_ooooo`03o`000?oooooooooo00Gooooo
001=ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005
o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00006o`000?oo003o
o`00ool00?l0003oo`000ol0001^ooooo`;o00001oooool004gooooo00Go0000ool00?oo003oo`00
o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool0
0004o`000?oo003oo`00o`0000?oo`0000Co0000ool00?oo003oo`001Ol0001_ooooo`03o`000?oo
oooooooo00Gooooo001=ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool0
0?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool0
0004o`000?oo003oo`00ool000?o000000?oo`00o`000?ooool0K_ooool00ol0003oooooooooo`05
ooooo`00COooool01Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo
00001Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001?l0003o
o`00ool00?oo0005o`0006oooooo00?o0000ooooooooool01Oooool004gooooo00Go0000ool00?oo
003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`00
0003ool00004o`000?oo003oo`00o`0000?oo`0000?o0000ool00?oo00000ol0001booooo`03o`00
0?oooooooooo00Gooooo001=ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00
ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003
ool000Go0000Loooool00ol0003oooooooooo`05ooooo`00COooool01Ol0003oo`00ool00?oo003o
000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`00
00Co0000ool00?oo003o00000ooo00001?l0003oooooo`000?l0001dooooo`03o`000?oooooooooo
00Gooooo001=ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003
ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool000Co0000
Loooool2o`0000Oooooo001=ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00
ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003
ool000?o0000MOooool00ol0003oooooooooo`05ooooo`00COooool01Ol0003oo`00ool00?oo003o
000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`00
00Co0000ool00?oo003o00000ooo0002o`0007Kooooo00?o0000ooooooooool01Oooool004gooooo
00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool0
0?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000;oo`000ol0001fooooo`03o`000?oo
oooooooo00Gooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED02Ooo
ool2o`000003oa0@4?oooooooooo00;ooooo00Go0000ool00?oo003oo`00o`000003ool00004o`00
0?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00
o`0000;oo`000_l0001gooooo`03o`000?oooooooooo00Gooooo000_ooooo`06okZj^_lQ8B7ogMgM
omgMgOlQ8B7o^[Zj1Oooool3o`0000[ooooo00?o0000ooooooooool00oooool01Ol0003oo`00ool0
0?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o0000
00?oo`0000Go0000ool00?oo003o0000ool00003o`0007Oooooo00?o0000ooooooooool01Oooool0
02oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo1_l0
0004ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005
o`000?oo003oo`00ool00?l000000ooo00001Ol0003oo`00ool00?l0003oo`0000?o0000Moooool0
0ol0003oooooooooo`05ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00Go
A4A4okZj^_ooooooooooo`000005ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003o
o`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00005
o`0007Kooooo0_l00007ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00cooooo00GogMgMob4Q8Oooooooooooo`000005ooooo`05o`000?oo003oo`00ool00?l000000ooo
00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003o
o`00ool00003o`0007Wooooo00?o0000ooooooooool01Oooool002oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0=ooooo`04ogMgMonHV9Soooooo`0000Gooooo00Go0000ool00?oo
003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`00
0003ool00003o`000?oo003oo`0000?o0000NOooool00ol0003oooooooooo`05ooooo`00;oooool0
1_l0003ok^k^ooooooooooook^k^o`0000oooooo00Cok^k^ob4Q8Ooooooo00001Oooool01Ol0003o
o`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo
003o000000?oo`0000?o0000ool00?oo00000_l0001jooooo`03o`000?oooooooooo00Gooooo000_
ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A44?ooool00omgMgOoV9RHo`000005ooooo`05o`00
0?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00
ool00?l000000ooo00000ol0003oo`00o`000002o`0007[ooooo00?o0000ooooooooool01Oooool0
02oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X@ooooo`03onk^k_lb<S;o000000Gooooo00Go
0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo
003oo`00o`000003ool00004o`000?oo003o0000o`0007_ooooo00?o0000ooooooooool01Oooool0
033ooooo00CoV9RHo`000?l0003oV9RH4_ooool00onHV9So410@ooooo`04ooooo`05o`000?oo003o
o`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l0
00000ooo0004o`0007_ooooo00?o0000ooooooooool01Oooool004gooooo00Go0000ool00?oo003o
o`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Go0000ool00?oo003oo`00o`000003
ool000Co0000Noooool00ol0003oooooooooo`05ooooo`00COooool01Ol0003oo`00ool00?oo003o
000000?oo`0000Co0000ool00?oo003o00000ooo00001Ol0003oo`00ool00?oo003o000000?oo`00
1?l0001jooooo`;o00001oooool0013ooooo00?o^[Zjoc8b<_ooool03_ooool00olb<S;o^[Zjoooo
o`0Yooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00005
o`000?oo003oo`00ool00?l000000ooo0002o`0007gooooo00?o0000ooooooooool01Oooool0013o
oooo00?o<S8bokZj^_ooool03_ooool00onj^[[o<S8booooo`0Yooooo`05o`000?oo003oo`00ool0
0?l000000ooo00001?l0003oo`00ool00?l00003ool00005o`000?oo003oo`00ool00?l000000_oo
0003o`0007gooooo00?o0000ooooooooool01Oooool000oooooo00?oc<c<oc8b<_ooool04?ooool0
0olb<S;oc<c<ooooo`0Xooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool0
0?l00003ool00005o`000?oo003oo`00ool00?l000000_oo0002o`0007kooooo00?o0000oooooooo
ool01Oooool000;ooooo00Go410@o`000?l0003o0000oa0@4008ooooo`03ofIVI_nYZJWooooo00Co
oooo00?o410@oc8b<_l@41000_l000000om4A4Coc<c<ooooo`04ooooo`03oiRHV?mVIVKooooo02So
oooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Ko0000
ool00?oo003oo`00o`000?oo0003o`0007kooooo00?o0000ooooooooool01Oooool000Cooooo00?o
0000ooooooooool02?ooool00olb<S;oooooooooo`04ooooo`03o`000?nHV9Sok^k^00;ooooo00?o
QhN7oa0@4?ooool01?ooool00oo^k^ko<S8booooo`0Xooooo`05o`000?oo003oo`00ool00?l00000
0ooo00001?l0003oo`00ool00?l00003ool00006o`000?oo003oo`00ool00?l0003oo`000ol0001n
ooooo`03o`000?oooooooooo00Gooooo0004ooooo`03o`000?oooooooooo00Sooooo00?o<S8boooo
ooooool02Oooool00onj^[[o0000ooooo`05ooooo`03o`000?oooooooooo02Oooooo00Go0000ool0
0?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Ko0000ool00?oo003oo`00
o`000?oo0003o`0007kooooo00?o0000ooooooooool01Oooool000Cooooo0ol000000ol@413oMgMg
onk^kP05ooooo`03oc8b<_oooooooooo00Cooooo00?oc<c<odA4A?l000000ol000000onHV9Sooooo
ooooo`04ooooo`03o`000?oooooooooo02Oooooo00Go0000ool00?oo003oo`00o`000003ool00004
o`000?oo003oo`00o`0000?oo`0000Co0000ool00?oo003oo`001Ol0001mooooo`;o00001oooool0
00Cooooo00Ko0000ooooooooooook^k^ogMgMomEEED5ooooo`03ob4Q8Ooooooooooo00Cooooo00Go
0000ohN7Qonj^[[o^[Zjolc<c008ooooo`03o`000?oooooooooo02Oooooo00Go0000ool00?oo003o
o`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000Co0000ool00?oo003oo`000ol00000
0ooo003o0000ooooo`1mooooo`03o`000?oooooooooo00Gooooo0004ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00olb<S;ok^k^ooooo`04ooooo`03o`000?nHV9Sooooo
00;ooooo00?oc<c<oa0@4?ooool01?ooool00ooMgMgo<S8booooo`0Xooooo`05o`000?oo003oo`00
ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00004o`000?oo003oo`00ool000Go0000
O_ooool00ol0003oooooooooo`05ooooo`001?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?oIVIVoiRHV?ooool01?ooool01oo<c<coA4A4o`000?l0003o410@oc8b<_l0
00001Oooool00onHV9SoIVIVooooo`0Xooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0
003oo`00ool00?l00003ool00004o`000?oo003oo`00ool000;o0000POooool00ol0003ooooooooo
o`05ooooo`001?ooool01_l0003oooooooooooo^k^koMgMgoeEEE@Gooooo00?ogMgMob4Q8Oooool0
4?ooool00ol@413oc<c<ooooo`0Xooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003o
o`00ool00?l00003ool00003o`000?oo003oo`0000?o0000POooool00ol0003oooooooooo`05oooo
o`000_ooool00ol@413o0000o`000002o`000003oa0@4?mgMgOok^k^00Kooooo00?o<S8bokZj^_oo
ool03_ooool00onj^[[o<S8booooo`0Yooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0
003oo`00ool00?l00003ool00003o`000?oo003oo`0000;o0000P_ooool00ol0003oooooooooo`05
ooooo`004?ooool00onj^[[o<S8booooo`0>ooooo`03oc8b<_nj^[[ooooo02Wooooo00Go0000ool0
0?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`0000?o0000ool00?l000000_l0
0022ooooo`03o`000?oooooooooo00Gooooo001=ooooo`05o`000?oo003oo`00ool00?l000000ooo
00001?l0003oo`00ool00?l00003ool00003o`000?oo003o000000;o0000POooool2o`0000Oooooo
001=ooooo`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00003ool00003
o`000?oo003o000000;o0000P_ooool00ol0003oooooooooo`05ooooo`00COooool01Ol0003oo`00
ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo0005o`0008;ooooo00?o0000oooo
ooooool01Oooool004gooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00
o`0000?oo`000ol000000ooo003o0000ooooo`21ooooo`03o`000?oooooooooo00Gooooo000`oooo
o`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01_ooool01_o^k^koEEEEo`000?l0
003oEEEEonk^kPCooooo00Go0000ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`00
00?oo`001Ol00022ooooo`03o`000?oooooooooo00Gooooo000_ooooo`06okZj^_lQ8B7ogMgMomgM
gOlQ8B7o^[Zj1Oooool3o`0000Kooooo0_mgMgL2ooooo`03ogMgMomEEEGooooo00?ooooo00Go0000
ool00?oo003oo`00o`000003ool00004o`000?oo003oo`00o`0000?oo`000ol00024ooooo`03o`00
0?oooooooooo00Gooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo
0000oeEEE@06ooooo`03ob4Q8Ooooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003o
o`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000ooo0002o`0008Gooooo00?o0000
ooooooooool01Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`03o`000?o^
k^kooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003oo`00ool00?oo003o000000?oo`00
00Co0000ool00?oo003o00000ooo0002o`0008Cooooo0_l00007ooooo`00;oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00cooooo00Ko0000oeEEEOo^k^koooooogMgMomEEED4oooo
o`05o`000?oo003oo`00ool00?l000000ooo00001?l0003oo`00ool00?l00002ool000?o0000QOoo
ool00ol0003oooooooooo`05ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00cooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^h4ooooo`05o`000?oo003oo`00ool00?l0
00000ooo00001?l0003oo`00ool00?l00002ool000;o0000Q_ooool00ol0003oooooooooo`05oooo
o`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00?oA4A4oiRHV?ooool01oooool0
1Ol0003oo`00ool00?oo003o000000?oo`0000Co0000ool00?oo003o00000_oo0002o`0008Kooooo
00?o0000ooooooooool01Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@>ooooo`03
okZj^_lQ8B7ooooo00Oooooo00Go0000ool00?oo003oo`00o`000003ool00005o`000?oo003oo`00
o`000?oo00000ol00026ooooo`03o`000?oooooooooo00Gooooo000_ooooo`06okZj^_lQ8B7ogMgM
omgMgOlQ8B7o^[Zj3oooool00omEEEGo<S8bomgMg@06ooooo`05o`000?oo003oo`00ool00?l00000
0ooo00000ol0003oo`00ool00005o`0008Kooooo00?o0000ooooooooool01Oooool0033ooooo00Co
V9RHo`000?l0003oV9RH4Oooool01?nHV9So8B4Qo`000?lQ8B44ooooo`05o`000?oo003oo`00ool0
0?l000000ooo00001Ol0003oo`00ool00?l0003ooooo00;o0000Qoooool00ol0003oooooooooo`05
ooooo`00COooool01Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00001?l00026
ooooo`;o00001oooool004gooooo00Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003o
o`0000?o0000R?ooool00ol0003oooooooooo`05ooooo`00COooool01Ol0003oo`00ool00?oo003o
000000?oo`0000?o0000ool00?oo00000ol00028ooooo`03o`000?oooooooooo00Gooooo001=oooo
o`05o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00003o`0008Sooooo00?o0000
ooooooooool01Oooool004gooooo00Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003o
o`0000?o0000R?ooool00ol0003oooooooooo`05ooooo`00COooool01Ol0003oo`00ool00?oo003o
000000?oo`0000?o0000ool00?oo00000_l00029ooooo`03o`000?oooooooooo00Gooooo001=oooo
o`05o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002o`0008Wooooo00?o0000
ooooooooool01Oooool004gooooo00Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003o
000000;o0000R?ooool2o`0000Oooooo001=ooooo`05o`000?oo003oo`00ool00?l000000ooo0000
1?l0003oo`00o`000?l0002:ooooo`03o`000?oooooooooo00Gooooo001=ooooo`05o`000?oo003o
o`00ool00?l000000ooo00001?l0003oo`00o`000?l0002:ooooo`03o`000?oooooooooo00Gooooo
001=ooooo`05o`000?oo003oo`00ool00?l000000ooo0004o`0008[ooooo00?o0000ooooooooool0
1Oooool004gooooo00Go0000ool00?oo003oo`00o`000003ool000Co0000R_ooool00ol0003ooooo
ooooo`05ooooo`00COooool01Ol0003oo`00ool00?oo003o000000?oo`001?l0002:ooooo`03o`00
0?oooooooooo00Gooooo001=ooooo`05o`000?oo003oo`00ool00?l000000ooo0004o`0008[ooooo
00?o0000ooooooooool01Oooool004gooooo00Go0000ool00?oo003oo`00o`000003ool000;o0000
00?oo`00o`000?ooool0R?ooool2o`0000Oooooo001=ooooo`05o`000?oo003oo`00ool00?l00000
0ooo0002o`000003ool00?l0003ooooo08Wooooo00?o0000ooooooooool01Oooool004gooooo00Go
0000ool00?oo003oo`00o`000003ool000;o000000?oo`00o`000?ooool0ROooool00ol0003ooooo
ooooo`05ooooo`00COooool01Ol0003oo`00ool00?oo003o000000;oo`001Ol0002:ooooo`03o`00
0?oooooooooo00Gooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED0
1_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPCooooo00Go0000ool00?oo003oo`00o`000002
ool000;o0000SOooool00ol0003oooooooooo`05ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo
8B4QokZj^PGooooo0ol00006ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE1?ooool01Ol0003o
o`00ool00?oo003o000000;oo`000_l0002=ooooo`03o`000?oooooooooo00Gooooo000_ooooo`06
odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool01_l0003oo`00ool00?oo003o0000ool000?o0000
SOooool00ol0003oooooooooo`05ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`06o`000?oo003oo`00ool0
0?l0003oo`000ol0002<ooooo`;o00001oooool002oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0<ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE1?ooool01_l0003oo`00ool0
0?oo003o0000ool000?o0000SOooool00ol0003oooooooooo`05ooooo`00;oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00cooooo00?ogMgMo`000?l000000_l000000ooMgMgooooo
ooooo`02ooooo`04o`000?oo003oo`00ool000Go0000SOooool00ol0003oooooooooo`05ooooo`00
;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00Ko<S8bofIVI_o^k^kok^k^ofIVI_lb
<S84ooooo`04o`000?oo003oo`00ool000Go0000SOooool00ol0003oooooooooo`05ooooo`00;ooo
ool01_m4A4CoV9RHooooooooooooV9RHodA4A0kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`04o`000?oo003oo`00ool000?o0000Soooool00ol0003oooooooooo`05oooo
o`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00Ko<S8bofIVI_o^k^kok^k^ofIV
I_lb<S84ooooo`04o`000?oo003oo`00ool000?o0000Soooool00ol0003oooooooooo`05ooooo`00
<?ooool01?nHV9So0000o`000?nHV9P?ooooo`06onk^k_m4A4Co0000o`000?m4A4Cok^k^1?ooool0
1?l0003oo`00ool00?oo0003o`0008oooooo00?o0000ooooooooool01Oooool004gooooo00Co0000
ool00?oo003oo`000_l0002@ooooo`03o`000?oooooooooo00Gooooo001=ooooo`04o`000?oo003o
o`00ool000;o0000Soooool2o`0000Oooooo001=ooooo`04o`000?oo003oo`00ool000;o0000T?oo
ool00ol0003oooooooooo`05ooooo`00COooool00ol0003oo`00ool00003o`00093ooooo00?o0000
ooooooooool01Oooool004gooooo00?o0000ool00?oo00000_l0002Aooooo`03o`000?oooooooooo
00Gooooo001=ooooo`03o`000?oo003oo`0000;o0000TOooool00ol0003oooooooooo`05ooooo`00
COooool00ol0003oo`00ool00002o`00097ooooo00?o0000ooooooooool01Oooool004gooooo00?o
0000ool00?oo00000_l0002Aooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oo003o
000000;o0000T?ooool2o`0000Oooooo001=ooooo`03o`000?oo003o000000;o0000TOooool00ol0
003oooooooooo`05ooooo`00COooool00ol0003oo`00o`000002o`00097ooooo00?o0000oooooooo
ool01Oooool004gooooo00?o0000ool00?l000000_l0002Aooooo`03o`000?oooooooooo00Gooooo
001=ooooo`Go0000TOooool00ol0003oooooooooo`05ooooo`00COooool3o`000003ool00?l0003o
oooo093ooooo00?o0000ooooooooool01Oooool004gooooo0ol000000ooo003o0000ooooo`2@oooo
o`03o`000?oooooooooo00Gooooo001=ooooo`Go0000T?ooool2o`0000Oooooo001=ooooo`?o0000
Toooool00ol0003oooooooooo`05ooooo`00COooool2o`0009Cooooo00?o0000ooooooooool01Ooo
ool004gooooo0_l0002Dooooo`03o`000?oooooooooo00Gooooo0012ooooo`Co000000?o410@oooo
ooooool01?ooool2o`0009Cooooo00?o0000ooooooooool01Oooool004Cooooo00?o0000oooooooo
ool01_ooool2o`0009Cooooo00?o0000ooooooooool01Oooool004Cooooo00?o0000ooooooooool0
1_ooool2o`0009Cooooo00?o0000ooooooooool01Oooool004Cooooo00?o0000ooooooooool01_oo
ool2o`0009?ooooo0_l00007ooooo`00A?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo09?ooooo00?o0000ooooooooool01Oooool004Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`2Cooooo`03o`000?oooooooooo00Gooooo0014ooooo`03o`000?oooooooooo00Ko
ooooUol00007ooooo`00A?ooool00ol0003oooooooooo`2Tooooo`00@_ooool00ol0003oA4A4o`00
002Vooooo`00@_ooool00oo<c<coEEEEo`00002Vooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo0000\
\>"],
  ImageRangeCache->{{{73.4375, 260.438}, {645.938, 458.938}} -> {-5.6802, \
3.59999, 0.033505, 0.00703604}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Random Matrix - GOE", "Section"],

Cell["\<\
In this section we will generate a Gaussian-random real symmetric \
matrix, compute its eigenvalues, calculate the level spacings, and generate a \
histogram of these level spacings.  This histogram closely matches the GOE \
distribution.  Be aware that these calculations take some time (roughly 900 \
seconds on a PowerMac G4 733 MHz).\
\>", "Text"],

Cell[TextData[{
  "First we must construct the matrix.  To do this we need to load the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package entitled \"Continuous Distributions\" that is contained within \
the Statistics package."
}], "Text"],

Cell[BoxData[
    \(<< Statistics`ContinuousDistributions`\)], "Input"],

Cell["\<\
Now we construct and n by n random real symmetric matrix.  Each \
matrix element is a random number and these numbers are Gaussian distributed \
with a mean of zero and a standard deviation of one (except the diagonal \
elements which have a standard deviation of square root of 2).  Here we \
generate a 3000 by 3000 matrix.  Once the matrix is generated we can find its \
eigenvalues and sort them.\
\>", "Text"],

Cell[BoxData[{
    \(\(n = 3000;\)\), "\n", 
    \(\(M = 
        Table[Which[i \[Equal] j, Random[NormalDistribution[0, 1]], i < j, 
            Random[NormalDistribution[0, 1/Sqrt[2]]], i > j, 0], {i, 1, 
            n}, {j, 1, n}];\)\), "\n", 
    \(\(MFull = 
        Table[Which[i \[GreaterEqual] j, M[\([j, i]\)], i < j, 
            M[\([i, j]\)]], {i, 1, n}, {j, 1, 
            n}];\)\), "\[IndentingNewLine]", 
    \(\(GOEev = Sort[Eigenvalues[MFull]];\)\)}], "Input"],

Cell["\<\
As mentioned in the article, the distribution of eigenvalues from a \
random matrix thins out toward the edges.  We can illustrate this by plotting \
a histogram of the density of the eigenvalues, as shown below.  The density \
is clearly much lower near the edges of the range of values.  Indeed, the \
histogram looks very much like a semicircle centered at zero.  Note that we \
need to load the Graphics package if it has no already been loaded.\
\>", \
"Text"],

Cell[BoxData[
    \(<< Graphics`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GOEDensity = 
      Histogram[GOEev, HistogramCategories \[Rule] 25, 
        HistogramScale \[Rule] n, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<E\>", "\<\[Rho](E)\>"}, 
        RotateLabel \[Rule] False]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00625 0.0147151 0.023734 [
[.125 -0.0125 -16.8125 -18 ]
[.125 -0.0125 16.8125 0 ]
[.25 -0.0125 -16.8125 -18 ]
[.25 -0.0125 16.8125 0 ]
[.375 -0.0125 -16.8125 -18 ]
[.375 -0.0125 16.8125 0 ]
[.5 -0.0125 -6.78125 -18 ]
[.5 -0.0125 6.78125 0 ]
[.625 -0.0125 -11.5625 -18 ]
[.625 -0.0125 11.5625 0 ]
[.75 -0.0125 -11.5625 -18 ]
[.75 -0.0125 11.5625 0 ]
[.875 -0.0125 -11.5625 -18 ]
[.875 -0.0125 11.5625 0 ]
[1 -0.0125 -11.5625 -18 ]
[1 -0.0125 11.5625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .13339 -13.5625 -9 ]
[-0.0125 .13339 0 9 ]
[-0.0125 .25206 -23.125 -9 ]
[-0.0125 .25206 0 9 ]
[-0.0125 .37073 -23.125 -9 ]
[-0.0125 .37073 0 9 ]
[-0.0125 .4894 -23.125 -9 ]
[-0.0125 .4894 0 9 ]
[-0.0125 .60807 -23.125 -9 ]
[-0.0125 .60807 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -65.375 -9 ]
[-0.01875 .30902 -23.125 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
gsave
.125 -0.0125 -77.8125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
73.500 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -77.8125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
73.500 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.375 0 m
.375 .00625 L
s
gsave
.375 -0.0125 -77.8125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
73.500 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.625 0 m
.625 .00625 L
s
gsave
.625 -0.0125 -72.5625 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -72.5625 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.875 0 m
.875 .00625 L
s
gsave
.875 -0.0125 -72.5625 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -72.5625 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.125 Mabswid
.03125 0 m
.03125 .00375 L
s
.0625 0 m
.0625 .00375 L
s
.09375 0 m
.09375 .00375 L
s
.15625 0 m
.15625 .00375 L
s
.1875 0 m
.1875 .00375 L
s
.21875 0 m
.21875 .00375 L
s
.28125 0 m
.28125 .00375 L
s
.3125 0 m
.3125 .00375 L
s
.34375 0 m
.34375 .00375 L
s
.40625 0 m
.40625 .00375 L
s
.4375 0 m
.4375 .00375 L
s
.46875 0 m
.46875 .00375 L
s
.53125 0 m
.53125 .00375 L
s
.5625 0 m
.5625 .00375 L
s
.59375 0 m
.59375 .00375 L
s
.65625 0 m
.65625 .00375 L
s
.6875 0 m
.6875 .00375 L
s
.71875 0 m
.71875 .00375 L
s
.78125 0 m
.78125 .00375 L
s
.8125 0 m
.8125 .00375 L
s
.84375 0 m
.84375 .00375 L
s
.90625 0 m
.90625 .00375 L
s
.9375 0 m
.9375 .00375 L
s
.96875 0 m
.96875 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13339 m
.00625 .13339 L
s
gsave
-0.0125 .13339 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .25206 m
.00625 .25206 L
s
gsave
-0.0125 .25206 -84.125 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .37073 m
.00625 .37073 L
s
gsave
-0.0125 .37073 -84.125 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .4894 m
.00625 .4894 L
s
gsave
-0.0125 .4894 -84.125 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .60807 m
.00625 .60807 L
s
gsave
-0.0125 .60807 -84.125 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03845 m
.00375 .03845 L
s
0 .06218 m
.00375 .06218 L
s
0 .08592 m
.00375 .08592 L
s
0 .10965 m
.00375 .10965 L
s
0 .15712 m
.00375 .15712 L
s
0 .18085 m
.00375 .18085 L
s
0 .20459 m
.00375 .20459 L
s
0 .22832 m
.00375 .22832 L
s
0 .27579 m
.00375 .27579 L
s
0 .29952 m
.00375 .29952 L
s
0 .32326 m
.00375 .32326 L
s
0 .34699 m
.00375 .34699 L
s
0 .39446 m
.00375 .39446 L
s
0 .41819 m
.00375 .41819 L
s
0 .44193 m
.00375 .44193 L
s
0 .46566 m
.00375 .46566 L
s
0 .51313 m
.00375 .51313 L
s
0 .53686 m
.00375 .53686 L
s
0 .5606 m
.00375 .5606 L
s
0 .58433 m
.00375 .58433 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -126.375 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.125 .61178 m
.125 .61803 L
s
.25 .61178 m
.25 .61803 L
s
.375 .61178 m
.375 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.625 .61178 m
.625 .61803 L
s
.75 .61178 m
.75 .61803 L
s
.875 .61178 m
.875 .61803 L
s
.125 Mabswid
.03125 .61428 m
.03125 .61803 L
s
.0625 .61428 m
.0625 .61803 L
s
.09375 .61428 m
.09375 .61803 L
s
.15625 .61428 m
.15625 .61803 L
s
.1875 .61428 m
.1875 .61803 L
s
.21875 .61428 m
.21875 .61803 L
s
.28125 .61428 m
.28125 .61803 L
s
.3125 .61428 m
.3125 .61803 L
s
.34375 .61428 m
.34375 .61803 L
s
.40625 .61428 m
.40625 .61803 L
s
.4375 .61428 m
.4375 .61803 L
s
.46875 .61428 m
.46875 .61803 L
s
.53125 .61428 m
.53125 .61803 L
s
.5625 .61428 m
.5625 .61803 L
s
.59375 .61428 m
.59375 .61803 L
s
.65625 .61428 m
.65625 .61803 L
s
.6875 .61428 m
.6875 .61803 L
s
.71875 .61428 m
.71875 .61803 L
s
.78125 .61428 m
.78125 .61803 L
s
.8125 .61428 m
.8125 .61803 L
s
.84375 .61428 m
.84375 .61803 L
s
.90625 .61428 m
.90625 .61803 L
s
.9375 .61428 m
.9375 .61803 L
s
.96875 .61428 m
.96875 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13339 m
1 .13339 L
s
.99375 .25206 m
1 .25206 L
s
.99375 .37073 m
1 .37073 L
s
.99375 .4894 m
1 .4894 L
s
.99375 .60807 m
1 .60807 L
s
.125 Mabswid
.99625 .03845 m
1 .03845 L
s
.99625 .06218 m
1 .06218 L
s
.99625 .08592 m
1 .08592 L
s
.99625 .10965 m
1 .10965 L
s
.99625 .15712 m
1 .15712 L
s
.99625 .18085 m
1 .18085 L
s
.99625 .20459 m
1 .20459 L
s
.99625 .22832 m
1 .22832 L
s
.99625 .27579 m
1 .27579 L
s
.99625 .29952 m
1 .29952 L
s
.99625 .32326 m
1 .32326 L
s
.99625 .34699 m
1 .34699 L
s
.99625 .39446 m
1 .39446 L
s
.99625 .41819 m
1 .41819 L
s
.99625 .44193 m
1 .44193 L
s
.99625 .46566 m
1 .46566 L
s
.99625 .51313 m
1 .51313 L
s
.99625 .53686 m
1 .53686 L
s
.99625 .5606 m
1 .5606 L
s
.99625 .58433 m
1 .58433 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .06218 L
.03125 .06218 L
.03125 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .06218 L
.03125 .06218 L
.03125 .01472 L
0 .01472 L
s
1 0 0 r
.03125 .01472 m
.03125 .22357 L
.0625 .22357 L
.0625 .01472 L
F
0 g
.03125 .01472 m
.03125 .22357 L
.0625 .22357 L
.0625 .01472 L
.03125 .01472 L
s
1 0 0 r
.0625 .01472 m
.0625 .30427 L
.09375 .30427 L
.09375 .01472 L
F
0 g
.0625 .01472 m
.0625 .30427 L
.09375 .30427 L
.09375 .01472 L
.0625 .01472 L
s
1 0 0 r
.09375 .01472 m
.09375 .36123 L
.125 .36123 L
.125 .01472 L
F
0 g
.09375 .01472 m
.09375 .36123 L
.125 .36123 L
.125 .01472 L
.09375 .01472 L
s
1 0 0 r
.125 .01472 m
.125 .39921 L
.15625 .39921 L
.15625 .01472 L
F
0 g
.125 .01472 m
.125 .39921 L
.15625 .39921 L
.15625 .01472 L
.125 .01472 L
s
1 0 0 r
.15625 .01472 m
.15625 .44193 L
.1875 .44193 L
.1875 .01472 L
F
0 g
.15625 .01472 m
.15625 .44193 L
.1875 .44193 L
.1875 .01472 L
.15625 .01472 L
s
1 0 0 r
.1875 .01472 m
.1875 .4799 L
.21875 .4799 L
.21875 .01472 L
F
0 g
.1875 .01472 m
.1875 .4799 L
.21875 .4799 L
.21875 .01472 L
.1875 .01472 L
s
1 0 0 r
.21875 .01472 m
.21875 .50364 L
.25 .50364 L
.25 .01472 L
F
0 g
.21875 .01472 m
.21875 .50364 L
.25 .50364 L
.25 .01472 L
.21875 .01472 L
s
1 0 0 r
.25 .01472 m
.25 .52737 L
.28125 .52737 L
.28125 .01472 L
F
0 g
.25 .01472 m
.25 .52737 L
.28125 .52737 L
.28125 .01472 L
.25 .01472 L
s
1 0 0 r
.28125 .01472 m
.28125 .54161 L
.3125 .54161 L
.3125 .01472 L
F
0 g
.28125 .01472 m
.28125 .54161 L
.3125 .54161 L
.3125 .01472 L
.28125 .01472 L
s
1 0 0 r
.3125 .01472 m
.3125 .5606 L
.34375 .5606 L
.34375 .01472 L
F
0 g
.3125 .01472 m
.3125 .5606 L
.34375 .5606 L
.34375 .01472 L
.3125 .01472 L
s
1 0 0 r
.34375 .01472 m
.34375 .57958 L
.375 .57958 L
.375 .01472 L
F
0 g
.34375 .01472 m
.34375 .57958 L
.375 .57958 L
.375 .01472 L
.34375 .01472 L
s
1 0 0 r
.375 .01472 m
.375 .57958 L
.40625 .57958 L
.40625 .01472 L
F
0 g
.375 .01472 m
.375 .57958 L
.40625 .57958 L
.40625 .01472 L
.375 .01472 L
s
1 0 0 r
.40625 .01472 m
.40625 .58908 L
.4375 .58908 L
.4375 .01472 L
F
0 g
.40625 .01472 m
.40625 .58908 L
.4375 .58908 L
.4375 .01472 L
.40625 .01472 L
s
1 0 0 r
.4375 .01472 m
.4375 .59857 L
.46875 .59857 L
.46875 .01472 L
F
0 g
.4375 .01472 m
.4375 .59857 L
.46875 .59857 L
.46875 .01472 L
.4375 .01472 L
s
1 0 0 r
.46875 .01472 m
.46875 .59857 L
.5 .59857 L
.5 .01472 L
F
0 g
.46875 .01472 m
.46875 .59857 L
.5 .59857 L
.5 .01472 L
.46875 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .60332 L
.53125 .60332 L
.53125 .01472 L
F
0 g
.5 .01472 m
.5 .60332 L
.53125 .60332 L
.53125 .01472 L
.5 .01472 L
s
1 0 0 r
.53125 .01472 m
.53125 .58908 L
.5625 .58908 L
.5625 .01472 L
F
0 g
.53125 .01472 m
.53125 .58908 L
.5625 .58908 L
.5625 .01472 L
.53125 .01472 L
s
1 0 0 r
.5625 .01472 m
.5625 .60332 L
.59375 .60332 L
.59375 .01472 L
F
0 g
.5625 .01472 m
.5625 .60332 L
.59375 .60332 L
.59375 .01472 L
.5625 .01472 L
s
1 0 0 r
.59375 .01472 m
.59375 .58433 L
.625 .58433 L
.625 .01472 L
F
0 g
.59375 .01472 m
.59375 .58433 L
.625 .58433 L
.625 .01472 L
.59375 .01472 L
s
1 0 0 r
.625 .01472 m
.625 .57484 L
.65625 .57484 L
.65625 .01472 L
F
0 g
.625 .01472 m
.625 .57484 L
.65625 .57484 L
.65625 .01472 L
.625 .01472 L
s
1 0 0 r
.65625 .01472 m
.65625 .5606 L
.6875 .5606 L
.6875 .01472 L
F
0 g
.65625 .01472 m
.65625 .5606 L
.6875 .5606 L
.6875 .01472 L
.65625 .01472 L
s
1 0 0 r
.6875 .01472 m
.6875 .54161 L
.71875 .54161 L
.71875 .01472 L
F
0 g
.6875 .01472 m
.6875 .54161 L
.71875 .54161 L
.71875 .01472 L
.6875 .01472 L
s
1 0 0 r
.71875 .01472 m
.71875 .53212 L
.75 .53212 L
.75 .01472 L
F
0 g
.71875 .01472 m
.71875 .53212 L
.75 .53212 L
.75 .01472 L
.71875 .01472 L
s
1 0 0 r
.75 .01472 m
.75 .49889 L
.78125 .49889 L
.78125 .01472 L
F
0 g
.75 .01472 m
.75 .49889 L
.78125 .49889 L
.78125 .01472 L
.75 .01472 L
s
1 0 0 r
.78125 .01472 m
.78125 .4799 L
.8125 .4799 L
.8125 .01472 L
F
0 g
.78125 .01472 m
.78125 .4799 L
.8125 .4799 L
.8125 .01472 L
.78125 .01472 L
s
1 0 0 r
.8125 .01472 m
.8125 .45142 L
.84375 .45142 L
.84375 .01472 L
F
0 g
.8125 .01472 m
.8125 .45142 L
.84375 .45142 L
.84375 .01472 L
.8125 .01472 L
s
1 0 0 r
.84375 .01472 m
.84375 .4087 L
.875 .4087 L
.875 .01472 L
F
0 g
.84375 .01472 m
.84375 .4087 L
.875 .4087 L
.875 .01472 L
.84375 .01472 L
s
1 0 0 r
.875 .01472 m
.875 .34699 L
.90625 .34699 L
.90625 .01472 L
F
0 g
.875 .01472 m
.875 .34699 L
.90625 .34699 L
.90625 .01472 L
.875 .01472 L
s
1 0 0 r
.90625 .01472 m
.90625 .30427 L
.9375 .30427 L
.9375 .01472 L
F
0 g
.90625 .01472 m
.90625 .30427 L
.9375 .30427 L
.9375 .01472 L
.90625 .01472 L
s
1 0 0 r
.9375 .01472 m
.9375 .21408 L
.96875 .21408 L
.96875 .01472 L
F
0 g
.9375 .01472 m
.9375 .21408 L
.96875 .21408 L
.96875 .01472 L
.9375 .01472 L
s
1 0 0 r
.96875 .01472 m
.96875 .06693 L
1 .06693 L
1 .01472 L
F
0 g
.96875 .01472 m
.96875 .06693 L
1 .06693 L
1 .01472 L
.96875 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo002=ooooo`So0000E_ooool008kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Dooooo`00S_ooool00ol0003oooooooooo`03ooooo`03oa0@4?oooooooooo05Cooooo002>oooo
o`04o`000?oooooooooooa0@45Wooooo002>ooooo`Co0000FOooool008kooooo00Co0000oooooooo
oooo410@FOooool008kooooo00?o0000ooooooooool00oooool00ol@413oooooooooo`1Dooooo`00
S_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Cooooo002=ooooo`So0000E_oo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool005Gooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h5ooooo`04oiRHV?l0003o0000oiRH
V0Oooooo0_l000000ol@413oooooooooo`03ooooo`04oiRHV?l0003o0000oiRHV0?ooooo1_l00006
ooooo`04oiRHV?l0003o0000oiRHV0Gooooo00CoV9RHo`000?l0003oV9RH2Oooool6o`0000Kooooo
00CoV9RHo`000?l0003oV9RH1oooool2o`000003oa0@4?oooooooooo00?ooooo00CoV9RHo`000?l0
003oV9RH1?ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPGooooo00CoV9RHo`000?l0003oV9RH
1?ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPGooooo00CoV9RHo`000?l0003oV9RH1_ooool0
05Gooooo0_mgMgL2ooooo`03ogMgMomEEEGooooo00?ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj
^[X7ooooo`03o`000?oooooooooo00?ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X2ooooo`03
oiRHV?l0003ogMgM00;ooooo00?o410@ooooooooool00oooool01_nj^[[o8B4QomgMgOoMgMgo8B4Q
okZj^P?ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X8ooooo`03oiRHV?l0003ogMgM00;ooooo
00?o410@ooooooooool00oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^POooooo00?o0000oooo
ooooool00oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^P?ooooo0_mgMgL2ooooo`03ogMgMomE
EEGooooo00?ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X3ooooo`06oeEEEOmgMgOooooooooo
oomgMgOoEEEE1?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo001Eooooo`03ob4Q8Ooo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0?o
oooo1_l00004ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A40oooool00on7QhOo8B4Qonk^kP07
ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A40oooool01_m4A4CoV9RHooooooooooooV9RHodA4
A0Wooooo00?oQhN7ob4Q8Oo^k^h01oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0?ooooo1_l0
0004ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A40oooool00olQ8B7oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@3ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo
001:ooooo`Ko00001Oooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo00Ko000000?o
k^k^o`000?ooool00_ooool01Om4A4Co^[Zjoooooooooooo000000Cooooo1ol00004ooooo`03ojVY
ZOlQ8B7ok^k^00Kooooo00Ko0000onk^k_ooooooooooonk^k_l00003ooooo`06o`000?o^k^kooooo
ooooooo^k^ko00002_ooool00onYZJWo8B4Qonk^kP06ooooo`06o`000?o^k^koooooooooooo^k^ko
00000oooool01Om4A4Co^[Zjoooooooooooo000000Gooooo00Ko0000onk^k_ooooooooooonk^k_l0
0003ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool00_ooool01_l0003ok^k^oooo
ooooooook^k^o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`06
o`000?o^k^koooooooooooo^k^ko00001Oooool005Gooooo00Ko0000oeEEEOo^k^koooooogMgMomE
EED4ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooomgMgOlQ8B42ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
oiRHV?lb<S;ooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool02Oooool00onHV9So<S8booooo`05ooooo`03o`000?oooooooooo
00;ooooo00Ko0000ooooooooooooooooomgMgOlQ8B42ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool02_l0003ooooooooooooooooo0000oeEEEOo^k^koooooogMgMomEEED4
ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooooooooeEEEOmgMgL2ooooo`03ogMg
MomEEEGooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`00EOoo
ool01_l0003oMgMgo`000?l0003oEEEEonk^kPCooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`04ogMgMonHV9Soooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03odA4A?mgMgOooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02_ooool00om4A4CoMgMgooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?mgMgOoV9RHooooool0
0005ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooo`000?mgMgL2o`000003
oeEEEOo^k^kooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooogMgM
00Co000000?ogMgMooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo001Eooooo`03odA4A?nHV9Sooooo00Oooooo00Ko0000onk^k_ooooooooooonk^k_l00004
ooooo`04onk^k_lQ8B7oooooo`0000Gooooo00Ko0000onk^k_ooooooooooonk^k_l00006ooooo`03
omgMgOl@413ooooo00Cooooo00Ko0000onk^k_ooooooooooonk^k_l00003ooooo`06o`000?o^k^ko
ooooooooooo^k^ko00003?ooool00ooMgMgo410@ooooo`04ooooo`06o`000?o^k^koooooooooooo^
k^ko00001?ooool01?o^k^ko8B4Qooooool00005ooooo`06o`000?o^k^koooooooooooo^k^ko0000
0oooool00om4A4CoV9RHooooo`07ooooo`06o`000?o^k^koooooooooooo^k^ko00000oooool01_lb
<S;oIVIVonk^k_o^k^koIVIVoc8b<PCooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooo`00
EOooool00onj^[[o8B4Qooooo`07ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omg
MgOoV9RHo`000005ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41oooool00ol0003ooooooooo
o`03ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A40oooool01_m4A4CoV9RHooooooooooooV9RH
odA4A0gooooo00?o0000ooooooooool00oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo
00?oMgMgoiRHV?l000001Oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0?ooooo00?o^[Zjob4Q
8Oooool01oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool005Kooooo
00?oEEEEoc8b<_oMgMd01_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00?ok^k^oc8b
<_l000001Oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^P;ooooo00Ko0000ohN7Qoo^k^kooooo
oiRHV?mEEED5ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj0oooool01_nj^[[o8B4QomgMgOoM
gMgo8B4QokZj^PSooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED5ooooo`06okZj^_lQ8B7ogMgM
omgMgOlQ8B7o^[Zj1Oooool00oo^k^ko<S8bo`000005ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o
^[Zj1?ooool00omEEEGo<S8bomgMg@06ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj0oooool0
1_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<PCooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5oooo
o`00Eoooool01?nHV9So8B4Qo`000?lQ8B45ooooo`04oiRHV?l0003o0000oiRHV0Oooooo00?oV9RH
oa0@4?ooool01Oooool01?nHV9So0000o`000?nHV9P3ooooo`06ojVYZOlb<S;o0000o`000?mEEEGo
k^k^1_ooool01?nHV9So0000o`000?nHV9P5ooooo`04oiRHV?l0003o0000oiRHV0Wooooo00KoZJVY
oc8b<_l0003o0000oeEEEOo^k^h6ooooo`04oiRHV?l0003o0000oiRHV0Oooooo00?oV9RHoa0@4?oo
ool01Oooool01?nHV9So0000o`000?nHV9P6ooooo`04oiRHV?lQ8B7o0000ob4Q8@Gooooo00CoV9RH
o`000?l0003oV9RH1?ooool01_o^k^koA4A4o`000?l0003oA4A4onk^kPGooooo00CoV9RHo`000?l0
003oV9RH1_ooool00>_ooooo003[ooooo`00joooool003Wooooo00CoV9RHo`000?l0003oV9RH[_oo
ool003Sooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X6oooooi_o00003?ooool003Sooooo00Ko
A4A4oiRHV?oooooooooooiRHV?m4A4@6ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`00>?ooool01_l0003ok^k^ooooooooooook^k^o`0000KoooooVol0000<
ooooo`00>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oooooooooo00[ooooo000hooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ooooooooool02_ooool003Sooooo00Ko0000onk^k_ooooooooooonk^k_l00006ooooo`03o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0:ooooo`00>?ooool01_m4A4CoV9RHoooo
ooooooooV9RHodA4A0Kooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo
00[ooooo000hooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1_ooool00ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ooooooooool02_ooool003Wooooo00CoV9RHo`000?l0003oV9RH1ooo
ool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool02_ooool004Cooooo00?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo00[ooooo0014ooooo`Ko00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`001_l0000<ooooo`00A?ooool0
0ol0003oooooooooo`02ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000
ooooooooool00_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Co
0000oooooooooooooooo0_l0000<ooooo`00A?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo00;ooooo
00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool00_ooool01Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00[ooooo0014ooooo`03o`000?oooooooooo00;ooooo00Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0:ooooo`00A?ooool00ol0003oooooooooo`02ooooo`05o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00004o`000?ooooooooooooooo`;o00003?ooool003Sooooo
00GoV9RHoa0@4?l0003o0000ofIVIP07ooooo`03o`000?oooooooooo00;ooooo00Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`00>?ooool01_l@413oQhN7ooooooooooooMgMgofIVIPKooooo00?o0000
ooooooooool00_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo000mooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo000l
ooooo`03onk^k_l0003ooooo00Gooooo0_l00003ooooo`05o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00004o`000?ooooooooooooooo`;o00003?ooool003Sooooo00Ko
410@oiRHV?ooooooooooogMgMomVIVH6ooooo`03o`000?oooooooooo00;ooooo00Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`00>?ooool01Ol0003o8B4Qo`000?l0003oIVIV00Oooooo00?o0000oooo
ooooool00_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo000hooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00001?l0003oooooooooooooool2o`0000cooooo000hooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo000h
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00[ooooo000hooooo`Go00001oooool00ol0003oooooooooo`02ooooo`05o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo00;ooooo00?o
0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool00_ooool01Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00001?l0003oooooooooooooool2o`0000cooooo
0014ooooo`03o`000?oooooooooo00;ooooo00Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`00A?oo
ool00ol0003oooooooooo`02ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool004Cooooo00?o
0000ooooooooool00_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00Co0000oooooooooooooooo0_l0000<ooooo`00A?ooool00ol0003oooooooooo`02ooooo`05o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo0006o`0000Cooooo00?o0000ooooooooool02_ooool004Cooooo
00?o0000ooooooooool00_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000oooooooo
ool01oooool00ol0003oooooooooo`0:ooooo`00A?ooool00ol0003oooooooooo`02ooooo`Go0000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oooooooooo`06ooooo`;o00003?ooool002oooooo1?l000000ol@413ooooooooo
o`04ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?o0000ooooooooool01_ooool00ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool0037ooooo00?o
0000ooooooooool01Oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00?o0000oooooooo
ool01_ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02_ooool0037ooooo00?o0000ooooooooool01Oooool01_m4A4CoV9RHooooooooooooV9RHodA4
A0Gooooo00?o0000ooooooooool01_ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooooooo
00Oooooo00?o0000ooooooooool02_ooool0037ooooo00?o0000ooooooooool01Oooool01_l0003o
k^k^ooooooooooook^k^o`0000Gooooo0_l00007ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ooooooooool01_ooool2o`0000cooooo000aooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo000aooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Kooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00[ooooo000@ooooo`03okZj^_lb<S;ooooo00kooooo00?o<S8bokZj^_ooool0
3Oooool00ol0003oooooooooo`05ooooo`06o`000?o^k^koooooooooooo^k^ko00001Oooool00ol0
003oooooooooo`06ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool01oooool00ol0
003oooooooooo`0:ooooo`000oooool00ol0003oooooooooo`0:ooooo`03oc8b<_nj^[[ooooo00ko
oooo00?o^[Zjoc8b<_ooool03Oooool00ol0003oooooooooo`05ooooo`06odA4A?nHV9Sooooooooo
oonHV9SoA4A41Oooool00ol0003oooooooooo`06ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ooooooooool01_ooool2o`0000cooooo0003ooooo`03oc8b<_nj^[[ooooo00Wooooo00?oc<c<oc8b
<_ooool04?ooool00olb<S;oc<c<ooooo`0:ooooo`03o`000?m4A4Co000000Oooooo00Ko^[Zjob4Q
8OoMgMgogMgMob4Q8Onj^[X5ooooo`03o`000?oooooooooo00Kooooo00?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo0003ooooo`03ogMgMon7QhOo
MgMg00;o000000?oA4A4olc<c?ooool01?ooool00omVIVKoZJVYooooo`04ooooo`So00001?ooool0
0onHV9SoIVIVooooo`0:ooooo`03olc<c?mEEEGo000000Sooooo00CoV9RHo`000?l0003oV9RH1_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0:ooooo`000oooool02?nHV9So410@ohN7Qoo^k^kooooooiRHV?l@413o
c<c<1?ooool00olb<S;oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00oo^k^ko<S8booooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oooooooooo`06ooooo`;o00003?ooool000?ooooo00?o^[Zjoc8b<_ooool0
0oooool00onHV9SoA4A4ooooo`03ooooo`03oc8b<_oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol@413oooooooooo`03ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
1_ooool6o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Co0000ool00?oo003oo`001_l00009ooooo`03o`00
0?oooooooooo00[ooooo0004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00olb<S;oooooooooo`05ooooo`04o`000?oooooooooooa0@40Sooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`00000>ooooo`03o`000?oooooooooo00[ooooo0004ooooo`03odA4A?nH
V9Sooooo00;ooooo00?ok^k^o`000?ooool00oooool00olQ8B7oooooooooo`05ooooo`Co00002?oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo00?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000kooooo00?o0000ooooooooool02_oo
ool000Cooooo00Oo^[Zjo`000?nj^[[oooooonk^k_mVIVKoEEEE00Cooooo00?o<S8bonk^k_ooool0
1Oooool01?l0003oooooooooool@4107ooooo`03omgMgOlb<S;ooooo01oooooo00?o0000oooooooo
ool02oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00003Oooool2o`0000cooooo0005ooooo`06ojVYZOlQ8B7o0000o`000?mEEEGok^k^1?ooool00omV
IVKoV9RHooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o410@ooooooooool00_ooool00onH
V9SoIVIVooooo`0Oooooo`03o`000?oooooooooo00_ooooo00?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000kooooo00?o0000ooooooooool02_ooool000oo
oooo00?ogMgMob4Q8Oooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o410@olc<c?ooool07oooool00ol0003oooooooooo`0;ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00000>ooooo`03o`000?oooooooooo00[o
oooo000@ooooo`03oc8b<_nj^[[ooooo00?ooooo2?l00003ooooo`03okZj^_lb<S;ooooo023ooooo
00?o0000ooooooooool02oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000003_ooool00ol0003oooooooooo`0:ooooo`004?ooool00onj^[[o<S8boooo
o`0>ooooo`03oc8b<_nj^[[ooooo00_ooooo1?l000000ol@413oooooooooo`03ooooo`05oiRHV?l@
413o0000o`000?mVIVH01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`001Ol0000=ooooo`;o00003?ooool0037ooooo00?o0000ooooooooool01Oooool0
1_l@413oQhN7ooooooooooooMgMgofIVIPGooooo00?o0000ooooooooool02oooool00ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oooooooooo013ooooo00?o0000ooooooooool02_oo
ool0037ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00_ooooo1_l00004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo000aooooo`03
o`000?oooooooooo00Wooooo00?ok^k^o`000?ooool01?ooool2o`00017ooooo00?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ooooooooool03oooool2o`0000cooooo000aooooo`03o`000?oooooooooo00Gooooo00Ko
410@oiRHV?ooooooooooogMgMomVIVH5ooooo`03o`000?oooooooooo013ooooo00?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`00<Oooool00ol0003ooooooooo
o`05ooooo`05o`000?lQ8B7o0000o`000?mVIVH01_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool0037ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`00<Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`0?ooooo`;o00003?ooool002oooooo00?o0000odA4A?l000001ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo1_l00004ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool04?ooool00ol0003oooooooooo`0:
ooooo`00;oooool00oo<c<coEEEEo`000007ooooo`Go00001_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`001_l0000Booooo`03o`000?oooooooooo00[o
oooo0014ooooo`03o`000?oooooooooo01Gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0Doooo
o`;o00003?ooool004Cooooo00?o0000ooooooooool05Oooool00ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool004Cooooo00?o
0000ooooooooool05Oooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooo
oooo01Gooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool05Oooool6o`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oooooooooo01Cooooo0_l0000<ooooo`00A?ooool00ol0003ooooooooo
o`0Jooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool0
04Cooooo00?o0000ooooooooool06_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`001_l0000Gooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`00
0?oooooooooo01[ooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000
ooooooooool06_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ooooooooool06Oooool2o`0000cooooo000^ooooo`Ko00001_ooool01?nHV9So
0000o`000?nHV9P6ooooo`03o`000?oooooooooo01[ooooo00Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo01[ooooo00?o0000oooooooo
ool02_ooool002kooooo00?oV9RHo`000?oMgMd00_ooool00ol@413oooooooooo`03ooooo`06okZj
^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool00ol0003oooooooooo`0Jooooo`Go00001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
1_l0000Looooo`03o`000?oooooooooo00[ooooo000_ooooo`03ohN7QolQ8B7ok^k^00Oooooo00Ko
A4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03o`000?oooooooooo01kooooo00?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`00<?ooool0
0onYZJWo8B4Qonk^kP06ooooo`06o`000?o^k^koooooooooooo^k^ko00001Oooool2o`0001oooooo
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool07_ooool2o`0000cooooo000aoooo
o`03oiRHV?lb<S;ooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01kooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001?l0003oo`00ool00?oo0006o`00027ooooo00?o0000ooooooooool0
2_ooool003;ooooo00?oA4A4ogMgMoooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool07_ooool6o`0000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000009_ooool00ol0003oooooooooo`0:ooooo`00<_ooool00ooMgMgo
410@ooooo`04ooooo`06o`000?o^k^koooooooooooo^k^ko00001Oooool00ol0003oooooooooo`0S
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00009Oooool2o`0000cooooo000cooooo`03o`000?oooooooooo00?ooooo00KoA4A4oiRHV?oooooo
oooooiRHV?m4A4@5ooooo`03o`000?oooooooooo02?ooooo00?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00000Vooooo`03o`000?oooooooooo00[ooooo
000^ooooo`06o`000?n7QhOok^k^oooooonHV9SoEEEE1Oooool01_nj^[[o8B4QomgMgOoMgMgo8B4Q
okZj^PGooooo00?o0000ooooooooool08oooool6o`0000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000002Ko
oooo00?o0000ooooooooool02_ooool002kooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h6oooo
o`04oiRHV?l0003o0000oiRHV0Kooooo00?o0000ooooooooool0:?ooool00ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
1Ol0000Vooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooooooo02Sooooo00?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oooooooooo02Oooooo0_l0000<ooooo`00A?ooool00ol0003ooooo
ooooo`0Xooooo`Ko00001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`001_l0000Zooooo`03o`000?oooooooooo
00[ooooo0014ooooo`03o`000?oooooooooo02gooooo00?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0;Oooool00ol0003oooooooooo`0:ooooo`00A?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
oooooooo02gooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool0;Oooool6
o`0000Coo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`001_l0000^ooooo`;o0000
3?ooool004Cooooo00?o0000ooooooooool0<_ooool00ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo03;ooooo00?o0000oooooooo
ool02_ooool004Cooooo00?o0000ooooooooool0<_ooool:o`0000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`001_l0000dooooo`03o`000?oooooooooo00[o
oooo0014ooooo`03o`000?oooooooooo03_ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`001_l0000hooooo`;o00003?ooool002kooooo1_l00005ooooo`05oiRH
V?l@413o0000o`000?mVIVH01_ooool00ol0003oooooooooo`0kooooo`Ko00001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`001Ol00004ool00003o`000?oooooooooo03co
oooo00?o0000ooooooooool02_ooool002kooooo00?oV9RHo`000?oMgMd00_ooool00ol@413ooooo
ooooo`03ooooo`06oa0@4?n7QhOooooooooooomgMgOoIVIV1Oooool00ol0003oooooooooo`10oooo
o`_o00001?oo00001Ol0003ooooooooooooooooo000000Coo`0000?o0000ooooooooool0??ooool0
0ol0003oooooooooo`0:ooooo`00;oooool00on7QhOo8B4Qonk^kP0<ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0B_ooool6o`0000?ooooo1_l0000nooooo`03o`000?oooooooooo
00[ooooo000`ooooo`03ojVYZOlQ8B7ok^k^00[ooooo00?ok^k^o`000?ooool01?ooool2o`00017o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool03oooool2o`0000cooooo000aooooo`03oiRHV?lb<S;ooooo00Gooooo
00Ko410@oiRHV?ooooooooooogMgMomVIVH5oooooi_o00003?ooool003;ooooo00?oA4A4ogMgMooo
ool01?ooool01Ol0003o8B4Qo`000?l0003oIVIV0:gooooo000booooo`03omgMgOl@413ooooo00Co
oooo00?o0000ooooooooool0[oooool003?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2_ooooo`00;_ooool01_l0003oQhN7onk^k_ooooooV9RHoeEEE@Gooooo00?o0000oooooooo
ool0[oooool002kooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h5ooooo`Go0000[Oooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo0000\
\>"],
  ImageRangeCache->{{{73.4375, 260.438}, {664.562, 477.562}} -> {-246.376, \
139.643, 1.03947, 0.273729}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Below we plot the theoretical density of eigenvalues known as Wigner's \
semicircle law (because the curve takes the shape of a semicircle centered at \
zero with radius ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\@\(2  N\)\)\(,\)\)\)]],
  "where N is the dimension of the random matrix (and hence the number of \
eigenvalues)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(WSC = 
      Plot[Sqrt[2*n - x^2]/\((Pi)\), {x, \(-Sqrt[2*n]\), Sqrt[2*n]}, 
        PlotStyle \[Rule] {Thickness[0.02]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00614759 0.0147151 0.0238725 [
[.03893 .00222 -9 -9 ]
[.03893 .00222 9 0 ]
[.19262 .00222 -9 -9 ]
[.19262 .00222 9 0 ]
[.34631 .00222 -9 -9 ]
[.34631 .00222 9 0 ]
[.65369 .00222 -6 -9 ]
[.65369 .00222 6 0 ]
[.80738 .00222 -6 -9 ]
[.80738 .00222 6 0 ]
[.96107 .00222 -6 -9 ]
[.96107 .00222 6 0 ]
[.4875 .13408 -6 -4.5 ]
[.4875 .13408 0 4.5 ]
[.4875 .25344 -12 -4.5 ]
[.4875 .25344 0 4.5 ]
[.4875 .3728 -12 -4.5 ]
[.4875 .3728 0 4.5 ]
[.4875 .49216 -12 -4.5 ]
[.4875 .49216 0 4.5 ]
[.4875 .61153 -12 -4.5 ]
[.4875 .61153 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03893 .01472 m
.03893 .02097 L
s
[(-75)] .03893 .00222 0 1 Mshowa
.19262 .01472 m
.19262 .02097 L
s
[(-50)] .19262 .00222 0 1 Mshowa
.34631 .01472 m
.34631 .02097 L
s
[(-25)] .34631 .00222 0 1 Mshowa
.65369 .01472 m
.65369 .02097 L
s
[(25)] .65369 .00222 0 1 Mshowa
.80738 .01472 m
.80738 .02097 L
s
[(50)] .80738 .00222 0 1 Mshowa
.96107 .01472 m
.96107 .02097 L
s
[(75)] .96107 .00222 0 1 Mshowa
.125 Mabswid
.06967 .01472 m
.06967 .01847 L
s
.10041 .01472 m
.10041 .01847 L
s
.13114 .01472 m
.13114 .01847 L
s
.16188 .01472 m
.16188 .01847 L
s
.22336 .01472 m
.22336 .01847 L
s
.2541 .01472 m
.2541 .01847 L
s
.28483 .01472 m
.28483 .01847 L
s
.31557 .01472 m
.31557 .01847 L
s
.37705 .01472 m
.37705 .01847 L
s
.40779 .01472 m
.40779 .01847 L
s
.43852 .01472 m
.43852 .01847 L
s
.46926 .01472 m
.46926 .01847 L
s
.53074 .01472 m
.53074 .01847 L
s
.56148 .01472 m
.56148 .01847 L
s
.59221 .01472 m
.59221 .01847 L
s
.62295 .01472 m
.62295 .01847 L
s
.68443 .01472 m
.68443 .01847 L
s
.71517 .01472 m
.71517 .01847 L
s
.7459 .01472 m
.7459 .01847 L
s
.77664 .01472 m
.77664 .01847 L
s
.83812 .01472 m
.83812 .01847 L
s
.86886 .01472 m
.86886 .01847 L
s
.89959 .01472 m
.89959 .01847 L
s
.93033 .01472 m
.93033 .01847 L
s
.00819 .01472 m
.00819 .01847 L
s
.99181 .01472 m
.99181 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .13408 m
.50625 .13408 L
s
[(5)] .4875 .13408 1 0 Mshowa
.5 .25344 m
.50625 .25344 L
s
[(10)] .4875 .25344 1 0 Mshowa
.5 .3728 m
.50625 .3728 L
s
[(15)] .4875 .3728 1 0 Mshowa
.5 .49216 m
.50625 .49216 L
s
[(20)] .4875 .49216 1 0 Mshowa
.5 .61153 m
.50625 .61153 L
s
[(25)] .4875 .61153 1 0 Mshowa
.125 Mabswid
.5 .03859 m
.50375 .03859 L
s
.5 .06246 m
.50375 .06246 L
s
.5 .08633 m
.50375 .08633 L
s
.5 .1102 m
.50375 .1102 L
s
.5 .15795 m
.50375 .15795 L
s
.5 .18182 m
.50375 .18182 L
s
.5 .20569 m
.50375 .20569 L
s
.5 .22957 m
.50375 .22957 L
s
.5 .27731 m
.50375 .27731 L
s
.5 .30118 m
.50375 .30118 L
s
.5 .32506 m
.50375 .32506 L
s
.5 .34893 m
.50375 .34893 L
s
.5 .39667 m
.50375 .39667 L
s
.5 .42055 m
.50375 .42055 L
s
.5 .44442 m
.50375 .44442 L
s
.5 .46829 m
.50375 .46829 L
s
.5 .51604 m
.50375 .51604 L
s
.5 .53991 m
.50375 .53991 L
s
.5 .56378 m
.50375 .56378 L
s
.5 .58765 m
.50375 .58765 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.02 w
.02381 .01496 m
.02499 .05605 L
.02605 .07181 L
.02846 .09674 L
.03279 .12846 L
.03784 .15654 L
.04262 .1785 L
.06244 .24696 L
.08265 .29814 L
.10458 .34268 L
.14545 .40764 L
.1848 .45591 L
.22263 .49316 L
.26292 .52518 L
.30169 .54985 L
.34292 .57037 L
.36351 .57862 L
.38262 .58516 L
.40229 .59079 L
.42082 .59512 L
.44134 .59884 L
.45995 .60123 L
.46971 .60213 L
.47505 .60251 L
.48003 .6028 L
.48428 .603 L
.48883 .60316 L
.49143 .60322 L
.49271 .60325 L
.49389 .60327 L
.49494 .60329 L
.4961 .6033 L
.49726 .60331 L
.4985 .60332 L
.49971 .60332 L
.50085 .60332 L
.50209 .60331 L
.50278 .60331 L
.50341 .6033 L
.50469 .60329 L
.50608 .60327 L
.50859 .60322 L
.51093 .60316 L
.51341 .60309 L
.51785 .60291 L
.52298 .60263 L
.52778 .60232 L
.5387 .60137 L
.54911 .60018 L
.55899 .59879 L
Mistroke
.57753 .59547 L
.59737 .59088 L
.61577 .58566 L
.65495 .57129 L
.69659 .55082 L
.73671 .52545 L
.77531 .49498 L
.81636 .45464 L
.8559 .40577 L
.89393 .34541 L
.91511 .30312 L
.9344 .25583 L
.944 .22745 L
.95442 .19064 L
.9592 .17054 L
.96427 .1456 L
.9686 .11942 L
.97089 .10228 L
.97336 .07874 L
.97408 .07002 L
.97484 .05902 L
.97549 .04674 L
.97619 .01496 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool000Sooooo00?o0000ooooooooool00_ooool3
o`0001_ooooo0ol00004ooooo`;o00006_ooool5o`0000;ooooo0ol0000jooooo`Go00000_ooool3
o`0001_ooooo0ol00004ooooo`;o00007?ooool00ol0003oooooooooo`02ooooo`?o00001oooool0
00Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Oooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001[ooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`03o`000?oooooooooo03Sooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0001_ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Cooooo0005o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`Go
00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo017ooooo1Ol00003oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool000Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo000:
ooooo`03o`000?oooooo000000?o00006_ooool4o`0000?ooooo00Co0000oooooooooooo00006Ooo
ool01_l0003ooooooooooooooooo0000ooooo`Co0000>_ooool01_l0003ooooooooooooooooo0000
ooooo`Co00006_ooool4o`0000?ooooo00Co0000oooooooooooo00007Oooool00ol0003oooooo`00
0003o`0000Oooooo0006ooooo`07o`000?ooooooooooooooool0003oooooo`00000Mooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo00006Oooool01ol0003ooooooooooooooooo0000
ooooool00000?Oooool01ol0003ooooooooooooooooo0000ooooool000007Oooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0001Wooooo00Oo0000ooooooooooooooooo`000?oooooo
000000[ooooo0006ooooo`Go000000?oooooo`000?l000000ol0000Iooooo`Go00000oooool2o`00
01_ooooo0ol00002ooooo`Go0000>_ooool3o`0000;ooooo1Ol0000Iooooo`Go00000oooool2o`00
01[ooooo1Ol000000ooooooo0000o`000003o`0000Kooooo003[ooooo`00MOooool00ol0003ooooo
ooooo`1cooooo`00MOooool00ol0003oooooooooo`1cooooo`000oooool4o`0006kooooo00?o0000
ooooooooool0J_ooool4o`0000Gooooo003[o`00000000?oooooo`000?ooool01?l00002ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooo000000?o00000_ooool1o`00007ooooo0Oooool000?ooooo1?l00002ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooo000000?o00001Oooool000?ooooo1?l0001^ooooo`03o`000?oooooooooo06[ooooo1?l0
0005ooooo`000oooool4o`0006kooooo00?o0000ooooooooool0J_ooool4o`0000Gooooo0003oooo
o`Co0000K_ooool00ol0003oooooooooo`1Zooooo`Co00001Oooool000?ooooo1?l0001^ooooo`03
o`000?oooooooooo06[ooooo1?l00005ooooo`000oooool4o`0006kooooo00?o0000ooooooooool0
J_ooool4o`0000Gooooo0003ooooo`Co0000K_ooool00ol0003oooooooooo`1Zooooo`Co00001Ooo
ool000?ooooo1?l0001^ooooo`03o`000?oooooooooo06[ooooo1?l00005ooooo`000oooool4o`00
06kooooo00?o0000ooooooooool0J_ooool4o`0000Gooooo0003ooooo`Co0000K_ooool00ol0003o
ooooooooo`1Zooooo`Co00001Oooool000?ooooo1Ol0001]ooooo`03o`000?oooooooooo06Wooooo
1Ol00005ooooo`000oooool5o`0006gooooo00?o0000ooooooooool0JOooool5o`0000Gooooo0003
ooooo`Go0000KOooool00ol0003oooooooooo`1Yooooo`Go00001Oooool000Cooooo1?l0001]oooo
o`03o`000?oooooooooo06Wooooo1?l00006ooooo`001?ooool4o`0006gooooo00?o0000oooooooo
ool0JOooool4o`0000Kooooo0004ooooo`Co0000KOooool00ol0003oooooooooo`1Yooooo`Co0000
1_ooool000Cooooo1?l0001]ooooo`03o`000?oooooooooo06Wooooo1?l00006ooooo`001?ooool4
o`0006gooooo00?o0000ooooooooool0JOooool4o`0000Kooooo0004ooooo`Co0000KOooool00ol0
003oooooooooo`1Yooooo`Co00001_ooool000Cooooo1?l0001]ooooo`03o`000?oooooooooo06Wo
oooo1?l00006ooooo`001?ooool4o`0006gooooo00?o0000ooooooooool0JOooool4o`0000Kooooo
0004ooooo`Go0000K?ooool00ol0003oooooooooo`1Xooooo`Go00001_ooool000Cooooo1Ol0001/
ooooo`03o`000?oooooooooo06Sooooo1Ol00006ooooo`001?ooool5o`0006cooooo00?o0000oooo
ooooool0J?ooool5o`0000Kooooo0005ooooo`Co0000I?ooool3o`0000Gooooo00?o0000oooooooo
ool0J?ooool4o`0000Oooooo0005ooooo`Co0000Hoooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0J?ooool4o`0000Oooooo0005ooooo`Co0000Ioooool00ol0003ooooo
ooooo`02ooooo`;o0000J?ooool5o`0000Oooooo0005ooooo`Co0000Ioooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06Oooooo1Ol00007ooooo`001Oooool5o`0006;ooooo1?l00005
ooooo`03o`000?oooooooooo06Oooooo1Ol00007ooooo`001Oooool5o`0006;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Wooooo`Co00002?ooool000Gooooo1Ol0001Rooooo`Go
00001?ooool00ol0003oooooooooo`1Wooooo`Co00002?ooool000Kooooo1?l0001[ooooo`03o`00
0?oooooooooo06Oooooo1?l00008ooooo`001_ooool4o`0006_ooooo00?o0000ooooooooool0I_oo
ool5o`0000Sooooo0006ooooo`Co0000Joooool00ol0003oooooooooo`1Vooooo`Go00002?ooool0
00Kooooo1Ol0001Zooooo`03o`000?oooooooooo06Kooooo1Ol00008ooooo`001_ooool5o`0006[o
oooo00?o0000ooooooooool0I_ooool4o`0000Wooooo0006ooooo`Go0000J_ooool00ol0003ooooo
ooooo`1Vooooo`Co00002Oooool000Oooooo1?l0001Zooooo`03o`000?oooooooooo06Gooooo1Ol0
0009ooooo`001oooool4o`0006[ooooo00?o0000ooooooooool0IOooool5o`0000Wooooo0007oooo
o`Go0000JOooool00ol0003oooooooooo`1Uooooo`Go00002Oooool000Oooooo1Ol0001Yooooo`03
o`000?oooooooooo06Gooooo1?l0000:ooooo`001oooool5o`0006Wooooo00?o0000ooooooooool0
I?ooool5o`0000[ooooo0008ooooo`Go0000J?ooool00ol0003oooooooooo`1Tooooo`Go00002_oo
ool000Sooooo1Ol0001Xooooo`03o`000?oooooooooo06Cooooo1Ol0000:ooooo`002?ooool5o`00
06Sooooo00?o0000ooooooooool0Hoooool5o`0000_ooooo0009ooooo`Go0000Ioooool00ol0003o
ooooooooo`1Sooooo`Go00002oooool000Wooooo1Ol0001Wooooo`03o`000?oooooooooo06?ooooo
1Ol0000;ooooo`002Oooool5o`0006Oooooo00?o0000ooooooooool0H_ooool5o`0000cooooo000:
ooooo`Go0000I_ooool00ol0003oooooooooo`1Rooooo`Go00003?ooool000[ooooo1Ol0001Voooo
o`03o`000?oooooooooo06;ooooo1Ol0000<ooooo`002_ooool5o`0006Kooooo00?o0000oooooooo
ool0HOooool5o`0000gooooo000;ooooo`Go0000IOooool00ol0003oooooooooo`1Qooooo`Go0000
3Oooool000_ooooo1Ol0001Gooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0HOoo
ool5o`0000gooooo000;ooooo`Go0000F?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0H?ooool5o`0000kooooo000<ooooo`Go0000Eoooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo0_l0001Qooooo`Go00003_oo
ool000cooooo1Ol0001Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`1Pooooo`Go00003_ooool000cooooo1Ol0001Gooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Oooooo`Go00003ooo
ool000gooooo1Ol0001Eooooo`;o00001?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo05oooooo1Ol0000?ooooo`003Oooool5o`0005Kooooo00?o0000ooooooooool00oooool2
o`0000Gooooo00?o0000ooooooooool0Goooool5o`0000oooooo000=ooooo`Ko0000H_ooool00ol0
003oooooooooo`1Nooooo`Go00004?ooool000kooooo1Ol0001Rooooo`03o`000?oooooooooo05ko
oooo1Ol0000@ooooo`003_ooool6o`00067ooooo00?o0000ooooooooool0G_ooool5o`00013ooooo
000?ooooo`Go0000HOooool00ol0003oooooooooo`1Mooooo`Go00004Oooool000oooooo1Ol0001Q
ooooo`03o`000?oooooooooo05gooooo1Ol0000Aooooo`004?ooool5o`00063ooooo00?o0000oooo
ooooool0GOooool5o`00017ooooo000@ooooo`Go0000H?ooool00ol0003oooooooooo`1Looooo`Go
00004_ooool0013ooooo1_l0001Oooooo`03o`000?oooooooooo05cooooo1Ol0000Booooo`004Ooo
ool5o`0005oooooo00?o0000ooooooooool0Foooool6o`0001;ooooo000Aooooo`Ko0000G_ooool0
0ol0003oooooooooo`1Kooooo`Go00004oooool001;ooooo1Ol0001Nooooo`03o`000?oooooooooo
05[ooooo1_l0000Cooooo`004_ooool6o`0005gooooo00?o0000ooooooooool0F_ooool5o`0001Co
oooo000Cooooo`Go0000GOooool00ol0003oooooooooo`1Iooooo`Ko00005?ooool001?ooooo1_l0
001Looooo`03o`000?oooooooooo05Wooooo1Ol0000Eooooo`005?ooool5o`0005cooooo00?o0000
ooooooooool0F?ooool6o`0001Gooooo000Dooooo`Ko0000Foooool00ol0003oooooooooo`1Hoooo
o`Go00005_ooool001Gooooo1Ol0001Kooooo`03o`000?oooooooooo05Oooooo1_l0000Fooooo`00
5Oooool6o`0005[ooooo00?o0000ooooooooool0Eoooool5o`0001Oooooo000Fooooo`Ko0000FOoo
ool00ol0003oooooooooo`1Fooooo`Ko00005oooool001Kooooo1_l0001Iooooo`03o`000?oooooo
oooo05Gooooo1_l0000Hooooo`005oooool6o`0005Sooooo00?o0000ooooooooool0EOooool6o`00
01Sooooo000Hooooo`Ko0000BOooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo05Co
oooo1_l0000Iooooo`006?ooool6o`0004[ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0Doooool6o`0001[ooooo000Iooooo`Ko0000
BOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l0001Dooooo`Ko0000
6_ooool001[ooooo1_l00018ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Booooo`Ko00006oooool001[ooooo1_l00018ooooo`04o`000?oooooo
ooooooooo`Co00001Oooool00ol0003oooooooooo`1Booooo`Go00007?ooool001_ooooo1_l00016
ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo057ooooo1_l0000L
ooooo`007?ooool6o`0004Kooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooo
oooo053ooooo1_l0000Mooooo`007?ooool6o`0005?ooooo00?o0000ooooooooool0D?ooool6o`00
01gooooo000Mooooo`Ko0000D_ooool00ol0003oooooooooo`1?ooooo`Ko00007_ooool001kooooo
1_l0001Aooooo`03o`000?oooooooooo04kooooo1_l0000Oooooo`007_ooool6o`00057ooooo00?o
0000ooooooooool0C_ooool6o`0001oooooo000Oooooo`Ko0000D?ooool00ol0003oooooooooo`1=
ooooo`Ko00008?ooool0023ooooo1_l0001?ooooo`03o`000?oooooooooo04cooooo1_l0000Qoooo
o`008?ooool7o`0004kooooo00?o0000ooooooooool0Boooool7o`00027ooooo000Qooooo`Ko0000
C_ooool00ol0003oooooooooo`1:ooooo`Oo00008_ooool002;ooooo1_l0001=ooooo`03o`000?oo
oooooooo04Wooooo1ol0000Sooooo`008oooool6o`0004cooooo00?o0000ooooooooool0BOooool6
o`0002Cooooo000Sooooo`Oo0000Boooool00ol0003oooooooooo`18ooooo`Ko00009Oooool002Co
oooo1_l0001;ooooo`03o`000?oooooooooo04Oooooo1_l0000Vooooo`009Oooool6o`0004[ooooo
00?o0000ooooooooool0A_ooool7o`0002Kooooo000Vooooo`Ko0000BOooool00ol0003ooooooooo
o`15ooooo`Oo00009oooool002Kooooo2?l00017ooooo`03o`000?oooooooooo04Cooooo1ol0000X
ooooo`009oooool8o`0004Kooooo00?o0000ooooooooool0@oooool7o`0002Wooooo000Xooooo`So
0000AOooool00ol0003oooooooooo`12ooooo`Oo0000:_ooool002Wooooo2?l00014ooooo`03o`00
0?oooooooooo047ooooo1ol0000[ooooo`00:oooool7o`0004?ooooo00?o0000ooooooooool0@?oo
ool7o`0002cooooo000/ooooo`Oo0000@_ooool00ol0003oooooooooo`0oooooo`Oo0000;Oooool0
02gooooo1ol00011ooooo`03o`000?oooooooooo03kooooo1ol0000^ooooo`00;_ooool7o`00037o
oooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0mooooo`Oo0000;oooool002oooooo
2?l0000`ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0looooo`Oo0000<?ooool0033ooooo2?l0000`ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001?ooool2o`0003_ooooo2?l0000aooooo`00<Oooool8o`00033o
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0>Oooool8o`0003;ooooo000booooo`So0000;?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0hooooo`So0000<oooool0
03Cooooo1ol0000[ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo03Kooooo2Ol0000dooooo`00=Oooool7o`0002_ooooo0ol00004
ooooo`;o00001Oooool00ol0003oooooooooo`0eooooo`So0000=_ooool003Kooooo1ol0000hoooo
o`03o`000?oooooooooo03Cooooo2?l0000gooooo`00=oooool7o`0003Oooooo00?o0000oooooooo
ool0<oooool8o`0003Sooooo000hooooo`So0000=Oooool00ol0003oooooooooo`0aooooo`So0000
>_ooool003Wooooo2?l0000dooooo`03o`000?oooooooooo033ooooo2?l0000kooooo`00>_ooool9
o`0003;ooooo00?o0000ooooooooool0;_ooool9o`0003cooooo000kooooo`Wo0000<Oooool00ol0
003oooooooooo`0]ooooo`Wo0000?Oooool003gooooo2Ol0000_ooooo`03o`000?oooooooooo02_o
oooo2Ol0000oooooo`00?_ooool9o`0002kooooo00?o0000ooooooooool0:_ooool9o`00043ooooo
0010ooooo`Wo0000;?ooool00ol0003oooooooooo`0Xooooo`Wo0000@_ooool0047ooooo2ol0000Y
ooooo`03o`000?oooooooooo02Kooooo2_l00013ooooo`00@oooool;o`0002Oooooo00?o0000oooo
ooooool09?ooool:o`0004Gooooo0014ooooo`go00009?ooool00ol0003oooooooooo`0Rooooo`_o
0000A_ooool004Kooooo3Ol0000Rooooo`03o`000?oooooooooo023ooooo2ol00018ooooo`00BOoo
ool=o`0001oooooo00?o0000ooooooooool07_ooool;o`0004[ooooo001;ooooo`go00007Oooool0
0ol0003oooooooooo`0Kooooo`co0000C?ooool004kooooo3?l0000Kooooo`03o`000?oooooooooo
01Sooooo3Ol0001>ooooo`00D?ooool>o`0001Oooooo00?o0000ooooooooool05?ooool?o`00053o
oooo001Cooooo`oo00004oooool00ol0003oooooooooo`0?oooooa;o0000D_ooool005Gooooo4_l0
000>ooooo`03o`000?oooooooooo00_ooooo4ol0001Eooooo`00EooooolDo`0000[ooooo00?o0000
ooooooooool01OoooolFo`0005Sooooo001KooooocCo0000G?ooool005oooooo:ol0001Qooooo`00
I?oooolRo`0006Gooooo001XoooooaSo0000Joooool006Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo07?ooooo001Vooooo`06o`000?oooooooooo
ooooool0003ooooo1?l00005ooooo`03o`000?oooooooooo07?ooooo001Vooooo`07o`000?oooooo
ooooooooool0003oooooo`00001nooooo`00Ioooool3o`0000;ooooo1Ol0001jooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00\
\>"],
  ImageRangeCache->{{{73.4375, 260.438}, {327.75, 140.75}} -> {-145.215, \
22.4195, 0.695902, 0.179207}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The plot below shows a comparison of Wigner's semicircle law to the \
computed eigenvalue density.  The agreement is excellent.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[GOEDensity, WSC, AspectRatio \[Rule] 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00625 0.0238095 0.0384025 [
[.125 -0.0125 -16.8125 -18 ]
[.125 -0.0125 16.8125 0 ]
[.25 -0.0125 -16.8125 -18 ]
[.25 -0.0125 16.8125 0 ]
[.375 -0.0125 -16.8125 -18 ]
[.375 -0.0125 16.8125 0 ]
[.5 -0.0125 -6.78125 -18 ]
[.5 -0.0125 6.78125 0 ]
[.625 -0.0125 -11.5625 -18 ]
[.625 -0.0125 11.5625 0 ]
[.75 -0.0125 -11.5625 -18 ]
[.75 -0.0125 11.5625 0 ]
[.875 -0.0125 -11.5625 -18 ]
[.875 -0.0125 11.5625 0 ]
[1 -0.0125 -11.5625 -18 ]
[1 -0.0125 11.5625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .02381 -13.5625 -9 ]
[-0.0125 .02381 0 9 ]
[-0.0125 .21582 -13.5625 -9 ]
[-0.0125 .21582 0 9 ]
[-0.0125 .40783 -23.125 -9 ]
[-0.0125 .40783 0 9 ]
[-0.0125 .59985 -23.125 -9 ]
[-0.0125 .59985 0 9 ]
[-0.0125 .79186 -23.125 -9 ]
[-0.0125 .79186 0 9 ]
[-0.0125 .98387 -23.125 -9 ]
[-0.0125 .98387 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -65.375 -9 ]
[-0.01875 .5 -23.125 9 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
gsave
.125 -0.0125 -77.8125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
73.500 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -77.8125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
73.500 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.375 0 m
.375 .00625 L
s
gsave
.375 -0.0125 -77.8125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
73.500 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.625 0 m
.625 .00625 L
s
gsave
.625 -0.0125 -72.5625 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -72.5625 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.875 0 m
.875 .00625 L
s
gsave
.875 -0.0125 -72.5625 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -72.5625 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.125 Mabswid
.03125 0 m
.03125 .00375 L
s
.0625 0 m
.0625 .00375 L
s
.09375 0 m
.09375 .00375 L
s
.15625 0 m
.15625 .00375 L
s
.1875 0 m
.1875 .00375 L
s
.21875 0 m
.21875 .00375 L
s
.28125 0 m
.28125 .00375 L
s
.3125 0 m
.3125 .00375 L
s
.34375 0 m
.34375 .00375 L
s
.40625 0 m
.40625 .00375 L
s
.4375 0 m
.4375 .00375 L
s
.46875 0 m
.46875 .00375 L
s
.53125 0 m
.53125 .00375 L
s
.5625 0 m
.5625 .00375 L
s
.59375 0 m
.59375 .00375 L
s
.65625 0 m
.65625 .00375 L
s
.6875 0 m
.6875 .00375 L
s
.71875 0 m
.71875 .00375 L
s
.78125 0 m
.78125 .00375 L
s
.8125 0 m
.8125 .00375 L
s
.84375 0 m
.84375 .00375 L
s
.90625 0 m
.90625 .00375 L
s
.9375 0 m
.9375 .00375 L
s
.96875 0 m
.96875 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02381 m
.00625 .02381 L
s
gsave
-0.0125 .02381 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .21582 m
.00625 .21582 L
s
gsave
-0.0125 .21582 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .40783 m
.00625 .40783 L
s
gsave
-0.0125 .40783 -84.125 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .59985 m
.00625 .59985 L
s
gsave
-0.0125 .59985 -84.125 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .79186 m
.00625 .79186 L
s
gsave
-0.0125 .79186 -84.125 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .98387 m
.00625 .98387 L
s
gsave
-0.0125 .98387 -84.125 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06221 m
.00375 .06221 L
s
0 .10061 m
.00375 .10061 L
s
0 .13902 m
.00375 .13902 L
s
0 .17742 m
.00375 .17742 L
s
0 .25422 m
.00375 .25422 L
s
0 .29263 m
.00375 .29263 L
s
0 .33103 m
.00375 .33103 L
s
0 .36943 m
.00375 .36943 L
s
0 .44624 m
.00375 .44624 L
s
0 .48464 m
.00375 .48464 L
s
0 .52304 m
.00375 .52304 L
s
0 .56144 m
.00375 .56144 L
s
0 .63825 m
.00375 .63825 L
s
0 .67665 m
.00375 .67665 L
s
0 .71505 m
.00375 .71505 L
s
0 .75346 m
.00375 .75346 L
s
0 .83026 m
.00375 .83026 L
s
0 .86866 m
.00375 .86866 L
s
0 .90707 m
.00375 .90707 L
s
0 .94547 m
.00375 .94547 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -126.375 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.125 .99375 m
.125 1 L
s
.25 .99375 m
.25 1 L
s
.375 .99375 m
.375 1 L
s
.5 .99375 m
.5 1 L
s
.625 .99375 m
.625 1 L
s
.75 .99375 m
.75 1 L
s
.875 .99375 m
.875 1 L
s
.125 Mabswid
.03125 .99625 m
.03125 1 L
s
.0625 .99625 m
.0625 1 L
s
.09375 .99625 m
.09375 1 L
s
.15625 .99625 m
.15625 1 L
s
.1875 .99625 m
.1875 1 L
s
.21875 .99625 m
.21875 1 L
s
.28125 .99625 m
.28125 1 L
s
.3125 .99625 m
.3125 1 L
s
.34375 .99625 m
.34375 1 L
s
.40625 .99625 m
.40625 1 L
s
.4375 .99625 m
.4375 1 L
s
.46875 .99625 m
.46875 1 L
s
.53125 .99625 m
.53125 1 L
s
.5625 .99625 m
.5625 1 L
s
.59375 .99625 m
.59375 1 L
s
.65625 .99625 m
.65625 1 L
s
.6875 .99625 m
.6875 1 L
s
.71875 .99625 m
.71875 1 L
s
.78125 .99625 m
.78125 1 L
s
.8125 .99625 m
.8125 1 L
s
.84375 .99625 m
.84375 1 L
s
.90625 .99625 m
.90625 1 L
s
.9375 .99625 m
.9375 1 L
s
.96875 .99625 m
.96875 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .21582 m
1 .21582 L
s
.99375 .40783 m
1 .40783 L
s
.99375 .59985 m
1 .59985 L
s
.99375 .79186 m
1 .79186 L
s
.99375 .98387 m
1 .98387 L
s
.125 Mabswid
.99625 .06221 m
1 .06221 L
s
.99625 .10061 m
1 .10061 L
s
.99625 .13902 m
1 .13902 L
s
.99625 .17742 m
1 .17742 L
s
.99625 .25422 m
1 .25422 L
s
.99625 .29263 m
1 .29263 L
s
.99625 .33103 m
1 .33103 L
s
.99625 .36943 m
1 .36943 L
s
.99625 .44624 m
1 .44624 L
s
.99625 .48464 m
1 .48464 L
s
.99625 .52304 m
1 .52304 L
s
.99625 .56144 m
1 .56144 L
s
.99625 .63825 m
1 .63825 L
s
.99625 .67665 m
1 .67665 L
s
.99625 .71505 m
1 .71505 L
s
.99625 .75346 m
1 .75346 L
s
.99625 .83026 m
1 .83026 L
s
.99625 .86866 m
1 .86866 L
s
.99625 .90707 m
1 .90707 L
s
.99625 .94547 m
1 .94547 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .02381 m
1 .02381 L
s
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
0 .02381 m
0 .10061 L
.03125 .10061 L
.03125 .02381 L
F
0 g
.5 Mabswid
0 .02381 m
0 .10061 L
.03125 .10061 L
.03125 .02381 L
0 .02381 L
s
1 0 0 r
.03125 .02381 m
.03125 .36175 L
.0625 .36175 L
.0625 .02381 L
F
0 g
.03125 .02381 m
.03125 .36175 L
.0625 .36175 L
.0625 .02381 L
.03125 .02381 L
s
1 0 0 r
.0625 .02381 m
.0625 .49232 L
.09375 .49232 L
.09375 .02381 L
F
0 g
.0625 .02381 m
.0625 .49232 L
.09375 .49232 L
.09375 .02381 L
.0625 .02381 L
s
1 0 0 r
.09375 .02381 m
.09375 .58449 L
.125 .58449 L
.125 .02381 L
F
0 g
.09375 .02381 m
.09375 .58449 L
.125 .58449 L
.125 .02381 L
.09375 .02381 L
s
1 0 0 r
.125 .02381 m
.125 .64593 L
.15625 .64593 L
.15625 .02381 L
F
0 g
.125 .02381 m
.125 .64593 L
.15625 .64593 L
.15625 .02381 L
.125 .02381 L
s
1 0 0 r
.15625 .02381 m
.15625 .71505 L
.1875 .71505 L
.1875 .02381 L
F
0 g
.15625 .02381 m
.15625 .71505 L
.1875 .71505 L
.1875 .02381 L
.15625 .02381 L
s
1 0 0 r
.1875 .02381 m
.1875 .7765 L
.21875 .7765 L
.21875 .02381 L
F
0 g
.1875 .02381 m
.1875 .7765 L
.21875 .7765 L
.21875 .02381 L
.1875 .02381 L
s
1 0 0 r
.21875 .02381 m
.21875 .8149 L
.25 .8149 L
.25 .02381 L
F
0 g
.21875 .02381 m
.21875 .8149 L
.25 .8149 L
.25 .02381 L
.21875 .02381 L
s
1 0 0 r
.25 .02381 m
.25 .8533 L
.28125 .8533 L
.28125 .02381 L
F
0 g
.25 .02381 m
.25 .8533 L
.28125 .8533 L
.28125 .02381 L
.25 .02381 L
s
1 0 0 r
.28125 .02381 m
.28125 .87634 L
.3125 .87634 L
.3125 .02381 L
F
0 g
.28125 .02381 m
.28125 .87634 L
.3125 .87634 L
.3125 .02381 L
.28125 .02381 L
s
1 0 0 r
.3125 .02381 m
.3125 .90707 L
.34375 .90707 L
.34375 .02381 L
F
0 g
.3125 .02381 m
.3125 .90707 L
.34375 .90707 L
.34375 .02381 L
.3125 .02381 L
s
1 0 0 r
.34375 .02381 m
.34375 .93779 L
.375 .93779 L
.375 .02381 L
F
0 g
.34375 .02381 m
.34375 .93779 L
.375 .93779 L
.375 .02381 L
.34375 .02381 L
s
1 0 0 r
.375 .02381 m
.375 .93779 L
.40625 .93779 L
.40625 .02381 L
F
0 g
.375 .02381 m
.375 .93779 L
.40625 .93779 L
.40625 .02381 L
.375 .02381 L
s
1 0 0 r
.40625 .02381 m
.40625 .95315 L
.4375 .95315 L
.4375 .02381 L
F
0 g
.40625 .02381 m
.40625 .95315 L
.4375 .95315 L
.4375 .02381 L
.40625 .02381 L
s
1 0 0 r
.4375 .02381 m
.4375 .96851 L
.46875 .96851 L
.46875 .02381 L
F
0 g
.4375 .02381 m
.4375 .96851 L
.46875 .96851 L
.46875 .02381 L
.4375 .02381 L
s
1 0 0 r
.46875 .02381 m
.46875 .96851 L
.5 .96851 L
.5 .02381 L
F
0 g
.46875 .02381 m
.46875 .96851 L
.5 .96851 L
.5 .02381 L
.46875 .02381 L
s
1 0 0 r
.5 .02381 m
.5 .97619 L
.53125 .97619 L
.53125 .02381 L
F
0 g
.5 .02381 m
.5 .97619 L
.53125 .97619 L
.53125 .02381 L
.5 .02381 L
s
1 0 0 r
.53125 .02381 m
.53125 .95315 L
.5625 .95315 L
.5625 .02381 L
F
0 g
.53125 .02381 m
.53125 .95315 L
.5625 .95315 L
.5625 .02381 L
.53125 .02381 L
s
1 0 0 r
.5625 .02381 m
.5625 .97619 L
.59375 .97619 L
.59375 .02381 L
F
0 g
.5625 .02381 m
.5625 .97619 L
.59375 .97619 L
.59375 .02381 L
.5625 .02381 L
s
1 0 0 r
.59375 .02381 m
.59375 .94547 L
.625 .94547 L
.625 .02381 L
F
0 g
.59375 .02381 m
.59375 .94547 L
.625 .94547 L
.625 .02381 L
.59375 .02381 L
s
1 0 0 r
.625 .02381 m
.625 .93011 L
.65625 .93011 L
.65625 .02381 L
F
0 g
.625 .02381 m
.625 .93011 L
.65625 .93011 L
.65625 .02381 L
.625 .02381 L
s
1 0 0 r
.65625 .02381 m
.65625 .90707 L
.6875 .90707 L
.6875 .02381 L
F
0 g
.65625 .02381 m
.65625 .90707 L
.6875 .90707 L
.6875 .02381 L
.65625 .02381 L
s
1 0 0 r
.6875 .02381 m
.6875 .87634 L
.71875 .87634 L
.71875 .02381 L
F
0 g
.6875 .02381 m
.6875 .87634 L
.71875 .87634 L
.71875 .02381 L
.6875 .02381 L
s
1 0 0 r
.71875 .02381 m
.71875 .86098 L
.75 .86098 L
.75 .02381 L
F
0 g
.71875 .02381 m
.71875 .86098 L
.75 .86098 L
.75 .02381 L
.71875 .02381 L
s
1 0 0 r
.75 .02381 m
.75 .80722 L
.78125 .80722 L
.78125 .02381 L
F
0 g
.75 .02381 m
.75 .80722 L
.78125 .80722 L
.78125 .02381 L
.75 .02381 L
s
1 0 0 r
.78125 .02381 m
.78125 .7765 L
.8125 .7765 L
.8125 .02381 L
F
0 g
.78125 .02381 m
.78125 .7765 L
.8125 .7765 L
.8125 .02381 L
.78125 .02381 L
s
1 0 0 r
.8125 .02381 m
.8125 .73041 L
.84375 .73041 L
.84375 .02381 L
F
0 g
.8125 .02381 m
.8125 .73041 L
.84375 .73041 L
.84375 .02381 L
.8125 .02381 L
s
1 0 0 r
.84375 .02381 m
.84375 .66129 L
.875 .66129 L
.875 .02381 L
F
0 g
.84375 .02381 m
.84375 .66129 L
.875 .66129 L
.875 .02381 L
.84375 .02381 L
s
1 0 0 r
.875 .02381 m
.875 .56144 L
.90625 .56144 L
.90625 .02381 L
F
0 g
.875 .02381 m
.875 .56144 L
.90625 .56144 L
.90625 .02381 L
.875 .02381 L
s
1 0 0 r
.90625 .02381 m
.90625 .49232 L
.9375 .49232 L
.9375 .02381 L
F
0 g
.90625 .02381 m
.90625 .49232 L
.9375 .49232 L
.9375 .02381 L
.90625 .02381 L
s
1 0 0 r
.9375 .02381 m
.9375 .34639 L
.96875 .34639 L
.96875 .02381 L
F
0 g
.9375 .02381 m
.9375 .34639 L
.96875 .34639 L
.96875 .02381 L
.9375 .02381 L
s
1 0 0 r
.96875 .02381 m
.96875 .10829 L
1 .10829 L
1 .02381 L
F
0 g
.96875 .02381 m
.96875 .10829 L
1 .10829 L
1 .02381 L
.96875 .02381 L
s
.02 w
.01588 .0242 m
.01707 .0903 L
.01816 .11565 L
.0206 .15577 L
.025 .20679 L
.03014 .25196 L
.035 .28729 L
.05516 .39741 L
.0757 .47974 L
.09799 .55139 L
.13954 .65589 L
.17955 .73355 L
.21801 .79346 L
.25897 .84497 L
.29839 .88465 L
.3403 .91767 L
.36123 .93094 L
.38067 .94145 L
.40066 .95052 L
.4195 .95749 L
.44036 .96346 L
.45928 .96731 L
.46921 .96875 L
.47463 .96937 L
.47969 .96983 L
.48401 .97015 L
.48865 .97041 L
.49129 .97051 L
.49258 .97056 L
.49379 .97059 L
.49485 .97061 L
.49603 .97064 L
.49722 .97065 L
.49847 .97066 L
.49971 .97067 L
.50086 .97067 L
.50212 .97066 L
.50283 .97065 L
.50347 .97064 L
.50477 .97062 L
.50618 .97059 L
.50873 .97051 L
.51111 .97042 L
.51363 .97029 L
.51814 .97 L
.52336 .96956 L
.52824 .96906 L
.53935 .96754 L
.54993 .96562 L
.55997 .96337 L
Mistroke
.57882 .95803 L
.59899 .95066 L
.6177 .94226 L
.65753 .91914 L
.69986 .88621 L
.74065 .8454 L
.77989 .79638 L
.82163 .7315 L
.86183 .65288 L
.90049 .55579 L
.92203 .48775 L
.94164 .41168 L
.9514 .36603 L
.96199 .30681 L
.96685 .27448 L
.972 .23436 L
.9764 .19225 L
.97874 .16467 L
.98125 .12681 L
.98198 .11278 L
.98275 .09508 L
.98341 .07532 L
.98412 .0242 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00SOooool8o`0005Kooooo002>
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0E?ooool008kooooo00?o0000oooo
ooooool00oooool00ol@413oooooooooo`1Dooooo`00S_ooool01?l0003oooooooooool@411Ioooo
o`00S_ooool4o`0005Wooooo002>ooooo`04o`000?oooooooooooa0@45Wooooo002>ooooo`03o`00
0?oooooooooo00?ooooo00?o410@ooooooooool0E?ooool008kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Dooooo`00SOooool8o`0005Kooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo001Eooooo`06onk^k_mEEEGo
0000o`000?mEEEGok^k^1Oooool01?nHV9So0000o`000?nHV9P7ooooo`;o000000?o410@oooooooo
ool00oooool01?nHV9So0000o`000?nHV9P3ooooo`Ko00001_ooool01?nHV9So0000o`000?nHV9P5
ooooo`04oiRHV?l0003o0000oiRHV0Wooooo1_l00006ooooo`04oiRHV?l0003o0000oiRHV0Oooooo
0_l000000ol@413oooooooooo`03ooooo`04oiRHV?l0003o0000oiRHV0Cooooo00Kok^k^oeEEEOl0
003o0000oeEEEOo^k^h5ooooo`04oiRHV?l0003o0000oiRHV0Cooooo00Kok^k^oeEEEOl0003o0000
oeEEEOo^k^h5ooooo`04oiRHV?l0003o0000oiRHV0Kooooo001Eooooo`;oMgMg0_ooool00omgMgOo
EEEEooooo`03ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1oooool00ol0003oooooooooo`03
ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj0_ooool00onHV9So0000omgMg@02ooooo`03oa0@
4?oooooooooo00?ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X3ooooo`06okZj^_lQ8B7ogMgM
omgMgOlQ8B7o^[Zj2?ooool00onHV9So0000omgMg@02ooooo`03oa0@4?oooooooooo00?ooooo00Ko
^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X7ooooo`03o`000?oooooooooo00?ooooo00Ko^[Zjob4Q8OoM
gMgogMgMob4Q8Onj^[X3ooooo`;oMgMg0_ooool00omgMgOoEEEEooooo`03ooooo`06okZj^_lQ8B7o
gMgMomgMgOlQ8B7o^[Zj0oooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Cooooo00Ko^[Zjob4Q
8OoMgMgogMgMob4Q8Onj^[X5ooooo`00EOooool00olQ8B7oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@3ooooo`Ko00001?ooool01_m4A4CoV9RH
ooooooooooooV9RHodA4A0?ooooo00?oQhN7ob4Q8Oo^k^h01oooool01_m4A4CoV9RHoooooooooooo
V9RHodA4A0?ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@9ooooo`03ohN7QolQ8B7ok^k^00Oo
oooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@3ooooo`Ko00001?ooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A0?ooooo00?o8B4Qooooooooool00_ooool00ol0003oooooooooo`02ooooo`06odA4
A?nHV9SooooooooooonHV9SoA4A40oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`00B_ooool6o`0000Gooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooooooo`06o`000003onk^k_l0003ooooo00;ooooo00GoA4A4
okZj^_ooooooooooo`000004ooooo`Oo00001?ooool00onYZJWo8B4Qonk^kP06ooooo`06o`000?o^
k^koooooooooooo^k^ko00000oooool01_l0003ok^k^ooooooooooook^k^o`0000[ooooo00?oZJVY
ob4Q8Oo^k^h01_ooool01_l0003ok^k^ooooooooooook^k^o`0000?ooooo00GoA4A4okZj^_oooooo
ooooo`000005ooooo`06o`000?o^k^koooooooooooo^k^ko00000oooool00ol0003ok^k^ooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Ko0000onk^k_ooooooooooonk^k_l00003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01_l0003ok^k^ooooooooooook^k^o`00
00Gooooo001Eooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE1?ooool00ol0003oooooooooo`02
ooooo`06o`000?oooooooooooooooooMgMgo8B4Q0_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00onHV9So<S8booooo`05ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Wo
oooo00?oV9RHoc8b<_ooool01Oooool00ol0003oooooooooo`02ooooo`06o`000?oooooooooooooo
oooMgMgo8B4Q0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00[o0000
ooooooooooooooooo`000?mEEEGok^k^oooooomgMgOoEEEE1?ooool00ol0003oooooooooo`02oooo
o`06o`000?oooooooooooooooomEEEGoMgMg0_ooool00omgMgOoEEEEooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool005Gooooo00Ko0000ogMgMol0003o0000oeEE
EOo^k^h4ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?mgMgOoV9RH
ooooool00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00om4A4Co
MgMgooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00[ooooo00?oA4A4ogMgMoooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00CoMgMgoiRHV?oooooo00001Oooool00ol0003oooooooooo`02
ooooo`06o`000?ooooooooooooooool0003oMgMg0_l000000omEEEGok^k^ooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooomgMg@04o`000003omgMgOoooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`00EOooool00om4A4CoV9RH
ooooo`07ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool01?o^k^ko8B4Qooooool00005
ooooo`06o`000?o^k^koooooooooooo^k^ko00001_ooool00ooMgMgo410@ooooo`04ooooo`06o`00
0?o^k^koooooooooooo^k^ko00000oooool01_l0003ok^k^ooooooooooook^k^o`0000cooooo00?o
gMgMoa0@4?ooool01?ooool01_l0003ok^k^ooooooooooook^k^o`0000Cooooo00Cok^k^ob4Q8Ooo
oooo00001Oooool01_l0003ok^k^ooooooooooook^k^o`0000?ooooo00?oA4A4oiRHV?ooool01ooo
ool01_l0003ok^k^ooooooooooook^k^o`0000?ooooo00Ko<S8bofIVI_o^k^kok^k^ofIVI_lb<S84
ooooo`06o`000?o^k^koooooooooooo^k^ko00001Oooool005Gooooo00?o^[Zjob4Q8Oooool01ooo
ool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oMgMgoiRHV?l000001Oooool01_m4A4Co
V9RHooooooooooooV9RHodA4A0Oooooo00?o0000ooooooooool00oooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A0?ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@=ooooo`03o`000?oooooooooo
00?ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03ogMgMonHV9So000000Gooooo00Ko
A4A4oiRHV?oooooooooooiRHV?m4A4@3ooooo`03okZj^_lQ8B7ooooo00Oooooo00KoA4A4oiRHV?oo
oooooooooiRHV?m4A4@3ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo001Fooooo`03oeEEEOlb<S;ogMgM00Kooooo00Ko
^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`03onk^k_lb<S;o000000Gooooo00Ko^[Zjob4Q8OoM
gMgogMgMob4Q8Onj^[X2ooooo`06o`000?n7QhOok^k^oooooonHV9SoEEEE1Oooool01_nj^[[o8B4Q
omgMgOoMgMgo8B4QokZj^P?ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X8ooooo`06o`000?n7
QhOok^k^oooooonHV9SoEEEE1Oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00?ok^k^
oc8b<_l000001Oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PCooooo00?oEEEEoc8b<_oMgMd0
1_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^P?ooooo00Ko<S8bofIVI_o^k^kok^k^ofIVI_lb
<S84ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool005Oooooo00CoV9RHob4Q8Ol0003o
8B4Q1Oooool01?nHV9So0000o`000?nHV9P7ooooo`03oiRHV?l@413ooooo00Gooooo00CoV9RHo`00
0?l0003oV9RH0oooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kPKooooo00CoV9RHo`000?l0003o
V9RH1Oooool01?nHV9So0000o`000?nHV9P9ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^1_oo
ool01?nHV9So0000o`000?nHV9P7ooooo`03oiRHV?l@413ooooo00Gooooo00CoV9RHo`000?l0003o
V9RH1_ooool01?nHV9So8B4Qo`000?lQ8B45ooooo`04oiRHV?l0003o0000oiRHV0Cooooo00Kok^k^
odA4A?l0003o0000odA4A?o^k^h5ooooo`04oiRHV?l0003o0000oiRHV0Kooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00A?oooonKo`0000cooooo000iooooo`04oiRHV?l0003o0000oiRHV0Oo
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo000hooooo`06
okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1_ooool00ol0003oooooooooo`2Gooooo`03o`000?oooooo
oooo00[ooooo000hooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41_ooool4o`0009;ooooo0ol0
00000ooooooo0000ooooo`0;ooooo`00>?ooool01_l0003ok^k^ooooooooooook^k^o`0000Kooooo
Vol0000<ooooo`00>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo1?l0
00000ooo003o0000ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
0004o`000003ool00?l0003ooooo00_ooooo000hooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool4o`000003ool00?l0003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool000Co000000?oo`00o`000?ooool02oooool003Sooooo00Ko0000onk^
k_ooooooooooonk^k_l00006ooooo`Co000000?oo`00o`000?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`001?l000000ooo003o0000ooooo`0;ooooo`00>?ooool0
1_m4A4CoV9RHooooooooooooV9RHodA4A0Kooooo1?l000000ooo003o0000ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo0004o`000003ool00?l0003ooooo00_ooooo
000hooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1_ooool4o`000003ool00?l0003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool000Co000000?oo`00o`000?oo
ool02oooool003Wooooo00CoV9RHo`000?l0003oV9RH1oooool4o`000003ool00?l0003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool000Co000000?oo`00o`000?oo
ool02oooool004Cooooo1?l000000ooo003o0000ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo0004o`000003ool00?l0003ooooo00_ooooo0014ooooo`Co000000?o
o`00o`000?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`001?l0
00000ooo003o0000ooooo`0;ooooo`00A?ooool4o`000003ool00?l0003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool000Co000000?oo`00o`000?ooool02oooool0
04Cooooo1?l000000ooo003o0000ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo0004o`000003ool00?l0003ooooo00_ooooo0014ooooo`Co000000?oo`00o`000?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`001?l000000ooo003o
0000ooooo`0;ooooo`00A?ooool6o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool000Co000000?oo`00o`000?ooool02oooool004Cooooo1_l00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo0006o`0000cooooo0014ooooo`03o`000?oooooo
000000?o00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`001?l00000
0ooooooo0000ooooo`0;ooooo`00A?ooool00ol0003oooooo`000003o`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool000Co000000?oooooo`000?ooool02oooool004Co
oooo00?o0000ooooool000000ol00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo0004o`000003ooooool0003ooooo00_ooooo0014ooooo`03o`000?oooooo000000?o0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`001?l000000ooooooo0000
ooooo`0;ooooo`00A?ooool00ol0003oooooo`000003o`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool000Ko00003?ooool004Cooooo00?o0000ooooool000000ol00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0004o`000003ooooool0003o
oooo00_ooooo0014ooooo`03o`000?oooooo000000?o00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`001?l000000ooooooo0000ooooo`0;ooooo`00A?ooool00ol0003o
ooooo`000003o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool000Co
000000?oooooo`000?ooool02oooool004Cooooo00?o0000ooooool000000ol00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo0004o`000003ooooool0003ooooo00_ooooo
0014ooooo`03o`000?oooooo000000?o00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`001_l0000<ooooo`00A?ooool00ol0003oooooo`000003o`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool000Co000000?oooooo`000?ooool02oooool0
04Cooooo00?o0000ooooool000000ol00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo0004o`000003ooooool0003ooooo00_ooooo000hooooo`05oiRHV?l@413o0000o`00
0?mVIVH01oooool00ol0003oooooooooo`03o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool000?o00000_ooool00ol0003oooooooooo`0:ooooo`00>?ooool01_l@413o
QhN7ooooooooooooMgMgofIVIPKooooo00?o0000ooooooooool00ol00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo0003o`0000;ooooo00?o0000ooooooooool02_ooool0
03gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03o`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool000?o00000_ooool00ol0003oooooooooo`0:oooo
o`00??ooool00oo^k^ko0000ooooo`05ooooo`;o000000Coooooo`000?l0003o00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`000ol000000ooooooo0000o`00000<oooo
o`00>?ooool01_l@413oV9RHooooooooooooMgMgofIVIPKooooo00?o0000ooooooooool00ol00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0003o`0000;ooooo00?o0000
ooooooooool02_ooool003Sooooo00Go0000ob4Q8Ol0003o0000ofIVIP07ooooo`03o`000?oooooo
oooo00?o00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`000ol00002
ooooo`03o`000?oooooooooo00[ooooo000hooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00ol00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0003o`00
00;ooooo00?o0000ooooooooool02_ooool003Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`03o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool000?o
00000_ooool00ol0003oooooooooo`0:ooooo`00>?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00?o00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
0ol00002ooooo`03o`000?oooooooooo00[ooooo000hooooo`Go00001oooool00ol0003ooooooooo
o`03o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00001?l0003oo`00ool00?oo0004o`000003oooo
ool0003o000000cooooo0014ooooo`03o`000?oooooooooo00?o00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00004o`000?oo003oo`00ool000Co00000_ooool00ol0003oooooooooo`0:ooooo`00A?oo
ool00ol0003oooooooooo`04o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001?l0003oo`00ool0
0?oo0003o`0000?ooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool01?l0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Co0000ool00?oo003oo`000ol00003ooooo`03o`00
0?oooooooooo00[ooooo0014ooooo`04o`000?ooooooooooooooo`?o00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00004o`000?oo003oo`00ool000?o00000oooool00ol0003oooooooooo`0:ooooo`00
A?ooool01?l0003oooooooooooooool3o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00004o`0000?ooooo00?o0000ooooooooool02_ooool004Cooooo00Co0000oooooooooooo
oooo0ol00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00001?l00002ooooo`;o
00003?ooool004Cooooo00Co0000oooooooooooooooo0ol00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000ol00004ooooo`03o`000?oooooooooo00[ooooo0014ooooo`04o`00
0?ooooooooooooooo`Co000000?oo`00o`000?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00003o`0000Co
oooo00?o0000ooooooooool02_ooool004Cooooo00Co0000oooooooooooooooo1?l000000ooo003o
0000ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000?o00001?ooool00ol0003oooooooooo`0:ooooo`00
A?ooool00ol0003oooooooooo`02ooooo`?o000000?oo`00o`000?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
o`000003o`0000Cooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool00_oo
ool3o`000003ool00?l0003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?l000000ol00004ooooo`03o`000?oo
oooooooo00[ooooo0014ooooo`03o`000?oooooooooo00;ooooo0ol000000ooo003o0000ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003o000000?o00000oooool2o`0000cooooo0014ooooo`03o`000?oooooooooo
00;ooooo1Ol00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003o000000?o00001?ooool00ol0003oooooooooo`0:oooo
o`00A?ooool00ol0003oooooooooo`02ooooo`Go00001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00o`000003o`0000Co
oooo00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool00_ooool5o`0000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
1_l00004ooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooooooo00;ooooo1Ol0
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool000Go00001Oooool00ol0003oooooooooo`0:ooooo`00A?ooool00ol0003oooooooooo`02
ooooo`Go00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo0004o`0000Kooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000oooo
ooooool00oooool4o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`001?l00005ooooo`;o00003?ooool004Cooooo00?o0000oooooooo
ool00oooool4o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`001?l00006ooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`00
0?oooooooooo00?ooooo1?l00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool000Co00001_ooool00ol0003oooooooooo`0:ooooo`00;ooo
ool4o`000003oa0@4?oooooooooo00Cooooo00CoV9RHo`000?l0003oV9RH1_ooool00ol0003ooooo
ooooo`04ooooo`?o00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo0004o`0000Kooooo00?o0000ooooooooool02_ooool0037ooooo00?o
0000ooooooooool01Oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00?o0000oooooooo
ool01?ooool3o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`001?l00006ooooo`03o`000?oooooooooo00[ooooo000aooooo`03o`00
0?oooooooooo00Gooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03o`000?oooooooooo
00Cooooo0ol00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool000?o00001oooool00ol0003oooooooooo`0:ooooo`00<Oooool00ol0003o
ooooooooo`05ooooo`06o`000?o^k^koooooooooooo^k^ko00001Oooool2o`0000Gooooo1?l00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool000?o00001_ooool2o`0000cooooo000aooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo1?l00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
00?o00001oooool00ol0003oooooooooo`0:ooooo`00<Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`?o
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo0003o`0000Oooooo00?o0000ooooooooool02_ooool0037ooooo00?o0000ooooooooool0
1Oooool01_l0003ok^k^ooooooooooook^k^o`0000Gooooo00?o0000ooooooooool01Oooool3o`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00?oo`001?l00007ooooo`03o`000?oooooooooo00[ooooo000aooooo`03o`000?oooooooooo00Go
oooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03o`000?oooooooooo00Gooooo1?l00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000003
ool000Co00001oooool00ol0003oooooooooo`0:ooooo`00;oooool00ol0003oA4A4o`000007oooo
o`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool00ol0003oooooooooo`05ooooo`Co00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000000ooo
0003o`0000Sooooo00?o0000ooooooooool02_ooool002oooooo00?oc<c<oeEEEOl000002?ooool0
1?nHV9So0000o`000?nHV9P6ooooo`03o`000?oooooooooo00Kooooo0ol00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000002ool000Co00001ooo
ool2o`0000cooooo0014ooooo`03o`000?oooooooooo00Kooooo0ol00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000002ool000Co00002?ooool0
0ol0003oooooooooo`0:ooooo`004?ooool00onj^[[o<S8booooo`0>ooooo`03oc8b<_nj^[[ooooo
023ooooo00?o0000ooooooooool01_ooool3o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000;oo`000ol00009ooooo`03o`000?oooooooooo
00[ooooo0003ooooo`03o`000?oooooooooo00[ooooo00?o<S8bokZj^_ooool03_ooool00onj^[[o
<S8booooo`0Pooooo`03o`000?oooooooooo00Kooooo1?l000000ooo003o0000ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000000_oo0003o`0000Wooooo00?o0000oooooooo
ool02_ooool000?ooooo00?o<S8bokZj^_ooool02Oooool00oo<c<co<S8booooo`0@ooooo`03oc8b
<_o<c<cooooo01oooooo00?o0000ooooooooool01_ooool4o`000003ool00?l0003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Ko0000ool00?oo003oo`00o`000?oo0004o`0000Wooooo00?o0000oooooooo
ool02_ooool000?ooooo00?oMgMgohN7QomgMgL00_l000000om4A4Coc<c<ooooo`04ooooo`03ofIV
I_nYZJWooooo00Cooooo2?l00004ooooo`03oiRHV?mVIVKooooo01oooooo00?o0000ooooooooool0
1_ooool4o`000003ool00?l0003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Ko0000ool00?oo003oo`00
o`000?oo0004o`0000Wooooo00?o0000ooooooooool02_ooool000?ooooo00SoV9RHoa0@4?n7QhOo
k^k^oooooonHV9So410@olc<c0Cooooo00?o<S8booooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?ok^k^oc8b<_ooool07oooool00ol0003oooooooooo`06
ooooo`Ko00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001_l0003oo`00ool00?oo003o0000ool000Co00002?oo
ool2o`0000cooooo0003ooooo`03okZj^_lb<S;ooooo00?ooooo00?oV9RHodA4A?ooool00oooool0
0olb<S;oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o410@ooooooooool00oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo1_l00004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0004o`000?oo003oo`00ool000Ko00002Oooool00ol0003oooooooooo`0:ooooo`001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o<S8booooooooool01Oooool01?l0
003oooooooooool@4108ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool4
o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Co0000ool00?oo003oo`001Ol0000:ooooo`03o`000?oooooo
oooo00[ooooo0004ooooo`03odA4A?nHV9Sooooo00;ooooo00?ok^k^o`000?ooool00oooool00olQ
8B7oooooooooo`05ooooo`Co00002?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Sooooo1?l00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00004o`000?oo003oo`00ool000Go00002_ooool00ol0
003oooooooooo`0:ooooo`001?ooool01onj^[[o0000okZj^_ooooook^k^ofIVI_mEEED01?ooool0
0olb<S;ok^k^ooooo`05ooooo`04o`000?oooooooooooa0@40Oooooo00?ogMgMoc8b<_ooool07ooo
ool00ol0003oooooooooo`08ooooo`Co00001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001?l0003oo`00ool00?oo
0004o`0000_ooooo00?o0000ooooooooool02_ooool000Gooooo00KoZJVYob4Q8Ol0003o0000oeEE
EOo^k^h4ooooo`03ofIVI_nHV9Sooooo00Gooooo00?o0000ooooooooool00oooool00ol@413ooooo
ooooo`02ooooo`03oiRHV?mVIVKooooo01oooooo00?o0000ooooooooool02Oooool3o`0000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Co0000ool00?oo003oo`001?l0000;ooooo`03o`000?oooooooooo00[ooooo
000?ooooo`03omgMgOlQ8B7ooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03oa0@4?o<c<cooooo01oooooo00?o0000ooooooooool02Oooool4o`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Co0000ool00?oo003oo`001?l0000:ooooo`;o00003?ooool0013ooooo00?o<S8b
okZj^_ooool00oooool8o`0000?ooooo00?o^[Zjoc8b<_ooool08?ooool00ol0003oooooooooo`09
ooooo`Co00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001?l0003oo`00ool00?oo0003o`0000cooooo00?o0000
ooooooooool02_ooool0013ooooo00?o^[Zjoc8b<_ooool03_ooool00olb<S;o^[Zjooooo`0Poooo
o`03o`000?oooooooooo00[ooooo0ol00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00004o`000?oo003oo`00ool0
00?o00003?ooool00ol0003oooooooooo`0:ooooo`00A?ooool00ol0003oooooooooo`0:ooooo`Co
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00004o`0000cooooo00?o0000ooooooooool0
2_ooool004Cooooo00?o0000ooooooooool02_ooool4o`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00001?l0000<ooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooooooo
00_ooooo1?l000000ooo003o0000ool00003ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003o`0000gooooo00?o0000oooooooo
ool02_ooool004Cooooo00?o0000ooooooooool02oooool4o`000003ool00?l0003oo`0000?oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000Ko00003?oo
ool2o`0000cooooo0014ooooo`03o`000?oooooooooo00_ooooo1?l000000ooo003o0000ool00003
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oooooo`000003o`0000gooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000oooooooo
ool02oooool6o`0000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oooooo000000;o00003_ooool00ol0003oooooooooo`0:ooooo`00;ooo
ool4o`000003oa0@4?oooooooooo00?ooooo00GoV9RHoa0@4?l0003o0000ofIVIP06ooooo`03o`00
0?oooooooooo00_ooooo1_l00004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo0005o`0000kooooo00?o0000ooooooooool02_ooool0037ooooo00?o0000
ooooooooool01Oooool01_l@413oQhN7ooooooooooooMgMgofIVIPGooooo00?o0000ooooooooool0
3Oooool4o`0000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool000Go00003_ooool00ol0003oooooooooo`0:ooooo`00<Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool4o`0000Coo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000Co00003oooool00ol0
003oooooooooo`0:ooooo`00<Oooool00ol0003oooooooooo`09ooooo`03onk^k_l0003ooooo00Co
oooo0_l0000>ooooo`Co00001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`001?l0000>ooooo`;o00003?ooool0037ooooo00?o0000ooooooooool01Ooo
ool01_l@413oV9RHooooooooooooMgMgofIVIPGooooo00?o0000ooooooooool03_ooool4o`0000?o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000?o0000
4?ooool00ol0003oooooooooo`0:ooooo`00<Oooool00ol0003oooooooooo`05ooooo`05o`000?lQ
8B7o0000o`000?mVIVH01_ooool00ol0003oooooooooo`0>ooooo`Co00000ooo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00004o`000?oo003oo`00ool000Co00004?ooool00ol0003ooooo
ooooo`0:ooooo`00<Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool03oooool3o`0000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1?l0003oo`00ool00?oo0004o`00013ooooo00?o0000ooooooooool02_ooool0037ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo1?l00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00001?l0000Aoooo
o`03o`000?oooooooooo00[ooooo000_ooooo`03o`000?m4A4Co000000Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0?ooooo`Co00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000Co00004Oooool00ol0003oooooooooo`0:ooooo`00;ooo
ool00oo<c<coEEEEo`000007ooooo`Go00001_ooool00ol0003oooooooooo`0@ooooo`?o00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o00004Oooool2
o`0000cooooo0014ooooo`03o`000?oooooooooo013ooooo1_l00004ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003o000000?o00004_ooool00ol0003oooooooooo`0:ooooo`00A?ooool00ol0003ooooo
ooooo`0@ooooo`Co000000?oooooo`000?oo00000ooo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00o`00
0003o`0001;ooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool04Oooool5
o`0000Coo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`001_l0000Booooo`03o`000?oooooooooo00[ooooo0014ooooo`03
o`000?oooooooooo017ooooo1Ol00004ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000Go00004oooool00ol0003ooooo
ooooo`0:ooooo`00A?ooool00ol0003oooooooooo`0Booooo`Co00001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0004
o`0001?ooooo0_l0000<ooooo`00A?ooool00ol0003oooooooooo`0Booooo`Co00001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Co0000ool00?oo
003oo`001Ol0000Dooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooooooo01?o
oooo1?l00003ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00001?l0003oo`00ool00?oo0004o`0001Gooooo00?o0000ooooooooool02_ooool004Cooooo
00?o0000ooooooooool04oooool4o`0000?oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000Co00005_ooool00ol0003ooooooooo
o`0:ooooo`00A?ooool00ol0003oooooooooo`0Dooooo`Co00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00001?l0000Foooo
o`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooooooo01Cooooo1?l00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
o`000003o`0001Oooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool05Ooo
ool6o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0006o`00
01Kooooo0_l0000<ooooo`00A?ooool00ol0003oooooooooo`0Eooooo`Co000000?oooooo`000?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool000Ko00005ooo
ool00ol0003oooooooooo`0:ooooo`00A?ooool00ol0003oooooooooo`0Fooooo`Go00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool000Co000000?oo`00o`000?oo
ool05_ooool00ol0003oooooooooo`0:ooooo`00A?ooool00ol0003oooooooooo`0Fooooo`Go0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool000Ko00005oooool0
0ol0003oooooooooo`0:ooooo`00A?ooool00ol0003oooooooooo`0Gooooo`Co00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00001?l0003oo`00ool00?oo0004o`0001[ooooo00?o0000oooooooo
ool02_ooool004Cooooo00?o0000ooooooooool05oooool5o`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00001Ol0000Jooooo`03o`000?oooooooooo00[ooooo0014oooo
o`03o`000?oooooooooo01Sooooo1?l00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000Co00006_ooool2o`0000cooooo0014ooooo`03o`000?oooooooooo01Wooooo1?l0
00000ooo003o0000ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00o`000003o`0001cooooo00?o0000oooo
ooooool02_ooool004Cooooo00?o0000ooooooooool06Oooool6o`0000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003o000000?o00007?ooool00ol0003oooooooooo`0:ooooo`00;_ooool6o`0000Kooooo00CoV9RH
o`000?l0003oV9RH1_ooool00ol0003oooooooooo`0Jooooo`Go00001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`001_l0000Loooo
o`03o`000?oooooooooo00[ooooo000^ooooo`03oiRHV?l0003ogMgM00;ooooo00?o410@oooooooo
ool00oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00?o0000ooooooooool06_ooool5
o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool000Ko00007?ooool00ol0003oooooooooo`0:ooooo`00;oooool00on7QhOo8B4Q
onk^kP07ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00ol0003oooooooooo`0Koooo
o`Go00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`001?l0000Nooooo`03o`000?oooooooooo00[ooooo000`ooooo`03ojVYZOlQ
8B7ok^k^00Kooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooo`;o00007Oooool4o`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0003ool000Co00007_ooool2o`0000cooooo000aooooo`03oiRHV?lb<S;ooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01gooooo1?l00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00000ooo0004o`0001oooooo00?o0000ooooooooool02_ooool003;ooooo00?oA4A4ogMgMoooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
7Oooool5o`000003ool00?l0003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000000_oo0004o`00023ooooo00?o0000ooooooooool02_ooool003;ooooo00?ogMgMoa0@
4?ooool01?ooool01_l0003ok^k^ooooooooooook^k^o`0000Gooooo00?o0000ooooooooool07_oo
ool6o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00004o`000?oo003oo`00ool000Oo00008?ooool00ol0
003oooooooooo`0:ooooo`00<oooool00ol0003oooooooooo`03ooooo`06odA4A?nHV9Sooooooooo
oonHV9SoA4A41Oooool00ol0003oooooooooo`0Nooooo`Ko00001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Co0000ool00?oo003oo`001_l0000Qooooo`03o`000?oooooooooo00[ooooo000^ooooo`06o`00
0?n7QhOok^k^oooooonHV9SoEEEE1Oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00?o
0000ooooooooool08?ooool5o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00004o`000?oo003oo`00ool0
00Go00008_ooool00ol0003oooooooooo`0:ooooo`00;_ooool01_nYZJWo<S8bo`000?l0003oEEEE
onk^kPKooooo00CoV9RHo`000?l0003oV9RH1_ooool00ol0003oooooooooo`0Qooooo`Go00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00001Ol0000Rooooo`;o00003?ooool004Cooooo
00?o0000ooooooooool08_ooool5o`000003ool00?l0003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00o`000004o`00
02Cooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool08oooool4o`000003
ool00?l0003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00o`000003o`0002Gooooo00?o0000ooooooooool02_ooool0
04Cooooo00?o0000ooooooooool08oooool6o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo0005o`0002Kooooo00?o0000ooooooooool02_oo
ool004Cooooo00?o0000ooooooooool08oooool6o`0000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0005o`0002Kooooo00?o0000ooooooooool0
2_ooool004Cooooo00?o0000ooooooooool09Oooool5o`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Co0000ool00?oo003oo`001_l0000Vooooo`03o`000?oooooooooo
00[ooooo0014ooooo`03o`000?oooooooooo02Kooooo1Ol00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000Go00009oooool2o`0000cooooo0014oooo
o`03o`000?oooooooooo02Oooooo1ol00004ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0007o`0002Wooooo00?o
0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool0:?ooool6o`0000Coo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool000Ko0000:_ooool00ol0003oooooooooo`0:ooooo`00A?ooool00ol0003ooooooooo
o`0Yooooo`Ko00000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00004o`000?oo003oo`00ool000Ko0000:oooool00ol0003oooooooooo`0:oooo
o`00A?ooool00ol0003oooooooooo`0Zooooo`Ko00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o000000Ko0000;?ooool0
0ol0003oooooooooo`0:ooooo`00A?ooool00ol0003oooooooooo`0/ooooo`Go000000?oo`00o`00
0?oo00000ooo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0007o`0002kooooo00?o
0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool0;Oooool6o`0000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`001_l0000^ooooo`;o00003?ooool004Cooooo00?o
0000ooooooooool0;_ooool6o`0000?oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000Ko
0000<Oooool00ol0003oooooooooo`0:ooooo`00A?ooool00ol0003oooooooooo`0_ooooo`Ko0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`002?l0000booooo`03o`000?oooooooooo00[ooooo0014ooooo`03
o`000?oooooooooo033ooooo2?l00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00004o`000?oo003oo`00ool000So0000<oooool00ol0003oooooooooo`0:
ooooo`00A?ooool00ol0003oooooooooo`0booooo`So000000?oo`00o`000?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?l000002?l0000dooooo`03o`000?oooooo
oooo00[ooooo0014ooooo`03o`000?oooooooooo03;ooooo2_l00004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo0008o`0003Oooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000oooo
ooooool0=_ooool8o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000003ool000Oo0000>?ooool2
o`0000cooooo0014ooooo`03o`000?oooooooooo03Sooooo2Ol00004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo000=o`0003_ooooo00?o0000ooooooooool02_ooool004Co
oooo00?o0000ooooooooool0>_ooool=o`0000?oo`0000Co0000ool00?oo003oo`003Ol0000loooo
o`03o`000?oooooooooo00[ooooo000^ooooo`Ko00001Oooool01OnHV9So410@o`000?l0003oIVIV
00Kooooo00?o0000ooooooooool0??oooolMo`0003kooooo00?o0000ooooooooool02_ooool002ko
oooo00?oV9RHo`000?oMgMd00_ooool00ol@413oooooooooo`03ooooo`06oa0@4?n7QhOooooooooo
oomgMgOoIVIV1Oooool00ol0003oooooooooo`0ooooooaOo00000_oo00000ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo00[ooooo000_ooooo`03ohN7QolQ8B7ok^k^00cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`15ooooo`_o00000oooool6o`0003kooooo00?o0000oooo
ooooool02_ooool0033ooooo00?oZJVYob4Q8Oo^k^h02_ooool00oo^k^ko0000ooooo`04ooooo`;o
0000Uoooool2o`0000cooooo000aooooo`03oiRHV?lb<S;ooooo00Gooooo00Ko410@oiRHV?oooooo
ooooogMgMomVIVH5ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0:ooooo`00<_ooool00om4A4CoMgMgooooo`04ooooo`05o`000?lQ8B7o0000o`00
0?mVIVH01_oooonKo`0000cooooo000booooo`03omgMgOl@413ooooo00Cooooo00?o0000oooooooo
ool0[oooool003?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2_ooooo`00;_oo
ool01_l0003oQhN7onk^k_ooooooV9RHoeEEE@Gooooo00?o0000ooooooooool0[oooool002kooooo
00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h5ooooo`Go0000[Oooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-150.848, -10.0147, 1.03781, \
0.168904}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
To analyze the level spacing statistics we must unfold the sequence \
of eigenvalues so that the unfolded eigenvalues are distributed uniformly on \
large scales (there will, of course, still be fluctuations about uniformity \
on small scales - that's what we want to focus our attention on).  For a \
sequence that follows the Wigner semicircle law the unfolded eigenvalues are \
given by\
\>", "Text"],

Cell[BoxData[
    \(e = \((E \@\( 2  N - E\^2\) + 
            2  N\ \(sin\^\(-1\)\) \((E/\@\(2  N\))\) + 
            N\ \[Pi])\)/\((2  \[Pi])\)\)], "DisplayFormula"],

Cell[TextData[{
  "The plot below shows the density of these unfolded eigenvalues.  As \
expected, the density is essentially uniform.  Note: watch out for \
eigenvalues with absolute value greater than ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(2  N\)\)]],
  ", which can occasiaonally occur, because these will lead to complex \
unfolded eigenvalues which will produce an error when constructing the \
histogram."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(UGOEev = 
      Table[\((GOEev[\([i]\)]*Sqrt[2*n - GOEev[\([i]\)]^2] + 
              2*n*ArcSin[GOEev[\([i]\)]/Sqrt[2*n]] + n*Pi)\)/\((2*Pi)\), {i, 
          1, n}]; GOEDensity = 
      Histogram[UGOEev, HistogramCategories \[Rule] 25, 
        HistogramScale \[Rule] n, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<e\>", "\<\[Rho](e)\>"}, 
        RotateLabel \[Rule] False]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.66967e-17 0.000333333 0.0147151 0.57687 [
[.16667 -0.0125 -16.3438 -18 ]
[.16667 -0.0125 16.3438 0 ]
[.33333 -0.0125 -21.125 -18 ]
[.33333 -0.0125 21.125 0 ]
[.5 -0.0125 -21.125 -18 ]
[.5 -0.0125 21.125 0 ]
[.66667 -0.0125 -21.125 -18 ]
[.66667 -0.0125 21.125 0 ]
[.83333 -0.0125 -21.125 -18 ]
[.83333 -0.0125 21.125 0 ]
[1 -0.0125 -21.125 -18 ]
[1 -0.0125 21.125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .13009 -32.6875 -9 ]
[-0.0125 .13009 0 9 ]
[-0.0125 .24546 -32.6875 -9 ]
[-0.0125 .24546 0 9 ]
[-0.0125 .36084 -32.6875 -9 ]
[-0.0125 .36084 0 9 ]
[-0.0125 .47621 -32.6875 -9 ]
[-0.0125 .47621 0 9 ]
[-0.0125 .59159 -13.5625 -9 ]
[-0.0125 .59159 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -74.9375 -9 ]
[-0.01875 .30902 -32.6875 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -82.125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -82.125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1500) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -82.125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -82.125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2500) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -82.125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3000) show
1.000 setlinewidth
grestore
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13009 m
.00625 .13009 L
s
gsave
-0.0125 .13009 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .24546 m
.00625 .24546 L
s
gsave
-0.0125 .24546 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .36084 m
.00625 .36084 L
s
gsave
-0.0125 .36084 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .47621 m
.00625 .47621 L
s
gsave
-0.0125 .47621 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .59159 m
.00625 .59159 L
s
gsave
-0.0125 .59159 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04356 m
.00375 .04356 L
s
0 .0724 m
.00375 .0724 L
s
0 .10125 m
.00375 .10125 L
s
0 .15893 m
.00375 .15893 L
s
0 .18778 m
.00375 .18778 L
s
0 .21662 m
.00375 .21662 L
s
0 .27431 m
.00375 .27431 L
s
0 .30315 m
.00375 .30315 L
s
0 .33199 m
.00375 .33199 L
s
0 .38968 m
.00375 .38968 L
s
0 .41852 m
.00375 .41852 L
s
0 .44737 m
.00375 .44737 L
s
0 .50505 m
.00375 .50505 L
s
0 .5339 m
.00375 .5339 L
s
0 .56274 m
.00375 .56274 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.03333 .61428 m
.03333 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.13333 .61428 m
.13333 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.23333 .61428 m
.23333 .61803 L
s
.26667 .61428 m
.26667 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.43333 .61428 m
.43333 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.53333 .61428 m
.53333 .61803 L
s
.56667 .61428 m
.56667 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.76667 .61428 m
.76667 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.93333 .61428 m
.93333 .61803 L
s
.96667 .61428 m
.96667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13009 m
1 .13009 L
s
.99375 .24546 m
1 .24546 L
s
.99375 .36084 m
1 .36084 L
s
.99375 .47621 m
1 .47621 L
s
.99375 .59159 m
1 .59159 L
s
.125 Mabswid
.99625 .04356 m
1 .04356 L
s
.99625 .0724 m
1 .0724 L
s
.99625 .10125 m
1 .10125 L
s
.99625 .15893 m
1 .15893 L
s
.99625 .18778 m
1 .18778 L
s
.99625 .21662 m
1 .21662 L
s
.99625 .27431 m
1 .27431 L
s
.99625 .30315 m
1 .30315 L
s
.99625 .33199 m
1 .33199 L
s
.99625 .38968 m
1 .38968 L
s
.99625 .41852 m
1 .41852 L
s
.99625 .44737 m
1 .44737 L
s
.99625 .50505 m
1 .50505 L
s
.99625 .5339 m
1 .5339 L
s
.99625 .56274 m
1 .56274 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .59178 L
.03333 .59178 L
.03333 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .59178 L
.03333 .59178 L
.03333 .01472 L
0 .01472 L
s
1 0 0 r
.03333 .01472 m
.03333 .60332 L
.06667 .60332 L
.06667 .01472 L
F
0 g
.03333 .01472 m
.03333 .60332 L
.06667 .60332 L
.06667 .01472 L
.03333 .01472 L
s
1 0 0 r
.06667 .01472 m
.06667 .57447 L
.1 .57447 L
.1 .01472 L
F
0 g
.06667 .01472 m
.06667 .57447 L
.1 .57447 L
.1 .01472 L
.06667 .01472 L
s
1 0 0 r
.1 .01472 m
.1 .59755 L
.13333 .59755 L
.13333 .01472 L
F
0 g
.1 .01472 m
.1 .59755 L
.13333 .59755 L
.13333 .01472 L
.1 .01472 L
s
1 0 0 r
.13333 .01472 m
.13333 .59178 L
.16667 .59178 L
.16667 .01472 L
F
0 g
.13333 .01472 m
.13333 .59178 L
.16667 .59178 L
.16667 .01472 L
.13333 .01472 L
s
1 0 0 r
.16667 .01472 m
.16667 .59178 L
.2 .59178 L
.2 .01472 L
F
0 g
.16667 .01472 m
.16667 .59178 L
.2 .59178 L
.2 .01472 L
.16667 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .59178 L
.23333 .59178 L
.23333 .01472 L
F
0 g
.2 .01472 m
.2 .59178 L
.23333 .59178 L
.23333 .01472 L
.2 .01472 L
s
1 0 0 r
.23333 .01472 m
.23333 .59178 L
.26667 .59178 L
.26667 .01472 L
F
0 g
.23333 .01472 m
.23333 .59178 L
.26667 .59178 L
.26667 .01472 L
.23333 .01472 L
s
1 0 0 r
.26667 .01472 m
.26667 .59178 L
.3 .59178 L
.3 .01472 L
F
0 g
.26667 .01472 m
.26667 .59178 L
.3 .59178 L
.3 .01472 L
.26667 .01472 L
s
1 0 0 r
.3 .01472 m
.3 .59178 L
.33333 .59178 L
.33333 .01472 L
F
0 g
.3 .01472 m
.3 .59178 L
.33333 .59178 L
.33333 .01472 L
.3 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .59755 L
.36667 .59755 L
.36667 .01472 L
F
0 g
.33333 .01472 m
.33333 .59755 L
.36667 .59755 L
.36667 .01472 L
.33333 .01472 L
s
1 0 0 r
.36667 .01472 m
.36667 .58601 L
.4 .58601 L
.4 .01472 L
F
0 g
.36667 .01472 m
.36667 .58601 L
.4 .58601 L
.4 .01472 L
.36667 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .59178 L
.43333 .59178 L
.43333 .01472 L
F
0 g
.4 .01472 m
.4 .59178 L
.43333 .59178 L
.43333 .01472 L
.4 .01472 L
s
1 0 0 r
.43333 .01472 m
.43333 .59178 L
.46667 .59178 L
.46667 .01472 L
F
0 g
.43333 .01472 m
.43333 .59178 L
.46667 .59178 L
.46667 .01472 L
.43333 .01472 L
s
1 0 0 r
.46667 .01472 m
.46667 .58601 L
.5 .58601 L
.5 .01472 L
F
0 g
.46667 .01472 m
.46667 .58601 L
.5 .58601 L
.5 .01472 L
.46667 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .59178 L
.53333 .59178 L
.53333 .01472 L
F
0 g
.5 .01472 m
.5 .59178 L
.53333 .59178 L
.53333 .01472 L
.5 .01472 L
s
1 0 0 r
.53333 .01472 m
.53333 .59178 L
.56667 .59178 L
.56667 .01472 L
F
0 g
.53333 .01472 m
.53333 .59178 L
.56667 .59178 L
.56667 .01472 L
.53333 .01472 L
s
1 0 0 r
.56667 .01472 m
.56667 .59755 L
.6 .59755 L
.6 .01472 L
F
0 g
.56667 .01472 m
.56667 .59755 L
.6 .59755 L
.6 .01472 L
.56667 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .59178 L
.63333 .59178 L
.63333 .01472 L
F
0 g
.6 .01472 m
.6 .59178 L
.63333 .59178 L
.63333 .01472 L
.6 .01472 L
s
1 0 0 r
.63333 .01472 m
.63333 .59178 L
.66667 .59178 L
.66667 .01472 L
F
0 g
.63333 .01472 m
.63333 .59178 L
.66667 .59178 L
.66667 .01472 L
.63333 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .59755 L
.7 .59755 L
.7 .01472 L
F
0 g
.66667 .01472 m
.66667 .59755 L
.7 .59755 L
.7 .01472 L
.66667 .01472 L
s
1 0 0 r
.7 .01472 m
.7 .58601 L
.73333 .58601 L
.73333 .01472 L
F
0 g
.7 .01472 m
.7 .58601 L
.73333 .58601 L
.73333 .01472 L
.7 .01472 L
s
1 0 0 r
.73333 .01472 m
.73333 .59178 L
.76667 .59178 L
.76667 .01472 L
F
0 g
.73333 .01472 m
.73333 .59178 L
.76667 .59178 L
.76667 .01472 L
.73333 .01472 L
s
1 0 0 r
.76667 .01472 m
.76667 .59178 L
.8 .59178 L
.8 .01472 L
F
0 g
.76667 .01472 m
.76667 .59178 L
.8 .59178 L
.8 .01472 L
.76667 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .58601 L
.83333 .58601 L
.83333 .01472 L
F
0 g
.8 .01472 m
.8 .58601 L
.83333 .58601 L
.83333 .01472 L
.8 .01472 L
s
1 0 0 r
.83333 .01472 m
.83333 .59755 L
.86667 .59755 L
.86667 .01472 L
F
0 g
.83333 .01472 m
.83333 .59755 L
.86667 .59755 L
.86667 .01472 L
.83333 .01472 L
s
1 0 0 r
.86667 .01472 m
.86667 .59178 L
.9 .59178 L
.9 .01472 L
F
0 g
.86667 .01472 m
.86667 .59178 L
.9 .59178 L
.9 .01472 L
.86667 .01472 L
s
1 0 0 r
.9 .01472 m
.9 .59755 L
.93333 .59755 L
.93333 .01472 L
F
0 g
.9 .01472 m
.9 .59755 L
.93333 .59755 L
.93333 .01472 L
.9 .01472 L
s
1 0 0 r
.93333 .01472 m
.93333 .58601 L
.96667 .58601 L
.96667 .01472 L
F
0 g
.93333 .01472 m
.93333 .58601 L
.96667 .58601 L
.96667 .01472 L
.93333 .01472 L
s
1 0 0 r
.96667 .01472 m
.96667 .58601 L
1 .58601 L
1 .01472 L
F
0 g
.96667 .01472 m
.96667 .58601 L
1 .58601 L
1 .01472 L
.96667 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00S_ooool0
1_mgMgOo410@o`000?l@413oEEEEomgMgEOooooo002=ooooo`07ogMgMom4A4CogMgMoooooooMgMgo
QhN7ob4Q8@1Gooooo`00SOooool00ol@413ok^k^ooooo`1Kooooo`00SOooool7o`0005Oooooo002=
ooooo`03oa0@4?oMgMgooooo00;ooooo00?ogMgMo`000?ooool0E_ooool008gooooo00OoQhN7ob4Q
8Onj^[[oooooomgMgOlQ8B7oMgMg05Oooooo002>ooooo`05ohN7Qol@413o0000oa0@4?mgMgL0F?oo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00Eoooool01OnHV9So410@o`000?l0003oIVIV00Kooooo00CoV9RH
o`000?l0003oV9RH0oooool6o`000003oiRHV?oooooooooo00;ooooo00CoV9RHo`000?l0003oV9RH
1_ooool00onHV9So0000o`000003o`000005oa0@4?oooooooooooooooonHV9P00_l000001?l:2P[o
0000o`000?mVIVH6ooooo`Ko00001?ooool00onHV9So0000o`000002o`000003oiRHV?oooooooooo
00Cooooo00?oV9RHo`000?l000001?l00003ooooo`04oiRHV?l0003o0000o`X:2P;o000000?oIVIV
ooooooooool01?ooool00onHV9So0000o`000002o`000003ofIVI_oooooooooo00;ooooo00?oV9RH
o`000?l000000_l000000onHV9Soooooooooo`04ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00Co
V9RHo`000?l0003oV9RH1Oooool005Oooooo00Ko410@ohN7QoooooooooooogMgMomVIVH4ooooo`06
okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_l0003o8B4QomgMgOoMgMgo8B4QokZj^P;ooooo
00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o00001?oo
ool02Onj^[[o8B4QomgMgOl>3Pko4A4AokZj^_ooooooMgMgofIVIP04ooooo`07okZj^_lC4a?o0000
omgMgOlQ8B7o^[Zjoa0@4003ooooo`08okZj^_lQ8B7oXZ:RoadM7OlL71coXJ6Qob4Q8Onj^[X4oooo
o`08okZj^_lQ8B7oQ8B4o`000?lL71co^[Zjooooool@4102ooooo`09okZj^_lQ8B7ogMgMo`h>3_lA
4A7o^[ZjoooooomgMgOoIVIV00Cooooo00So^[Zjob4Q8Ol>3Pko/;2`ob4Q8Onj^[[oMgMgofIVIP;o
oooo00So^[Zjob4Q8OnRXZ;o7AdMoa`L7?nQXJ7o8B4QokZj^PCooooo00Ko^[Zjob4Q8OoMgMgogMgM
ob4Q8Onj^[X4ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool005cooooo00?o0000oooo
ooooool00_ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo00Ko0000oiRHV?oooooooooo
oiRHV?m4A4@2ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41?ooool01_m4A4CoV9RHoooooooo
ooooV9RHo`0000Cooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@2ooooo`03o`000?oooooooooo
00;ooooo00KoA4A4oiRHV?n7QhOo8B4Qohf=SOm4A4@4ooooo`03odA4A?nHV9SoA4A400;oV9RH00?o
A4A4oiRHV?m4A4@01?ooool01_m4A4CoV9RHoooooon7QhOo51@Doclo?`Cooooo00KoA4A4oiRHV?oo
oooooooooiRHV?m4A4@2ooooo`03o`000?oooooooooo00;ooooo00SoA4A4oiRHV?oooooooooooiRH
V?m4A4Coooooo`0000;ooooo00?oA4A4oiRHV?m4A4@00_nHV9P00om4A4CoV9RHodA4A004ooooo`06
odA4A?nHV9SooooooooooonHV9SoA4A41?ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo
001Kooooo`03onk^k_l0003ooooo00?ooooo00Ko0000onk^k_ooooooooooonk^k_l00004ooooo`06
o`000?o^k^koooooooooooo^k^ko00000_ooool01_l0003ok^k^ooooooooooook^k^o`0000Cooooo
00Ko0000onk^k_ooooooooooonk^k_l00004ooooo`09o`000?o^k^koooooooooooo^k^ko0000oooo
ooo^k^ko000000Cooooo00Ko0000onk^k_ooooooZJVYoalO7ol00004ooooo`03o`000?o^k^ko0000
00;ok^k^00?o0000onk^k_l000001?ooool01ol0003ok^k^ooooooooooooWYjNo`000?o^k^h00ooo
ool02Ol0003ok^k^ooooooooooook^k^o`000?ooooook^k^o`000004ooooo`08o`000?o^k^kooooo
ooooooo^k^ko0000ooooool00002ooooo`03o`000?o^k^ko000000;ok^k^00?o0000onk^k_l00000
1?ooool01_l0003ok^k^ooooooooooook^k^o`0000Cooooo00Ko0000onk^k_ooooooooooonk^k_l0
0004ooooo`00Eoooool01_l@413oV9RHooooooooooooMgMgofIVIPCooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool02Ol0003oooooooooool@413oV9RHo`000?ooooooMgMgofIVIP04ooooo`06o`000?oo
oooooooooooooonHV9So00001?ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000Co
oooo00?o0000ooooooooool00_ooool00ol0003o<S8booooo`02ooooo`09o`000?oooooooooooa0@
4?nHV9So0000oooooomgMgOoIVIV00Cooooo00?o0000ooooooooool00_ooool00ol0003oZJVYodA4
A002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000001?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`00Eoooool01Ol0003o8B4Qo`000?l0003oIVIV00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool01Ol0003oooooooooool0003o8B4Q00;o000000?oIVIVooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?mgMgOooooo00;ooooo00?o0000ooooool000000_ooool00ol0003o
ooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000odA4A?mgMgL00_ooool01Ol0003o
ooooooooool0003o8B4Q00;o000000?oIVIVooooooooool00oooool01Ol0003ooooooooooooooooo
8B4Q00;o000000KogMgMoooooooooooo0000ooooool00002ooooo`03o`000?oooooo000000Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool005Oooooo00?o0000ooooooooool01oooool01_l0003ok^k^oooo
ooooooook^k^o`0000Cooooo00Ko0000onk^k_ooooooooooonk^k_l00002ooooo`06o`000?o^k^ko
ooooooooooo^k^ko00001?ooool01_l0003ok^k^ooooooooooook^k^o`0000Cooooo00Ko0000onk^
k_oooooo0000onk^k_l00007ooooo`07o`000?o^k^koooooooooooo^k^ko0000oa0@4003ooooo`03
o`000?o^k^ko000000;ok^k^00?o0000onk^k_l000001?ooool02?l0003ok^k^ooooooooooook^k^
o`000?oMgMgo410@0_ooool01_l0003ok^k^ooooool0003ok^k^o`0000Oooooo00So0000onk^k_oo
ooooooooonk^k_l0003oZJVYoc8b<P;ooooo00?o0000onk^k_l000000_o^k^h00ol0003ok^k^o`00
0004ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool01_l0003ok^k^ooooooooooook^k^
o`0000Cooooo001Gooooo`03o`000?oooooooooo00Oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4
A4@4ooooo`06o`000?nHV9SooooooooooonHV9SoA4A40_ooool01_m4A4CoV9RHooooooooooooV9RH
odA4A0Cooooo00KoA4A4oiRHV?oooooooooooiRHV?l00004ooooo`06odA4A?nHV9Soooooo`000?nH
V9SoA4A41oooool01om4A4CoV9RHooooooooooooV9RHodA4A?l000000oooool00om4A4CoV9RHodA4
A002oiRHV003odA4A?nHV9SoA4A400Cooooo00SoA4A4oiRHV?oooooooooooiRHV?m4A4Coooooo`00
00;ooooo00KoA4A4oiRHV?oooooo0000oiRHV?m4A4@7ooooo`08odA4A?nHV9SooooooooooonHV9So
A4A4ooooool00002ooooo`03odA4A?nHV9SoA4A400;oV9RH00?oA4A4oiRHV?m4A4@01?ooool01_m4
A4CoV9RHooooooooooooV9RHodA4A0Cooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@4ooooo`00
Eoooool00ol0003oooooooooo`07ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj0_ooool01?l0
003oA4A4o`000?lQ8B42omgMg@06ob4Q8Onj^[[ooooooooooonj^[[o8B4Q0_oMgMd00olQ8B7o^[Zj
ooooo`03ooooo`06okZj^_lQ8B7ogMgMo`000?l820So00001?ooool01_nj^[[o8B4QomgMgOl0003o
8B4QokZj^POooooo00Oo^[Zjo`000?meMGGoc/k>ob4Q8Om_KfooEEEE00?ooooo00So^[Zjob4Q8OnR
XZ;o7AdMoa`L7?nQXJ7o8B4QokZj^PCooooo00So^[Zjob4Q8Ol0003oMGEeoahN7_nj^[[oV9RHoeEE
E@;ooooo00Ko^[Zjob4Q8OoMgMgo0000ob4Q8Onj^[X7ooooo`08okZj^_lQ8B7o7AdMoj:RX_lQ8B7o
^[ZjofIVI_lb<S82ooooo`08okZj^_lQ8B7oXZ:RoadM7OlL71coXJ6Qob4Q8Onj^[X4ooooo`06okZj
^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PCooooo001G
ooooo`Go00001_ooool01?nHV9So0000o`000?nHV9P3ooooo`04olc<c?mEEEGo0000oiRHV0;o0000
00?oV9RHooooooooool00_ooool01?nHV9So0000o`000?nHV9P6ooooo`05oiRHV?l0003o0000oc8b
<_l000001Oooool00onHV9So0000o`000004o`0000Kooooo00KoIFEUo`000?l0003o0000oeEEEOo^
k^h4ooooo`03oiRHV?l0003o000000;o000000?oV9RHooooooooool01?ooool00onHV9So0000o`00
0002o`000003oeEEEOo^k^kooooo00;ooooo00?oV9RHo`000?l000001?l00006ooooo`03oiRHV?l0
003o000000;o000000?oA4A4onk^k_ooool00_ooool00onHV9So0000o`000002o`000003oiRHV?oo
oooooooo00Cooooo00CoV9RHo`000?l0003oV9RH1_ooool01?nHV9So0000o`000?nHV9P5ooooo`00
joooool00>_ooooo003[ooooo`00@oooool01?nHV9So0000o`000?nHV9RTooooo`00@_ooool01_nj
^[[o8B4QomgMgOoMgMgo8B4QokZj^PGoooooR?l0000Fooooo`00@_ooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A0Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05?ooool004;ooooo00Ko0000onk^k_oooooooooo
onk^k_l00005ooooohSo00005_ooool004;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000001Kooooo0012ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`00000Fooooo`00@_ooool01_l0003ok^k^oooooooo
ooook^k^o`0000Gooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000005_ooool004;ooooo00KoA4A4oiRHV?oooooooooo
oiRHV?m4A4@5ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000001Kooooo0012ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ
8B7o^[Zj1Oooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`00000Fooooo`00@oooool01?nHV9So0000o`000?nHV9P6oooo
o`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000001Kooooo001=ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000001Kooooo001=ooooo`05o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000001Kooooo001=ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000001Kooooo001=ooooo`05o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000001Kooooo001=ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000001Kooooo000`ooooo`04oiRHV?l0003o0000oiRH
V0Kooooo00?oEEEEo`000?mEEED01Oooool6o`0000Gooooo00Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000005_ooool002oo
oooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001Oooool00onHV9So0000omgMg@02
ooooo`03oa0@4?oooooooooo00?ooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000005_ooool002oooooo00KoA4A4oiRH
V?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?oQhN7ob4Q8Oo^k^h01ooo
ool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`00000Fooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000oooooo
00?oZJVYob4Q8Oo^k^h01_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`00000Fooooo`00;oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00kooooo00?oV9RHoc8b<_ooool01Oooool01Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
000Fooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?oA4A4
ogMgMoooool01?ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`00000Fooooo`00;oooool01_l0003ok^k^oooooooooooo
k^k^o`00017ooooo00?ogMgMoa0@4?ooool01?ooool01Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00000Fooooo`00;oooool0
1_m4A4CoV9RHooooooooooooV9RHodA4A1;ooooo00?o0000ooooooooool00oooool01Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`00000Fooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pgooooo00Ko0000ohN7Qoo^
k^kooooooiRHV?mEEED5ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000001Kooooo000`ooooo`04oiRHV?l0003o0000
oiRHV0kooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h5ooooo`05o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000001Kooooo
001=ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000001Kooooo001=ooooo`05o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000001Kooooo001=oooo
o`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000001Kooooo001=ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000001Kooooo001=ooooo`05o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000001Kooooo001=ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000001Kooooo000`ooooo`04oiRHV?l0003o
0000oiRHV0Kooooo00?oEEEEo`000?mEEED02Oooool2o`000003oa0@4?oooooooooo00;ooooo00Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000005_ooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o0000
2_ooool00ol0003oooooooooo`03ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000001Kooooo000_ooooo`06odA4A?nH
V9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`Ko00001?ooool01Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`00000Fooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00GoA4A4okZj
^_ooooooooooo`000005ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000001Kooooo000_ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03?ooool01OoMgMgo8B4Qoooooooooooo000000Gooooo00Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000005_ooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=oooo
o`04ogMgMonHV9Soooooo`0000Gooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000005_ooool0013ooooo00?o^[Zjoc8b
<_ooool03_ooool00olb<S;o^[Zjooooo`0;ooooo`06o`000?o^k^koooooooooooo^k^ko00003ooo
ool01?o^k^ko8B4Qooooool00005ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000001Kooooo0003ooooo`03o`000?oo
oooooooo00[ooooo00?o<S8bokZj^_ooool03_ooool00onj^[[o<S8booooo`0;ooooo`06odA4A?nH
V9SooooooooooonHV9SoA4A44?ooool00omgMgOoV9RHo`000005ooooo`05o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000001Ko
oooo0003ooooo`03oc8b<_nj^[[ooooo00Wooooo00?oc<c<oc8b<_ooool04?ooool00olb<S;oc<c<
ooooo`0:ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj4?ooool00oo^k^ko<S8bo`000005oooo
o`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000001Kooooo0003ooooo`03ogMgMon7QhOoMgMg00;o000000?oA4A4olc<c?oo
ool01?ooool00omVIVKoZJVYooooo`05ooooo`06ogMgMol@413o0000oa0@4?mEEEGogMgM1Oooool0
0onHV9SoIVIVooooo`0;ooooo`04oiRHV?l0003o0000oiRHV1;ooooo00?oV9RHoa0@4?ooool01?oo
ool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`00000Fooooo`000oooool02?nHV9So410@ohN7Qoo^k^kooooooiRHV?l@413o
c<c<1?ooool00olb<S;oooooooooo`04ooooo`07ogMgMom4A4CogMgMoooooooMgMgoQhN7ob4Q8@05
ooooo`03onk^k_lb<S;ooooo02Sooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000005_ooool000?ooooo00?o^[Zjoc8b
<_ooool00oooool00onHV9SoA4A4ooooo`03ooooo`03oc8b<_oooooooooo00Cooooo00?o410@onk^
k_ooool02_ooool00ol0003oooooooooo`0Wooooo`05o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000001Kooooo0004ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00olb<S;oooooooooo`04ooooo`Oo
00001_ooool00ol0003oooooooooo`0Wooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000001Kooooo0004ooooo`03odA4
A?nHV9Sooooo00;ooooo00?ok^k^o`000?ooool00oooool00olQ8B7oooooooooo`04ooooo`03oa0@
4?oMgMgooooo00;ooooo00?ogMgMo`000?ooool01Oooool00ol0003oooooooooo`0Wooooo`05o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000001Kooooo0004ooooo`07okZj^_l0003o^[Zjooooooo^k^koIVIVoeEEE@04ooooo`03
oc8b<_o^k^kooooo00Cooooo00OoQhN7ob4Q8Onj^[[oooooomgMgOlQ8B7oMgMg00Gooooo00?ogMgM
oc8b<_ooool0:?ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`00000Fooooo`001Oooool01_nYZJWo8B4Qo`000?l0003o
EEEEonk^kPCooooo00?oIVIVoiRHV?ooool01Oooool01On7QhOo410@o`000?l@413oMgMg00Kooooo
00?oV9RHofIVI_ooool0:?ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`00000Fooooo`003oooool00ooMgMgo8B4Qoooo
o`0@ooooo`03oa0@4?o<c<cooooo00_ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000
oeEEE@06ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^1?ooool01Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00000Foooo
o`004?ooool00olb<S;o^[Zjooooo`0>ooooo`03okZj^_lb<S;ooooo00_ooooo00Ko^[Zjob4Q8OoM
gMgogMgMob4Q8Onj^[X5ooooo`?o00001_ooool2ogMgM`;ooooo00?oMgMgoeEEEOooool00oooool0
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`00000Fooooo`004?ooool00onj^[[o<S8booooo`0>ooooo`03oc8b<_nj^[[ooooo
00_ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?o
8B4Qooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000001Kooooo000_
ooooo`06o`000?o^k^koooooooooooo^k^ko00003_ooool00ol0003ok^k^ooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000005_ooool002oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0<ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE1?ooool01Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`00000Fooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo
00Ko0000ogMgMol0003o0000oeEEEOo^k^h4ooooo`05o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000001Kooooo000_ooooo`06
o`000?o^k^koooooooooooo^k^ko00003_ooool00om4A4CoV9RHooooo`07ooooo`05o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000001Kooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A43_ooool00onj^[[o8B4Qoooo
o`07ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000001Kooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj
3oooool00omEEEGo<S8bomgMg@06ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000001Kooooo000`ooooo`04oiRHV?l0
003o0000oiRHV17ooooo00CoV9RHob4Q8Ol0003o8B4Q1?ooool01Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00000Fooooo`00
COooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`00000Fooooo`00COooool01Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00000Fooooo`00COooool0
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`00000Fooooo`00COooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00000Fooooo`00COooool01Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`00000Fooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Ko
oooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h4ooooo`05o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000001Kooooo000_oooo
o`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo00KoEEEEogMgMooooooooooo
ogMgMomEEED4ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000001Kooooo000_ooooo`06odA4A?nHV9SooooooooooonH
V9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`00000Fooooo`00;oooool01_l0003ok^k^ooooooooooook^k^
o`0000kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000001Kooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01_mE
EEGoMgMgooooooooooooMgMgoeEEE@Cooooo00Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000005_ooool002oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03omgMgOl0003o000000;o000000?ogMgM
ooooooooool00_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`00000Fooooo`00;oooool01_l0003ok^k^oooooooooooo
k^k^o`0000kooooo00Ko<S8bofIVI_o^k^kok^k^ofIVI_lb<S84ooooo`05o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000001Ko
oooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A43_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000005_ooool002oooooo00Ko^[Zjob4Q8OoM
gMgogMgMob4Q8Onj^[X>ooooo`06oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b1?ooool01Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`00000Fooooo`00<?ooool01?nHV9So0000o`000?nHV9P?ooooo`06onk^k_m4A4Co0000o`000?m4
A4Cok^k^1?ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`00000Fooooo`00COooool01Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00000Fooooo`00
COooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`00000Fooooo`00COooool01Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00000Fooooo`00COooool0
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`00000Fooooo`00COooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00000Fooooo`00COooool01Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`00000Fooooo`00@_ooool4o`000003oa0@4?oooooooooo00Cooooo00Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
5_ooool004Cooooo00?o0000ooooooooool01_ooool01Ol0003oo`00ool00?oo003o000000Coo`00
1_l00003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`00000Fooooo`00A?ooool00ol0003oooooooooo`06oooo
o`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`02ooooo`05o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0005o`0000Coo`0000Co0000ool0
0?oo003oo`001_l00003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo0005o`0000Coo`0000Co0000ool00?oo003o
o`001_l00003ool00003o`000?oo003oo`0000;oo`0000Co0000ool00?oo003oo`002_l0000Foooo
o`00A?ooool00ol0003oooooooooo`06ooooo`Go00001?oo00000ol0003oooooooooo`02ooooo`04
o`000?oo003oo`00ool001co00001?oo00001?l0003oooooooooooooool:o`0000Cooooo2_l00003
ool000[o00001?oo00001?l0003oooooooooooooool:o`0000Cooooo00Co0000ool00?oo003oo`00
1_l00003ool00003o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool004Cooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooooooool6o`0000Cooooo1Ol0000Jooooo`Ko0000
6_ooool5o`0000Sooooo1_l0000Aooooo`Go00001?ooool5o`0000Sooooo00?o0000ooooooooool0
5?ooool004Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`24ooooo`03o`000?oo
oooooooo01Cooooo0014ooooo`03o`000?oooooooooo00KoooooR?l0000Fooooo`00A?ooool00ol0
003oooooooooo`2Tooooo`00@_ooool00ol0003oA4A4o`00002Vooooo`00@_ooool00oo<c<coEEEE
o`00002Vooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-1716.66, -1.19438, 22.157, \
0.012803}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
 The code below calculates the spacings for the unfolded \
eigenvalues and generates a hisogram of the spacings.  \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SpcGOEev = 
        Table[UGOEev[\([i + 1]\)] - UGOEev[\([i]\)], {i, 1, 
            n - 2}];\)\), "\n", 
    \(\(int\  = \ Table[0 + i/8, {i, 0, 40}];\)\), "\n", 
    \(GOEHist = 
      Histogram[SpcGOEev, HistogramCategories \[Rule] int, 
        HistogramScale \[Rule] 1, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<s\>", "\<P(s)\>"}, 
        RotateLabel \[Rule] False]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.32 0.0147151 0.782196 [
[.16 -0.0125 -16.3438 -18 ]
[.16 -0.0125 16.3438 0 ]
[.32 -0.0125 -6.78125 -18 ]
[.32 -0.0125 6.78125 0 ]
[.48 -0.0125 -16.3438 -18 ]
[.48 -0.0125 16.3438 0 ]
[.64 -0.0125 -6.78125 -18 ]
[.64 -0.0125 6.78125 0 ]
[.8 -0.0125 -16.3438 -18 ]
[.8 -0.0125 16.3438 0 ]
[.96 -0.0125 -6.78125 -18 ]
[.96 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .09293 -32.6875 -9 ]
[-0.0125 .09293 0 9 ]
[-0.0125 .17115 -32.6875 -9 ]
[-0.0125 .17115 0 9 ]
[-0.0125 .24937 -32.6875 -9 ]
[-0.0125 .24937 0 9 ]
[-0.0125 .32759 -32.6875 -9 ]
[-0.0125 .32759 0 9 ]
[-0.0125 .40581 -32.6875 -9 ]
[-0.0125 .40581 0 9 ]
[-0.0125 .48403 -32.6875 -9 ]
[-0.0125 .48403 0 9 ]
[-0.0125 .56225 -32.6875 -9 ]
[-0.0125 .56225 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -74.9375 -9 ]
[-0.01875 .30902 -32.6875 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16 0 m
.16 .00625 L
s
gsave
.16 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.32 0 m
.32 .00625 L
s
gsave
.32 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.48 0 m
.48 .00625 L
s
gsave
.48 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.64 0 m
.64 .00625 L
s
gsave
.64 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.8 0 m
.8 .00625 L
s
gsave
.8 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.96 0 m
.96 .00625 L
s
gsave
.96 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.032 0 m
.032 .00375 L
s
.064 0 m
.064 .00375 L
s
.096 0 m
.096 .00375 L
s
.128 0 m
.128 .00375 L
s
.192 0 m
.192 .00375 L
s
.224 0 m
.224 .00375 L
s
.256 0 m
.256 .00375 L
s
.288 0 m
.288 .00375 L
s
.352 0 m
.352 .00375 L
s
.384 0 m
.384 .00375 L
s
.416 0 m
.416 .00375 L
s
.448 0 m
.448 .00375 L
s
.512 0 m
.512 .00375 L
s
.544 0 m
.544 .00375 L
s
.576 0 m
.576 .00375 L
s
.608 0 m
.608 .00375 L
s
.672 0 m
.672 .00375 L
s
.704 0 m
.704 .00375 L
s
.736 0 m
.736 .00375 L
s
.768 0 m
.768 .00375 L
s
.832 0 m
.832 .00375 L
s
.864 0 m
.864 .00375 L
s
.896 0 m
.896 .00375 L
s
.928 0 m
.928 .00375 L
s
.992 0 m
.992 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .09293 m
.00625 .09293 L
s
gsave
-0.0125 .09293 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .17115 m
.00625 .17115 L
s
gsave
-0.0125 .17115 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .24937 m
.00625 .24937 L
s
gsave
-0.0125 .24937 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
0 .32759 m
.00625 .32759 L
s
gsave
-0.0125 .32759 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .40581 m
.00625 .40581 L
s
gsave
-0.0125 .40581 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .48403 m
.00625 .48403 L
s
gsave
-0.0125 .48403 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .56225 m
.00625 .56225 L
s
gsave
-0.0125 .56225 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03036 m
.00375 .03036 L
s
0 .046 m
.00375 .046 L
s
0 .06165 m
.00375 .06165 L
s
0 .07729 m
.00375 .07729 L
s
0 .10858 m
.00375 .10858 L
s
0 .12422 m
.00375 .12422 L
s
0 .13987 m
.00375 .13987 L
s
0 .15551 m
.00375 .15551 L
s
0 .1868 m
.00375 .1868 L
s
0 .20244 m
.00375 .20244 L
s
0 .21809 m
.00375 .21809 L
s
0 .23373 m
.00375 .23373 L
s
0 .26502 m
.00375 .26502 L
s
0 .28066 m
.00375 .28066 L
s
0 .29631 m
.00375 .29631 L
s
0 .31195 m
.00375 .31195 L
s
0 .34324 m
.00375 .34324 L
s
0 .35888 m
.00375 .35888 L
s
0 .37453 m
.00375 .37453 L
s
0 .39017 m
.00375 .39017 L
s
0 .42146 m
.00375 .42146 L
s
0 .4371 m
.00375 .4371 L
s
0 .45274 m
.00375 .45274 L
s
0 .46839 m
.00375 .46839 L
s
0 .49968 m
.00375 .49968 L
s
0 .51532 m
.00375 .51532 L
s
0 .53096 m
.00375 .53096 L
s
0 .54661 m
.00375 .54661 L
s
0 .5779 m
.00375 .5779 L
s
0 .59354 m
.00375 .59354 L
s
0 .60918 m
.00375 .60918 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.16 .61178 m
.16 .61803 L
s
.32 .61178 m
.32 .61803 L
s
.48 .61178 m
.48 .61803 L
s
.64 .61178 m
.64 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.96 .61178 m
.96 .61803 L
s
.125 Mabswid
.032 .61428 m
.032 .61803 L
s
.064 .61428 m
.064 .61803 L
s
.096 .61428 m
.096 .61803 L
s
.128 .61428 m
.128 .61803 L
s
.192 .61428 m
.192 .61803 L
s
.224 .61428 m
.224 .61803 L
s
.256 .61428 m
.256 .61803 L
s
.288 .61428 m
.288 .61803 L
s
.352 .61428 m
.352 .61803 L
s
.384 .61428 m
.384 .61803 L
s
.416 .61428 m
.416 .61803 L
s
.448 .61428 m
.448 .61803 L
s
.512 .61428 m
.512 .61803 L
s
.544 .61428 m
.544 .61803 L
s
.576 .61428 m
.576 .61803 L
s
.608 .61428 m
.608 .61803 L
s
.672 .61428 m
.672 .61803 L
s
.704 .61428 m
.704 .61803 L
s
.736 .61428 m
.736 .61803 L
s
.768 .61428 m
.768 .61803 L
s
.832 .61428 m
.832 .61803 L
s
.864 .61428 m
.864 .61803 L
s
.896 .61428 m
.896 .61803 L
s
.928 .61428 m
.928 .61803 L
s
.992 .61428 m
.992 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09293 m
1 .09293 L
s
.99375 .17115 m
1 .17115 L
s
.99375 .24937 m
1 .24937 L
s
.99375 .32759 m
1 .32759 L
s
.99375 .40581 m
1 .40581 L
s
.99375 .48403 m
1 .48403 L
s
.99375 .56225 m
1 .56225 L
s
.125 Mabswid
.99625 .03036 m
1 .03036 L
s
.99625 .046 m
1 .046 L
s
.99625 .06165 m
1 .06165 L
s
.99625 .07729 m
1 .07729 L
s
.99625 .10858 m
1 .10858 L
s
.99625 .12422 m
1 .12422 L
s
.99625 .13987 m
1 .13987 L
s
.99625 .15551 m
1 .15551 L
s
.99625 .1868 m
1 .1868 L
s
.99625 .20244 m
1 .20244 L
s
.99625 .21809 m
1 .21809 L
s
.99625 .23373 m
1 .23373 L
s
.99625 .26502 m
1 .26502 L
s
.99625 .28066 m
1 .28066 L
s
.99625 .29631 m
1 .29631 L
s
.99625 .31195 m
1 .31195 L
s
.99625 .34324 m
1 .34324 L
s
.99625 .35888 m
1 .35888 L
s
.99625 .37453 m
1 .37453 L
s
.99625 .39017 m
1 .39017 L
s
.99625 .42146 m
1 .42146 L
s
.99625 .4371 m
1 .4371 L
s
.99625 .45274 m
1 .45274 L
s
.99625 .46839 m
1 .46839 L
s
.99625 .49968 m
1 .49968 L
s
.99625 .51532 m
1 .51532 L
s
.99625 .53096 m
1 .53096 L
s
.99625 .54661 m
1 .54661 L
s
.99625 .5779 m
1 .5779 L
s
.99625 .59354 m
1 .59354 L
s
.99625 .60918 m
1 .60918 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .10655 L
.04 .10655 L
.04 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .10655 L
.04 .10655 L
.04 .01472 L
0 .01472 L
s
1 0 0 r
.04 .01472 m
.04 .213 L
.08 .213 L
.08 .01472 L
F
0 g
.04 .01472 m
.04 .213 L
.08 .213 L
.08 .01472 L
.04 .01472 L
s
1 0 0 r
.08 .01472 m
.08 .39042 L
.12 .39042 L
.12 .01472 L
F
0 g
.08 .01472 m
.08 .39042 L
.12 .39042 L
.12 .01472 L
.08 .01472 L
s
1 0 0 r
.12 .01472 m
.12 .50939 L
.16 .50939 L
.16 .01472 L
F
0 g
.12 .01472 m
.12 .50939 L
.16 .50939 L
.16 .01472 L
.12 .01472 L
s
1 0 0 r
.16 .01472 m
.16 .58245 L
.2 .58245 L
.2 .01472 L
F
0 g
.16 .01472 m
.16 .58245 L
.2 .58245 L
.2 .01472 L
.16 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .58245 L
.24 .58245 L
.24 .01472 L
F
0 g
.2 .01472 m
.2 .58245 L
.24 .58245 L
.24 .01472 L
.2 .01472 L
s
1 0 0 r
.24 .01472 m
.24 .60332 L
.28 .60332 L
.28 .01472 L
F
0 g
.24 .01472 m
.24 .60332 L
.28 .60332 L
.28 .01472 L
.24 .01472 L
s
1 0 0 r
.28 .01472 m
.28 .5741 L
.32 .5741 L
.32 .01472 L
F
0 g
.28 .01472 m
.28 .5741 L
.32 .5741 L
.32 .01472 L
.28 .01472 L
s
1 0 0 r
.32 .01472 m
.32 .49269 L
.36 .49269 L
.36 .01472 L
F
0 g
.32 .01472 m
.32 .49269 L
.36 .49269 L
.36 .01472 L
.32 .01472 L
s
1 0 0 r
.36 .01472 m
.36 .48435 L
.4 .48435 L
.4 .01472 L
F
0 g
.36 .01472 m
.36 .48435 L
.4 .48435 L
.4 .01472 L
.36 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .46556 L
.44 .46556 L
.44 .01472 L
F
0 g
.4 .01472 m
.4 .46556 L
.44 .46556 L
.44 .01472 L
.4 .01472 L
s
1 0 0 r
.44 .01472 m
.44 .32989 L
.48 .32989 L
.48 .01472 L
F
0 g
.44 .01472 m
.44 .32989 L
.48 .32989 L
.48 .01472 L
.44 .01472 L
s
1 0 0 r
.48 .01472 m
.48 .29232 L
.52 .29232 L
.52 .01472 L
F
0 g
.48 .01472 m
.48 .29232 L
.52 .29232 L
.52 .01472 L
.48 .01472 L
s
1 0 0 r
.52 .01472 m
.52 .22761 L
.56 .22761 L
.56 .01472 L
F
0 g
.52 .01472 m
.52 .22761 L
.56 .22761 L
.56 .01472 L
.52 .01472 L
s
1 0 0 r
.56 .01472 m
.56 .19631 L
.6 .19631 L
.6 .01472 L
F
0 g
.56 .01472 m
.56 .19631 L
.6 .19631 L
.6 .01472 L
.56 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .13786 L
.64 .13786 L
.64 .01472 L
F
0 g
.6 .01472 m
.6 .13786 L
.64 .13786 L
.64 .01472 L
.6 .01472 L
s
1 0 0 r
.64 .01472 m
.64 .11073 L
.68 .11073 L
.68 .01472 L
F
0 g
.64 .01472 m
.64 .11073 L
.68 .11073 L
.68 .01472 L
.64 .01472 L
s
1 0 0 r
.68 .01472 m
.68 .08151 L
.72 .08151 L
.72 .01472 L
F
0 g
.68 .01472 m
.68 .08151 L
.72 .08151 L
.72 .01472 L
.68 .01472 L
s
1 0 0 r
.72 .01472 m
.72 .06063 L
.76 .06063 L
.76 .01472 L
F
0 g
.72 .01472 m
.72 .06063 L
.76 .06063 L
.76 .01472 L
.72 .01472 L
s
1 0 0 r
.76 .01472 m
.76 .05855 L
.8 .05855 L
.8 .01472 L
F
0 g
.76 .01472 m
.76 .05855 L
.8 .05855 L
.8 .01472 L
.76 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .03767 L
.84 .03767 L
.84 .01472 L
F
0 g
.8 .01472 m
.8 .03767 L
.84 .03767 L
.84 .01472 L
.8 .01472 L
s
1 0 0 r
.84 .01472 m
.84 .02515 L
.88 .02515 L
.88 .01472 L
F
0 g
.84 .01472 m
.84 .02515 L
.88 .02515 L
.88 .01472 L
.84 .01472 L
s
1 0 0 r
.88 .01472 m
.88 .02515 L
.92 .02515 L
.92 .01472 L
F
0 g
.88 .01472 m
.88 .02515 L
.92 .02515 L
.92 .01472 L
.88 .01472 L
s
1 0 0 r
.92 .01472 m
.92 .02098 L
.96 .02098 L
.96 .01472 L
F
0 g
.92 .01472 m
.92 .02098 L
.96 .02098 L
.96 .01472 L
.92 .01472 L
s
1 0 0 r
.96 .01472 m
.96 .0168 L
1 .0168 L
1 .01472 L
F
0 g
.96 .01472 m
.96 .0168 L
1 .0168 L
1 .01472 L
.96 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo002Gooooo`03oa0@4?lb<S;o410@00;o000000?oA4A4olc<
c?ooool0C?ooool009Oooooo00?o0000oiRHV?o^k^h00_ooool00on7QhOo410@ooooo`1<ooooo`00
W?ooool00onj^[[o0000ooooo`1<ooooo`00Uoooool00oo<c<coA4A4o`000003o`000003oiRHV?oo
oooooooo04_ooooo002Gooooo`05o`000?n7QhOo^[ZjokZj^_o<c<`0Coooool009Oooooo00?o0000
oiRHV?ooool00_ooool00oo<c<co410@ooooo`1<ooooo`00Uoooool01oo<c<coA4A4o`000?l0003o
410@oc8b<_l00000COooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00Foooool01?nHV9So0000o`000?nHV9P6
ooooo`03oeEEEOl0003oEEEE00Kooooo00GoV9RHoa0@4?l0003o0000ofIVIP09ooooo`Co000000?o
410@ooooooooool02Oooool4o`000003oa0@4?oooooooooo00Cooooo00?oEEEEo`000?mEEED01_oo
ool01OnHV9So410@o`000?l0003oIVIV00Sooooo1_l00009ooooo`Ko00001_ooool00omEEEGo0000
oeEEE@06ooooo`05oiRHV?l@413o0000o`000?mVIVH02_ooool01OnYZJWo8B4Qo`000?l0003oIVIV
00Kooooo001Jooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo00Ko410@
ohN7QoooooooooooogMgMomVIVH:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1_ooool3o`0000Kooooo00Ko410@ohN7QoooooooooooogMgMomVIVH7ooooo`03oiRHV?l0003ogMgM
00;ooooo00?o410@ooooooooool01oooool00onHV9So0000omgMg@02ooooo`03oa0@4?oooooooooo
00Cooooo0ol00006ooooo`06oa0@4?n7QhOooooooooooomgMgOoIVIV2Oooool01_l@413oc<c<oooo
ooooooooMgMgofIVIPGooooo001Jooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omE
EEGo0000oeEEE@0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`06ooooo`03oeEEEOl0003oEEEE00_ooooo00?o0000ooooooooool01_ooool00on7
QhOo8B4Qonk^kP0<ooooo`03ohN7QolQ8B7ok^k^00Sooooo00?oEEEEo`000?mEEED02oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo001Jooooo`06o`000?o^k^kooooooooo
ooo^k^ko00004_ooool00oo^k^ko0000ooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool04oooool00oo^k^ko0000ooooo`08ooooo`03ojVYZOlQ8B7ok^k^00cooooo00?oZJVY
ob4Q8Oo^k^h05?ooool00oo^k^ko0000ooooo`0=ooooo`03o`000?oooooooooo00?ooooo001Joooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01_l@413oV9RHoooooooooooo
MgMgofIVIP[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`06oa0@4?nH
V9SooooooooooomgMgOoIVIV2_ooool00onHV9So<S8booooo`0<ooooo`03oiRHV?lb<S;ooooo00oo
oooo00Ko410@oiRHV?ooooooooooogMgMomVIVH=ooooo`03ojVYZOm4A4Cooooo00Cooooo001Joooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01Ol0003o8B4Qo`000?l0003o
IVIV00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`05o`000?lQ8B7o
0000o`000?mVIVH03?ooool00om4A4CoMgMgooooo`0<ooooo`03odA4A?mgMgOooooo00kooooo00Go
0000ob4Q8Ol0003o0000ofIVIP0<ooooo`04ob4Q8Ol0003o0000omgMg@Gooooo001Jooooo`06o`00
0?o^k^koooooooooooo^k^ko00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03omgMgOl@413ooooo
00cooooo00?ogMgMoa0@4?ooool03_ooool00ol0003oooooooooo`0@ooooo`03ojVYZOlb<S;ooooo
00Cooooo001Jooooo`06odA4A?nHV9SooooooooooonHV9SoA4A43_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00?ooooo001Jooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?m4A4Co000000gooooo00?o0000odA4A?l000004Ooo
ool00ol0003oooooooooo`0:ooooo`06o`000?n7QhOok^k^oooooonHV9SoEEEE2Oooool01_l0003o
QhN7onk^k_ooooooV9RHoeEEE@oooooo00?o0000ooooooooool03?ooool01_lQ8B7o^[Zjoooooooo
ooooIVIVoc8b<PGooooo001Kooooo`04oiRHV?l0003o0000oiRHV0oooooo1Ol00009ooooo`03olc<
c?mEEEGo000000gooooo00?oc<c<oeEEEOl000004Oooool5o`0000Sooooo00KoZJVYoc8b<_l0003o
0000oeEEEOo^k^h9ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^3oooool5o`0000[ooooo00Ko
^[ZjodA4A?l0003o0000odA4A?o^k^h5ooooo`00joooool00>_ooooo003[ooooo`00joooool004?o
oooo00CoV9RHo`000?l0003oV9RH1_oooonMo`00007ooooo0012ooooo`06okZj^_lQ8B7ogMgMomgM
gOlQ8B7o^[Zj1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00000Oooool004;ooooo00KoA4A4oiRH
V?oooooooooooiRHV?m4A4@5ooooo`03o`000?oooooooooo09Wooooo0Ol00001ooooo`00@_ooool0
1_l0003ok^k^ooooooooooook^k^o`0000GoooooWOl00001ooooo`00@_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`003Ol0000<ooooo`7o00000Oooool004;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo01Gooooo0_l00001
ooooo`00@_ooool01_l0003ok^k^ooooooooooook^k^o`0000Gooooo00?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool000Oo00006?ooool1o`00007ooooo0012ooooo`06odA4A?nHV9So
oooooooooonHV9SoA4A41Oooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ooooooooool06oooool2o`00007ooooo0012ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o
^[Zj1Oooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool07?ooool1o`00007ooooo0013ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo0007o`0001kooooo0Ol00001ooooo`00COooool00ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0008o`0002?ooooo0_l00001ooooo`00COoo
ool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`0Yooooo`7o00000Oooool0033ooooo00CoV9RHo`000?l0003oV9RH1_oo
ool00omEEEGo0000oeEEE@06ooooo`Co000000?o410@ooooooooool00oooool00ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`0Xooooo`;o00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o0000
2?ooool00ol0003oooooooooo`05ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo0007o`0002_ooooo0Ol00001ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Go
oooo00?oEEEEo`000?mEEED02?ooool00ol0003oooooooooo`05ooooo`03o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0_ooooo`7o00000Oooool002oooooo
00Ko0000onk^k_ooooooooooonk^k_l0000@ooooo`03o`000?oooooooooo00Gooooo00?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo02kooooo0_l00001oooo
o`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01Oooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0;oooool1o`00007ooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`05ooooo`So00001Ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`001ol0000`ooooo`;o00000Oooool002oooooo00Ko0000onk^k_oooooooooo
onk^k_l0000@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`0eooooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@@oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0eoooo
o`7o00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X>ooooo`03o`000?m4A4Co
000000Oooooo0_l00005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oooooooooo03Cooooo0_l00001ooooo`00<?ooool01?nH
V9So0000o`000?nHV9P?ooooo`03olc<c?mEEEGo000000Oooooo00?o0000ooooooooool01?ooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`0eooooo`7o00000Oooool004gooooo0_l00005ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo0007o`0003Kooooo0_l00001ooooo`00COooool00ol0003o
ooooooooo`04ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
ooooooooo`0kooooo`7o00000Oooool0033ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo
0000oeEEE@05ooooo`Ko00001Oooool2o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oooooooooo03[ooooo0_l00001ooooo`00;oooool01_nj^[[o8B4Q
omgMgOoMgMgo8B4QokZj^PGooooo0ol00005ooooo`03oiRHV?l0003ogMgM00;ooooo00?o410@oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oooooooooo`0kooooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oo
oooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?oQhN7ob4Q8Oo^k^h01oooool0
0ol0003oooooooooo`04ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oooooooooo`0kooooo`7o00000Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0
000?ooooo`03ojVYZOlQ8B7ok^k^00Kooooo0_l00005ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oooooooooo`0jooooo`;o00000Oooool002oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03oiRHV?lb<S;ooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ooooooooool0>oooool1o`00007ooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03oooool00om4A4CoMgMgooooo`04ooooo`;o00001Oooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ooooooooool0>_ooool2o`00007ooooo000_ooooo`06
o`000?o^k^koooooooooooo^k^ko00004Oooool00ooMgMgo410@ooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oooooo
oooo03_ooooo0Ol00001ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A1;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`002?l0
000mooooo`7o00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X=ooooo`06o`00
0?n7QhOok^k^oooooonHV9SoEEEE1Oooool2o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`11ooooo`;o00000Oooool0033ooooo00CoV9RHo`000?l0003oV9RH3_ooool01_nY
ZJWo<S8bo`000?l0003oEEEEonk^kPGooooo00?o0000ooooooooool01?ooool7o`0000Goo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04;ooooo0Ol0
0001ooooo`00COooool2o`0000_ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0@Oooool2o`00007ooooo001=oooo
o`03o`000?oooooooooo00[ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0@_ooool1o`00007ooooo000`ooooo`04
oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01_ooool01OnYZJWo8B4Qo`000?l0003o
IVIV00Gooooo00?o0000ooooooooool02_ooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`001ol00014ooooo`7o00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj
^[X5ooooo`?o00001_ooool01_l@413oc<c<ooooooooooooMgMgofIVIPCooooo0_l0000;ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`17ooooo`;o
00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE
00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`18ooooo`7o00000Oooool002oo
oooo00Ko0000onk^k_ooooooooooonk^k_l0000Cooooo`03o`000?oooooooooo00;ooooo0_l0000;
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`17
ooooo`;o00000Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@oooo
o`03ojVYZOm4A4Cooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0B?ooool1o`00007ooooo000_ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool01?lQ8B7o0000o`000?oMgMd4oooo
o`;o00002oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0Aoooool2o`00007ooooo000@ooooo`03okZj^_lb<S;ooooo00kooooo00?o<S8bokZj^_oo
ool02oooool01_l0003ok^k^ooooooooooook^k^o`0001;ooooo00?oZJVYoc8b<_ooool00oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`18ooooo`7o00000Oooool0013ooooo00?o<S8bokZj^_ooool03_ooool00onj
^[[o<S8booooo`0;ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A44oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo04Sooooo0Ol00001ooooo`003oooool00oo<c<co<S8booooo`0@
ooooo`03oc8b<_o<c<cooooo00[ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X>ooooo`06ob4Q
8Onj^[[ooooooooooomVIVKo<S8b1?ooool2o`0000_ooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo04Oooooo0_l00001ooooo`000_ooool01Ol@413o
0000o`000?l0003o410@00Sooooo00?oIVIVojVYZOooool01?ooool00ol@413o<S8boa0@4002o`00
0003odA4A?o<c<cooooo00Cooooo00?oV9RHofIVI_ooool02oooool01?nHV9So0000o`000?nHV9P?
ooooo`06okZj^_m4A4Co0000o`000?m4A4Cok^k^1?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`18ooooo`7o0000
0Oooool000Cooooo00?o0000ooooooooool02?ooool00olb<S;oooooooooo`04ooooo`03o`000?nH
V9Sok^k^00;ooooo00?oQhN7oa0@4?ooool01?ooool00oo^k^ko<S8booooo`0Xooooo`;o00002ooo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool000Oo0000BOooool2o`00007ooooo0004ooooo`03o`000?oooooo
oooo00Sooooo00?o<S8booooooooool02Oooool00onj^[[o0000ooooo`05ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool02_ooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo
oooo04kooooo0Ol00001ooooo`001?ooool3o`000003oa0@4?mgMgOok^k^00Gooooo00?o<S8boooo
ooooool01?ooool00oo<c<coA4A4o`000003o`000003oiRHV?oooooooooo00Cooooo00?o0000oooo
ooooool02_ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Wooooo0_l00000
0ol@413oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`1>ooooo`7o00000Oooool000Cooooo00Ko0000ooooooooooook^k^ogMgMomE
EED5ooooo`03ob4Q8Ooooooooooo00Cooooo00Go0000ohN7Qonj^[[o^[Zjolc<c008ooooo`03o`00
0?oooooooooo00Wooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00002_ooool00ol0
003oooooooooo`03ooooo`;o00002oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
04gooooo0_l00001ooooo`001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o<S8bonk^k_ooool01?ooool00ol0003oV9RHooooo`02ooooo`03olc<c?l@413ooooo00Co
oooo00?ogMgMoc8b<_ooool02_ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEE
o`000?mEEED01_ooool6o`0000Cooooo00?o0000ooooooooool02_ooool00ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo04kooooo0Ol00001ooooo`001?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?oIVIVoiRHV?ooool01?ooool01oo<c<coA4A4o`000?l0003o
410@oc8b<_l000001Oooool00onHV9SoIVIVooooo`0:ooooo`06o`000?o^k^koooooooooooo^k^ko
00003_ooool01Om4A4Co^[Zjoooooooooooo000000Gooooo0_l0000;ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0COooool2o`00007ooooo0004ooooo`06o`000?ooooooooooonk^
k_mgMgOoEEEE1Oooool00ooMgMgo8B4Qooooo`0@ooooo`03oa0@4?o<c<cooooo00[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`05omgMgOlQ8B7oooooooooool000001Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool000Oo0000D?ooool1o`00007ooooo0002ooooo`03oa0@4?l0003o
000000;o000000?o410@ogMgMoo^k^h01_ooool00olb<S;o^[Zjooooo`0>ooooo`03okZj^_lb<S;o
oooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`04ogMgMonHV9So
ooooo`0000Gooooo00?o0000ooooooooool02_ooool00ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Dooooo`7o00000Ooo
ool0013ooooo00?o^[Zjoc8b<_ooool03_ooool00olb<S;o^[Zjooooo`0;ooooo`06o`000?o^k^ko
ooooooooooo^k^ko00003oooool01?o^k^ko8B4Qooooool00005ooooo`;o00002oooool00ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`1Cooooo`;o00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@@oooo
o`03ogMgMonHV9So000000Gooooo00?o0000ooooooooool02_ooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Doooo
o`7o00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X@ooooo`03onk^k_lb<S;o
000000Gooooo0_l0000;ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oooooooooo05?ooooo0_l00001ooooo`00<?ooool01?nH
V9So0000o`000?nHV9PBooooo`03oiRHV?l@413ooooo00Cooooo00?o0000ooooooooool02_ooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`1Dooooo`7o00000Oooool004gooooo00?o0000ooooooooool02_ooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`1Dooooo`7o00000Oooool004gooooo0_l0000;ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo05?o
oooo0_l00001ooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Ko
oooo00GoV9RHoa0@4?l0003o0000ofIVIP05ooooo`03o`000?oooooooooo00[ooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0E?ooool1o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3
o`0000Kooooo00Ko410@ohN7QoooooooooooogMgMomVIVH4ooooo`;o00002oooool7o`0000Goo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Cooooo`;o00000Oooool002oooooo00Ko
A4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00_ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`1Dooooo`7o00000Oooool002oooooo00Ko0000onk^k_oooooo
ooooonk^k_l0000Booooo`03onk^k_l0003ooooo00?ooooo0_l0000Aooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Cooooo`;o00000Oooool002oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`06oa0@4?nHV9Sooooooooo
oomgMgOoIVIV1?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`1Dooooo`7o00000Oooool002oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0<ooooo`05o`000?lQ8B7o0000o`000?mVIVH01Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`1Dooooo`7o00000Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0
000>ooooo`03o`000?oooooooooo00Oooooo0_l0000Aooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oooooooooo`1Cooooo`;o00000Oooool002oooooo00KoA4A4
oiRHV?oooooooooooiRHV?m4A4@>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
E?ooool1o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool00ol0003o
ooooooooo`07ooooo`;o00004Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0Doooool2o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0oo
oooo1Ol00005ooooo`03o`000?oooooooooo013ooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo05Cooooo0Ol00001ooooo`00COooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`1Dooooo`7o00000Oooool004gooooo0_l0000Aooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oooooooooo`1Cooooo`;o00000Oooool004gooooo00?o0000
ooooooooool04?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0E?ooool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEE
o`000?mEEED01_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPCooooo0_l0000Aooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`001ol0001Eooooo`;o00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgM
ob4Q8Onj^[X5ooooo`?o00001_ooool2ogMgM`;ooooo00?oMgMgoeEEEOooool00oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ooooooooool0F_ooool1o`00007o
oooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06oooo
o`03ob4Q8Ooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ooooooooool0F_ooool1o`00007ooooo000_ooooo`06
o`000?o^k^koooooooooooo^k^ko00003_ooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooo
oooo00;ooooo0_l0000Aooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool000So0000Foooool2o`00007ooooo000_ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03?ooool01_l0003oEEEEonk^k_ooooooMgMgoeEEE@Cooooo00?o
0000ooooooooool04?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001ol0
001Sooooo`7o00000Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<
ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^1?ooool2o`00017ooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo06Kooooo0_l00001ooooo`00;ooo
ool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00?oA4A4oiRHV?ooool01oooool00ol0003o
ooooooooo`0@ooooo`Oo00001Ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Wooooo`7o00000Oooool002oooooo
00KoA4A4oiRHV?oooooooooooiRHV?m4A4@>ooooo`03okZj^_lQ8B7ooooo00Oooooo0_l0000Goooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0I_ooool2o`00007ooooo000_ooooo`06
okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3oooool00omEEEGo<S8bomgMg@06ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Wooooo`7o00000Oooool0
033ooooo00CoV9RHo`000?l0003oV9RH4Oooool01?nHV9So8B4Qo`000?lQ8B44ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Wooooo`7o00000Ooo
ool004gooooo0_l0000Gooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0I_ooool2
o`00007ooooo001=ooooo`03o`000?oooooooooo01Kooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`1Wooooo`7o00000Oooool0033ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omE
EEGo0000oeEEE@08ooooo`03o`000?nYZJWooooo00Gooooo0_l0000Gooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0I_ooool2o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgM
gOlQ8B7o^[Zj1Oooool3o`0000Sooooo0_mEEED6ooooo`03o`000?oooooooooo01Kooooo00?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`1Wooooo`7o00000Oooool002oooooo00KoA4A4oiRH
V?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Sooooo00?oZJVYo`000?ooool01Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Iooo
ool1o`00007ooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00004Oooool00ol0003oc<c<
ooooo`04ooooo`;o00005oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo06Kooooo
0_l00001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o
EEEEofIVI_ooool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0Ioooool1o`00007ooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03oooool00onYZJWo410@ooooo`04ooooo`;o00005oooool00ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0007o`0006Sooooo0_l00001
ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0001;ooooo00?o0000omgMgOooool00ooo
ool00ol0003oooooooooo`0Fooooo`ko00001Ooo00000ol0003oooooooooo`1]ooooo`7o00000Ooo
ool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@Booooo`03oeEEEOn7QhOooooo00?ooooo
00?o0000ooooooooool08oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo06gooooo
0Ol00001ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00Ko410@oooooooo
ooooooooojVYZOlb<S84ooooo`;o00009?ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo06cooooo0_l00001ooooo`00<?ooool01?nHV9So0000o`000?nHV9P?ooooo`Ko00001?ooool0
0ol0003oooooooooo`0Sooooo`Oo0000Koooool1o`00007ooooo001=ooooo`;o00005oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool2o`00
007ooooo001=oooooigo00000Oooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-1.56376, -0.739719, 0.0200854, \
0.00821702}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Below we create a plot that compares the level spacing hisogram of \
our random real symmetric matrix to the GOE distribution.  We see that that \
agreement is very good.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[GOEHist, GOE, AspectRatio \[Rule] 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.32 0.0238095 1.25285 [
[.16 -0.0125 -16.3438 -18 ]
[.16 -0.0125 16.3438 0 ]
[.32 -0.0125 -6.78125 -18 ]
[.32 -0.0125 6.78125 0 ]
[.48 -0.0125 -16.3438 -18 ]
[.48 -0.0125 16.3438 0 ]
[.64 -0.0125 -6.78125 -18 ]
[.64 -0.0125 6.78125 0 ]
[.8 -0.0125 -16.3438 -18 ]
[.8 -0.0125 16.3438 0 ]
[.96 -0.0125 -6.78125 -18 ]
[.96 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .02381 -13.5625 -9 ]
[-0.0125 .02381 0 9 ]
[-0.0125 .14909 -32.6875 -9 ]
[-0.0125 .14909 0 9 ]
[-0.0125 .27438 -32.6875 -9 ]
[-0.0125 .27438 0 9 ]
[-0.0125 .39966 -32.6875 -9 ]
[-0.0125 .39966 0 9 ]
[-0.0125 .52495 -32.6875 -9 ]
[-0.0125 .52495 0 9 ]
[-0.0125 .65023 -32.6875 -9 ]
[-0.0125 .65023 0 9 ]
[-0.0125 .77552 -32.6875 -9 ]
[-0.0125 .77552 0 9 ]
[-0.0125 .9008 -32.6875 -9 ]
[-0.0125 .9008 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -74.9375 -9 ]
[-0.01875 .5 -32.6875 9 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16 0 m
.16 .00625 L
s
gsave
.16 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.32 0 m
.32 .00625 L
s
gsave
.32 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.48 0 m
.48 .00625 L
s
gsave
.48 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.64 0 m
.64 .00625 L
s
gsave
.64 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.8 0 m
.8 .00625 L
s
gsave
.8 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.96 0 m
.96 .00625 L
s
gsave
.96 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.032 0 m
.032 .00375 L
s
.064 0 m
.064 .00375 L
s
.096 0 m
.096 .00375 L
s
.128 0 m
.128 .00375 L
s
.192 0 m
.192 .00375 L
s
.224 0 m
.224 .00375 L
s
.256 0 m
.256 .00375 L
s
.288 0 m
.288 .00375 L
s
.352 0 m
.352 .00375 L
s
.384 0 m
.384 .00375 L
s
.416 0 m
.416 .00375 L
s
.448 0 m
.448 .00375 L
s
.512 0 m
.512 .00375 L
s
.544 0 m
.544 .00375 L
s
.576 0 m
.576 .00375 L
s
.608 0 m
.608 .00375 L
s
.672 0 m
.672 .00375 L
s
.704 0 m
.704 .00375 L
s
.736 0 m
.736 .00375 L
s
.768 0 m
.768 .00375 L
s
.832 0 m
.832 .00375 L
s
.864 0 m
.864 .00375 L
s
.896 0 m
.896 .00375 L
s
.928 0 m
.928 .00375 L
s
.992 0 m
.992 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02381 m
.00625 .02381 L
s
gsave
-0.0125 .02381 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .14909 m
.00625 .14909 L
s
gsave
-0.0125 .14909 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .27438 m
.00625 .27438 L
s
gsave
-0.0125 .27438 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .39966 m
.00625 .39966 L
s
gsave
-0.0125 .39966 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
0 .52495 m
.00625 .52495 L
s
gsave
-0.0125 .52495 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .65023 m
.00625 .65023 L
s
gsave
-0.0125 .65023 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .77552 m
.00625 .77552 L
s
gsave
-0.0125 .77552 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .9008 m
.00625 .9008 L
s
gsave
-0.0125 .9008 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04887 m
.00375 .04887 L
s
0 .07392 m
.00375 .07392 L
s
0 .09898 m
.00375 .09898 L
s
0 .12404 m
.00375 .12404 L
s
0 .17415 m
.00375 .17415 L
s
0 .19921 m
.00375 .19921 L
s
0 .22427 m
.00375 .22427 L
s
0 .24932 m
.00375 .24932 L
s
0 .29944 m
.00375 .29944 L
s
0 .32449 m
.00375 .32449 L
s
0 .34955 m
.00375 .34955 L
s
0 .37461 m
.00375 .37461 L
s
0 .42472 m
.00375 .42472 L
s
0 .44978 m
.00375 .44978 L
s
0 .47483 m
.00375 .47483 L
s
0 .49989 m
.00375 .49989 L
s
0 .55001 m
.00375 .55001 L
s
0 .57506 m
.00375 .57506 L
s
0 .60012 m
.00375 .60012 L
s
0 .62518 m
.00375 .62518 L
s
0 .67529 m
.00375 .67529 L
s
0 .70035 m
.00375 .70035 L
s
0 .7254 m
.00375 .7254 L
s
0 .75046 m
.00375 .75046 L
s
0 .80057 m
.00375 .80057 L
s
0 .82563 m
.00375 .82563 L
s
0 .85069 m
.00375 .85069 L
s
0 .87575 m
.00375 .87575 L
s
0 .92586 m
.00375 .92586 L
s
0 .95092 m
.00375 .95092 L
s
0 .97597 m
.00375 .97597 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.16 .99375 m
.16 1 L
s
.32 .99375 m
.32 1 L
s
.48 .99375 m
.48 1 L
s
.64 .99375 m
.64 1 L
s
.8 .99375 m
.8 1 L
s
.96 .99375 m
.96 1 L
s
.125 Mabswid
.032 .99625 m
.032 1 L
s
.064 .99625 m
.064 1 L
s
.096 .99625 m
.096 1 L
s
.128 .99625 m
.128 1 L
s
.192 .99625 m
.192 1 L
s
.224 .99625 m
.224 1 L
s
.256 .99625 m
.256 1 L
s
.288 .99625 m
.288 1 L
s
.352 .99625 m
.352 1 L
s
.384 .99625 m
.384 1 L
s
.416 .99625 m
.416 1 L
s
.448 .99625 m
.448 1 L
s
.512 .99625 m
.512 1 L
s
.544 .99625 m
.544 1 L
s
.576 .99625 m
.576 1 L
s
.608 .99625 m
.608 1 L
s
.672 .99625 m
.672 1 L
s
.704 .99625 m
.704 1 L
s
.736 .99625 m
.736 1 L
s
.768 .99625 m
.768 1 L
s
.832 .99625 m
.832 1 L
s
.864 .99625 m
.864 1 L
s
.896 .99625 m
.896 1 L
s
.928 .99625 m
.928 1 L
s
.992 .99625 m
.992 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .14909 m
1 .14909 L
s
.99375 .27438 m
1 .27438 L
s
.99375 .39966 m
1 .39966 L
s
.99375 .52495 m
1 .52495 L
s
.99375 .65023 m
1 .65023 L
s
.99375 .77552 m
1 .77552 L
s
.99375 .9008 m
1 .9008 L
s
.125 Mabswid
.99625 .04887 m
1 .04887 L
s
.99625 .07392 m
1 .07392 L
s
.99625 .09898 m
1 .09898 L
s
.99625 .12404 m
1 .12404 L
s
.99625 .17415 m
1 .17415 L
s
.99625 .19921 m
1 .19921 L
s
.99625 .22427 m
1 .22427 L
s
.99625 .24932 m
1 .24932 L
s
.99625 .29944 m
1 .29944 L
s
.99625 .32449 m
1 .32449 L
s
.99625 .34955 m
1 .34955 L
s
.99625 .37461 m
1 .37461 L
s
.99625 .42472 m
1 .42472 L
s
.99625 .44978 m
1 .44978 L
s
.99625 .47483 m
1 .47483 L
s
.99625 .49989 m
1 .49989 L
s
.99625 .55001 m
1 .55001 L
s
.99625 .57506 m
1 .57506 L
s
.99625 .60012 m
1 .60012 L
s
.99625 .62518 m
1 .62518 L
s
.99625 .67529 m
1 .67529 L
s
.99625 .70035 m
1 .70035 L
s
.99625 .7254 m
1 .7254 L
s
.99625 .75046 m
1 .75046 L
s
.99625 .80057 m
1 .80057 L
s
.99625 .82563 m
1 .82563 L
s
.99625 .85069 m
1 .85069 L
s
.99625 .87575 m
1 .87575 L
s
.99625 .92586 m
1 .92586 L
s
.99625 .95092 m
1 .95092 L
s
.99625 .97597 m
1 .97597 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .02381 m
1 .02381 L
s
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
0 .02381 m
0 .17091 L
.04 .17091 L
.04 .02381 L
F
0 g
.5 Mabswid
0 .02381 m
0 .17091 L
.04 .17091 L
.04 .02381 L
0 .02381 L
s
1 0 0 r
.04 .02381 m
.04 .34141 L
.08 .34141 L
.08 .02381 L
F
0 g
.04 .02381 m
.04 .34141 L
.08 .34141 L
.08 .02381 L
.04 .02381 L
s
1 0 0 r
.08 .02381 m
.08 .62558 L
.12 .62558 L
.12 .02381 L
F
0 g
.08 .02381 m
.08 .62558 L
.12 .62558 L
.12 .02381 L
.08 .02381 L
s
1 0 0 r
.12 .02381 m
.12 .81614 L
.16 .81614 L
.16 .02381 L
F
0 g
.12 .02381 m
.12 .81614 L
.16 .81614 L
.16 .02381 L
.12 .02381 L
s
1 0 0 r
.16 .02381 m
.16 .93315 L
.2 .93315 L
.2 .02381 L
F
0 g
.16 .02381 m
.16 .93315 L
.2 .93315 L
.2 .02381 L
.16 .02381 L
s
1 0 0 r
.2 .02381 m
.2 .93315 L
.24 .93315 L
.24 .02381 L
F
0 g
.2 .02381 m
.2 .93315 L
.24 .93315 L
.24 .02381 L
.2 .02381 L
s
1 0 0 r
.24 .02381 m
.24 .96658 L
.28 .96658 L
.28 .02381 L
F
0 g
.24 .02381 m
.24 .96658 L
.28 .96658 L
.28 .02381 L
.24 .02381 L
s
1 0 0 r
.28 .02381 m
.28 .91977 L
.32 .91977 L
.32 .02381 L
F
0 g
.28 .02381 m
.28 .91977 L
.32 .91977 L
.32 .02381 L
.28 .02381 L
s
1 0 0 r
.32 .02381 m
.32 .78939 L
.36 .78939 L
.36 .02381 L
F
0 g
.32 .02381 m
.32 .78939 L
.36 .78939 L
.36 .02381 L
.32 .02381 L
s
1 0 0 r
.36 .02381 m
.36 .77602 L
.4 .77602 L
.4 .02381 L
F
0 g
.36 .02381 m
.36 .77602 L
.4 .77602 L
.4 .02381 L
.36 .02381 L
s
1 0 0 r
.4 .02381 m
.4 .74593 L
.44 .74593 L
.44 .02381 L
F
0 g
.4 .02381 m
.4 .74593 L
.44 .74593 L
.44 .02381 L
.4 .02381 L
s
1 0 0 r
.44 .02381 m
.44 .52863 L
.48 .52863 L
.48 .02381 L
F
0 g
.44 .02381 m
.44 .52863 L
.48 .52863 L
.48 .02381 L
.44 .02381 L
s
1 0 0 r
.48 .02381 m
.48 .46845 L
.52 .46845 L
.52 .02381 L
F
0 g
.48 .02381 m
.48 .46845 L
.52 .46845 L
.52 .02381 L
.48 .02381 L
s
1 0 0 r
.52 .02381 m
.52 .36481 L
.56 .36481 L
.56 .02381 L
F
0 g
.52 .02381 m
.52 .36481 L
.56 .36481 L
.56 .02381 L
.52 .02381 L
s
1 0 0 r
.56 .02381 m
.56 .31466 L
.6 .31466 L
.6 .02381 L
F
0 g
.56 .02381 m
.56 .31466 L
.6 .31466 L
.6 .02381 L
.56 .02381 L
s
1 0 0 r
.6 .02381 m
.6 .22106 L
.64 .22106 L
.64 .02381 L
F
0 g
.6 .02381 m
.6 .22106 L
.64 .22106 L
.64 .02381 L
.6 .02381 L
s
1 0 0 r
.64 .02381 m
.64 .17759 L
.68 .17759 L
.68 .02381 L
F
0 g
.64 .02381 m
.64 .17759 L
.68 .17759 L
.68 .02381 L
.64 .02381 L
s
1 0 0 r
.68 .02381 m
.68 .13079 L
.72 .13079 L
.72 .02381 L
F
0 g
.68 .02381 m
.68 .13079 L
.72 .13079 L
.72 .02381 L
.68 .02381 L
s
1 0 0 r
.72 .02381 m
.72 .09736 L
.76 .09736 L
.76 .02381 L
F
0 g
.72 .02381 m
.72 .09736 L
.76 .09736 L
.76 .02381 L
.72 .02381 L
s
1 0 0 r
.76 .02381 m
.76 .09402 L
.8 .09402 L
.8 .02381 L
F
0 g
.76 .02381 m
.76 .09402 L
.8 .09402 L
.8 .02381 L
.76 .02381 L
s
1 0 0 r
.8 .02381 m
.8 .06058 L
.84 .06058 L
.84 .02381 L
F
0 g
.8 .02381 m
.8 .06058 L
.84 .06058 L
.84 .02381 L
.8 .02381 L
s
1 0 0 r
.84 .02381 m
.84 .04053 L
.88 .04053 L
.88 .02381 L
F
0 g
.84 .02381 m
.84 .04053 L
.88 .04053 L
.88 .02381 L
.84 .02381 L
s
1 0 0 r
.88 .02381 m
.88 .04053 L
.92 .04053 L
.92 .02381 L
F
0 g
.88 .02381 m
.88 .04053 L
.92 .04053 L
.92 .02381 L
.88 .02381 L
s
1 0 0 r
.92 .02381 m
.92 .03384 L
.96 .03384 L
.96 .02381 L
F
0 g
.92 .02381 m
.92 .03384 L
.96 .03384 L
.96 .02381 L
.92 .02381 L
s
1 0 0 r
.96 .02381 m
.96 .02715 L
1 .02715 L
1 .02381 L
F
0 g
.96 .02381 m
.96 .02715 L
1 .02715 L
1 .02381 L
.96 .02381 L
s
.01 w
0 .02381 m
.06491 .41029 L
.09869 .58706 L
.13569 .7484 L
.15232 .80787 L
.17011 .86174 L
.18678 .90282 L
.20217 .93255 L
.21034 .94515 L
.21934 .95648 L
.22838 .96524 L
.23333 .96894 L
.23797 .9717 L
.24233 .97368 L
.24448 .97445 L
.24648 .97504 L
.24843 .97549 L
.2502 .97581 L
.25217 .97604 L
.25427 .97617 L
.25537 .97619 L
.25653 .97617 L
.25861 .97603 L
.25976 .9759 L
.26084 .97575 L
.2633 .97527 L
.26544 .97471 L
.2674 .97409 L
.2718 .97231 L
.27988 .96768 L
.28846 .96091 L
.30387 .94422 L
.32044 .92037 L
.33874 .88781 L
.40628 .72827 L
.47128 .55142 L
.54039 .37768 L
.60696 .24506 L
.67099 .15439 L
.70393 .1206 L
.73913 .09265 L
.77499 .0714 L
.80884 .05673 L
.84247 .04621 L
.87347 .03925 L
.90499 .03422 L
.9229 .03207 L
.93966 .03043 L
.95715 .02904 L
.97375 .02797 L
Mistroke
Mfstroke
.97375 .02797 m
1 .02672 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00Uoooool00ol@413o<S8boa0@4002o`000003odA4A?o<c<cooooo04cooooo002Gooooo`03o`00
0?nHV9Sok^k^00;ooooo00?oQhN7oa0@4?ooool0C?ooool009cooooo00?o^[Zjo`000?ooool0C?oo
ool009Oooooo00?oc<c<odA4A?l000000ol000000onHV9Soooooooooo`1;ooooo`00Uoooool01Ol0
003oQhN7okZj^_nj^[[oc<c<04oooooo002Gooooo`03o`000?nHV9Sooooo00;ooooo00?oc<c<oa0@
4?ooool0C?ooool009Oooooo00Ooc<c<odA4A?l0003o0000oa0@4?lb<S;o000004gooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool005_ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@06oooo
o`05oiRHV?l@413o0000o`000?mVIVH02Oooool4o`000003oa0@4?oooooooooo00Wooooo1?l00000
0ol@413oooooooooo`04ooooo`03oeEEEOl0003oEEEE00Kooooo00GoV9RHoa0@4?l0003o0000ofIV
IP08ooooo`Ko00002Oooool6o`0000Kooooo00?oEEEEo`000?mEEED01_ooool01OnHV9So410@o`00
0?l0003oIVIV00[ooooo00GoZJVYob4Q8Ol0003o0000ofIVIP06ooooo`00F_ooool01_nj^[[o8B4Q
omgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`06oa0@4?n7QhOooooooooooomgMgOoIVIV2_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo0ol00006ooooo`06oa0@4?n7
QhOooooooooooomgMgOoIVIV1oooool00onHV9So0000omgMg@02ooooo`03oa0@4?oooooooooo00Oo
oooo00?oV9RHo`000?oMgMd00_ooool00ol@413oooooooooo`04ooooo`?o00001_ooool01_l@413o
QhN7ooooooooooooMgMgofIVIPWooooo00Ko410@olc<c?ooooooooooogMgMomVIVH5ooooo`00F_oo
ool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED02oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00omEEEGo
0000oeEEE@0;ooooo`03o`000?oooooooooo00Kooooo00?oQhN7ob4Q8Oo^k^h03?ooool00on7QhOo
8B4Qonk^kP08ooooo`03oeEEEOl0003oEEEE00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`03ooooo`00F_ooool01_l0003ok^k^ooooooooooook^k^o`0001;ooooo00?ok^k^o`00
0?ooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01?ooooo00?ok^k^o`00
0?ooool02?ooool00onYZJWo8B4Qonk^kP0<ooooo`03ojVYZOlQ8B7ok^k^01Cooooo00?ok^k^o`00
0?ooool03Oooool00ol0003oooooooooo`03ooooo`00F_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00cooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH:ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03oooool01_l@413oV9RHooooooooooooMgMgofIVIP[ooooo
00?oV9RHoc8b<_ooool03?ooool00onHV9So<S8booooo`0?ooooo`06oa0@4?nHV9Sooooooooooomg
MgOoIVIV3Oooool00onYZJWoA4A4ooooo`04ooooo`00F_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00cooooo00Go0000ob4Q8Ol0003o0000ofIVIP0;ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03oooool01Ol0003o8B4Qo`000?l0003oIVIV00cooooo00?oA4A4
ogMgMoooool03?ooool00om4A4CoMgMgooooo`0>ooooo`05o`000?lQ8B7o0000o`000?mVIVH03?oo
ool01?lQ8B7o0000o`000?oMgMd5ooooo`00F_ooool01_l0003ok^k^ooooooooooook^k^o`0000ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03_ooool00ooMgMgo410@ooooo`0<ooooo`03omgMgOl@413ooooo00ko
oooo00?o0000ooooooooool04?ooool00onYZJWo<S8booooo`04ooooo`00F_ooool01_m4A4CoV9RH
ooooooooooooV9RHodA4A0kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03oooo
o`00F_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00?o0000ooooooooool02oooool0
0ol0003oA4A4o`00000=ooooo`03o`000?m4A4Co0000017ooooo00?o0000ooooooooool02_ooool0
1_l0003oQhN7onk^k_ooooooV9RHoeEEE@Wooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED?oooo
o`03o`000?oooooooooo00cooooo00Ko8B4QokZj^_ooooooooooofIVI_lb<S85ooooo`00Foooool0
1?nHV9So0000o`000?nHV9P?ooooo`Go00002Oooool00oo<c<coEEEEo`00000=ooooo`03olc<c?mE
EEGo0000017ooooo1Ol00008ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^2Oooool01_nYZJWo
<S8bo`000?l0003oEEEEonk^kPoooooo1Ol0000:ooooo`06okZj^_m4A4Co0000o`000?m4A4Cok^k^
1Oooool00>_ooooo003[ooooo`00joooool00>_ooooo0013ooooo`04oiRHV?l0003o0000oiRHV0Ko
ooooWOl00001ooooo`00@_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool00oooool1o`00007ooooo0012ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool0
0ol0003oooooooooo`2Iooooo`7o00000Oooool004;ooooo00Ko0000onk^k_ooooooooooonk^k_l0
0005oooooigo00000Oooool004;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0000;
o`00007ooooo0012ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003o000000_o00001Oooool1o`00007ooooo0012ooooo`06
o`000?o^k^koooooooooooo^k^ko00001Oooool00ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo000=o`0000cooooo0Ol00001ooooo`00@_ooool01_m4
A4CoV9RHooooooooooooV9RHodA4A0Gooooo0_l00005ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo0004o`0001Gooooo0_l00001ooooo`00@_ooool01_nj^[[o8B4QomgMgOoM
gMgo8B4QokZj^PGooooo0_l00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?l00000
0_l000000ooo003o0000ooooo`0Gooooo`7o00000Oooool004?ooooo00CoV9RHo`000?l0003oV9RH
1_ooool2o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0007o`0001Sooooo0Ol00001ooooo`00COoo
ool2o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00001?l0000Nooooo`7o00000Oooool004gooooo0_l00005
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool000?o00000ooo00000ol0003oooooooooo`0Kooooo`;o00000Oooool004gooooo0_l00005ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
00;o00001Ooo00000ol0003oooooooooo`0Looooo`7o00000Oooool004gooooo00?o0000ool00?l0
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000ool00?oo
003oo`000_l000000ooo003o0000ool00004ool00003o`000?oooooooooo01cooooo0Ol00001oooo
o`00COooool00ol0003oo`00o`000004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00001?l0003oo`00o`000?l00003ool000Oo00007_ooool1o`00007ooooo001=ooooo`03
o`000?oo003o000000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000So
00008oooool2o`00007ooooo001=ooooo`03o`000?oo003o000000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo02Wooooo0Ol00001ooooo`00COoo
ool00ol0003oo`00o`000004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
0002o`0002_ooooo0Ol00001ooooo`00COooool00ol0003oo`00o`000004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000Oo0000ool00?oo003oo`00o`000?oo003o000002_ooooo0Ol00001ooooo`00COoo
ool01?l0003oo`00ool00?l00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Oo0000ool00?oo003o
o`00o`000?oo003o000002[ooooo0_l00001ooooo`00<?ooool01?nHV9So0000o`000?nHV9P6oooo
o`03oeEEEOl0003oEEEE00Kooooo1?l000000ol@413oooooooooo`03ooooo`04o`000?oo003oo`00
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo0007o`0002_ooooo0Ol00001ooooo`00;oooool01_nj
^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol00008ooooo`03o`000?oooooooooo00Gooooo00Co
0000ool00?oo003o00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo000002oooooo
0Ol00001ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mE
EED02?ooool00ol0003oooooooooo`05ooooo`04o`000?oo003oo`00o`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo0002o`00033ooooo0Ol00001ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^
o`00013ooooo00?o0000ooooooooool01Oooool01?l0003oo`00ool00?l00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0;_ooool2o`00007ooooo000_ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`04o`000?oo003o
o`00o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo0002o`00037ooooo0Ol00001ooooo`00;oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool0
1Ol0003oo`00ool00?oo003o000000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0002o`00037ooooo0Ol0
0001ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`00013ooooo00?o0000ooooooooool0
1Oooool8o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00007o`00
0?oo003oo`00ool00?l0003oo`00o`00000aooooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oo
oooooooooiRHV?m4A4@@ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`04o`000?oooooo
ooooo`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool000Oo0000<?oo
ool2o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool00ol0003oA4A4
o`000007ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oooooo`00000eooooo`7o
00000Oooool0033ooooo00CoV9RHo`000?l0003oV9RH3oooool00oo<c<coEEEEo`000007ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oooooo`00000eooooo`7o00000Oooool004go
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool000;o0000=_ooool1o`00007ooooo001=ooooo`;o
00000oooool00ol0003oooooo`000005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`0dooooo`;o00000Oooool004gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooo`000005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`0eooooo`7o00000Oooool004gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`000005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000_oo
0002o`0003Oooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
000000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo0007o`0003Oooooo0Ol00001ooooo`00COooool2o`00
00?ooooo00?o0000ooooool000001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00004o`000?oooooooooo
o`0003Wooooo0_l00001ooooo`00COooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000
00Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00001?l0003oooooooooool0000jooooo`7o00000Oooool0
04gooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000005ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ooooool00000>oooool1o`00007ooooo001=ooooo`;o00001?ooool2o`0000Go
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo0002o`0003_ooooo0_l00001ooooo`00<?ooool01?nHV9So0000
o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Gooooo1_l00005ooooo`03o`000?oooooooooo00?o
oooo0_l00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`000_l0000looooo`7o00000Oooool002oooooo
00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001Oooool00onHV9So0000omgMg@02oooo
o`03oa0@4?oooooooooo00?ooooo00?o0000ooooooooool00oooool2o`0000Goo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oooooooooo`0kooooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oo
oooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?oQhN7ob4Q8Oo^k^h01oooool0
0ol0003oooooooooo`03ooooo`;o00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oooooo
oooo03_ooooo0Ol00001ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000oooooo00?o
ZJVYob4Q8Oo^k^h01_ooool2o`0000Cooooo0_l00005ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000_l0
000looooo`;o00000Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>
ooooo`03oiRHV?lb<S;ooooo00Gooooo00?o0000ooooooooool00oooool2o`0000Goo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo0002o`0003gooooo0Ol00001ooooo`00;oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00oooooo00?oA4A4ogMgMoooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00o`00000moooo
o`7o00000Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000Aooooo`03omgMgOl@413o
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00005o`000?oo003o
o`00ool00?l000000_oo00000ol0003oooooooooo`0kooooo`7o00000Oooool002oooooo00KoA4A4
oiRHV?oooooooooooiRHV?m4A4@Booooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000Go0000ool00?oo003oo`00o`000002ool00003o`000?oooooooooo03[o
oooo0_l00001ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pgooooo00Ko0000ohN7
Qoo^k^kooooooiRHV?mEEED5ooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00001?l0003oo`00ool00?l00003ool00003o`000?oooooooooo03_ooooo0Ol00001ooooo`00<?oo
ool01?nHV9So0000o`000?nHV9P>ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^1Oooool00ol0
003oooooooooo`04ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000ool00?oo003o00000ooo0000
0ol0003oooooooooo`0kooooo`7o00000Oooool004gooooo00?o0000ooooooooool01?ooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool000So0000?Oooool1o`00007ooooo001=ooooo`;o00001Oooool2o`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ooooool00000@Oooool2o`00007ooooo001=ooooo`03o`000?oooooooooo00Cooooo
0_l00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool000;o0000@oooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00Cooooo0_l0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool000;o0000@oooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00Cooooo1ol00005
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`12
ooooo`7o00000Oooool004gooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`000_l00013oooo
o`;o00000Oooool004gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool000;o
0000A?ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooo
ooooo`000005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`001ol00014ooooo`7o00000Oooool004gooooo
00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Goo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00001Ol0003ooooooooooooooooo000004Kooooo0Ol00001ooooo`00COooool2o`0000Oo
oooo00Go0000ooooooooooooooooo`000005ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000oooo
oooooooo0000A_ooool2o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEE
o`000?mEEED01_ooool01OnYZJWo8B4Qo`000?l0003oIVIV00Gooooo00?o0000ooooooooool01_oo
ool01Ol0003ooooooooooooooooo000000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003ooooo
ooooool00017ooooo`7o00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5oooo
o`?o00001_ooool01_l@413oc<c<ooooooooooooMgMgofIVIPCooooo00?o0000ooooooooool01_oo
ool01Ol0003ooooooooooooooooo000000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
o`000018ooooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03
oeEEEOl0003oEEEE00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05
o`000?ooooooooooooooool000001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo0000
04Sooooo0Ol00001ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0001?ooooo00?o0000
ooooooooool00_ooool2o`0000Sooooo00Co0000oooooooooooo00001Ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooo000004Oooooo0_l00001ooooo`00;oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo013ooooo00?oZJVYodA4A?ooool00oooool00ol0003oooooooooo`07
ooooo`04o`000?ooooooooooo`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0002o`0004Wooooo0Ol0
0001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00Co8B4Q
o`000?l0003ogMgM1?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000Goo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo0002o`0004Wooooo0Ol00001ooooo`00;oooool01_l0003ok^k^oooo
ooooooook^k^o`0001;ooooo00?oZJVYoc8b<_ooool00oooool00ol0003oooooooooo`07ooooo`04
o`000?ooooooooooo`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0002o`0004Wooooo0Ol00001oooo
o`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A1?ooooo00?o0000ooooooooool00_ooool2
o`0000Sooooo00Co0000oooooooooooo00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
oooooooo04Oooooo0_l00001ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pkooooo
00Ko8B4QokZj^_ooooooooooofIVI_lb<S84ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ool000001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04Sooooo0Ol00001oooo
o`00<?ooool01?nHV9So0000o`000?nHV9P?ooooo`06okZj^_m4A4Co0000o`000?m4A4Cok^k^1?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Goo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
0002o`0004[ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
000000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo0002o`0004[ooooo0Ol00001ooooo`00COooool2o`00
00Wooooo00?o0000ooooool000001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool000;o0000BOooool2o`00
007ooooo000@ooooo`03okZj^_lb<S;ooooo00kooooo00?o<S8bokZj^_ooool0:Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooo000000Goo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000Oo0000ool00?oo003oo`00o`000?oo003o
000004[ooooo0Ol00001ooooo`004?ooool00olb<S;o^[Zjooooo`0>ooooo`03okZj^_lb<S;ooooo
02Wooooo00?o0000ooooooooool02Oooool2o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Oo0000ool00?oo003oo`00o`000?oo
003o000004[ooooo0Ol00001ooooo`003oooool00oo<c<co<S8booooo`0@ooooo`03oc8b<_o<c<co
oooo02Sooooo00?o0000ooooooooool02Oooool2o`0000Goo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001ol0001:ooooo`7o00000Oooool0
00;ooooo00Go410@o`000?l0003o0000oa0@4008ooooo`03ofIVI_nYZJWooooo00Cooooo00?o410@
oc8b<_l@41000_l000000om4A4Coc<c<ooooo`04ooooo`03oiRHV?mVIVKooooo02Sooooo0_l0000:
ooooo`;o00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00001?l0003oooooooooool0001<ooooo`;o00000Oooool000Cooooo00?o0000
ooooooooool02?ooool00olb<S;oooooooooo`04ooooo`03o`000?nHV9Sok^k^00;ooooo00?oQhN7
oa0@4?ooool01?ooool00oo^k^ko<S8booooo`0Xooooo`03o`000?oooooooooo00Wooooo0_l00005
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00004o`000?ooooooooooo`0004gooooo0Ol00001ooooo`001?ooool00ol0003oooooooooo`08
ooooo`03oc8b<_oooooooooo00Wooooo00?o^[Zjo`000?ooool01Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00[ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003oooooooooool0
001=ooooo`7o00000Oooool000Cooooo0ol000000ol@413oMgMgonk^kP05ooooo`03oc8b<_oooooo
oooo00Cooooo00?oc<c<odA4A?l000000ol000000onHV9Soooooooooo`04ooooo`03o`000?oooooo
oooo02Oooooo0_l0000;ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooool00000COooool2
o`00007ooooo0004ooooo`06o`000?ooooooooooonk^k_mgMgOoEEEE1Oooool00olQ8B7ooooooooo
o`04ooooo`05o`000?n7QhOo^[ZjokZj^_o<c<`02?ooool00ol0003oooooooooo`0:ooooo`04oiRH
V?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED02Oooool2o`000003oa0@4?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo000004ko
oooo0Ol00001ooooo`001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o<S8bonk^k_ooool01?ooool00ol0003oV9RHooooo`02ooooo`03olc<c?l@413ooooo00Cooooo
00?ogMgMoc8b<_ooool02_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol0000:oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
00;o0000Coooool1o`00007ooooo0004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00omVIVKoV9RHooooo`04ooooo`07olc<c?m4A4Co0000o`000?l@413o<S8bo`000005
ooooo`03oiRHV?mVIVKooooo00[ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEE
EOl0003oEEEE00Kooooo1_l00004ooooo`03o`000?oooooooooo00[ooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo0002o`0004oooooo0Ol00001ooooo`001?ooool01_l0003oooooooooooo^k^koMgMgoeEEE@Go
oooo00?ogMgMob4Q8Oooool04?ooool00ol@413oc<c<ooooo`0:ooooo`06o`000?o^k^kooooooooo
ooo^k^ko00003_ooool01Om4A4Co^[Zjoooooooooooo000000Gooooo0_l0000;ooooo`;o00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
0002o`0004kooooo0_l00001ooooo`000_ooool00ol@413o0000o`000002o`000003oa0@4?mgMgOo
k^k^00Kooooo00?o<S8bokZj^_ooool03_ooool00onj^[[o<S8booooo`0;ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03?ooool01OoMgMgo8B4Qoooooooooooo000000Gooooo00?o
0000ooooooooool02_ooool2o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool000Oo0000D?ooool1o`00007ooooo000@ooooo`03okZj^_lb<S;ooooo00kooooo00?o<S8b
okZj^_ooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00CoMgMg
oiRHV?oooooo00001Oooool00ol0003oooooooooo`0:ooooo`;o00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003ooooooooo
o`1>ooooo`7o00000Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000?ooooo`04onk^
k_lQ8B7oooooo`0000Gooooo00?o0000ooooooooool02_ooool2o`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0C_ooool1o`00007ooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A44?ooool00omg
MgOoV9RHo`000005ooooo`;o00002oooool00ol0003oo`00o`000003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo
04kooooo0_l00001ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Q3ooooo00?ok^k^
oc8b<_l000001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo003o000000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Coooool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV1;ooooo00?oV9RH
oa0@4?ooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo003o000000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00005o`000?ooooooooooooooool00000D_oo
ool1o`00007ooooo001=ooooo`03o`000?oooooooooo00[ooooo00?o0000ool00?l000000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000Go0000ooooooooooooooooo`00
001Booooo`7o00000Oooool004gooooo0_l0000;ooooo`03o`000?oo003o000000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00005o`000?ooooooooooooooool00000DOoo
ool2o`00007ooooo001=ooooo`03o`000?oooooooooo00[ooooo00Co0000ool00?oo003o00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000Co0000oooooooooooo0000
Doooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00[ooooo00Co0000ool00?oo003o0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000Co0000oooooooooooo
0000Doooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00[ooooo00Co0000ool00?oo003o
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000Co0000oooooooo
oooo0000Doooool1o`00007ooooo001=ooooo`;o00002oooool01?l0003oo`00ool00?l00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oooooo`00001Coooo
o`;o00000Oooool004gooooo00?o0000ooooooooool02_ooool01ol0003oo`00ool00?oo003o0000
ool00?l000001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oooooo000005Cooooo0Ol00001
ooooo`00COooool00ol0003oooooooooo`0:ooooo`07o`000?oo003oo`00ool00?l0003oo`00o`00
0005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ooooool00000E?ooool1o`00007ooooo001=
ooooo`03o`000?oooooooooo00[ooooo00Oo0000ool00?oo003oo`00o`000?oo003o000000Goo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo0002o`0005Gooooo0Ol00001ooooo`00COooool2o`0000_ooooo1ol0
0005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`000_l0001Dooooo`;o00000Oooool0033ooooo00CoV9RH
o`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@06ooooo`05oiRHV?l@413o0000o`000?mVIVH0
1Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo000000Goo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo0002o`0005Gooooo0Ol00001ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGo
oooo0ol00006ooooo`06oa0@4?n7QhOooooooooooomgMgOoIVIV1?ooool00ol0003oooooooooo`0?
ooooo`;o00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo05Cooooo0Ol00001
ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED02ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo0_l00005ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0E?ooool1o`00007ooooo000_ooooo`06o`000?o^k^ko
ooooooooooo^k^ko00004_ooool00oo^k^ko0000ooooo`03ooooo`;o00004?ooool2o`0000Goo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000_oo0002o`0005Gooooo0_l00001ooooo`00;oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00cooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH4ooooo`03
o`000?oooooooooo00oooooo0_l00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000;oo`000_l0001Fooooo`7o
00000Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`05o`00
0?lQ8B7o0000o`000?mVIVH01Oooool00ol0003oooooooooo`0?ooooo`;o00001Ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00002ool000;o0000E_ooool1o`00007ooooo000_ooooo`06o`000?o^k^koooooooooooo^
k^ko00003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00001ol0003oo`00ool00?oo003o0000ool00?l00000E_ooool1o`00007ooooo000_
ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A43_ooool00ol0003oooooooooo`07ooooo`;o0000
4Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00007o`000?oo003oo`00ool00?l0003oo`00o`00001Eoooo
o`;o00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X>ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool04?ooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00007o`000?oo003o
o`00ool00?l0003oo`00o`00001Fooooo`7o00000Oooool0033ooooo00CoV9RHo`000?l0003oV9RH
3oooool5o`0000Gooooo00?o0000ooooooooool04?ooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00004o`00
0?oo003oo`00o`0000;oo`0000?o0000ooooooooool0E?ooool1o`00007ooooo001=ooooo`03o`00
0?oooooooooo013ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00001?l0003oo`00ool00?l00002ool00003
o`000?oooooooooo05Cooooo0Ol00001ooooo`00COooool2o`00017ooooo0_l00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00004o`00
0?oo003oo`00o`0000;oo`0000?o0000ooooooooool0Doooool2o`00007ooooo001=ooooo`03o`00
0?oooooooooo013ooooo0_l00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003o000000?oo`0000?o0000ooooooooool0
E?ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo013ooooo0_l00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003o000000?oo`0000?o0000ooooooooool0E?ooool1o`00007ooooo001=ooooo`03o`000?oooooo
oooo013ooooo0_l00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003o000000?oo`0000?o0000ooooooooool0E?ooool1
o`00007ooooo001=ooooo`;o00004Oooool2o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`000_l00004ool00003o`000?oooooooooo
05?ooooo0_l00001ooooo`00COooool00ol0003oooooooooo`0@ooooo`03o`000?oo003o000000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`000_l00004ool00003o`000?oooooooooo05Cooooo0Ol00001ooooo`00COooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oo003o000000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`1Dooooo`7o00000Oooool004gooooo0_l0000Aooooo`03o`000?oo003o000000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`001ol0
001Eooooo`;o00000Oooool0033ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEE
E@06ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^1?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oo003o000000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`000_l0001Looooo`7o00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgo
gMgMob4Q8Onj^[X5ooooo`?o00001_ooool2ogMgM`;ooooo00?oMgMgoeEEEOooool00oooool00ol0
003oooooooooo`0@ooooo`04o`000?oo003oo`00o`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000_l0001Looooo`7o00000Oooool0
02oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?o
8B4Qooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00Co
0000ool00?oo003o00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo0002o`0005cooooo0Ol00001ooooo`00;oooool01_l0003ok^k^oooo
ooooooook^k^o`0000kooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`02ooooo`;o
00004Oooool01?l0003oo`00ool00?l00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo0008o`0005_ooooo0_l00001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00cooooo00Ko0000oeEEEOo^k^koooooogMgMomEEED4ooooo`03o`000?oooooo
oooo013ooooo00Oo0000ool00?oo003oo`00o`000?oo003o000000Goo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo0Ol00001ooooo`00;ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Ko0000ogMgMol0003o0000
oeEEEOo^k^h4ooooo`03o`000?oooooooooo013ooooo00Oo0000ool00?oo003oo`00o`000?oo003o
000000Goo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`001ol00003ooooo`03o`000?oooooooooo05gooooo0Ol00001ooooo`00;oooool01_l0
003ok^k^ooooooooooook^k^o`0000kooooo00?oA4A4oiRHV?ooool01oooool00ol0003ooooooooo
o`0@ooooo`07o`000?oo003oo`00ool00?l0003oo`00o`000005ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0GOooool1o`00007ooooo000_ooooo`06odA4A?nHV9SooooooooooonH
V9SoA4A43_ooool00onj^[[o8B4Qooooo`07ooooo`;o00004Oooool00ol0003oo`00ool00002ool0
00;o00001Ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`06ooooo`03o`000?oooooooooo05gooooo0_l00001oooo
o`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Poooooo00?oEEEEoc8b<_oMgMd01_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oo003oo`0000;oo`000_l00005ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0G_ooool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000
oiRHV17ooooo00CoV9RHob4Q8Ol0003o8B4Q1?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
003oo`0000;oo`000_l00005ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oooooooooo00Gooooo00?o0000ooooooooool0Gooo
ool1o`00007ooooo001=ooooo`03o`000?oooooooooo013ooooo1ol00005ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0Goooool1o`00007ooooo001=ooooo`;o00005oooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo00Gooooo00?o0000ooooooooool0G_ooool2o`00
007ooooo001=ooooo`03o`000?oooooooooo01Kooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo063ooooo0Ol00001ooooo`00COooool00ol0003ooooo
ooooo`0Fooooo`;o00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo
0Ol00001ooooo`00COooool00ol0003oooooooooo`0Fooooo`;o00001?oo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo067ooooo0Ol00001ooooo`00COooool2o`0001Oooooo0_l00004
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo00?ooooo00?o0000ooooooooool0H?ooool2o`00007ooooo001=oooo
o`03o`000?oooooooooo01Kooooo00?o0000ool00?l000000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`02oooo
o`03o`000?oooooooooo06;ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Fooooo`03
o`000?oo003o000000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`1Rooooo`7o
00000Oooool004gooooo00?o0000ooooooooool05_ooool00ol0003oo`00o`000003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0H_ooool1o`00007ooooo001=ooooo`;o00005ooo
ool01?l0003oo`00ool00?l00002ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00005o`000?ooooooooooooooool00000I?ooool2o`00007o
oooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED02?ooool00ol0003o
ZJVYooooo`05ooooo`03o`000?oooooooooo01Kooooo00Co0000ool00?oo003o00000_oo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001Ol0
003ooooooooooooooooo000006Gooooo0Ol00001ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo
8B4QokZj^PGooooo0ol00008ooooo`;oEEEE1_ooool00ol0003oooooooooo`0Fooooo`04o`000?oo
003oo`00o`0000;oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000Co0000oooooooooooo0000I_ooool1o`00007ooooo000_ooooo`06odA4
A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@08ooooo`03ojVYZOl0003ooooo
00Gooooo00?o0000ooooooooool05_ooool01ol0003oo`00ool00?oo003o0000ool00?l000001_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000oooooooooooo0000
I_ooool1o`00007ooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00004Oooool00ol0003o
c<c<ooooo`04ooooo`;o00005oooool01ol0003oo`00ool00?oo003o0000ool00?l000001_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooool00000I_ooool2
o`00007ooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool00omE
EEGoIVIVooooo`04ooooo`03o`000?oooooooooo01Kooooo00Oo0000ool00?oo003oo`00o`000?oo
003o000000Koo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000;o0000J?oo
ool1o`00007ooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool0
0onYZJWo410@ooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ool00?oo00000_oo0002
o`0000Koo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000;o0000J?ooool1
o`00007ooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00004_ooool00ol0003ogMgMoooo
o`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`001ol0001Yooooo`7o00000Oooool002oooooo00KoA4A4
oiRHV?oooooooooooiRHV?m4A4@Booooo`03oeEEEOn7QhOooooo00?ooooo0_l0000Gooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0I_ooool2o`00007ooooo000_ooooo`06okZj^_lQ
8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool01_l@413oooooooooooooooooZJVYoc8b<PCooooo00?o0000
ooooooooool05_ooool>o`0000Goo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`1X
ooooo`7o00000Oooool0033ooooo00CoV9RHo`000?l0003oV9RH3oooool6o`0000Cooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Xooooo`7o00000Oooool004gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_l0001[ooooo`7o00000Oooool004gooooo0_l0000Pooooo`05o`000?oooooooooooooo
ool000001Ooo00000ol0003oooooo`00001/ooooo`;o00000Oooool004gooooo00?o0000oooooooo
ool08?ooool01?l0003oooooooooool00005ool000;o0000K_ooool1o`00007ooooo001=ooooo`03
o`000?oooooooooo027ooooo2Ol0001_ooooo`7o00000Oooool004gooooo00?o0000ooooooooool0
8_ooool3o`000004ooooool0003o0000o`00073ooooo0Ol00001ooooo`00COooool2o`0002Kooooo
0_l0001aooooo`;o00000Oooool004gooooo00?o0000ooooooooool0VOooool1o`00007ooooo001=
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00COoooonMo`00007ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00001\
\>"],
  ImageRangeCache->{{{73.4375, 260.438}, {304.062, 117.062}} -> {-3.41304, \
0.43395, 0.0201184, 0.00513859}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Random Matrix - 2 GOEs", "Section"],

Cell[TextData[{
  "In this section we generate a level spacing histogram for a combination of \
eigenvalues from two random real symmetric matrices.  The code below \
generates the two random matrices, finds their eigenvalues, unfolds the \
eigenvalues so that they are distributed uniformly on a large scale, combines \
the unfolded eigenvalues into a single list, and sorts them.  Note: this will \
take roughly twice as long as the calculations for a single GOE matrix \
(approximately 1800 seconds on a PowerMac G4 733 MHz).  As with the GOE \
matrix above, watch out for eigenvalues with absolute value greater than ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(2  N\)\)]],
  ".  Also, note that when the two unfolded sequences are mixed together the \
mean spacing of the resulting sequence will be 0.5 rather than 1, so the \
spacing must be rescaled to have mean spacing 1."
}], "Text"],

Cell[BoxData[
    \(<< Statistics`ContinuousDistributions`\)], "Input"],

Cell[BoxData[
    \(<< Graphics`\)], "Input"],

Cell[BoxData[{
    \(\(n = 3000;\)\), "\n", 
    \(M1 = 
      Table[Which[i \[Equal] j, Random[NormalDistribution[0, 1]], i < j, 
          Random[NormalDistribution[0, 1/Sqrt[2]]], i > j, 0], {i, 1, n}, {j, 
          1, n}]; \), "\n", 
    \(M1Full = 
      Table[Which[i \[GreaterEqual] j, M1[\([\)\(j, i\)\(]\)], i < j, 
          M1[\([\)\(i, j\)\(]\)]], {i, 1, n}, {j, 1, n}]; \), "\n", 
    \(M2 = 
      Table[Which[i \[Equal] j, Random[NormalDistribution[0, 1]], i < j, 
          Random[NormalDistribution[0, 1/Sqrt[2]]], i > j, 0], {i, 1, n}, {j, 
          1, n}]; \), "\n", 
    \(M2Full = 
      Table[Which[i \[GreaterEqual] j, M2[\([\)\(j, i\)\(]\)], i < j, 
          M2[\([\)\(i, j\)\(]\)]], {i, 1, n}, {j, 1, n}]; \), "\n", 
    \(\(EV1 = Eigenvalues[M1Full];\)\), "\n", 
    \(\(UEV1 = 
        Table[\((EV1[\([\)\(i\)\(]\)]*Sqrt[2*n - EV1[\([\)\(i\)\(]\)]^2] + 
                2*n*ArcSin[EV1[\([\)\(i\)\(]\)]/Sqrt[2*n]] + n*Pi)\)/\((2*
                Pi)\), {i, 1, n}];\)\), "\n", 
    \(EV2 = Eigenvalues[M2Full]; \), "\n", 
    \(\(UEV2 = 
        Table[\((EV2[\([\)\(i\)\(]\)]*Sqrt[2*n - EV2[\([\)\(i\)\(]\)]^2] + 
                2*n*ArcSin[EV2[\([\)\(i\)\(]\)]/Sqrt[2*n]] + n*Pi)\)/\((2*
                Pi)\), {i, 1, n}];\)\), "\[IndentingNewLine]", 
    \(\(UEV = Join[UEV1, UEV2];\)\), "\n", 
    \(\(SUev = Sort[UEV];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SpcUev = 
        Table[SUev[\([i + 1]\)] - SUev[\([i]\)], {i, 1, 
            2*n - 1}];\)\), "\n", 
    \(\(SpcUevNorm = SpcUev/Mean[SpcUev];\)\), "\n", 
    \(\(int\  = \ Table[0 + i/8, {i, 0, 40}];\)\), "\n", 
    \(GOE2Hist = 
      Histogram[SpcUevNorm, HistogramCategories \[Rule] int, 
        HistogramScale \[Rule] 1, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] False]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.38778e-17 0.242424 0.0147151 1.00313 [
[.24242 .00222 -6.78125 -18 ]
[.24242 .00222 6.78125 0 ]
[.48485 .00222 -6.78125 -18 ]
[.48485 .00222 6.78125 0 ]
[.72727 .00222 -6.78125 -18 ]
[.72727 .00222 6.78125 0 ]
[.9697 .00222 -6.78125 -18 ]
[.9697 .00222 6.78125 0 ]
[-0.0125 .11503 -32.6875 -9 ]
[-0.0125 .11503 0 9 ]
[-0.0125 .21534 -32.6875 -9 ]
[-0.0125 .21534 0 9 ]
[-0.0125 .31566 -32.6875 -9 ]
[-0.0125 .31566 0 9 ]
[-0.0125 .41597 -32.6875 -9 ]
[-0.0125 .41597 0 9 ]
[-0.0125 .51628 -32.6875 -9 ]
[-0.0125 .51628 0 9 ]
[-0.0125 .6166 -32.6875 -9 ]
[-0.0125 .6166 0 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.24242 .01472 m
.24242 .02097 L
s
gsave
.24242 .00222 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.48485 .01472 m
.48485 .02097 L
s
gsave
.48485 .00222 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.72727 .01472 m
.72727 .02097 L
s
gsave
.72727 .00222 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.9697 .01472 m
.9697 .02097 L
s
gsave
.9697 .00222 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .01472 m
1 .01472 L
s
0 .11503 m
.00625 .11503 L
s
gsave
-0.0125 .11503 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .21534 m
.00625 .21534 L
s
gsave
-0.0125 .21534 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .31566 m
.00625 .31566 L
s
gsave
-0.0125 .31566 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
0 .41597 m
.00625 .41597 L
s
gsave
-0.0125 .41597 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .51628 m
.00625 .51628 L
s
gsave
-0.0125 .51628 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .6166 m
.00625 .6166 L
s
gsave
-0.0125 .6166 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03478 m
.00375 .03478 L
s
0 .05484 m
.00375 .05484 L
s
0 .0749 m
.00375 .0749 L
s
0 .09497 m
.00375 .09497 L
s
0 .13509 m
.00375 .13509 L
s
0 .15515 m
.00375 .15515 L
s
0 .17522 m
.00375 .17522 L
s
0 .19528 m
.00375 .19528 L
s
0 .2354 m
.00375 .2354 L
s
0 .25547 m
.00375 .25547 L
s
0 .27553 m
.00375 .27553 L
s
0 .29559 m
.00375 .29559 L
s
0 .33572 m
.00375 .33572 L
s
0 .35578 m
.00375 .35578 L
s
0 .37584 m
.00375 .37584 L
s
0 .39591 m
.00375 .39591 L
s
0 .43603 m
.00375 .43603 L
s
0 .45609 m
.00375 .45609 L
s
0 .47616 m
.00375 .47616 L
s
0 .49622 m
.00375 .49622 L
s
0 .53635 m
.00375 .53635 L
s
0 .55641 m
.00375 .55641 L
s
0 .57647 m
.00375 .57647 L
s
0 .59653 m
.00375 .59653 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .55784 L
.0303 .55784 L
.0303 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .55784 L
.0303 .55784 L
.0303 .01472 L
0 .01472 L
s
1 0 0 r
.0303 .01472 m
.0303 .55917 L
.06061 .55917 L
.06061 .01472 L
F
0 g
.0303 .01472 m
.0303 .55917 L
.06061 .55917 L
.06061 .01472 L
.0303 .01472 L
s
1 0 0 r
.06061 .01472 m
.06061 .60332 L
.09091 .60332 L
.09091 .01472 L
F
0 g
.06061 .01472 m
.06061 .60332 L
.09091 .60332 L
.09091 .01472 L
.06061 .01472 L
s
1 0 0 r
.09091 .01472 m
.09091 .5672 L
.12121 .5672 L
.12121 .01472 L
F
0 g
.09091 .01472 m
.09091 .5672 L
.12121 .5672 L
.12121 .01472 L
.09091 .01472 L
s
1 0 0 r
.12121 .01472 m
.12121 .59797 L
.15152 .59797 L
.15152 .01472 L
F
0 g
.12121 .01472 m
.12121 .59797 L
.15152 .59797 L
.15152 .01472 L
.12121 .01472 L
s
1 0 0 r
.15152 .01472 m
.15152 .59931 L
.18182 .59931 L
.18182 .01472 L
F
0 g
.15152 .01472 m
.15152 .59931 L
.18182 .59931 L
.18182 .01472 L
.15152 .01472 L
s
1 0 0 r
.18182 .01472 m
.18182 .54446 L
.21212 .54446 L
.21212 .01472 L
F
0 g
.18182 .01472 m
.18182 .54446 L
.21212 .54446 L
.21212 .01472 L
.18182 .01472 L
s
1 0 0 r
.21212 .01472 m
.21212 .58058 L
.24242 .58058 L
.24242 .01472 L
F
0 g
.21212 .01472 m
.21212 .58058 L
.24242 .58058 L
.24242 .01472 L
.21212 .01472 L
s
1 0 0 r
.24242 .01472 m
.24242 .51503 L
.27273 .51503 L
.27273 .01472 L
F
0 g
.24242 .01472 m
.24242 .51503 L
.27273 .51503 L
.27273 .01472 L
.24242 .01472 L
s
1 0 0 r
.27273 .01472 m
.27273 .49898 L
.30303 .49898 L
.30303 .01472 L
F
0 g
.27273 .01472 m
.27273 .49898 L
.30303 .49898 L
.30303 .01472 L
.27273 .01472 L
s
1 0 0 r
.30303 .01472 m
.30303 .45617 L
.33333 .45617 L
.33333 .01472 L
F
0 g
.30303 .01472 m
.30303 .45617 L
.33333 .45617 L
.33333 .01472 L
.30303 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .37992 L
.36364 .37992 L
.36364 .01472 L
F
0 g
.33333 .01472 m
.33333 .37992 L
.36364 .37992 L
.36364 .01472 L
.33333 .01472 L
s
1 0 0 r
.36364 .01472 m
.36364 .36119 L
.39394 .36119 L
.39394 .01472 L
F
0 g
.36364 .01472 m
.36364 .36119 L
.39394 .36119 L
.39394 .01472 L
.36364 .01472 L
s
1 0 0 r
.39394 .01472 m
.39394 .24614 L
.42424 .24614 L
.42424 .01472 L
F
0 g
.39394 .01472 m
.39394 .24614 L
.42424 .24614 L
.42424 .01472 L
.39394 .01472 L
s
1 0 0 r
.42424 .01472 m
.42424 .25952 L
.45455 .25952 L
.45455 .01472 L
F
0 g
.42424 .01472 m
.42424 .25952 L
.45455 .25952 L
.45455 .01472 L
.42424 .01472 L
s
1 0 0 r
.45455 .01472 m
.45455 .21136 L
.48485 .21136 L
.48485 .01472 L
F
0 g
.45455 .01472 m
.45455 .21136 L
.48485 .21136 L
.48485 .01472 L
.45455 .01472 L
s
1 0 0 r
.48485 .01472 m
.48485 .14983 L
.51515 .14983 L
.51515 .01472 L
F
0 g
.48485 .01472 m
.48485 .14983 L
.51515 .14983 L
.51515 .01472 L
.48485 .01472 L
s
1 0 0 r
.51515 .01472 m
.51515 .14448 L
.54545 .14448 L
.54545 .01472 L
F
0 g
.51515 .01472 m
.51515 .14448 L
.54545 .14448 L
.54545 .01472 L
.51515 .01472 L
s
1 0 0 r
.54545 .01472 m
.54545 .1204 L
.57576 .1204 L
.57576 .01472 L
F
0 g
.54545 .01472 m
.54545 .1204 L
.57576 .1204 L
.57576 .01472 L
.54545 .01472 L
s
1 0 0 r
.57576 .01472 m
.57576 .09364 L
.60606 .09364 L
.60606 .01472 L
F
0 g
.57576 .01472 m
.57576 .09364 L
.60606 .09364 L
.60606 .01472 L
.57576 .01472 L
s
1 0 0 r
.60606 .01472 m
.60606 .06287 L
.63636 .06287 L
.63636 .01472 L
F
0 g
.60606 .01472 m
.60606 .06287 L
.63636 .06287 L
.63636 .01472 L
.60606 .01472 L
s
1 0 0 r
.63636 .01472 m
.63636 .06555 L
.66667 .06555 L
.66667 .01472 L
F
0 g
.63636 .01472 m
.63636 .06555 L
.66667 .06555 L
.66667 .01472 L
.63636 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .06421 L
.69697 .06421 L
.69697 .01472 L
F
0 g
.66667 .01472 m
.66667 .06421 L
.69697 .06421 L
.69697 .01472 L
.66667 .01472 L
s
1 0 0 r
.69697 .01472 m
.69697 .03612 L
.72727 .03612 L
.72727 .01472 L
F
0 g
.69697 .01472 m
.69697 .03612 L
.72727 .03612 L
.72727 .01472 L
.69697 .01472 L
s
1 0 0 r
.72727 .01472 m
.72727 .03211 L
.75758 .03211 L
.75758 .01472 L
F
0 g
.72727 .01472 m
.72727 .03211 L
.75758 .03211 L
.75758 .01472 L
.72727 .01472 L
s
1 0 0 r
.75758 .01472 m
.75758 .04682 L
.78788 .04682 L
.78788 .01472 L
F
0 g
.75758 .01472 m
.75758 .04682 L
.78788 .04682 L
.78788 .01472 L
.75758 .01472 L
s
1 0 0 r
.78788 .01472 m
.78788 .02943 L
.81818 .02943 L
.81818 .01472 L
F
0 g
.78788 .01472 m
.78788 .02943 L
.81818 .02943 L
.81818 .01472 L
.78788 .01472 L
s
1 0 0 r
.81818 .01472 m
.81818 .02943 L
.84848 .02943 L
.84848 .01472 L
F
0 g
.81818 .01472 m
.81818 .02943 L
.84848 .02943 L
.84848 .01472 L
.81818 .01472 L
s
1 0 0 r
.84848 .01472 m
.84848 .02542 L
.87879 .02542 L
.87879 .01472 L
F
0 g
.84848 .01472 m
.84848 .02542 L
.87879 .02542 L
.87879 .01472 L
.84848 .01472 L
s
1 0 0 r
.87879 .01472 m
.87879 .02274 L
.90909 .02274 L
.90909 .01472 L
F
0 g
.87879 .01472 m
.87879 .02274 L
.90909 .02274 L
.90909 .01472 L
.87879 .01472 L
s
1 0 0 r
.90909 .01472 m
.90909 .01605 L
.93939 .01605 L
.93939 .01472 L
F
0 g
.90909 .01472 m
.90909 .01605 L
.93939 .01605 L
.93939 .01472 L
.90909 .01472 L
s
1 0 0 r
.93939 .01472 m
.93939 .01739 L
.9697 .01739 L
.9697 .01472 L
F
0 g
.93939 .01472 m
.93939 .01739 L
.9697 .01739 L
.9697 .01472 L
.93939 .01472 L
s
1 0 0 r
.9697 .01472 m
.9697 .01605 L
1 .01605 L
1 .01472 L
F
0 g
.9697 .01472 m
.9697 .01605 L
1 .01605 L
1 .01472 L
.9697 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0053ooooo1?l000000ol@413ooooooooo
o`0Xooooo`Ko0000:oooool01OnYZJWo8B4Qo`000?l0003oIVIV02kooooo0_l000000ol@413ooooo
ooooo`03ooooo`00D_ooool00ol0003oooooooooo`0Zooooo`03oiRHV?l0003ogMgM00;ooooo00?o
410@ooooooooool0:Oooool01_l@413oc<c<ooooooooooooMgMgofIVIRkooooo00?o0000oooooooo
ool01?ooool005;ooooo00?o0000ooooooooool0:oooool00on7QhOo8B4Qonk^kP0booooo`03o`00
0?oooooooooo02Sooooo1_l00005ooooo`00D_ooool00ol0003oooooooooo`0/ooooo`03ojVYZOlQ
8B7ok^k^037ooooo00?o0000ooooooooool0:?ooool01Om4A4Co^[Zjoooooooooooo000000Kooooo
001Booooo`03o`000?oooooooooo02gooooo00?oV9RHoc8b<_ooool0;oooool00onYZJWoA4A4oooo
o`0Yooooo`05omgMgOlQ8B7oooooooooool000001_ooool005;ooooo00?o0000ooooooooool0;_oo
ool00om4A4CoMgMgooooo`0/ooooo`04ob4Q8Ol0003o0000omgMgB_ooooo00CoMgMgoiRHV?oooooo
00001_ooool005;ooooo00?o0000ooooooooool0;_ooool00ooMgMgo410@ooooo`0^ooooo`03ojVY
ZOlb<S;ooooo02[ooooo00Cok^k^ob4Q8Ooooooo00001_ooool005;ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02[ooooo00?oMgMgoiRHV?l00000
1_ooool0053ooooo00?o0000odA4A?l00000;?ooool01_l0003oQhN7onk^k_ooooooV9RHoeEEEB_o
oooo00Ko8B4QokZj^_ooooooooooofIVI_lb<S8/ooooo`03onk^k_lb<S;o000000Kooooo001@oooo
o`03olc<c?mEEEGo000002cooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h[ooooo`06okZj^_m4
A4Co0000o`000?m4A4Cok^k^;Oooool00onHV9So410@ooooo`05ooooo`00joooool00>_ooooo000S
ooooo`03o`000?oooooooooo0<Gooooo000Sooooo`03o`000?oooooooooo0<Gooooo000Sooooo`03
o`000?oooooooooo0<Gooooo000SooooolOo00000Oooool002?ooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool000Oo00002oooool00ol0003oooooooooo`05ooooo`008oooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool000Oo00006Oooool002?ooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001ol00005ool000go00007oooool002?o
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000Oo00001Oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo02Wooooo000Sooooo`03o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`09ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0:Oooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo00Wooooo1ol0000[ooooo`008oooool00ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0>oooool002?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo03_ooooo000Sooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0007o`0000Goo`001ol0000mooooo`00
8oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool7o`0004?ooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`1=ooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0COooool002?ooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo04gooooo000Sooooo`03o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1=ooooo`008oooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool000Oo0000Coooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`1Cooooo`001Oooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Kooooo1?l0
00000ol@413oooooooooo`04ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Dooo
ool000Cooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00002?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Doooool000Cooooo00Ko
A4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Sooooo00?o0000oooooooo
ool01_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo05?ooooo0004ooooo`06o`00
0?o^k^koooooooooooo^k^ko00004?ooool00ol0003oooooooooo`06ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0Doooool000Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`001ol0001Eooooo`001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`1Iooooo`001?ooool01_l0003ok^k^ooooooooooook^k^o`00013ooooo00?o0000oooooooo
ool01_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`1Iooooo`001?ooool01_m4A4CoV9RHooooooooooooV9RHodA4
A13ooooo00?o0000ooooooooool01_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Iooooo`001?ooool01_nj^[[o
8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00?o0000odA4A?l000002?ooool00ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`001ol0001Kooooo`001Oooool01?nHV9So0000o`000?nHV9P?
ooooo`03olc<c?mEEEGo000000Sooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0007o`00067ooooo000Soooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0IOooool002?ooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`1Uooooo`008oooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo06Gooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0IOoo
ool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Uooooo`008oooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo06Gooooo000Sooooo`03o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0IOooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`1Uooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo06Gooooo0005
ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01Oooool6o`0000Kooooo00?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oooooooooo`1Uooooo`001?ooool01_nj^[[o8B4QomgMgOoM
gMgo8B4QokZj^PGooooo0ol00005ooooo`03oiRHV?l0003ogMgM00;ooooo00?o410@ooooooooool0
1?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo06Gooooo0004ooooo`06odA4A?nH
V9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`03ohN7QolQ8B7ok^k^00So
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Uooooo`001?ooool01_l0003ok^k^
ooooooooooook^k^o`0000oooooo00?oZJVYob4Q8Oo^k^h01oooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0007o`0006Oooooo0004ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00onHV9So<S8booooo`06ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo06_ooooo0004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3oooool00om4A4CoMgMgooooo`05ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo06_ooooo0004ooooo`06o`000?o^
k^koooooooooooo^k^ko00004Oooool00ooMgMgo410@ooooo`05ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo06_o
oooo0004ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A44_ooool00ol0003oooooooooo`04oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo06_ooooo0004ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3Oooool0
1_l0003oQhN7onk^k_ooooooV9RHoeEEE@Kooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Joooool000Gooooo00Co
V9RHo`000?l0003oV9RH3_ooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kPKooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo0007o`0000Goo`0000?o0000ooooooooool0Joooool002?ooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Joooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0Joooool002?ooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`03ooooo`Oo0000KOooool002?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`1gooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
07Oooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Moooool002?ooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1gooooo`008oooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo07Oooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0Moooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1goooo
o`001Oooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Kooooo00GoZJVYob4Q
8Ol0003o0000ofIVIP06ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Moooool0
00Cooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001_ooool01_l@413oc<c<oooo
ooooooooMgMgofIVIPGooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1gooooo`00
1?ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED02oooool00ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Moooool000Co
oooo00Ko0000onk^k_ooooooooooonk^k_l0000Cooooo`03o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`1gooooo`001?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo013ooooo00?oZJVYodA4A?ooool01?ooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo07Oooooo0004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03_ooool01?lQ8B7o0000o`000?oMgMd5ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0Moooool000Cooooo00Ko0000onk^k_ooooooooooonk^k_l0000Booooo`03ojVYZOlb<S;o
oooo00Cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1gooooo`001?ooool01_m4
A4CoV9RHooooooooooooV9RHodA4A1?ooooo00?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo07Oooooo0004ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj
3_ooool01_lQ8B7o^[ZjooooooooooooIVIVoc8b<PGooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`1gooooo`001Oooool01?nHV9So0000o`000?nHV9P?ooooo`06okZj^_m4A4Co0000
o`000?m4A4Cok^k^1Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo07Oooooo000S
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Moooool002?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`1gooooo`008oooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0007o`0007Wooooo000Sooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo07gooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oooooooooo07gooooo000Sooooo`03o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo
oooo07gooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0007o`00
07oooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`23ooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0Poooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo08?ooooo0005ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?o
EEEEo`000?mEEED02Oooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oooooooooo08?ooooo0004ooooo`06okZj^_lQ8B7o
gMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Poooool000Cooooo00Ko
A4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo1_l00005ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`23ooooo`00
1?ooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00GoA4A4okZj^_ooooooooooo`000006
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`23
ooooo`001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00GogMgMob4Q
8Oooooooooooo`000006ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`23ooooo`001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00gooooo00CoMgMgoiRHV?oooooo00001_ooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0Poooool000Cooooo00Ko0000onk^k_ooooooooooonk^k_l0
000?ooooo`04onk^k_lQ8B7oooooo`0000Kooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oooooooooo08?ooooo0004ooooo`06odA4A?nHV9SooooooooooonHV9So
A4A44?ooool00omgMgOoV9RHo`000006ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`23ooooo`001?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj
^Q3ooooo00?ok^k^oc8b<_l000001_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0Poooool000Gooooo00CoV9RHo`000?l0003oV9RH4_ooool00onH
V9So410@ooooo`05ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`23ooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0Poooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0007o`0008Gooooo
000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool002?ooooo00?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`008oooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo08Wooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0ROooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`29ooooo`008ooo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oooooooooo08Wooooo000Sooooo`03o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0ROooool002?ooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`29ooooo`001Oooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE
00Kooooo00GoV9RHoa0@4?l0003o0000ofIVIP06ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool000Oo0000Roooool000Cooooo00Ko^[Zjob4Q
8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001_ooool01_l@413oQhN7ooooooooooooMgMgofIVIPGo
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0Soooool000Cooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5oooo
o`03oeEEEOl0003oEEEE00_ooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`2?oooo
o`001?ooool01_l0003ok^k^ooooooooooook^k^o`0001;ooooo00?ok^k^o`000?ooool01?ooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001ol0002Aooooo`001?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Ko410@oiRHV?ooooooooooogMgMomV
IVH5ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2Eooooo`001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Go0000
ob4Q8Ol0003o0000ofIVIP06ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`2Eooooo`001?ooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo
00?o0000ooooooooool02?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0UOooool000Cooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@>ooooo`03
o`000?oooooooooo00Sooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo09Gooooo0004ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool00ol0
003oooooooooo`08ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`2Eooooo`001Oooool01?nHV9So0000o`000?nHV9P?ooooo`Go00001_ooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0007o`00
00Goo`0000?o0000ooooooooool0UOooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo09Gooooo000Sooooo`go00001Ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0UOooool002?ooooo00?o
0000ooooooooool02Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o
0000ool00?oo00000ooo00000ol0003oooooooooo`2Eooooo`008oooool00ol0003oooooooooo`09
ooooo`03o`000?oo003oo`0000?oo`001ol00005ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo09Gooooo000Soooo
o`03o`000?oooooooooo00Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0UOooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2Eooooo`008oooool00ol0003oooooooooo`09ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00oooool7o`0009Oooooo000Sooooo`03o`000?oo
oooooooo00Wooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`2Qooooo`008oooool0
0ol0003oooooooooo`09ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0XOooool0
02?ooooo00?o0000ooooooooool02Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo3Ol0002Sooooo`001Oooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE
00Kooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h5ooooo`03o`000?oooooooooo00Wooooo1ol0
002eooooo`001?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`;oMgMg
0_ooool00omgMgOoEEEEooooo`04ooooo`03o`000?oooooooooo0<Gooooo0004ooooo`06odA4A?nH
V9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`03ob4Q8Ooooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`35ooooo`001?ooool01_l0003ok^k^
ooooooooooook^k^o`0000kooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`03oooo
o`;o0000a_ooool000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`06
o`000?mEEEGok^k^oooooomgMgOoEEEEcOooool000Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0<ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^cOooool000Cooooo00Ko0000
onk^k_ooooooooooonk^k_l0000>ooooo`03odA4A?nHV9Sooooo0=3ooooo0004ooooo`06odA4A?nH
V9SooooooooooonHV9SoA4A43_ooool00onj^[[o8B4Qooooo`3@ooooo`001?ooool01_nj^[[o8B4Q
omgMgOoMgMgo8B4QokZj^Poooooo00?oEEEEoc8b<_oMgMd0coooool000Gooooo00CoV9RHo`000?l0
003oV9RH4Oooool01?nHV9So8B4Qo`000?lQ8B7=ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00\
\>"],
  ImageRangeCache->{{{73.4375, 260.438}, {310.062, 123.062}} -> {-2.64763, \
0.457334, 0.0208544, 0.00503983}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Below we compare the histogram to the theoretical distribution for \
a combination of two sets of data that have GOE spacings.  The fit is very \
good.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[GOE2Hist, GOE2, AspectRatio \[Rule] 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.38778e-17 0.242424 0.0238095 1.60249 [
[.24242 .01131 -6.78125 -18 ]
[.24242 .01131 6.78125 0 ]
[.48485 .01131 -6.78125 -18 ]
[.48485 .01131 6.78125 0 ]
[.72727 .01131 -6.78125 -18 ]
[.72727 .01131 6.78125 0 ]
[.9697 .01131 -6.78125 -18 ]
[.9697 .01131 6.78125 0 ]
[-0.0125 .18406 -32.6875 -9 ]
[-0.0125 .18406 0 9 ]
[-0.0125 .34431 -32.6875 -9 ]
[-0.0125 .34431 0 9 ]
[-0.0125 .50456 -32.6875 -9 ]
[-0.0125 .50456 0 9 ]
[-0.0125 .6648 -32.6875 -9 ]
[-0.0125 .6648 0 9 ]
[-0.0125 .82505 -32.6875 -9 ]
[-0.0125 .82505 0 9 ]
[-0.0125 .9853 -32.6875 -9 ]
[-0.0125 .9853 0 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.24242 .02381 m
.24242 .03006 L
s
gsave
.24242 .01131 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.48485 .02381 m
.48485 .03006 L
s
gsave
.48485 .01131 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.72727 .02381 m
.72727 .03006 L
s
gsave
.72727 .01131 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.9697 .02381 m
.9697 .03006 L
s
gsave
.9697 .01131 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .02381 m
1 .02381 L
s
0 .18406 m
.00625 .18406 L
s
gsave
-0.0125 .18406 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .34431 m
.00625 .34431 L
s
gsave
-0.0125 .34431 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .50456 m
.00625 .50456 L
s
gsave
-0.0125 .50456 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
0 .6648 m
.00625 .6648 L
s
gsave
-0.0125 .6648 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .82505 m
.00625 .82505 L
s
gsave
-0.0125 .82505 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .9853 m
.00625 .9853 L
s
gsave
-0.0125 .9853 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05586 m
.00375 .05586 L
s
0 .08791 m
.00375 .08791 L
s
0 .11996 m
.00375 .11996 L
s
0 .15201 m
.00375 .15201 L
s
0 .21611 m
.00375 .21611 L
s
0 .24816 m
.00375 .24816 L
s
0 .28021 m
.00375 .28021 L
s
0 .31226 m
.00375 .31226 L
s
0 .37636 m
.00375 .37636 L
s
0 .40841 m
.00375 .40841 L
s
0 .44046 m
.00375 .44046 L
s
0 .47251 m
.00375 .47251 L
s
0 .53661 m
.00375 .53661 L
s
0 .56866 m
.00375 .56866 L
s
0 .60071 m
.00375 .60071 L
s
0 .63275 m
.00375 .63275 L
s
0 .69685 m
.00375 .69685 L
s
0 .7289 m
.00375 .7289 L
s
0 .76095 m
.00375 .76095 L
s
0 .793 m
.00375 .793 L
s
0 .8571 m
.00375 .8571 L
s
0 .88915 m
.00375 .88915 L
s
0 .9212 m
.00375 .9212 L
s
0 .95325 m
.00375 .95325 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
0 .02381 m
0 .89143 L
.0303 .89143 L
.0303 .02381 L
F
0 g
.5 Mabswid
0 .02381 m
0 .89143 L
.0303 .89143 L
.0303 .02381 L
0 .02381 L
s
1 0 0 r
.0303 .02381 m
.0303 .89357 L
.06061 .89357 L
.06061 .02381 L
F
0 g
.0303 .02381 m
.0303 .89357 L
.06061 .89357 L
.06061 .02381 L
.0303 .02381 L
s
1 0 0 r
.06061 .02381 m
.06061 .96409 L
.09091 .96409 L
.09091 .02381 L
F
0 g
.06061 .02381 m
.06061 .96409 L
.09091 .96409 L
.09091 .02381 L
.06061 .02381 L
s
1 0 0 r
.09091 .02381 m
.09091 .90639 L
.12121 .90639 L
.12121 .02381 L
F
0 g
.09091 .02381 m
.09091 .90639 L
.12121 .90639 L
.12121 .02381 L
.09091 .02381 L
s
1 0 0 r
.12121 .02381 m
.12121 .95554 L
.15152 .95554 L
.15152 .02381 L
F
0 g
.12121 .02381 m
.12121 .95554 L
.15152 .95554 L
.15152 .02381 L
.12121 .02381 L
s
1 0 0 r
.15152 .02381 m
.15152 .95768 L
.18182 .95768 L
.18182 .02381 L
F
0 g
.15152 .02381 m
.15152 .95768 L
.18182 .95768 L
.18182 .02381 L
.15152 .02381 L
s
1 0 0 r
.18182 .02381 m
.18182 .87006 L
.21212 .87006 L
.21212 .02381 L
F
0 g
.18182 .02381 m
.18182 .87006 L
.21212 .87006 L
.21212 .02381 L
.18182 .02381 L
s
1 0 0 r
.21212 .02381 m
.21212 .92776 L
.24242 .92776 L
.24242 .02381 L
F
0 g
.21212 .02381 m
.21212 .92776 L
.24242 .92776 L
.24242 .02381 L
.21212 .02381 L
s
1 0 0 r
.24242 .02381 m
.24242 .82305 L
.27273 .82305 L
.27273 .02381 L
F
0 g
.24242 .02381 m
.24242 .82305 L
.27273 .82305 L
.27273 .02381 L
.24242 .02381 L
s
1 0 0 r
.27273 .02381 m
.27273 .79741 L
.30303 .79741 L
.30303 .02381 L
F
0 g
.27273 .02381 m
.27273 .79741 L
.30303 .79741 L
.30303 .02381 L
.27273 .02381 L
s
1 0 0 r
.30303 .02381 m
.30303 .72902 L
.33333 .72902 L
.33333 .02381 L
F
0 g
.30303 .02381 m
.30303 .72902 L
.33333 .72902 L
.33333 .02381 L
.30303 .02381 L
s
1 0 0 r
.33333 .02381 m
.33333 .60721 L
.36364 .60721 L
.36364 .02381 L
F
0 g
.33333 .02381 m
.33333 .60721 L
.36364 .60721 L
.36364 .02381 L
.33333 .02381 L
s
1 0 0 r
.36364 .02381 m
.36364 .57729 L
.39394 .57729 L
.39394 .02381 L
F
0 g
.36364 .02381 m
.36364 .57729 L
.39394 .57729 L
.39394 .02381 L
.36364 .02381 L
s
1 0 0 r
.39394 .02381 m
.39394 .39351 L
.42424 .39351 L
.42424 .02381 L
F
0 g
.39394 .02381 m
.39394 .39351 L
.42424 .39351 L
.42424 .02381 L
.39394 .02381 L
s
1 0 0 r
.42424 .02381 m
.42424 .41488 L
.45455 .41488 L
.45455 .02381 L
F
0 g
.42424 .02381 m
.42424 .41488 L
.45455 .41488 L
.45455 .02381 L
.42424 .02381 L
s
1 0 0 r
.45455 .02381 m
.45455 .33795 L
.48485 .33795 L
.48485 .02381 L
F
0 g
.45455 .02381 m
.45455 .33795 L
.48485 .33795 L
.48485 .02381 L
.45455 .02381 L
s
1 0 0 r
.48485 .02381 m
.48485 .23965 L
.51515 .23965 L
.51515 .02381 L
F
0 g
.48485 .02381 m
.48485 .23965 L
.51515 .23965 L
.51515 .02381 L
.48485 .02381 L
s
1 0 0 r
.51515 .02381 m
.51515 .2311 L
.54545 .2311 L
.54545 .02381 L
F
0 g
.51515 .02381 m
.51515 .2311 L
.54545 .2311 L
.54545 .02381 L
.51515 .02381 L
s
1 0 0 r
.54545 .02381 m
.54545 .19263 L
.57576 .19263 L
.57576 .02381 L
F
0 g
.54545 .02381 m
.54545 .19263 L
.57576 .19263 L
.57576 .02381 L
.54545 .02381 L
s
1 0 0 r
.57576 .02381 m
.57576 .14989 L
.60606 .14989 L
.60606 .02381 L
F
0 g
.57576 .02381 m
.57576 .14989 L
.60606 .14989 L
.60606 .02381 L
.57576 .02381 L
s
1 0 0 r
.60606 .02381 m
.60606 .10074 L
.63636 .10074 L
.63636 .02381 L
F
0 g
.60606 .02381 m
.60606 .10074 L
.63636 .10074 L
.63636 .02381 L
.60606 .02381 L
s
1 0 0 r
.63636 .02381 m
.63636 .10502 L
.66667 .10502 L
.66667 .02381 L
F
0 g
.63636 .02381 m
.63636 .10502 L
.66667 .10502 L
.66667 .02381 L
.63636 .02381 L
s
1 0 0 r
.66667 .02381 m
.66667 .10288 L
.69697 .10288 L
.69697 .02381 L
F
0 g
.66667 .02381 m
.66667 .10288 L
.69697 .10288 L
.69697 .02381 L
.66667 .02381 L
s
1 0 0 r
.69697 .02381 m
.69697 .058 L
.72727 .058 L
.72727 .02381 L
F
0 g
.69697 .02381 m
.69697 .058 L
.72727 .058 L
.72727 .02381 L
.69697 .02381 L
s
1 0 0 r
.72727 .02381 m
.72727 .05159 L
.75758 .05159 L
.75758 .02381 L
F
0 g
.72727 .02381 m
.72727 .05159 L
.75758 .05159 L
.75758 .02381 L
.72727 .02381 L
s
1 0 0 r
.75758 .02381 m
.75758 .0751 L
.78788 .0751 L
.78788 .02381 L
F
0 g
.75758 .02381 m
.75758 .0751 L
.78788 .0751 L
.78788 .02381 L
.75758 .02381 L
s
1 0 0 r
.78788 .02381 m
.78788 .04732 L
.81818 .04732 L
.81818 .02381 L
F
0 g
.78788 .02381 m
.78788 .04732 L
.81818 .04732 L
.81818 .02381 L
.78788 .02381 L
s
1 0 0 r
.81818 .02381 m
.81818 .04732 L
.84848 .04732 L
.84848 .02381 L
F
0 g
.81818 .02381 m
.81818 .04732 L
.84848 .04732 L
.84848 .02381 L
.81818 .02381 L
s
1 0 0 r
.84848 .02381 m
.84848 .04091 L
.87879 .04091 L
.87879 .02381 L
F
0 g
.84848 .02381 m
.84848 .04091 L
.87879 .04091 L
.87879 .02381 L
.84848 .02381 L
s
1 0 0 r
.87879 .02381 m
.87879 .03663 L
.90909 .03663 L
.90909 .02381 L
F
0 g
.87879 .02381 m
.87879 .03663 L
.90909 .03663 L
.90909 .02381 L
.87879 .02381 L
s
1 0 0 r
.90909 .02381 m
.90909 .02595 L
.93939 .02595 L
.93939 .02381 L
F
0 g
.90909 .02381 m
.90909 .02595 L
.93939 .02595 L
.93939 .02381 L
.90909 .02381 L
s
1 0 0 r
.93939 .02381 m
.93939 .02808 L
.9697 .02808 L
.9697 .02381 L
F
0 g
.93939 .02381 m
.93939 .02808 L
.9697 .02808 L
.9697 .02381 L
.93939 .02381 L
s
1 0 0 r
.9697 .02381 m
.9697 .02595 L
1 .02595 L
1 .02381 L
F
0 g
.9697 .02381 m
.9697 .02595 L
1 .02595 L
1 .02381 L
.9697 .02381 L
s
.01 w
0 .82505 m
.02394 .88095 L
.04917 .92602 L
.06242 .9439 L
.07477 .95697 L
.08173 .96284 L
.08831 .96738 L
.0959 .97144 L
.09946 .97291 L
.1028 .97404 L
.10586 .97487 L
.10867 .97545 L
.11027 .9757 L
.11179 .9759 L
.11339 .97605 L
.1143 .97611 L
.11514 .97615 L
.11596 .97618 L
.11685 .97619 L
.11846 .97617 L
.12003 .9761 L
.12147 .976 L
.12303 .97583 L
.12475 .97559 L
.12822 .97493 L
.13128 .97414 L
.13408 .97327 L
.14036 .97073 L
.15169 .96427 L
.16431 .95432 L
.17598 .94269 L
.2024 .90848 L
.25238 .81959 L
.30042 .7145 L
.35159 .59406 L
.40083 .48024 L
.45319 .36992 L
.50362 .27906 L
.55212 .20778 L
.60374 .14895 L
.65344 .10716 L
.68061 .08959 L
.70625 .07592 L
.75521 .05638 L
.78051 .04903 L
.80729 .04287 L
.83249 .03832 L
.85551 .03503 L
.88026 .03226 L
.90685 .02998 L
Mistroke
.93106 .0284 L
.95746 .02711 L
.98254 .0262 L
Mfstroke
.98254 .0262 m
1 .02573 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo001@ooooo`Co000000?o410@ooooooooool0:?oo
ool6o`0002_ooooo00GoZJVYob4Q8Ol0003o0000ofIVIP0^ooooo`;o000000?o410@ooooooooool0
0oooool005;ooooo00?o0000ooooooooool0:_ooool00onHV9So0000omgMg@02ooooo`03oa0@4?oo
oooooooo02Wooooo00Ko410@olc<c?ooooooooooogMgMomVIVH^ooooo`03o`000?oooooooooo00Co
oooo001Booooo`03o`000?oooooooooo02_ooooo00?oQhN7ob4Q8Oo^k^h0<_ooool00ol0003ooooo
ooooo`0Xooooo`Ko00001Oooool005;ooooo00?o0000ooooooooool0;?ooool00onYZJWo8B4Qonk^
kP0aooooo`03o`000?oooooooooo02Sooooo00GoA4A4okZj^_ooooooooooo`000006ooooo`00D_oo
ool00ol0003oooooooooo`0]ooooo`03oiRHV?lb<S;ooooo02oooooo00?oZJVYodA4A?ooool0:Ooo
ool01OoMgMgo8B4Qoooooooooooo000000Kooooo001Booooo`03o`000?oooooooooo02kooooo00?o
A4A4ogMgMoooool0;?ooool01?lQ8B7o0000o`000?oMgMd[ooooo`04ogMgMonHV9Soooooo`0000Ko
oooo001Booooo`03o`000?oooooooooo02kooooo00?ogMgMoa0@4?ooool0;_ooool00onYZJWo<S8b
ooooo`0Zooooo`04onk^k_lQ8B7oooooo`0000Kooooo001Booooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Zooooo`03ogMgMonHV9So000000Kooooo
001@ooooo`03o`000?m4A4Co000002cooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED[ooooo`06
ob4Q8Onj^[[ooooooooooomVIVKo<S8b;?ooool00oo^k^ko<S8bo`000006ooooo`008oooool00ol0
003oooooooooo`0Zooooo`03olc<c?mEEEGo000002cooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^
k^h[ooooo`06okZj^_m4A4Co0000o`000?m4A4Cok^k^;Oooool00onHV9So410@ooooo`05ooooo`00
8oooool00ol0003oooooooooo`35ooooo`008oooool00ol0003oooooooooo`35ooooo`008oooool0
0ol0003oooooooooo`35ooooo`008oooool00ol0003oooooooooo`35ooooo`008oooooo7o`00007o
oooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool0000@o`0000Oooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`002_l00003ool00003o`000?oo
oooooooo017ooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool000Go000000?oo`00o`000?l000002ol0000Cooooo`008oooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001ol00005ool00003o`000?oooooooooo
01gooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?l000004?l0000Oooooo`00
8oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo0008o`0000Coo`0000?o0000ooooooooool0:Oooool002?ooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool000Oo000000?oooooo`000?l000000_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo02Wooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo02Wooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02o`0000Oooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`0Yooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`000ol00009ooooo`Oo0000:oooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool000;o0000?Oooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002o`000003ool00?l0003ooooo03cooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000ol00003
ool00003o`000?oooooooooo03_ooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`0kooooo`008oooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`001ol00004ool000;o00001Ooo00000ol0003oooooooooo`0kooooo`00
8oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0oooool=o`0003gooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`05ooooo`;o0000A_ooool002?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oooooooooo00Cooooo00?o0000ooooooooool0A_ooool0
02?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Aoooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool0B?ooool002?ooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00;o0000
Boooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
oooo000004gooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0002
o`0004kooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`1=ooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000Oo0000Coooool002?ooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo04kooooo
000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000Go0000ooooooooooooooooo`00001Aooooo`008ooo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00004o`000?ooooooooooo`0005;ooooo0005ooooo`04oiRHV?l0
003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01_ooool4o`000003oa0@4?oooooooooo00Cooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooo`00001Cooooo`001?ooool01_nj^[[o8B4QomgM
gOoMgMgo8B4QokZj^PGooooo0ol00008ooooo`03o`000?oooooooooo00Kooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo0002o`0005Cooooo0004ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omE
EEGo0000oeEEE@08ooooo`03o`000?oooooooooo00Kooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`1Cooooo`001?ooool01_l0003ok^k^ooooooooooook^k^o`00013ooooo00?o0000
ooooooooool01_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool000;o0000EOooool000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001ol0001Eoooo
o`001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00001?l0003oooooooooool0001Hooooo`001?ooool01_l0003ok^k^ooooooooooook^k^
o`00013ooooo00?o0000ooooooooool01_ooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooo`00001Iooooo`001?ooool01_m4
A4CoV9RHooooooooooooV9RHodA4A13ooooo00?o0000ooooooooool01_ooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0002o`0005[ooooo0004
ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool00ol0003oA4A4o`000008ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000;o0000
F_ooool000Gooooo00CoV9RHo`000?l0003oV9RH3oooool00oo<c<coEEEEo`000008ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo05Wooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool000;o0000Foooool002?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`000_l0001Kooooo`008oooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001ol0001Kooooo`008oooool00ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000oooooooooooo0000G_ooool002?o
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo0007o`0000;ooooo00?o0000ooooooooool0G?ooool002?ooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo
000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Nooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00Cooooo00?o0000
ooooooooool0G_ooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05oooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Pooooo`008oooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool002?ooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00001Ol0003ooooooooooooooooo000006?ooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co
0000oooooooooooo0000I?ooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003ooooooooo
ool0001Tooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo000006Gooooo000S
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ooooool00000IOooool002?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo0002o`0006Kooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0IOooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Uooooo`008ooo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool000;o0000Ioooool002?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0002
o`0006Oooooo0005ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01Oooool6
o`0000Kooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000Oo0000ool00?oo003oo`00o`000?oo003o000006Oooooo0004ooooo`06okZj^_lQ
8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Gooooo00?oV9RHo`000?oMgMd00_ooool00ol@413o
ooooooooo`04ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00007o`000?oo003oo`00ool00?l0003oo`00o`00001Wooooo`001?ooool01_m4
A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool00on7QhOo8B4Qonk^
kP08ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool000Oo0000Ioooool000Cooooo00Ko0000onk^k_ooooooooooonk^k_l0000?ooooo`03ojVY
ZOlQ8B7ok^k^00Oooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000Co0000oooooooooooo0000J_ooool000Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0>ooooo`03oiRHV?lb<S;ooooo00Kooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooool00000
Joooool000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03odA4A?mg
MgOooooo00Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`000_l0001/ooooo`001?ooool01_l0003ok^k^ooooooooooook^k^o`00017ooooo
00?ogMgMoa0@4?ooool01Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo0002o`0006cooooo0004ooooo`06odA4A?nHV9SooooooooooonHV9So
A4A44_ooool00ol0003oooooooooo`04ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo06_ooooo0004ooooo`06okZj
^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3Oooool01_l0003oQhN7onk^k_ooooooV9RHoeEEE@Kooooo00?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0Joooool000Gooooo00CoV9RHo`000?l0003oV9RH3_ooool01_nYZJWo<S8bo`00
0?l0003oEEEEonk^kPKooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`000_l0001]ooooo`008oooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0002o`0006gooooo000Sooooo`03o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00001ol0003oo`00ool00?oo003o0000ool00?l0
0000KOooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00007o`00
0?oo003oo`00ool00?l0003oo`00o`00001]ooooo`008oooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000Oo
00000_oo00001?l0003oo`00ool00?l0001]ooooo`008oooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00Co0000ool00?oo003o00000_oo00000ol0003oooooooooo`1[oooo
o`008oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo00?o0000ool00?l0
00000ooo00000ol0003oooooooooo`1[ooooo`008oooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo00?ooooo00?o0000ool00?l000000ooo00000ol0003oooooooooo`1[ooooo`008ooo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo1ol0001]ooooo`008oooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oooooooooo00Cooooo00?o0000ooooooooool0L?ooool0
02?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`03ooooo`03o`000?oooooooooo
077ooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003o
ooooooooo`1aooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ooooooooool0LOooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo07;ooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool00ol0003oooooooooo`1booooo`008oooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0005o`000?ooooooooooooooool00000MOooool002?ooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001Ol0
003ooooooooooooooooo000007Gooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000oooo
oooooooo0000M_ooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003oooooooooool0001f
ooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo000007Oooooo000Sooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ooooool00000Moooool002?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo0002o`0007Sooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000_l0001hooooo`001Oooool0
1?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Kooooo00GoZJVYob4Q8Ol0003o0000
ofIVIP06ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Moooool000Cooooo00Ko
^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001_ooool01_l@413oc<c<ooooooooooooMgMg
ofIVIPGooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1gooooo`001?ooool01_m4
A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED02oooool00ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`000_l0001iooooo`001?ooool01_l0003ok^k^oooooooo
ooook^k^o`0001?ooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool000;o0000
NOooool000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`03ojVYZOm4
A4Cooooo00Cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo0002o`0007Wooooo0004ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03_ooool01?lQ8B7o0000o`000?oMgMd5ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00007o`000?oo
003oo`00ool00?l0003oo`00o`00001iooooo`001?ooool01_l0003ok^k^ooooooooooook^k^o`00
01;ooooo00?oZJVYoc8b<_ooool01?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00001ol0003oo`00ool00?oo003o0000ool00?l00000NOoo
ool000Cooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@Cooooo`03o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00Co0000ool00?oo003o00000_oo00000ol0003oooooooooo`1gooooo`001?ooool01_nj^[[o8B4Q
omgMgOoMgMgo8B4QokZj^Pkooooo00Ko8B4QokZj^_ooooooooooofIVI_lb<S85ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?oo
003oo`00o`0000;oo`0000?o0000ooooooooool0Moooool000Gooooo00CoV9RHo`000?l0003oV9RH
3oooool01_nj^[[oA4A4o`000?l0003oA4A4onk^kPGooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?l000000ooo00000ol0
003oooooooooo`1gooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00o`000003ool00003o`000?oooooooooo07Oo
oooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003o000000?oo`0000?o0000ooooooooool0Moooool002?ooooo00?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000_l0
0004ool00003o`000?oooooooooo07Oooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool000;o00001?oo00000ol0003oooooooooo`1g
ooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo07Oooooo000Sooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Moooool002?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`000_l00005ool00003o`00
0?oooooooooo07Oooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool000;o00001Ooo00000ol0003oooooooooo`1gooooo`008oooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0008
o`0007Wooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001ol0
003oo`00ool00?oo003o0000ool00?l00000Ooooool002?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00007o`000?oo003oo`00ool00?l0003oo`00o`00001oooooo`008ooo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000ool00?oo003o0000
0_oo00000ol0003oooooooooo`1mooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000Co0000ool00?oo003o00000_oo00000ol0003oooooooooo`1mooooo`008ooo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?l000000ooo
00000ol0003oooooooooo`1mooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`001ol0001oooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ooooool00000Poooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool000;o0000Q?ooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool000;o0000Q?ooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo08?ooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`23ooooo`008oooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`000_l00025ooooo`008oooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`000_l00025ooooo`001Oooool01?nHV9So0000o`000?nHV9P6ooooo`03
oeEEEOl0003oEEEE00Wooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo0002o`0008Gooooo0004ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ
8B7o^[Zj1Oooool3o`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0007o`000?oo003oo`00ool00?l0003oo`00o`000025ooooo`001?ooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool6o`0000Gooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00001ol0003oo`00ool00?oo003o0000ool00?l00000QOooool000Cooooo00Ko0000onk^k_oo
ooooooooonk^k_l0000>ooooo`05odA4A?nj^[[oooooooooool000001_ooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00004o`000?oo003oo`00o`0000;oo`0000?o0000ooooooooool0Poooool000Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`05omgMgOlQ8B7oooooooooool00000
1_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00004o`000?oo003oo`00o`0000;oo`0000?o0000oooooooo
ool0Poooool000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`04ogMg
MonHV9Soooooo`0000Kooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003oo`00ool00?l00002ool0
0003o`000?oooooooooo08?ooooo0004ooooo`06o`000?o^k^koooooooooooo^k^ko00003oooool0
1?o^k^ko8B4Qooooool00006ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?l000000ooo
00000ol0003oooooooooo`23ooooo`001?ooool01_m4A4CoV9RHooooooooooooV9RHodA4A13ooooo
00?oMgMgoiRHV?l000001_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o000000?oo`00
00?o0000ooooooooool0Poooool000Cooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X@ooooo`03
onk^k_lb<S;o000000Kooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0002o`0000Coo`0000?o0000oooooooo
ool0Poooool000Gooooo00CoV9RHo`000?l0003oV9RH4_ooool00onHV9So410@ooooo`05ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`000_l00004ool00003o`000?oooooooooo08?ooooo000Sooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`23ooooo`008ooo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Pooo
ool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo
oooo08?ooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`000_l00005ool00003o`000?oooooooooo
08?ooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`000_l00005ool00003o`000?oooooooooo08?o
oooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00007o`000?oo003oo`00ool00?l0003oo`00o`000005ool00003o`000?oooooooooo
08?ooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00006o`000?oo003oo`00ool00?l0003oo`001ol00025ooooo`008oooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0
003oo`00ool00?l00002ool00003o`000?oooooooooo08Wooooo000Sooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?oo003oo`00
o`0000;oo`0000?o0000ooooooooool0ROooool002?ooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000ool00?oo003o00000_oo0000
0ol0003oooooooooo`29ooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00o`000003ool00003o`000?oooooooooo
08Wooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003o000000?oo`0000?o0000ooooooooool0ROooool002?ooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
0_l00004ool00003o`000?oooooooooo08Wooooo000Sooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000;o00001?oo00000ol0003ooooooooo
o`29ooooo`008oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo08Wooooo000Soooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0ROooool002?ooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`29ooooo`008oooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0002o`0000Goo`0000?o0000ooooooooool0
ROooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`000_l00005ool00003o`000?oooooooooo08Wooooo000Sooooo`03o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00001_l0003oo`00ool00?oo003o0000ool000Oo0000
Roooool002?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00007o`000?oo
003oo`00ool00?l0003oo`00o`00002Aooooo`008oooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000Co0000ool00?oo003o00000_oo00000ol0003oooooooooo`2?ooooo`00
1Oooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Kooooo00GoV9RHoa0@4?l0
003o0000ofIVIP06ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0
003oo`00ool00?l00002ool00003o`000?oooooooooo08oooooo0004ooooo`06okZj^_lQ8B7ogMgM
omgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo00Ko410@ohN7QoooooooooooogMgMomVIVH5ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003oo`00ool00?l00002ool0
0003o`000?oooooooooo08oooooo0004ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool0
0omEEEGo0000oeEEE@0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool000Oo0000TOooool000Cooooo00Ko0000onk^k_ooooooooooonk^k_l0
000Booooo`03onk^k_l0003ooooo00Cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooo000009Gooooo0004ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03?ooool01_l@413oV9RHooooooooooooMgMgofIVIPGooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool000;o0000U_ooool000Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0<ooooo`05o`000?lQ8B7o0000o`000?mVIVH01_ooool2o`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo0002o`0009Kooooo0004ooooo`06o`000?o^k^koooooooooooo^k^ko
00003_ooool00ol0003oooooooooo`08ooooo`;o00001?oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo09Gooooo0004ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A43_ooool00ol0
003oooooooooo`08ooooo`;o00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool000;o0000Uoooool000Co
oooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X>ooooo`03o`000?oooooooooo00Sooooo00?o0000
ool00?l000000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool000;o0000Uoooool000Gooooo00CoV9RHo`00
0?l0003oV9RH3oooool5o`0000Kooooo00?o0000ool00?l000000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001ol0003oo`00ool00?oo
003o0000ool00?l00000Uoooool002?ooooo00?o0000ool00?l000000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001ol0003oo`00ool0
0?oo003o0000ool00?l00000Uoooool002?ooooo00Co0000ool00?oo003o00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003o
o`00ool00?l00002ool00003o`000?oooooooooo09Gooooo000Sooooo`04o`000?oo003oo`00o`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000Oo000000?oo`00o`00
0?oo00000_oo00000ol0003oooooooooo`2Eooooo`008oooool01?l0003oo`00ool00?l00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`03oooo
o`03o`000?oo003o000000?oo`0000?o0000ooooooooool0UOooool002?ooooo00Oo0000ool00?oo
003oo`00o`000?oo003o000000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`;o00001?oo00000ol0003oooooooooo`2Eooooo`008oooool01ol0003oo`00ool00?oo003o
0000ool00?l000001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo0_l0
0004ool00003o`000?oooooooooo09Gooooo000Sooooo`go00001Ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`03
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0UOooool002?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00_ooool2o`0000Goo`0000?o0000ooooooooool0UOooool002?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool2o`0000Goo`0000?o0000ooooooooool0UOooool002?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`001ol00005ool00003o`00
0?oo003oo`0000?oo`0000Oo0000ooooooooooooooooo`000?oooooo000000Goo`0000?o0000oooo
ooooool0UOooool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000Oo0000ooooooooooooooooo`000?oooooo000000Goo`0000?o0000
ooooooooool0UOooool002?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000Goo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000Co0000oooooooooooo00000_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo09Gooooo000Sooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00
0005ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooo000000?ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`2Eooooo`008oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Goo`0000?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000_l0
0004ooooo`Oo0000Uoooool002?ooooo00?o0000ooooooooool01oooool00ol0003oooooo`000005
ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool000;o0000X_ooool002?ooooo00?o0000ooooooooool02?ooool2o`0000Goo`0000?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0XOooool002?ooooo00?o0000ooooooooool02Oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00001?l0003oo`00ool00?oo0003o`00
0:?ooooo000Sooooo`03o`000?oooooooooo00Wooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000Co0000ool00?oo003o00000_oo00000ol0
003oooooooooo`2Qooooo`008oooool00ol0003oooooooooo`09ooooo`;o00001?oo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?l000000ooo00000ol0003o
ooooooooo`2Qooooo`008oooool00ol0003oooooooooo`09ooooo`04o`000?oo003o0000o`0000;o
o`0000?o0000ooooooooool00oooool=o`000:?ooooo000Sooooo`03o`000?oooooooooo00Wooooo
1ol0000:ooooo`;o0000ZOooool000Gooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000
oeEEE@06ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^1Oooool00ol0003oooooooooo`0>oooo
o`;o00002Oooool00ol0003oooooooooo`2Yooooo`001?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4Q
okZj^PGooooo0ol00006ooooo`;oMgMg0_ooool00omgMgOoEEEEooooo`04ooooo`03o`000?oooooo
oooo013ooooo0ol00003ooooo`?o0000[?ooool000Cooooo00KoA4A4oiRHV?oooooooooooiRHV?m4
A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?o8B4Qooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01?ooooo0ol0002_ooooo`001?ooool01_l0003ok^k^oooooooo
ooook^k^o`0000kooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`03ooooo`;o0000
a_ooool000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`06o`000?mE
EEGok^k^oooooomgMgOoEEEE1Oooool00ol0003oooooooooo`35ooooo`001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00cooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^h5oooo
o`03o`000?oooooooooo0<Gooooo0004ooooo`06o`000?o^k^koooooooooooo^k^ko00003_ooool0
0om4A4CoV9RHooooo`08ooooo`03o`000?oooooooooo0<Gooooo0004ooooo`06odA4A?nHV9Sooooo
oooooonHV9SoA4A43_ooool00onj^[[o8B4Qooooo`3@ooooo`001?ooool01_nj^[[o8B4QomgMgOoM
gMgo8B4QokZj^Poooooo00?oEEEEoc8b<_oMgMd0coooool000Gooooo00CoV9RHo`000?l0003oV9RH
4Oooool01?nHV9So8B4Qo`000?lQ8B7=ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00001\
\>"],
  ImageRangeCache->{{{73.4375, 260.438}, {586.438, 399.438}} -> {-2.64763, \
1.48838, 0.0208544, 0.00315485}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Random Matrix - GUE", "Section"],

Cell["\<\
In this section we will generate a Gaussian-random complex \
Hermitian matrix, compute its eigenvalues, calculate the level spacings, and \
generate a histogram of these level spacings.  This histogram closely matches \
the GUE distribution.  Be aware that these calculations take some time \
(roughly 900 seconds on a PowerMac G4 733 MHz).\
\>", "Text"],

Cell[TextData[{
  "First we must construct the matrix.  To do this we need to load the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package entitled \"Continuous Distributions\" that is contained within \
the Statistics package."
}], "Text"],

Cell[BoxData[
    \(<< Statistics`ContinuousDistributions`\)], "Input"],

Cell["\<\
Now we construct and n by n random complex Hermitian matrix.  Each \
matrix element is a complex number with random real and imaginary parts that \
are Gaussian distributed with a mean of zero and a standard deviation of one \
(except the diagonal elements which are real and have standard deviation of \
square root of 2).  Here we generate a 3000 by 3000 matrix.  Once the matrix \
is generated we can find its eigenvalues and sort them.\
\>", "Text"],

Cell[BoxData[{
    \(\(n = 3000;\)\), "\n", 
    \(\(MGUE = 
        Table[Which[i \[Equal] j, Random[NormalDistribution[0, 1]], i < j, 
            Random[NormalDistribution[0, 1/2]] + 
              I*Random[NormalDistribution[0, 1/2]], i > j, 0], {i, 1, n}, {j, 
            1, n}];\)\), "\n", 
    \(\(MGUEFull = 
        Table[Which[i \[GreaterEqual] j, MGUE[\([j, i]\)], i < j, 
            Conjugate[MGUE[\([i, j]\)]]], {i, 1, n}, {j, 1, 
            n}];\)\), "\[IndentingNewLine]", 
    \(\(GUEev = Sort[Eigenvalues[MGUEFull]];\)\)}], "Input"],

Cell["\<\
For the GOE matrix above we found that the density of eigenvalues \
is not uniform, but thins out toward the edges.  The plot below shows the \
density of eigenvalues of our GUE matrix.  We see the same thinning of the \
eigenvalues toward the edges that we saw for the GOE matrix.  Indeed, the \
eigenvalues of the GUE matrix follow the same Wigner semicircle law as did \
those of the GOE matrix.  Note that we need to load the Graphics package if \
it has not already been loaded.\
\>", "Text"],

Cell[BoxData[
    \(<< Graphics`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(int = Table[\(-25\) + 2*i, {i, 0, 25}];\)\), "\[IndentingNewLine]", 
    \(GUEHist = 
      Histogram[GUEev, HistogramCategories \[Rule] 25, 
        HistogramScale \[Rule] n, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<E\>", "\<\[Rho](E)\>"}, 
        RotateLabel \[Rule] False]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00625 0.0147151 0.023734 [
[.125 -0.0125 -16.8125 -18 ]
[.125 -0.0125 16.8125 0 ]
[.25 -0.0125 -16.8125 -18 ]
[.25 -0.0125 16.8125 0 ]
[.375 -0.0125 -16.8125 -18 ]
[.375 -0.0125 16.8125 0 ]
[.5 -0.0125 -6.78125 -18 ]
[.5 -0.0125 6.78125 0 ]
[.625 -0.0125 -11.5625 -18 ]
[.625 -0.0125 11.5625 0 ]
[.75 -0.0125 -11.5625 -18 ]
[.75 -0.0125 11.5625 0 ]
[.875 -0.0125 -11.5625 -18 ]
[.875 -0.0125 11.5625 0 ]
[1 -0.0125 -11.5625 -18 ]
[1 -0.0125 11.5625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .13339 -13.5625 -9 ]
[-0.0125 .13339 0 9 ]
[-0.0125 .25206 -23.125 -9 ]
[-0.0125 .25206 0 9 ]
[-0.0125 .37073 -23.125 -9 ]
[-0.0125 .37073 0 9 ]
[-0.0125 .4894 -23.125 -9 ]
[-0.0125 .4894 0 9 ]
[-0.0125 .60807 -23.125 -9 ]
[-0.0125 .60807 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -65.375 -9 ]
[-0.01875 .30902 -23.125 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
gsave
.125 -0.0125 -77.8125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
73.500 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -77.8125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
73.500 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.375 0 m
.375 .00625 L
s
gsave
.375 -0.0125 -77.8125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
73.500 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.625 0 m
.625 .00625 L
s
gsave
.625 -0.0125 -72.5625 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -72.5625 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.875 0 m
.875 .00625 L
s
gsave
.875 -0.0125 -72.5625 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -72.5625 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.125 Mabswid
.03125 0 m
.03125 .00375 L
s
.0625 0 m
.0625 .00375 L
s
.09375 0 m
.09375 .00375 L
s
.15625 0 m
.15625 .00375 L
s
.1875 0 m
.1875 .00375 L
s
.21875 0 m
.21875 .00375 L
s
.28125 0 m
.28125 .00375 L
s
.3125 0 m
.3125 .00375 L
s
.34375 0 m
.34375 .00375 L
s
.40625 0 m
.40625 .00375 L
s
.4375 0 m
.4375 .00375 L
s
.46875 0 m
.46875 .00375 L
s
.53125 0 m
.53125 .00375 L
s
.5625 0 m
.5625 .00375 L
s
.59375 0 m
.59375 .00375 L
s
.65625 0 m
.65625 .00375 L
s
.6875 0 m
.6875 .00375 L
s
.71875 0 m
.71875 .00375 L
s
.78125 0 m
.78125 .00375 L
s
.8125 0 m
.8125 .00375 L
s
.84375 0 m
.84375 .00375 L
s
.90625 0 m
.90625 .00375 L
s
.9375 0 m
.9375 .00375 L
s
.96875 0 m
.96875 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13339 m
.00625 .13339 L
s
gsave
-0.0125 .13339 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .25206 m
.00625 .25206 L
s
gsave
-0.0125 .25206 -84.125 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .37073 m
.00625 .37073 L
s
gsave
-0.0125 .37073 -84.125 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .4894 m
.00625 .4894 L
s
gsave
-0.0125 .4894 -84.125 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .60807 m
.00625 .60807 L
s
gsave
-0.0125 .60807 -84.125 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03845 m
.00375 .03845 L
s
0 .06218 m
.00375 .06218 L
s
0 .08592 m
.00375 .08592 L
s
0 .10965 m
.00375 .10965 L
s
0 .15712 m
.00375 .15712 L
s
0 .18085 m
.00375 .18085 L
s
0 .20459 m
.00375 .20459 L
s
0 .22832 m
.00375 .22832 L
s
0 .27579 m
.00375 .27579 L
s
0 .29952 m
.00375 .29952 L
s
0 .32326 m
.00375 .32326 L
s
0 .34699 m
.00375 .34699 L
s
0 .39446 m
.00375 .39446 L
s
0 .41819 m
.00375 .41819 L
s
0 .44193 m
.00375 .44193 L
s
0 .46566 m
.00375 .46566 L
s
0 .51313 m
.00375 .51313 L
s
0 .53686 m
.00375 .53686 L
s
0 .5606 m
.00375 .5606 L
s
0 .58433 m
.00375 .58433 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -126.375 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.125 .61178 m
.125 .61803 L
s
.25 .61178 m
.25 .61803 L
s
.375 .61178 m
.375 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.625 .61178 m
.625 .61803 L
s
.75 .61178 m
.75 .61803 L
s
.875 .61178 m
.875 .61803 L
s
.125 Mabswid
.03125 .61428 m
.03125 .61803 L
s
.0625 .61428 m
.0625 .61803 L
s
.09375 .61428 m
.09375 .61803 L
s
.15625 .61428 m
.15625 .61803 L
s
.1875 .61428 m
.1875 .61803 L
s
.21875 .61428 m
.21875 .61803 L
s
.28125 .61428 m
.28125 .61803 L
s
.3125 .61428 m
.3125 .61803 L
s
.34375 .61428 m
.34375 .61803 L
s
.40625 .61428 m
.40625 .61803 L
s
.4375 .61428 m
.4375 .61803 L
s
.46875 .61428 m
.46875 .61803 L
s
.53125 .61428 m
.53125 .61803 L
s
.5625 .61428 m
.5625 .61803 L
s
.59375 .61428 m
.59375 .61803 L
s
.65625 .61428 m
.65625 .61803 L
s
.6875 .61428 m
.6875 .61803 L
s
.71875 .61428 m
.71875 .61803 L
s
.78125 .61428 m
.78125 .61803 L
s
.8125 .61428 m
.8125 .61803 L
s
.84375 .61428 m
.84375 .61803 L
s
.90625 .61428 m
.90625 .61803 L
s
.9375 .61428 m
.9375 .61803 L
s
.96875 .61428 m
.96875 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13339 m
1 .13339 L
s
.99375 .25206 m
1 .25206 L
s
.99375 .37073 m
1 .37073 L
s
.99375 .4894 m
1 .4894 L
s
.99375 .60807 m
1 .60807 L
s
.125 Mabswid
.99625 .03845 m
1 .03845 L
s
.99625 .06218 m
1 .06218 L
s
.99625 .08592 m
1 .08592 L
s
.99625 .10965 m
1 .10965 L
s
.99625 .15712 m
1 .15712 L
s
.99625 .18085 m
1 .18085 L
s
.99625 .20459 m
1 .20459 L
s
.99625 .22832 m
1 .22832 L
s
.99625 .27579 m
1 .27579 L
s
.99625 .29952 m
1 .29952 L
s
.99625 .32326 m
1 .32326 L
s
.99625 .34699 m
1 .34699 L
s
.99625 .39446 m
1 .39446 L
s
.99625 .41819 m
1 .41819 L
s
.99625 .44193 m
1 .44193 L
s
.99625 .46566 m
1 .46566 L
s
.99625 .51313 m
1 .51313 L
s
.99625 .53686 m
1 .53686 L
s
.99625 .5606 m
1 .5606 L
s
.99625 .58433 m
1 .58433 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .06693 L
.03125 .06693 L
.03125 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .06693 L
.03125 .06693 L
.03125 .01472 L
0 .01472 L
s
1 0 0 r
.03125 .01472 m
.03125 .21408 L
.0625 .21408 L
.0625 .01472 L
F
0 g
.03125 .01472 m
.03125 .21408 L
.0625 .21408 L
.0625 .01472 L
.03125 .01472 L
s
1 0 0 r
.0625 .01472 m
.0625 .30427 L
.09375 .30427 L
.09375 .01472 L
F
0 g
.0625 .01472 m
.0625 .30427 L
.09375 .30427 L
.09375 .01472 L
.0625 .01472 L
s
1 0 0 r
.09375 .01472 m
.09375 .36123 L
.125 .36123 L
.125 .01472 L
F
0 g
.09375 .01472 m
.09375 .36123 L
.125 .36123 L
.125 .01472 L
.09375 .01472 L
s
1 0 0 r
.125 .01472 m
.125 .4087 L
.15625 .4087 L
.15625 .01472 L
F
0 g
.125 .01472 m
.125 .4087 L
.15625 .4087 L
.15625 .01472 L
.125 .01472 L
s
1 0 0 r
.15625 .01472 m
.15625 .43718 L
.1875 .43718 L
.1875 .01472 L
F
0 g
.15625 .01472 m
.15625 .43718 L
.1875 .43718 L
.1875 .01472 L
.15625 .01472 L
s
1 0 0 r
.1875 .01472 m
.1875 .47516 L
.21875 .47516 L
.21875 .01472 L
F
0 g
.1875 .01472 m
.1875 .47516 L
.21875 .47516 L
.21875 .01472 L
.1875 .01472 L
s
1 0 0 r
.21875 .01472 m
.21875 .50838 L
.25 .50838 L
.25 .01472 L
F
0 g
.21875 .01472 m
.21875 .50838 L
.25 .50838 L
.25 .01472 L
.21875 .01472 L
s
1 0 0 r
.25 .01472 m
.25 .52737 L
.28125 .52737 L
.28125 .01472 L
F
0 g
.25 .01472 m
.25 .52737 L
.28125 .52737 L
.28125 .01472 L
.25 .01472 L
s
1 0 0 r
.28125 .01472 m
.28125 .54161 L
.3125 .54161 L
.3125 .01472 L
F
0 g
.28125 .01472 m
.28125 .54161 L
.3125 .54161 L
.3125 .01472 L
.28125 .01472 L
s
1 0 0 r
.3125 .01472 m
.3125 .5606 L
.34375 .5606 L
.34375 .01472 L
F
0 g
.3125 .01472 m
.3125 .5606 L
.34375 .5606 L
.34375 .01472 L
.3125 .01472 L
s
1 0 0 r
.34375 .01472 m
.34375 .57484 L
.375 .57484 L
.375 .01472 L
F
0 g
.34375 .01472 m
.34375 .57484 L
.375 .57484 L
.375 .01472 L
.34375 .01472 L
s
1 0 0 r
.375 .01472 m
.375 .57958 L
.40625 .57958 L
.40625 .01472 L
F
0 g
.375 .01472 m
.375 .57958 L
.40625 .57958 L
.40625 .01472 L
.375 .01472 L
s
1 0 0 r
.40625 .01472 m
.40625 .59857 L
.4375 .59857 L
.4375 .01472 L
F
0 g
.40625 .01472 m
.40625 .59857 L
.4375 .59857 L
.4375 .01472 L
.40625 .01472 L
s
1 0 0 r
.4375 .01472 m
.4375 .59857 L
.46875 .59857 L
.46875 .01472 L
F
0 g
.4375 .01472 m
.4375 .59857 L
.46875 .59857 L
.46875 .01472 L
.4375 .01472 L
s
1 0 0 r
.46875 .01472 m
.46875 .59383 L
.5 .59383 L
.5 .01472 L
F
0 g
.46875 .01472 m
.46875 .59383 L
.5 .59383 L
.5 .01472 L
.46875 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .60332 L
.53125 .60332 L
.53125 .01472 L
F
0 g
.5 .01472 m
.5 .60332 L
.53125 .60332 L
.53125 .01472 L
.5 .01472 L
s
1 0 0 r
.53125 .01472 m
.53125 .59383 L
.5625 .59383 L
.5625 .01472 L
F
0 g
.53125 .01472 m
.53125 .59383 L
.5625 .59383 L
.5625 .01472 L
.53125 .01472 L
s
1 0 0 r
.5625 .01472 m
.5625 .59857 L
.59375 .59857 L
.59375 .01472 L
F
0 g
.5625 .01472 m
.5625 .59857 L
.59375 .59857 L
.59375 .01472 L
.5625 .01472 L
s
1 0 0 r
.59375 .01472 m
.59375 .58433 L
.625 .58433 L
.625 .01472 L
F
0 g
.59375 .01472 m
.59375 .58433 L
.625 .58433 L
.625 .01472 L
.59375 .01472 L
s
1 0 0 r
.625 .01472 m
.625 .57958 L
.65625 .57958 L
.65625 .01472 L
F
0 g
.625 .01472 m
.625 .57958 L
.65625 .57958 L
.65625 .01472 L
.625 .01472 L
s
1 0 0 r
.65625 .01472 m
.65625 .55585 L
.6875 .55585 L
.6875 .01472 L
F
0 g
.65625 .01472 m
.65625 .55585 L
.6875 .55585 L
.6875 .01472 L
.65625 .01472 L
s
1 0 0 r
.6875 .01472 m
.6875 .54636 L
.71875 .54636 L
.71875 .01472 L
F
0 g
.6875 .01472 m
.6875 .54636 L
.71875 .54636 L
.71875 .01472 L
.6875 .01472 L
s
1 0 0 r
.71875 .01472 m
.71875 .52737 L
.75 .52737 L
.75 .01472 L
F
0 g
.71875 .01472 m
.71875 .52737 L
.75 .52737 L
.75 .01472 L
.71875 .01472 L
s
1 0 0 r
.75 .01472 m
.75 .50364 L
.78125 .50364 L
.78125 .01472 L
F
0 g
.75 .01472 m
.75 .50364 L
.78125 .50364 L
.78125 .01472 L
.75 .01472 L
s
1 0 0 r
.78125 .01472 m
.78125 .4799 L
.8125 .4799 L
.8125 .01472 L
F
0 g
.78125 .01472 m
.78125 .4799 L
.8125 .4799 L
.8125 .01472 L
.78125 .01472 L
s
1 0 0 r
.8125 .01472 m
.8125 .44667 L
.84375 .44667 L
.84375 .01472 L
F
0 g
.8125 .01472 m
.8125 .44667 L
.84375 .44667 L
.84375 .01472 L
.8125 .01472 L
s
1 0 0 r
.84375 .01472 m
.84375 .39921 L
.875 .39921 L
.875 .01472 L
F
0 g
.84375 .01472 m
.84375 .39921 L
.875 .39921 L
.875 .01472 L
.84375 .01472 L
s
1 0 0 r
.875 .01472 m
.875 .36598 L
.90625 .36598 L
.90625 .01472 L
F
0 g
.875 .01472 m
.875 .36598 L
.90625 .36598 L
.90625 .01472 L
.875 .01472 L
s
1 0 0 r
.90625 .01472 m
.90625 .29952 L
.9375 .29952 L
.9375 .01472 L
F
0 g
.90625 .01472 m
.90625 .29952 L
.9375 .29952 L
.9375 .01472 L
.90625 .01472 L
s
1 0 0 r
.9375 .01472 m
.9375 .21408 L
.96875 .21408 L
.96875 .01472 L
F
0 g
.9375 .01472 m
.9375 .21408 L
.96875 .21408 L
.96875 .01472 L
.9375 .01472 L
s
1 0 0 r
.96875 .01472 m
.96875 .06218 L
1 .06218 L
1 .01472 L
F
0 g
.96875 .01472 m
.96875 .06218 L
1 .06218 L
1 .01472 L
.96875 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo002=ooooo`So0000E_ooool008kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Dooooo`00S_ooool00ol0003oooooooooo`03ooooo`03oa0@4?oooooooooo05Cooooo002>oooo
o`04o`000?oooooooooooa0@45Wooooo002>ooooo`Co0000FOooool008kooooo00Co0000oooooooo
oooo410@FOooool008kooooo00?o0000ooooooooool00oooool00ol@413oooooooooo`1Dooooo`00
S_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Cooooo002=ooooo`So0000E_oo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool005Gooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h5ooooo`04oiRHV?l0003o0000oiRH
V0Oooooo0_l000000ol@413oooooooooo`03ooooo`04oiRHV?l0003o0000oiRHV0?ooooo1_l00006
ooooo`04oiRHV?l0003o0000oiRHV0Gooooo00CoV9RHo`000?l0003oV9RH2Oooool6o`0000Kooooo
00CoV9RHo`000?l0003oV9RH1oooool2o`000003oa0@4?oooooooooo00?ooooo00CoV9RHo`000?l0
003oV9RH1?ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPGooooo00CoV9RHo`000?l0003oV9RH
1?ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPGooooo00CoV9RHo`000?l0003oV9RH1_ooool0
05Gooooo0_mgMgL2ooooo`03ogMgMomEEEGooooo00?ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj
^[X7ooooo`03o`000?oooooooooo00?ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X2ooooo`03
oiRHV?l0003ogMgM00;ooooo00?o410@ooooooooool00oooool01_nj^[[o8B4QomgMgOoMgMgo8B4Q
okZj^P?ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X8ooooo`03oiRHV?l0003ogMgM00;ooooo
00?o410@ooooooooool00oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^POooooo00?o0000oooo
ooooool00oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^P?ooooo0_mgMgL2ooooo`03ogMgMomE
EEGooooo00?ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X3ooooo`06oeEEEOmgMgOooooooooo
oomgMgOoEEEE1?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo001Eooooo`03ob4Q8Ooo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0?o
oooo1_l00004ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A40oooool00on7QhOo8B4Qonk^kP07
ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A40oooool01_m4A4CoV9RHooooooooooooV9RHodA4
A0Wooooo00?oQhN7ob4Q8Oo^k^h01oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0?ooooo1_l0
0004ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A40oooool00olQ8B7oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@3ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo
001:ooooo`Ko00001Oooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo00Ko000000?o
k^k^o`000?ooool00_ooool01Om4A4Co^[Zjoooooooooooo000000Cooooo1ol00004ooooo`03ojVY
ZOlQ8B7ok^k^00Kooooo00Ko0000onk^k_ooooooooooonk^k_l00003ooooo`06o`000?o^k^kooooo
ooooooo^k^ko00002_ooool00onYZJWo8B4Qonk^kP06ooooo`06o`000?o^k^koooooooooooo^k^ko
00000oooool01Om4A4Co^[Zjoooooooooooo000000Gooooo00Ko0000onk^k_ooooooooooonk^k_l0
0003ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool00_ooool01_l0003ok^k^oooo
ooooooook^k^o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`06
o`000?o^k^koooooooooooo^k^ko00001Oooool005Gooooo00Ko0000oeEEEOo^k^koooooogMgMomE
EED4ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooomgMgOlQ8B42ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
oiRHV?lb<S;ooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool02Oooool00onHV9So<S8booooo`05ooooo`03o`000?oooooooooo
00;ooooo00Ko0000ooooooooooooooooomgMgOlQ8B42ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool02_l0003ooooooooooooooooo0000oeEEEOo^k^koooooogMgMomEEED4
ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooooooooeEEEOmgMgL2ooooo`03ogMg
MomEEEGooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`00EOoo
ool01_l0003oMgMgo`000?l0003oEEEEonk^kPCooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`04ogMgMonHV9Soooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03odA4A?mgMgOooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02_ooool00om4A4CoMgMgooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?mgMgOoV9RHooooool0
0005ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooo`000?mgMgL2o`000003
oeEEEOo^k^kooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooogMgM
00Co000000?ogMgMooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo001Eooooo`03odA4A?nHV9Sooooo00Oooooo00Ko0000onk^k_ooooooooooonk^k_l00004
ooooo`04onk^k_lQ8B7oooooo`0000Gooooo00Ko0000onk^k_ooooooooooonk^k_l00006ooooo`03
omgMgOl@413ooooo00Cooooo00Ko0000onk^k_ooooooooooonk^k_l00003ooooo`06o`000?o^k^ko
ooooooooooo^k^ko00003?ooool00ooMgMgo410@ooooo`04ooooo`06o`000?o^k^koooooooooooo^
k^ko00001?ooool01?o^k^ko8B4Qooooool00005ooooo`06o`000?o^k^koooooooooooo^k^ko0000
0oooool00om4A4CoV9RHooooo`07ooooo`06o`000?o^k^koooooooooooo^k^ko00000oooool01_lb
<S;oIVIVonk^k_o^k^koIVIVoc8b<PCooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooo`00
EOooool00onj^[[o8B4Qooooo`07ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omg
MgOoV9RHo`000005ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41oooool00ol0003ooooooooo
o`03ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A40oooool01_m4A4CoV9RHooooooooooooV9RH
odA4A0gooooo00?o0000ooooooooool00oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo
00?oMgMgoiRHV?l000001Oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0?ooooo00?o^[Zjob4Q
8Oooool01oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool005Kooooo
00?oEEEEoc8b<_oMgMd01_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00?ok^k^oc8b
<_l000001Oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^P;ooooo00Ko0000ohN7Qoo^k^kooooo
oiRHV?mEEED5ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj0oooool01_nj^[[o8B4QomgMgOoM
gMgo8B4QokZj^PSooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED5ooooo`06okZj^_lQ8B7ogMgM
omgMgOlQ8B7o^[Zj1Oooool00oo^k^ko<S8bo`000005ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o
^[Zj1?ooool00omEEEGo<S8bomgMg@06ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj0oooool0
1_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<PCooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5oooo
o`00Eoooool01?nHV9So8B4Qo`000?lQ8B45ooooo`04oiRHV?l0003o0000oiRHV0Oooooo00?oV9RH
oa0@4?ooool01Oooool01?nHV9So0000o`000?nHV9P3ooooo`06ojVYZOlb<S;o0000o`000?mEEEGo
k^k^1_ooool01?nHV9So0000o`000?nHV9P5ooooo`04oiRHV?l0003o0000oiRHV0Wooooo00KoZJVY
oc8b<_l0003o0000oeEEEOo^k^h6ooooo`04oiRHV?l0003o0000oiRHV0Oooooo00?oV9RHoa0@4?oo
ool01Oooool01?nHV9So0000o`000?nHV9P6ooooo`04oiRHV?lQ8B7o0000ob4Q8@Gooooo00CoV9RH
o`000?l0003oV9RH1?ooool01_o^k^koA4A4o`000?l0003oA4A4onk^kPGooooo00CoV9RHo`000?l0
003oV9RH1_ooool00>_ooooo003[ooooo`00joooool003Wooooo00CoV9RHo`000?l0003oV9RH[_oo
ool003Sooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X6oooooi_o00003?ooool003Sooooo00Ko
A4A4oiRHV?oooooooooooiRHV?m4A4@6ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`00>?ooool01_l0003ok^k^ooooooooooook^k^o`0000KoooooVol0000<
ooooo`00>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oooooooooo00[ooooo000hooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ooooooooool02_ooool003Sooooo00Ko0000onk^k_ooooooooooonk^k_l00006ooooo`03o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0:ooooo`00>?ooool01_m4A4CoV9RHoooo
ooooooooV9RHodA4A0Kooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo
00[ooooo000hooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1_ooool00ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ooooooooool02_ooool003Wooooo00CoV9RHo`000?l0003oV9RH1ooo
ool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool02_ooool004Cooooo00?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo00[ooooo0014ooooo`Ko00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`001_l0000<ooooo`00A?ooool0
0ol0003oooooooooo`02ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000
ooooooooool00_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Co
0000oooooooooooooooo0_l0000<ooooo`00A?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo00;ooooo
00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool00_ooool01Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00[ooooo0014ooooo`03o`000?oooooooooo00;ooooo00Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0:ooooo`00A?ooool00ol0003oooooooooo`02ooooo`05o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00004o`000?ooooooooooooooo`;o00003?ooool003Sooooo
00GoV9RHoa0@4?l0003o0000ofIVIP07ooooo`03o`000?oooooooooo00;ooooo00Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`00>?ooool01_l@413oQhN7ooooooooooooMgMgofIVIPKooooo00?o0000
ooooooooool00_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo000mooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo000l
ooooo`03onk^k_l0003ooooo00Gooooo0_l00003ooooo`05o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00004o`000?ooooooooooooooo`;o00003?ooool003Sooooo00Ko
410@oiRHV?ooooooooooogMgMomVIVH6ooooo`03o`000?oooooooooo00;ooooo00Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`00>?ooool01Ol0003o8B4Qo`000?l0003oIVIV00Oooooo00?o0000oooo
ooooool00_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo000hooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00001?l0003oooooooooooooool2o`0000cooooo000hooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo000h
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00[ooooo000hooooo`Go00001oooool00ol0003oooooooooo`02ooooo`05o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo00;ooooo00?o
0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool00_ooool01Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00001?l0003oooooooooooooool2o`0000cooooo
0014ooooo`03o`000?oooooooooo00;ooooo00Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`00A?oo
ool00ol0003oooooooooo`02ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool004Cooooo00?o
0000ooooooooool00_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00Co0000oooooooooooooooo0_l0000<ooooo`00A?ooool00ol0003oooooooooo`02ooooo`Go0000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo0006o`0000Cooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool01_oo
ool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oooooooooo00Oooooo00?o0000ooooooooool02_oo
ool004Cooooo00?o0000ooooooooool01_ooool00ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooo
oooo00Kooooo0_l0000<ooooo`00;oooool4o`000003oa0@4?oooooooooo00Cooooo00CoV9RHo`00
0?l0003oV9RH1_ooool00ol0003oooooooooo`06ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ooooooooool01oooool00ol0003oooooooooo`0:ooooo`00<Oooool00ol0003oooooooooo`05oooo
o`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`00<Oooool0
0ol0003oooooooooo`05ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0:ooooo`00<Oooool00ol0003oooooooooo`05ooooo`06o`000?o^k^koooooooooooo^k^ko
00001Oooool2o`0000Oooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`06ooooo`;o
00003?ooool0037ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02_ooool0037ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_oo
ool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oooooooooo00Oooooo00?o0000ooooooooool02_oo
ool0013ooooo00?o^[Zjoc8b<_ooool03_ooool00olb<S;o^[Zjooooo`0=ooooo`03o`000?oooooo
oooo00Gooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooo`03o`000?oooooooooo00Kooooo
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo
0003ooooo`03o`000?oooooooooo00[ooooo00?o<S8bokZj^_ooool03_ooool00onj^[[o<S8boooo
o`0=ooooo`03o`000?oooooooooo00Gooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03
o`000?oooooooooo00Kooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`06ooooo`;o
00003?ooool000?ooooo00?o<S8bokZj^_ooool02Oooool00oo<c<co<S8booooo`0@ooooo`03oc8b
<_o<c<cooooo00[ooooo00?o0000odA4A?l000001oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj
^PGooooo00?o0000ooooooooool01_ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooooooo
00Oooooo00?o0000ooooooooool02_ooool000?ooooo00?oMgMgohN7QomgMgL00_l000000om4A4Co
c<c<ooooo`04ooooo`03ofIVI_nYZJWooooo00Cooooo2?l00004ooooo`03oiRHV?mVIVKooooo00[o
oooo00?oc<c<oeEEEOl000002?ooool01?nHV9So0000o`000?nHV9P6ooooo`03o`000?oooooooooo
00Kooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00[ooooo0003ooooo`08oiRHV?l@413oQhN7onk^k_ooooooV9RHoa0@4?o<c<`4ooooo`03oc8b<_oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03onk^k_lb
<S;ooooo01oooooo00?o0000ooooooooool01_ooool00ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Co0000ool00?oo003oo`001_l00008ooooo`;o00003?oo
ool000?ooooo00?o^[Zjoc8b<_ooool00oooool00onHV9SoA4A4ooooo`03ooooo`03oc8b<_oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool01_ooool6o`0000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`00000>ooooo`03o`000?oooooooooo00[ooooo0004ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00olb<S;oooooooooo`05ooooo`04o`000?oooooooooo
oa0@40Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00000>ooooo`03o`000?oooooo
oooo00[ooooo0004ooooo`03odA4A?nHV9Sooooo00;ooooo00?ok^k^o`000?ooool00oooool00olQ
8B7oooooooooo`05ooooo`Co00002?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00_ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00kooooo00?o0000ooooooooool02_ooool000Cooooo00Oo^[Zjo`000?nj^[[oooooonk^k_mVIVKo
EEEE00Cooooo00?o<S8bonk^k_ooool01Oooool01?l0003oooooooooool@4107ooooo`03omgMgOlb
<S;ooooo01oooooo00?o0000ooooooooool02oooool00ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000003Oooool2o`0000cooooo0005ooooo`06ojVYZOlQ8B7o
0000o`000?mEEEGok^k^1?ooool00omVIVKoV9RHooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o410@ooooooooool00_ooool00onHV9SoIVIVooooo`0Oooooo`03o`000?oooooooooo00_ooooo
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000kooooo
00?o0000ooooooooool02_ooool000oooooo00?ogMgMob4Q8Oooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o410@olc<c?ooool07oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
000>ooooo`03o`000?oooooooooo00[ooooo000@ooooo`03oc8b<_nj^[[ooooo00?ooooo2?l00003
ooooo`03okZj^_lb<S;ooooo023ooooo00?o0000ooooooooool02oooool00ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000003_ooool00ol0003oooooooooo`0:
ooooo`004?ooool00onj^[[o<S8booooo`0>ooooo`03oc8b<_nj^[[ooooo00_ooooo1?l000000ol@
413oooooooooo`03ooooo`05oiRHV?l@413o0000o`000?mVIVH01_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00000=
ooooo`;o00003?ooool0037ooooo00?o0000ooooooooool01Oooool01_l@413oQhN7oooooooooooo
MgMgofIVIPGooooo00?o0000ooooooooool02oooool00ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000003_ooool00ol0003oooooooooo`0:ooooo`00<Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool6
o`0000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000003_ooool00ol0003oooooooooo`0:ooooo`00<Oooool00ol0
003oooooooooo`09ooooo`03onk^k_l0003ooooo00Cooooo0_l0000Aooooo`03o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000Go
00003Oooool2o`0000cooooo000aooooo`03o`000?oooooooooo00Gooooo00Ko410@oiRHV?oooooo
ooooogMgMomVIVH5ooooo`03o`000?oooooooooo013ooooo00?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0:ooooo`00<Oooool00ol0003oooooooooo`05ooooo`05o`00
0?lQ8B7o0000o`000?mVIVH01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oooooooooo013ooooo00?o0000ooooooooool02_ooool0037ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`00<Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`0?ooooo`;o00003?ooool002oooooo00?o0000odA4A?l000001oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool000Ko00004_ooool00ol0003oooooooooo`0:ooooo`00;oooool0
0oo<c<coEEEEo`000007ooooo`Go00001_ooool00ol0003oooooooooo`0@ooooo`Ko00001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo0014ooooo`03
o`000?oooooooooo01Gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooooooo01Gooooo00?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0Dooooo`;o00003?ooool0
04Cooooo00?o0000ooooooooool05Oooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool0
5Oooool6o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool0
04Cooooo00?o0000ooooooooool06_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0Dooooo`;o
00003?ooool004Cooooo00?o0000ooooooooool06_ooool01Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`001_l0000Gooooo`03o`000?oooooooooo00[ooooo0014
ooooo`03o`000?oooooooooo01[ooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool004Co
oooo00?o0000ooooooooool06_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`00A?oo
ool00ol0003oooooooooo`0Jooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oooooooooo`0Iooooo`;o00003?ooool002kooooo1_l00006oooo
o`04oiRHV?l0003o0000oiRHV0Kooooo00?o0000ooooooooool06_ooool5o`0000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`00
;_ooool00onHV9So0000omgMg@02ooooo`03oa0@4?oooooooooo00?ooooo00Ko^[Zjob4Q8OoMgMgo
gMgMob4Q8Onj^[X5ooooo`03o`000?oooooooooo01kooooo00?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
1_l0000Looooo`03o`000?oooooooooo00[ooooo000_ooooo`03ohN7QolQ8B7ok^k^00Oooooo00Ko
A4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03o`000?oooooooooo01kooooo00?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`00<?ooool0
0onYZJWo8B4Qonk^kP06ooooo`06o`000?o^k^koooooooooooo^k^ko00001Oooool2o`0001oooooo
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool07_ooool2o`0000cooooo000aoooo
o`03oiRHV?lb<S;ooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01kooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool0
7oooool00ol0003oooooooooo`0:ooooo`00<_ooool00om4A4CoMgMgooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Nooooo`Ko00001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Co0000ool00?oo003oo`001_l0000Qooooo`03o`000?oooooooooo
00[ooooo000booooo`03omgMgOl@413ooooo00Cooooo00Ko0000onk^k_ooooooooooonk^k_l00005
ooooo`03o`000?oooooooooo02?ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`00000Uooooo`;o00003?ooool003?ooooo00?o0000ooooooooool0
0oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?o0000ooooooooool08oooool00ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000002Kooooo
00?o0000ooooooooool02_ooool002kooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED5ooooo`06
okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool00ol0003oooooooooo`0Sooooo`Ko00001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000Go0000
9_ooool00ol0003oooooooooo`0:ooooo`00;_ooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kPKo
oooo00CoV9RHo`000?l0003oV9RH1_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo02Oooooo0_l0000<ooooo`00A?oo
ool00ol0003oooooooooo`0Xooooo`Ko00001?oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`001_l0000Zooooo`03
o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooooooo02gooooo00?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0;Oooool00ol0003oooooooooo`0:oooo
o`00A?ooool00ol0003oooooooooo`0]ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0006o`0002oooooo00?o0000
ooooooooool02_ooool004Cooooo00?o0000ooooooooool0;Oooool6o`0000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0<Oooool2o`0000cooooo0014
ooooo`03o`000?oooooooooo03;ooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0booooo`03o`000?oooooooooo00[ooooo
0014ooooo`03o`000?oooooooooo03;ooooo2_l00004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool000Ko0000=?ooool00ol0003oooooooooo`0:ooooo`00A?oo
ool00ol0003oooooooooo`0kooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool000Ko0000>?ooool2o`0000cooooo000^ooooo`Ko00001Oooool01OnHV9So410@o`00
0?l0003oIVIV00Kooooo00?o0000ooooooooool0>oooool00ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`0looooo`03o`000?oooooooooo00[o
oooo000^ooooo`03oiRHV?l0003ogMgM00;ooooo00?o410@ooooooooool00oooool01_l@413oQhN7
ooooooooooooMgMgofIVIPGooooo00?o0000ooooooooool0>oooool@o`0000Coo`002_l0000noooo
o`03o`000?oooooooooo00[ooooo000_ooooo`03ohN7QolQ8B7ok^k^00cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1:ooooo`Ko0000Aoooool00ol0003oooooooooo`0:ooooo`00
<?ooool00onYZJWo8B4Qonk^kP0:ooooo`03onk^k_l0003ooooo00Cooooo0_l0000Aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00oooooo0_l0000<ooooo`00<Oooool00onHV9So<S8booooo`05ooooo`06oa0@4?nH
V9SooooooooooomgMgOoIVIV1OoooonKo`0000cooooo000booooo`03odA4A?mgMgOooooo00Cooooo
00Go0000ob4Q8Ol0003o0000ofIVIP2]ooooo`00<_ooool00ooMgMgo410@ooooo`04ooooo`03o`00
0?oooooooooo0:oooooo000cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[ooo
ool002kooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED5ooooo`03o`000?oooooooooo0:oooooo
000^ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^1Oooool5o`000:gooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-150.848, -23.738, 1.03781, \
0.273293}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Below we plot the theoretical density of eigenvalues known as Wigner's \
semicircle law (because the curve takes the shape of a semicircle centered at \
zero with radius ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\@\(2  N\)\)\(,\)\)\)]],
  "where N is the dimension of the random matrix (and hence the number of \
eigenvalues)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(WSC = 
      Plot[Sqrt[2*n - x^2]/\((Pi)\), {x, \(-Sqrt[2*n]\), Sqrt[2*n]}, 
        PlotStyle \[Rule] {Thickness[0.02]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00614759 0.0147151 0.0238725 [
[.03893 .00222 -9 -9 ]
[.03893 .00222 9 0 ]
[.19262 .00222 -9 -9 ]
[.19262 .00222 9 0 ]
[.34631 .00222 -9 -9 ]
[.34631 .00222 9 0 ]
[.65369 .00222 -6 -9 ]
[.65369 .00222 6 0 ]
[.80738 .00222 -6 -9 ]
[.80738 .00222 6 0 ]
[.96107 .00222 -6 -9 ]
[.96107 .00222 6 0 ]
[.4875 .13408 -6 -4.5 ]
[.4875 .13408 0 4.5 ]
[.4875 .25344 -12 -4.5 ]
[.4875 .25344 0 4.5 ]
[.4875 .3728 -12 -4.5 ]
[.4875 .3728 0 4.5 ]
[.4875 .49216 -12 -4.5 ]
[.4875 .49216 0 4.5 ]
[.4875 .61153 -12 -4.5 ]
[.4875 .61153 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03893 .01472 m
.03893 .02097 L
s
[(-75)] .03893 .00222 0 1 Mshowa
.19262 .01472 m
.19262 .02097 L
s
[(-50)] .19262 .00222 0 1 Mshowa
.34631 .01472 m
.34631 .02097 L
s
[(-25)] .34631 .00222 0 1 Mshowa
.65369 .01472 m
.65369 .02097 L
s
[(25)] .65369 .00222 0 1 Mshowa
.80738 .01472 m
.80738 .02097 L
s
[(50)] .80738 .00222 0 1 Mshowa
.96107 .01472 m
.96107 .02097 L
s
[(75)] .96107 .00222 0 1 Mshowa
.125 Mabswid
.06967 .01472 m
.06967 .01847 L
s
.10041 .01472 m
.10041 .01847 L
s
.13114 .01472 m
.13114 .01847 L
s
.16188 .01472 m
.16188 .01847 L
s
.22336 .01472 m
.22336 .01847 L
s
.2541 .01472 m
.2541 .01847 L
s
.28483 .01472 m
.28483 .01847 L
s
.31557 .01472 m
.31557 .01847 L
s
.37705 .01472 m
.37705 .01847 L
s
.40779 .01472 m
.40779 .01847 L
s
.43852 .01472 m
.43852 .01847 L
s
.46926 .01472 m
.46926 .01847 L
s
.53074 .01472 m
.53074 .01847 L
s
.56148 .01472 m
.56148 .01847 L
s
.59221 .01472 m
.59221 .01847 L
s
.62295 .01472 m
.62295 .01847 L
s
.68443 .01472 m
.68443 .01847 L
s
.71517 .01472 m
.71517 .01847 L
s
.7459 .01472 m
.7459 .01847 L
s
.77664 .01472 m
.77664 .01847 L
s
.83812 .01472 m
.83812 .01847 L
s
.86886 .01472 m
.86886 .01847 L
s
.89959 .01472 m
.89959 .01847 L
s
.93033 .01472 m
.93033 .01847 L
s
.00819 .01472 m
.00819 .01847 L
s
.99181 .01472 m
.99181 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .13408 m
.50625 .13408 L
s
[(5)] .4875 .13408 1 0 Mshowa
.5 .25344 m
.50625 .25344 L
s
[(10)] .4875 .25344 1 0 Mshowa
.5 .3728 m
.50625 .3728 L
s
[(15)] .4875 .3728 1 0 Mshowa
.5 .49216 m
.50625 .49216 L
s
[(20)] .4875 .49216 1 0 Mshowa
.5 .61153 m
.50625 .61153 L
s
[(25)] .4875 .61153 1 0 Mshowa
.125 Mabswid
.5 .03859 m
.50375 .03859 L
s
.5 .06246 m
.50375 .06246 L
s
.5 .08633 m
.50375 .08633 L
s
.5 .1102 m
.50375 .1102 L
s
.5 .15795 m
.50375 .15795 L
s
.5 .18182 m
.50375 .18182 L
s
.5 .20569 m
.50375 .20569 L
s
.5 .22957 m
.50375 .22957 L
s
.5 .27731 m
.50375 .27731 L
s
.5 .30118 m
.50375 .30118 L
s
.5 .32506 m
.50375 .32506 L
s
.5 .34893 m
.50375 .34893 L
s
.5 .39667 m
.50375 .39667 L
s
.5 .42055 m
.50375 .42055 L
s
.5 .44442 m
.50375 .44442 L
s
.5 .46829 m
.50375 .46829 L
s
.5 .51604 m
.50375 .51604 L
s
.5 .53991 m
.50375 .53991 L
s
.5 .56378 m
.50375 .56378 L
s
.5 .58765 m
.50375 .58765 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.02 w
.02381 .01496 m
.02499 .05605 L
.02605 .07181 L
.02846 .09674 L
.03279 .12846 L
.03784 .15654 L
.04262 .1785 L
.06244 .24696 L
.08265 .29814 L
.10458 .34268 L
.14545 .40764 L
.1848 .45591 L
.22263 .49316 L
.26292 .52518 L
.30169 .54985 L
.34292 .57037 L
.36351 .57862 L
.38262 .58516 L
.40229 .59079 L
.42082 .59512 L
.44134 .59884 L
.45995 .60123 L
.46971 .60213 L
.47505 .60251 L
.48003 .6028 L
.48428 .603 L
.48883 .60316 L
.49143 .60322 L
.49271 .60325 L
.49389 .60327 L
.49494 .60329 L
.4961 .6033 L
.49726 .60331 L
.4985 .60332 L
.49971 .60332 L
.50085 .60332 L
.50209 .60331 L
.50278 .60331 L
.50341 .6033 L
.50469 .60329 L
.50608 .60327 L
.50859 .60322 L
.51093 .60316 L
.51341 .60309 L
.51785 .60291 L
.52298 .60263 L
.52778 .60232 L
.5387 .60137 L
.54911 .60018 L
.55899 .59879 L
Mistroke
.57753 .59547 L
.59737 .59088 L
.61577 .58566 L
.65495 .57129 L
.69659 .55082 L
.73671 .52545 L
.77531 .49498 L
.81636 .45464 L
.8559 .40577 L
.89393 .34541 L
.91511 .30312 L
.9344 .25583 L
.944 .22745 L
.95442 .19064 L
.9592 .17054 L
.96427 .1456 L
.9686 .11942 L
.97089 .10228 L
.97336 .07874 L
.97408 .07002 L
.97484 .05902 L
.97549 .04674 L
.97619 .01496 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool000Sooooo00?o0000ooooooooool00_ooool3
o`0001_ooooo0ol00004ooooo`;o00006_ooool5o`0000;ooooo0ol0000jooooo`Go00000_ooool3
o`0001_ooooo0ol00004ooooo`;o00007?ooool00ol0003oooooooooo`02ooooo`?o00001oooool0
00Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01Oooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001[ooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`03o`000?oooooooooo03Sooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0001_ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Cooooo0005o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`Go
00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo017ooooo1Ol00003oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool000Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo000:
ooooo`03o`000?oooooo000000?o00006_ooool4o`0000?ooooo00Co0000oooooooooooo00006Ooo
ool01_l0003ooooooooooooooooo0000ooooo`Co0000>_ooool01_l0003ooooooooooooooooo0000
ooooo`Co00006_ooool4o`0000?ooooo00Co0000oooooooooooo00007Oooool00ol0003oooooo`00
0003o`0000Oooooo0006ooooo`07o`000?ooooooooooooooool0003oooooo`00000Mooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo00006Oooool01ol0003ooooooooooooooooo0000
ooooool00000?Oooool01ol0003ooooooooooooooooo0000ooooool000007Oooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0001Wooooo00Oo0000ooooooooooooooooo`000?oooooo
000000[ooooo0006ooooo`Go000000?oooooo`000?l000000ol0000Iooooo`Go00000oooool2o`00
01_ooooo0ol00002ooooo`Go0000>_ooool3o`0000;ooooo1Ol0000Iooooo`Go00000oooool2o`00
01[ooooo1Ol000000ooooooo0000o`000003o`0000Kooooo003[ooooo`00MOooool00ol0003ooooo
ooooo`1cooooo`00MOooool00ol0003oooooooooo`1cooooo`000oooool4o`0006kooooo00?o0000
ooooooooool0J_ooool4o`0000Gooooo003[o`00000000?oooooo`000?ooool01?l00002ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooo000000?o00000_ooool1o`00007ooooo0Oooool000?ooooo1?l00002ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooo000000?o00001Oooool000?ooooo1?l0001^ooooo`03o`000?oooooooooo06[ooooo1?l0
0005ooooo`000oooool4o`0006kooooo00?o0000ooooooooool0J_ooool4o`0000Gooooo0003oooo
o`Co0000K_ooool00ol0003oooooooooo`1Zooooo`Co00001Oooool000?ooooo1?l0001^ooooo`03
o`000?oooooooooo06[ooooo1?l00005ooooo`000oooool4o`0006kooooo00?o0000ooooooooool0
J_ooool4o`0000Gooooo0003ooooo`Co0000K_ooool00ol0003oooooooooo`1Zooooo`Co00001Ooo
ool000?ooooo1?l0001^ooooo`03o`000?oooooooooo06[ooooo1?l00005ooooo`000oooool4o`00
06kooooo00?o0000ooooooooool0J_ooool4o`0000Gooooo0003ooooo`Co0000K_ooool00ol0003o
ooooooooo`1Zooooo`Co00001Oooool000?ooooo1Ol0001]ooooo`03o`000?oooooooooo06Wooooo
1Ol00005ooooo`000oooool5o`0006gooooo00?o0000ooooooooool0JOooool5o`0000Gooooo0003
ooooo`Go0000KOooool00ol0003oooooooooo`1Yooooo`Go00001Oooool000Cooooo1?l0001]oooo
o`03o`000?oooooooooo06Wooooo1?l00006ooooo`001?ooool4o`0006gooooo00?o0000oooooooo
ool0JOooool4o`0000Kooooo0004ooooo`Co0000KOooool00ol0003oooooooooo`1Yooooo`Co0000
1_ooool000Cooooo1?l0001]ooooo`03o`000?oooooooooo06Wooooo1?l00006ooooo`001?ooool4
o`0006gooooo00?o0000ooooooooool0JOooool4o`0000Kooooo0004ooooo`Co0000KOooool00ol0
003oooooooooo`1Yooooo`Co00001_ooool000Cooooo1?l0001]ooooo`03o`000?oooooooooo06Wo
oooo1?l00006ooooo`001?ooool4o`0006gooooo00?o0000ooooooooool0JOooool4o`0000Kooooo
0004ooooo`Go0000K?ooool00ol0003oooooooooo`1Xooooo`Go00001_ooool000Cooooo1Ol0001/
ooooo`03o`000?oooooooooo06Sooooo1Ol00006ooooo`001?ooool5o`0006cooooo00?o0000oooo
ooooool0J?ooool5o`0000Kooooo0005ooooo`Co0000I?ooool3o`0000Gooooo00?o0000oooooooo
ool0J?ooool4o`0000Oooooo0005ooooo`Co0000Hoooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0J?ooool4o`0000Oooooo0005ooooo`Co0000Ioooool00ol0003ooooo
ooooo`02ooooo`;o0000J?ooool5o`0000Oooooo0005ooooo`Co0000Ioooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06Oooooo1Ol00007ooooo`001Oooool5o`0006;ooooo1?l00005
ooooo`03o`000?oooooooooo06Oooooo1Ol00007ooooo`001Oooool5o`0006;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Wooooo`Co00002?ooool000Gooooo1Ol0001Rooooo`Go
00001?ooool00ol0003oooooooooo`1Wooooo`Co00002?ooool000Kooooo1?l0001[ooooo`03o`00
0?oooooooooo06Oooooo1?l00008ooooo`001_ooool4o`0006_ooooo00?o0000ooooooooool0I_oo
ool5o`0000Sooooo0006ooooo`Co0000Joooool00ol0003oooooooooo`1Vooooo`Go00002?ooool0
00Kooooo1Ol0001Zooooo`03o`000?oooooooooo06Kooooo1Ol00008ooooo`001_ooool5o`0006[o
oooo00?o0000ooooooooool0I_ooool4o`0000Wooooo0006ooooo`Go0000J_ooool00ol0003ooooo
ooooo`1Vooooo`Co00002Oooool000Oooooo1?l0001Zooooo`03o`000?oooooooooo06Gooooo1Ol0
0009ooooo`001oooool4o`0006[ooooo00?o0000ooooooooool0IOooool5o`0000Wooooo0007oooo
o`Go0000JOooool00ol0003oooooooooo`1Uooooo`Go00002Oooool000Oooooo1Ol0001Yooooo`03
o`000?oooooooooo06Gooooo1?l0000:ooooo`001oooool5o`0006Wooooo00?o0000ooooooooool0
I?ooool5o`0000[ooooo0008ooooo`Go0000J?ooool00ol0003oooooooooo`1Tooooo`Go00002_oo
ool000Sooooo1Ol0001Xooooo`03o`000?oooooooooo06Cooooo1Ol0000:ooooo`002?ooool5o`00
06Sooooo00?o0000ooooooooool0Hoooool5o`0000_ooooo0009ooooo`Go0000Ioooool00ol0003o
ooooooooo`1Sooooo`Go00002oooool000Wooooo1Ol0001Wooooo`03o`000?oooooooooo06?ooooo
1Ol0000;ooooo`002Oooool5o`0006Oooooo00?o0000ooooooooool0H_ooool5o`0000cooooo000:
ooooo`Go0000I_ooool00ol0003oooooooooo`1Rooooo`Go00003?ooool000[ooooo1Ol0001Voooo
o`03o`000?oooooooooo06;ooooo1Ol0000<ooooo`002_ooool5o`0006Kooooo00?o0000oooooooo
ool0HOooool5o`0000gooooo000;ooooo`Go0000IOooool00ol0003oooooooooo`1Qooooo`Go0000
3Oooool000_ooooo1Ol0001Gooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0HOoo
ool5o`0000gooooo000;ooooo`Go0000F?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0H?ooool5o`0000kooooo000<ooooo`Go0000Eoooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo0_l0001Qooooo`Go00003_oo
ool000cooooo1Ol0001Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`1Pooooo`Go00003_ooool000cooooo1Ol0001Gooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Oooooo`Go00003ooo
ool000gooooo1Ol0001Eooooo`;o00001?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo05oooooo1Ol0000?ooooo`003Oooool5o`0005Kooooo00?o0000ooooooooool00oooool2
o`0000Gooooo00?o0000ooooooooool0Goooool5o`0000oooooo000=ooooo`Ko0000H_ooool00ol0
003oooooooooo`1Nooooo`Go00004?ooool000kooooo1Ol0001Rooooo`03o`000?oooooooooo05ko
oooo1Ol0000@ooooo`003_ooool6o`00067ooooo00?o0000ooooooooool0G_ooool5o`00013ooooo
000?ooooo`Go0000HOooool00ol0003oooooooooo`1Mooooo`Go00004Oooool000oooooo1Ol0001Q
ooooo`03o`000?oooooooooo05gooooo1Ol0000Aooooo`004?ooool5o`00063ooooo00?o0000oooo
ooooool0GOooool5o`00017ooooo000@ooooo`Go0000H?ooool00ol0003oooooooooo`1Looooo`Go
00004_ooool0013ooooo1_l0001Oooooo`03o`000?oooooooooo05cooooo1Ol0000Booooo`004Ooo
ool5o`0005oooooo00?o0000ooooooooool0Foooool6o`0001;ooooo000Aooooo`Ko0000G_ooool0
0ol0003oooooooooo`1Kooooo`Go00004oooool001;ooooo1Ol0001Nooooo`03o`000?oooooooooo
05[ooooo1_l0000Cooooo`004_ooool6o`0005gooooo00?o0000ooooooooool0F_ooool5o`0001Co
oooo000Cooooo`Go0000GOooool00ol0003oooooooooo`1Iooooo`Ko00005?ooool001?ooooo1_l0
001Looooo`03o`000?oooooooooo05Wooooo1Ol0000Eooooo`005?ooool5o`0005cooooo00?o0000
ooooooooool0F?ooool6o`0001Gooooo000Dooooo`Ko0000Foooool00ol0003oooooooooo`1Hoooo
o`Go00005_ooool001Gooooo1Ol0001Kooooo`03o`000?oooooooooo05Oooooo1_l0000Fooooo`00
5Oooool6o`0005[ooooo00?o0000ooooooooool0Eoooool5o`0001Oooooo000Fooooo`Ko0000FOoo
ool00ol0003oooooooooo`1Fooooo`Ko00005oooool001Kooooo1_l0001Iooooo`03o`000?oooooo
oooo05Gooooo1_l0000Hooooo`005oooool6o`0005Sooooo00?o0000ooooooooool0EOooool6o`00
01Sooooo000Hooooo`Ko0000BOooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo05Co
oooo1_l0000Iooooo`006?ooool6o`0004[ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0Doooool6o`0001[ooooo000Iooooo`Ko0000
BOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l0001Dooooo`Ko0000
6_ooool001[ooooo1_l00018ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Booooo`Ko00006oooool001[ooooo1_l00018ooooo`04o`000?oooooo
ooooooooo`Co00001Oooool00ol0003oooooooooo`1Booooo`Go00007?ooool001_ooooo1_l00016
ooooo`;o00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo057ooooo1_l0000L
ooooo`007?ooool6o`0004Kooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooo
oooo053ooooo1_l0000Mooooo`007?ooool6o`0005?ooooo00?o0000ooooooooool0D?ooool6o`00
01gooooo000Mooooo`Ko0000D_ooool00ol0003oooooooooo`1?ooooo`Ko00007_ooool001kooooo
1_l0001Aooooo`03o`000?oooooooooo04kooooo1_l0000Oooooo`007_ooool6o`00057ooooo00?o
0000ooooooooool0C_ooool6o`0001oooooo000Oooooo`Ko0000D?ooool00ol0003oooooooooo`1=
ooooo`Ko00008?ooool0023ooooo1_l0001?ooooo`03o`000?oooooooooo04cooooo1_l0000Qoooo
o`008?ooool7o`0004kooooo00?o0000ooooooooool0Boooool7o`00027ooooo000Qooooo`Ko0000
C_ooool00ol0003oooooooooo`1:ooooo`Oo00008_ooool002;ooooo1_l0001=ooooo`03o`000?oo
oooooooo04Wooooo1ol0000Sooooo`008oooool6o`0004cooooo00?o0000ooooooooool0BOooool6
o`0002Cooooo000Sooooo`Oo0000Boooool00ol0003oooooooooo`18ooooo`Ko00009Oooool002Co
oooo1_l0001;ooooo`03o`000?oooooooooo04Oooooo1_l0000Vooooo`009Oooool6o`0004[ooooo
00?o0000ooooooooool0A_ooool7o`0002Kooooo000Vooooo`Ko0000BOooool00ol0003ooooooooo
o`15ooooo`Oo00009oooool002Kooooo2?l00017ooooo`03o`000?oooooooooo04Cooooo1ol0000X
ooooo`009oooool8o`0004Kooooo00?o0000ooooooooool0@oooool7o`0002Wooooo000Xooooo`So
0000AOooool00ol0003oooooooooo`12ooooo`Oo0000:_ooool002Wooooo2?l00014ooooo`03o`00
0?oooooooooo047ooooo1ol0000[ooooo`00:oooool7o`0004?ooooo00?o0000ooooooooool0@?oo
ool7o`0002cooooo000/ooooo`Oo0000@_ooool00ol0003oooooooooo`0oooooo`Oo0000;Oooool0
02gooooo1ol00011ooooo`03o`000?oooooooooo03kooooo1ol0000^ooooo`00;_ooool7o`00037o
oooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0mooooo`Oo0000;oooool002oooooo
2?l0000`ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0looooo`Oo0000<?ooool0033ooooo2?l0000`ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001?ooool2o`0003_ooooo2?l0000aooooo`00<Oooool8o`00033o
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0>Oooool8o`0003;ooooo000booooo`So0000;?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0hooooo`So0000<oooool0
03Cooooo1ol0000[ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo03Kooooo2Ol0000dooooo`00=Oooool7o`0002_ooooo0ol00004
ooooo`;o00001Oooool00ol0003oooooooooo`0eooooo`So0000=_ooool003Kooooo1ol0000hoooo
o`03o`000?oooooooooo03Cooooo2?l0000gooooo`00=oooool7o`0003Oooooo00?o0000oooooooo
ool0<oooool8o`0003Sooooo000hooooo`So0000=Oooool00ol0003oooooooooo`0aooooo`So0000
>_ooool003Wooooo2?l0000dooooo`03o`000?oooooooooo033ooooo2?l0000kooooo`00>_ooool9
o`0003;ooooo00?o0000ooooooooool0;_ooool9o`0003cooooo000kooooo`Wo0000<Oooool00ol0
003oooooooooo`0]ooooo`Wo0000?Oooool003gooooo2Ol0000_ooooo`03o`000?oooooooooo02_o
oooo2Ol0000oooooo`00?_ooool9o`0002kooooo00?o0000ooooooooool0:_ooool9o`00043ooooo
0010ooooo`Wo0000;?ooool00ol0003oooooooooo`0Xooooo`Wo0000@_ooool0047ooooo2ol0000Y
ooooo`03o`000?oooooooooo02Kooooo2_l00013ooooo`00@oooool;o`0002Oooooo00?o0000oooo
ooooool09?ooool:o`0004Gooooo0014ooooo`go00009?ooool00ol0003oooooooooo`0Rooooo`_o
0000A_ooool004Kooooo3Ol0000Rooooo`03o`000?oooooooooo023ooooo2ol00018ooooo`00BOoo
ool=o`0001oooooo00?o0000ooooooooool07_ooool;o`0004[ooooo001;ooooo`go00007Oooool0
0ol0003oooooooooo`0Kooooo`co0000C?ooool004kooooo3?l0000Kooooo`03o`000?oooooooooo
01Sooooo3Ol0001>ooooo`00D?ooool>o`0001Oooooo00?o0000ooooooooool05?ooool?o`00053o
oooo001Cooooo`oo00004oooool00ol0003oooooooooo`0?oooooa;o0000D_ooool005Gooooo4_l0
000>ooooo`03o`000?oooooooooo00_ooooo4ol0001Eooooo`00EooooolDo`0000[ooooo00?o0000
ooooooooool01OoooolFo`0005Sooooo001KooooocCo0000G?ooool005oooooo:ol0001Qooooo`00
I?oooolRo`0006Gooooo001XoooooaSo0000Joooool006Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo07?ooooo001Vooooo`06o`000?oooooooooo
ooooool0003ooooo1?l00005ooooo`03o`000?oooooooooo07?ooooo001Vooooo`07o`000?oooooo
ooooooooool0003oooooo`00001nooooo`00Ioooool3o`0000;ooooo1Ol0001jooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-81.3335, -9.10925, 0.695158, \
0.179015}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The plot below comapres the computed eigenvalue density to the \
Wigner semicircle law.  The agreement is excellent.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[GUEHist, WSC, AspectRatio \[Rule] 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00625 0.0238095 0.0384025 [
[.125 -0.0125 -16.8125 -18 ]
[.125 -0.0125 16.8125 0 ]
[.25 -0.0125 -16.8125 -18 ]
[.25 -0.0125 16.8125 0 ]
[.375 -0.0125 -16.8125 -18 ]
[.375 -0.0125 16.8125 0 ]
[.5 -0.0125 -6.78125 -18 ]
[.5 -0.0125 6.78125 0 ]
[.625 -0.0125 -11.5625 -18 ]
[.625 -0.0125 11.5625 0 ]
[.75 -0.0125 -11.5625 -18 ]
[.75 -0.0125 11.5625 0 ]
[.875 -0.0125 -11.5625 -18 ]
[.875 -0.0125 11.5625 0 ]
[1 -0.0125 -11.5625 -18 ]
[1 -0.0125 11.5625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .02381 -13.5625 -9 ]
[-0.0125 .02381 0 9 ]
[-0.0125 .21582 -13.5625 -9 ]
[-0.0125 .21582 0 9 ]
[-0.0125 .40783 -23.125 -9 ]
[-0.0125 .40783 0 9 ]
[-0.0125 .59985 -23.125 -9 ]
[-0.0125 .59985 0 9 ]
[-0.0125 .79186 -23.125 -9 ]
[-0.0125 .79186 0 9 ]
[-0.0125 .98387 -23.125 -9 ]
[-0.0125 .98387 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -65.375 -9 ]
[-0.01875 .5 -23.125 9 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
gsave
.125 -0.0125 -77.8125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
73.500 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -77.8125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
73.500 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.375 0 m
.375 .00625 L
s
gsave
.375 -0.0125 -77.8125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
73.500 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.625 0 m
.625 .00625 L
s
gsave
.625 -0.0125 -72.5625 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -72.5625 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.875 0 m
.875 .00625 L
s
gsave
.875 -0.0125 -72.5625 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -72.5625 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.125 Mabswid
.03125 0 m
.03125 .00375 L
s
.0625 0 m
.0625 .00375 L
s
.09375 0 m
.09375 .00375 L
s
.15625 0 m
.15625 .00375 L
s
.1875 0 m
.1875 .00375 L
s
.21875 0 m
.21875 .00375 L
s
.28125 0 m
.28125 .00375 L
s
.3125 0 m
.3125 .00375 L
s
.34375 0 m
.34375 .00375 L
s
.40625 0 m
.40625 .00375 L
s
.4375 0 m
.4375 .00375 L
s
.46875 0 m
.46875 .00375 L
s
.53125 0 m
.53125 .00375 L
s
.5625 0 m
.5625 .00375 L
s
.59375 0 m
.59375 .00375 L
s
.65625 0 m
.65625 .00375 L
s
.6875 0 m
.6875 .00375 L
s
.71875 0 m
.71875 .00375 L
s
.78125 0 m
.78125 .00375 L
s
.8125 0 m
.8125 .00375 L
s
.84375 0 m
.84375 .00375 L
s
.90625 0 m
.90625 .00375 L
s
.9375 0 m
.9375 .00375 L
s
.96875 0 m
.96875 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02381 m
.00625 .02381 L
s
gsave
-0.0125 .02381 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .21582 m
.00625 .21582 L
s
gsave
-0.0125 .21582 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .40783 m
.00625 .40783 L
s
gsave
-0.0125 .40783 -84.125 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .59985 m
.00625 .59985 L
s
gsave
-0.0125 .59985 -84.125 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .79186 m
.00625 .79186 L
s
gsave
-0.0125 .79186 -84.125 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .98387 m
.00625 .98387 L
s
gsave
-0.0125 .98387 -84.125 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06221 m
.00375 .06221 L
s
0 .10061 m
.00375 .10061 L
s
0 .13902 m
.00375 .13902 L
s
0 .17742 m
.00375 .17742 L
s
0 .25422 m
.00375 .25422 L
s
0 .29263 m
.00375 .29263 L
s
0 .33103 m
.00375 .33103 L
s
0 .36943 m
.00375 .36943 L
s
0 .44624 m
.00375 .44624 L
s
0 .48464 m
.00375 .48464 L
s
0 .52304 m
.00375 .52304 L
s
0 .56144 m
.00375 .56144 L
s
0 .63825 m
.00375 .63825 L
s
0 .67665 m
.00375 .67665 L
s
0 .71505 m
.00375 .71505 L
s
0 .75346 m
.00375 .75346 L
s
0 .83026 m
.00375 .83026 L
s
0 .86866 m
.00375 .86866 L
s
0 .90707 m
.00375 .90707 L
s
0 .94547 m
.00375 .94547 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -126.375 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.125 .99375 m
.125 1 L
s
.25 .99375 m
.25 1 L
s
.375 .99375 m
.375 1 L
s
.5 .99375 m
.5 1 L
s
.625 .99375 m
.625 1 L
s
.75 .99375 m
.75 1 L
s
.875 .99375 m
.875 1 L
s
.125 Mabswid
.03125 .99625 m
.03125 1 L
s
.0625 .99625 m
.0625 1 L
s
.09375 .99625 m
.09375 1 L
s
.15625 .99625 m
.15625 1 L
s
.1875 .99625 m
.1875 1 L
s
.21875 .99625 m
.21875 1 L
s
.28125 .99625 m
.28125 1 L
s
.3125 .99625 m
.3125 1 L
s
.34375 .99625 m
.34375 1 L
s
.40625 .99625 m
.40625 1 L
s
.4375 .99625 m
.4375 1 L
s
.46875 .99625 m
.46875 1 L
s
.53125 .99625 m
.53125 1 L
s
.5625 .99625 m
.5625 1 L
s
.59375 .99625 m
.59375 1 L
s
.65625 .99625 m
.65625 1 L
s
.6875 .99625 m
.6875 1 L
s
.71875 .99625 m
.71875 1 L
s
.78125 .99625 m
.78125 1 L
s
.8125 .99625 m
.8125 1 L
s
.84375 .99625 m
.84375 1 L
s
.90625 .99625 m
.90625 1 L
s
.9375 .99625 m
.9375 1 L
s
.96875 .99625 m
.96875 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .21582 m
1 .21582 L
s
.99375 .40783 m
1 .40783 L
s
.99375 .59985 m
1 .59985 L
s
.99375 .79186 m
1 .79186 L
s
.99375 .98387 m
1 .98387 L
s
.125 Mabswid
.99625 .06221 m
1 .06221 L
s
.99625 .10061 m
1 .10061 L
s
.99625 .13902 m
1 .13902 L
s
.99625 .17742 m
1 .17742 L
s
.99625 .25422 m
1 .25422 L
s
.99625 .29263 m
1 .29263 L
s
.99625 .33103 m
1 .33103 L
s
.99625 .36943 m
1 .36943 L
s
.99625 .44624 m
1 .44624 L
s
.99625 .48464 m
1 .48464 L
s
.99625 .52304 m
1 .52304 L
s
.99625 .56144 m
1 .56144 L
s
.99625 .63825 m
1 .63825 L
s
.99625 .67665 m
1 .67665 L
s
.99625 .71505 m
1 .71505 L
s
.99625 .75346 m
1 .75346 L
s
.99625 .83026 m
1 .83026 L
s
.99625 .86866 m
1 .86866 L
s
.99625 .90707 m
1 .90707 L
s
.99625 .94547 m
1 .94547 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .02381 m
1 .02381 L
s
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
0 .02381 m
0 .10829 L
.03125 .10829 L
.03125 .02381 L
F
0 g
.5 Mabswid
0 .02381 m
0 .10829 L
.03125 .10829 L
.03125 .02381 L
0 .02381 L
s
1 0 0 r
.03125 .02381 m
.03125 .34639 L
.0625 .34639 L
.0625 .02381 L
F
0 g
.03125 .02381 m
.03125 .34639 L
.0625 .34639 L
.0625 .02381 L
.03125 .02381 L
s
1 0 0 r
.0625 .02381 m
.0625 .49232 L
.09375 .49232 L
.09375 .02381 L
F
0 g
.0625 .02381 m
.0625 .49232 L
.09375 .49232 L
.09375 .02381 L
.0625 .02381 L
s
1 0 0 r
.09375 .02381 m
.09375 .58449 L
.125 .58449 L
.125 .02381 L
F
0 g
.09375 .02381 m
.09375 .58449 L
.125 .58449 L
.125 .02381 L
.09375 .02381 L
s
1 0 0 r
.125 .02381 m
.125 .66129 L
.15625 .66129 L
.15625 .02381 L
F
0 g
.125 .02381 m
.125 .66129 L
.15625 .66129 L
.15625 .02381 L
.125 .02381 L
s
1 0 0 r
.15625 .02381 m
.15625 .70737 L
.1875 .70737 L
.1875 .02381 L
F
0 g
.15625 .02381 m
.15625 .70737 L
.1875 .70737 L
.1875 .02381 L
.15625 .02381 L
s
1 0 0 r
.1875 .02381 m
.1875 .76882 L
.21875 .76882 L
.21875 .02381 L
F
0 g
.1875 .02381 m
.1875 .76882 L
.21875 .76882 L
.21875 .02381 L
.1875 .02381 L
s
1 0 0 r
.21875 .02381 m
.21875 .82258 L
.25 .82258 L
.25 .02381 L
F
0 g
.21875 .02381 m
.21875 .82258 L
.25 .82258 L
.25 .02381 L
.21875 .02381 L
s
1 0 0 r
.25 .02381 m
.25 .8533 L
.28125 .8533 L
.28125 .02381 L
F
0 g
.25 .02381 m
.25 .8533 L
.28125 .8533 L
.28125 .02381 L
.25 .02381 L
s
1 0 0 r
.28125 .02381 m
.28125 .87634 L
.3125 .87634 L
.3125 .02381 L
F
0 g
.28125 .02381 m
.28125 .87634 L
.3125 .87634 L
.3125 .02381 L
.28125 .02381 L
s
1 0 0 r
.3125 .02381 m
.3125 .90707 L
.34375 .90707 L
.34375 .02381 L
F
0 g
.3125 .02381 m
.3125 .90707 L
.34375 .90707 L
.34375 .02381 L
.3125 .02381 L
s
1 0 0 r
.34375 .02381 m
.34375 .93011 L
.375 .93011 L
.375 .02381 L
F
0 g
.34375 .02381 m
.34375 .93011 L
.375 .93011 L
.375 .02381 L
.34375 .02381 L
s
1 0 0 r
.375 .02381 m
.375 .93779 L
.40625 .93779 L
.40625 .02381 L
F
0 g
.375 .02381 m
.375 .93779 L
.40625 .93779 L
.40625 .02381 L
.375 .02381 L
s
1 0 0 r
.40625 .02381 m
.40625 .96851 L
.4375 .96851 L
.4375 .02381 L
F
0 g
.40625 .02381 m
.40625 .96851 L
.4375 .96851 L
.4375 .02381 L
.40625 .02381 L
s
1 0 0 r
.4375 .02381 m
.4375 .96851 L
.46875 .96851 L
.46875 .02381 L
F
0 g
.4375 .02381 m
.4375 .96851 L
.46875 .96851 L
.46875 .02381 L
.4375 .02381 L
s
1 0 0 r
.46875 .02381 m
.46875 .96083 L
.5 .96083 L
.5 .02381 L
F
0 g
.46875 .02381 m
.46875 .96083 L
.5 .96083 L
.5 .02381 L
.46875 .02381 L
s
1 0 0 r
.5 .02381 m
.5 .97619 L
.53125 .97619 L
.53125 .02381 L
F
0 g
.5 .02381 m
.5 .97619 L
.53125 .97619 L
.53125 .02381 L
.5 .02381 L
s
1 0 0 r
.53125 .02381 m
.53125 .96083 L
.5625 .96083 L
.5625 .02381 L
F
0 g
.53125 .02381 m
.53125 .96083 L
.5625 .96083 L
.5625 .02381 L
.53125 .02381 L
s
1 0 0 r
.5625 .02381 m
.5625 .96851 L
.59375 .96851 L
.59375 .02381 L
F
0 g
.5625 .02381 m
.5625 .96851 L
.59375 .96851 L
.59375 .02381 L
.5625 .02381 L
s
1 0 0 r
.59375 .02381 m
.59375 .94547 L
.625 .94547 L
.625 .02381 L
F
0 g
.59375 .02381 m
.59375 .94547 L
.625 .94547 L
.625 .02381 L
.59375 .02381 L
s
1 0 0 r
.625 .02381 m
.625 .93779 L
.65625 .93779 L
.65625 .02381 L
F
0 g
.625 .02381 m
.625 .93779 L
.65625 .93779 L
.65625 .02381 L
.625 .02381 L
s
1 0 0 r
.65625 .02381 m
.65625 .89939 L
.6875 .89939 L
.6875 .02381 L
F
0 g
.65625 .02381 m
.65625 .89939 L
.6875 .89939 L
.6875 .02381 L
.65625 .02381 L
s
1 0 0 r
.6875 .02381 m
.6875 .88402 L
.71875 .88402 L
.71875 .02381 L
F
0 g
.6875 .02381 m
.6875 .88402 L
.71875 .88402 L
.71875 .02381 L
.6875 .02381 L
s
1 0 0 r
.71875 .02381 m
.71875 .8533 L
.75 .8533 L
.75 .02381 L
F
0 g
.71875 .02381 m
.71875 .8533 L
.75 .8533 L
.75 .02381 L
.71875 .02381 L
s
1 0 0 r
.75 .02381 m
.75 .8149 L
.78125 .8149 L
.78125 .02381 L
F
0 g
.75 .02381 m
.75 .8149 L
.78125 .8149 L
.78125 .02381 L
.75 .02381 L
s
1 0 0 r
.78125 .02381 m
.78125 .7765 L
.8125 .7765 L
.8125 .02381 L
F
0 g
.78125 .02381 m
.78125 .7765 L
.8125 .7765 L
.8125 .02381 L
.78125 .02381 L
s
1 0 0 r
.8125 .02381 m
.8125 .72273 L
.84375 .72273 L
.84375 .02381 L
F
0 g
.8125 .02381 m
.8125 .72273 L
.84375 .72273 L
.84375 .02381 L
.8125 .02381 L
s
1 0 0 r
.84375 .02381 m
.84375 .64593 L
.875 .64593 L
.875 .02381 L
F
0 g
.84375 .02381 m
.84375 .64593 L
.875 .64593 L
.875 .02381 L
.84375 .02381 L
s
1 0 0 r
.875 .02381 m
.875 .59217 L
.90625 .59217 L
.90625 .02381 L
F
0 g
.875 .02381 m
.875 .59217 L
.90625 .59217 L
.90625 .02381 L
.875 .02381 L
s
1 0 0 r
.90625 .02381 m
.90625 .48464 L
.9375 .48464 L
.9375 .02381 L
F
0 g
.90625 .02381 m
.90625 .48464 L
.9375 .48464 L
.9375 .02381 L
.90625 .02381 L
s
1 0 0 r
.9375 .02381 m
.9375 .34639 L
.96875 .34639 L
.96875 .02381 L
F
0 g
.9375 .02381 m
.9375 .34639 L
.96875 .34639 L
.96875 .02381 L
.9375 .02381 L
s
1 0 0 r
.96875 .02381 m
.96875 .10061 L
1 .10061 L
1 .02381 L
F
0 g
.96875 .02381 m
.96875 .10061 L
1 .10061 L
1 .02381 L
.96875 .02381 L
s
.02 w
.01588 .0242 m
.01707 .0903 L
.01816 .11565 L
.0206 .15577 L
.025 .20679 L
.03014 .25196 L
.035 .28729 L
.05516 .39741 L
.0757 .47974 L
.09799 .55139 L
.13954 .65589 L
.17955 .73355 L
.21801 .79346 L
.25897 .84497 L
.29839 .88465 L
.3403 .91767 L
.36123 .93094 L
.38067 .94145 L
.40066 .95052 L
.4195 .95749 L
.44036 .96346 L
.45928 .96731 L
.46921 .96875 L
.47463 .96937 L
.47969 .96983 L
.48401 .97015 L
.48865 .97041 L
.49129 .97051 L
.49258 .97056 L
.49379 .97059 L
.49485 .97061 L
.49603 .97064 L
.49722 .97065 L
.49847 .97066 L
.49971 .97067 L
.50086 .97067 L
.50212 .97066 L
.50283 .97065 L
.50347 .97064 L
.50477 .97062 L
.50618 .97059 L
.50873 .97051 L
.51111 .97042 L
.51363 .97029 L
.51814 .97 L
.52336 .96956 L
.52824 .96906 L
.53935 .96754 L
.54993 .96562 L
.55997 .96337 L
Mistroke
.57882 .95803 L
.59899 .95066 L
.6177 .94226 L
.65753 .91914 L
.69986 .88621 L
.74065 .8454 L
.77989 .79638 L
.82163 .7315 L
.86183 .65288 L
.90049 .55579 L
.92203 .48775 L
.94164 .41168 L
.9514 .36603 L
.96199 .30681 L
.96685 .27448 L
.972 .23436 L
.9764 .19225 L
.97874 .16467 L
.98125 .12681 L
.98198 .11278 L
.98275 .09508 L
.98341 .07532 L
.98412 .0242 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00SOooool8o`0005Kooooo002>
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0E?ooool008kooooo00?o0000oooo
ooooool00oooool00ol@413oooooooooo`1Dooooo`00S_ooool01?l0003oooooooooool@411Ioooo
o`00S_ooool4o`0005Wooooo002>ooooo`04o`000?oooooooooooa0@45Wooooo002>ooooo`03o`00
0?oooooooooo00?ooooo00?o410@ooooooooool0E?ooool008kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Dooooo`00SOooool8o`0005Kooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo001Eooooo`06onk^k_mEEEGo
0000o`000?mEEEGok^k^1Oooool01?nHV9So0000o`000?nHV9P7ooooo`;o000000?o410@oooooooo
ool00oooool01?nHV9So0000o`000?nHV9P3ooooo`Ko00001_ooool01?nHV9So0000o`000?nHV9P5
ooooo`04oiRHV?l0003o0000oiRHV0Wooooo1_l00006ooooo`04oiRHV?l0003o0000oiRHV0Oooooo
0_l000000ol@413oooooooooo`03ooooo`04oiRHV?l0003o0000oiRHV0Cooooo00Kok^k^oeEEEOl0
003o0000oeEEEOo^k^h5ooooo`04oiRHV?l0003o0000oiRHV0Cooooo00Kok^k^oeEEEOl0003o0000
oeEEEOo^k^h5ooooo`04oiRHV?l0003o0000oiRHV0Kooooo001Eooooo`;oMgMg0_ooool00omgMgOo
EEEEooooo`03ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1oooool00ol0003oooooooooo`03
ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj0_ooool00onHV9So0000omgMg@02ooooo`03oa0@
4?oooooooooo00?ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X3ooooo`06okZj^_lQ8B7ogMgM
omgMgOlQ8B7o^[Zj2?ooool00onHV9So0000omgMg@02ooooo`03oa0@4?oooooooooo00?ooooo00Ko
^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X7ooooo`03o`000?oooooooooo00?ooooo00Ko^[Zjob4Q8OoM
gMgogMgMob4Q8Onj^[X3ooooo`;oMgMg0_ooool00omgMgOoEEEEooooo`03ooooo`06okZj^_lQ8B7o
gMgMomgMgOlQ8B7o^[Zj0oooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Cooooo00Ko^[Zjob4Q
8OoMgMgogMgMob4Q8Onj^[X5ooooo`00EOooool00olQ8B7oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@3ooooo`Ko00001?ooool01_m4A4CoV9RH
ooooooooooooV9RHodA4A0?ooooo00?oQhN7ob4Q8Oo^k^h01oooool01_m4A4CoV9RHoooooooooooo
V9RHodA4A0?ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@9ooooo`03ohN7QolQ8B7ok^k^00Oo
oooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@3ooooo`Ko00001?ooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A0?ooooo00?o8B4Qooooooooool00_ooool00ol0003oooooooooo`02ooooo`06odA4
A?nHV9SooooooooooonHV9SoA4A40oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`00B_ooool6o`0000Gooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooooooo`06o`000003onk^k_l0003ooooo00;ooooo00GoA4A4
okZj^_ooooooooooo`000004ooooo`Oo00001?ooool00onYZJWo8B4Qonk^kP06ooooo`06o`000?o^
k^koooooooooooo^k^ko00000oooool01_l0003ok^k^ooooooooooook^k^o`0000[ooooo00?oZJVY
ob4Q8Oo^k^h01_ooool01_l0003ok^k^ooooooooooook^k^o`0000?ooooo00GoA4A4okZj^_oooooo
ooooo`000005ooooo`06o`000?o^k^koooooooooooo^k^ko00000oooool00ol0003ok^k^ooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Ko0000onk^k_ooooooooooonk^k_l00003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01_l0003ok^k^ooooooooooook^k^o`00
00Gooooo001Eooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE1?ooool00ol0003oooooooooo`02
ooooo`06o`000?oooooooooooooooooMgMgo8B4Q0_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00onHV9So<S8booooo`05ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Wo
oooo00?oV9RHoc8b<_ooool01Oooool00ol0003oooooooooo`02ooooo`06o`000?oooooooooooooo
oooMgMgo8B4Q0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00[o0000
ooooooooooooooooo`000?mEEEGok^k^oooooomgMgOoEEEE1?ooool00ol0003oooooooooo`02oooo
o`06o`000?oooooooooooooooomEEEGoMgMg0_ooool00omgMgOoEEEEooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool005Gooooo00Ko0000ogMgMol0003o0000oeEE
EOo^k^h4ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?mgMgOoV9RH
ooooool00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00om4A4Co
MgMgooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00[ooooo00?oA4A4ogMgMoooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00CoMgMgoiRHV?oooooo00001Oooool00ol0003oooooooooo`02
ooooo`06o`000?ooooooooooooooool0003oMgMg0_l000000omEEEGok^k^ooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooomgMg@04o`000003omgMgOoooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`00EOooool00om4A4CoV9RH
ooooo`07ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool01?o^k^ko8B4Qooooool00005
ooooo`06o`000?o^k^koooooooooooo^k^ko00001_ooool00ooMgMgo410@ooooo`04ooooo`06o`00
0?o^k^koooooooooooo^k^ko00000oooool01_l0003ok^k^ooooooooooook^k^o`0000cooooo00?o
gMgMoa0@4?ooool01?ooool01_l0003ok^k^ooooooooooook^k^o`0000Cooooo00Cok^k^ob4Q8Ooo
oooo00001Oooool01_l0003ok^k^ooooooooooook^k^o`0000?ooooo00?oA4A4oiRHV?ooool01ooo
ool01_l0003ok^k^ooooooooooook^k^o`0000?ooooo00Ko<S8bofIVI_o^k^kok^k^ofIVI_lb<S84
ooooo`06o`000?o^k^koooooooooooo^k^ko00001Oooool005Gooooo00?o^[Zjob4Q8Oooool01ooo
ool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oMgMgoiRHV?l000001Oooool01_m4A4Co
V9RHooooooooooooV9RHodA4A0Oooooo00?o0000ooooooooool00oooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A0?ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@=ooooo`03o`000?oooooooooo
00?ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03ogMgMonHV9So000000Gooooo00Ko
A4A4oiRHV?oooooooooooiRHV?m4A4@3ooooo`03okZj^_lQ8B7ooooo00Oooooo00KoA4A4oiRHV?oo
oooooooooiRHV?m4A4@3ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo001Fooooo`03oeEEEOlb<S;ogMgM00Kooooo00Ko
^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`03onk^k_lb<S;o000000Gooooo00Ko^[Zjob4Q8OoM
gMgogMgMob4Q8Onj^[X2ooooo`06o`000?n7QhOok^k^oooooonHV9SoEEEE1Oooool01_nj^[[o8B4Q
omgMgOoMgMgo8B4QokZj^P?ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X8ooooo`06o`000?n7
QhOok^k^oooooonHV9SoEEEE1Oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00?ok^k^
oc8b<_l000001Oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PCooooo00?oEEEEoc8b<_oMgMd0
1_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^P?ooooo00Ko<S8bofIVI_o^k^kok^k^ofIVI_lb
<S84ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool005Oooooo00CoV9RHob4Q8Ol0003o
8B4Q1Oooool01?nHV9So0000o`000?nHV9P7ooooo`03oiRHV?l@413ooooo00Gooooo00CoV9RHo`00
0?l0003oV9RH0oooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kPKooooo00CoV9RHo`000?l0003o
V9RH1Oooool01?nHV9So0000o`000?nHV9P9ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^1_oo
ool01?nHV9So0000o`000?nHV9P7ooooo`03oiRHV?l@413ooooo00Gooooo00CoV9RHo`000?l0003o
V9RH1_ooool01?nHV9So8B4Qo`000?lQ8B45ooooo`04oiRHV?l0003o0000oiRHV0Cooooo00Kok^k^
odA4A?l0003o0000odA4A?o^k^h5ooooo`04oiRHV?l0003o0000oiRHV0Kooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00A?oooonKo`0000cooooo000iooooo`04oiRHV?l0003o0000oiRHV0Oo
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo000hooooo`06
okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1_ooool00ol0003oooooooooo`2Gooooo`03o`000?oooooo
oooo00[ooooo000hooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41_ooool4o`0009;ooooo0ol0
00000ooooooo0000ooooo`0;ooooo`00>?ooool01_l0003ok^k^ooooooooooook^k^o`0000Kooooo
Vol0000<ooooo`00>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo1?l0
00000ooo003o0000ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
0004o`000003ool00?l0003ooooo00_ooooo000hooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool4o`000003ool00?l0003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool000Co000000?oo`00o`000?ooool02oooool003Sooooo00Ko0000onk^
k_ooooooooooonk^k_l00006ooooo`Co000000?oo`00o`000?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`001?l000000ooo003o0000ooooo`0;ooooo`00>?ooool0
1_m4A4CoV9RHooooooooooooV9RHodA4A0Kooooo1?l000000ooo003o0000ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo0004o`000003ool00?l0003ooooo00_ooooo
000hooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1_ooool4o`000003ool00?l0003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool000Co000000?oo`00o`000?oo
ool02oooool003Wooooo00CoV9RHo`000?l0003oV9RH1oooool4o`000003ool00?l0003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool000Co000000?oo`00o`000?oo
ool02oooool004Cooooo1?l000000ooo003o0000ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo0004o`000003ool00?l0003ooooo00_ooooo0014ooooo`Co000000?o
o`00o`000?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`001?l0
00000ooo003o0000ooooo`0;ooooo`00A?ooool4o`000003ool00?l0003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool000Co000000?oo`00o`000?ooool02oooool0
04Cooooo1?l000000ooo003o0000ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo0004o`000003ool00?l0003ooooo00_ooooo0014ooooo`Co000000?oo`00o`000?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`001?l000000ooo003o
0000ooooo`0;ooooo`00A?ooool6o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool000Ko00003?ooool004Cooooo1_l00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo0004o`000003ooooool0003ooooo00_ooooo0014ooooo`03o`000?oooooo
000000?o00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`001?l00000
0ooooooo0000ooooo`0;ooooo`00A?ooool00ol0003oooooo`000003o`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool000Co000000?oooooo`000?ooool02oooool004Co
oooo00?o0000ooooool000000ol00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo0004o`000003ooooool0003ooooo00_ooooo0014ooooo`03o`000?oooooo000000?o0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`001?l000000ooooooo0000
ooooo`0;ooooo`00A?ooool00ol0003oooooo`000003o`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool000Ko00003?ooool004Cooooo00?o0000ooooool000000ol00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0004o`000003ooooool0003o
oooo00_ooooo0014ooooo`03o`000?oooooo000000?o00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`001?l000000ooooooo0000ooooo`0;ooooo`00A?ooool00ol0003o
ooooo`000003o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool000Co
000000?oooooo`000?ooool02oooool004Cooooo00?o0000ooooool000000ol00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo0004o`000003ooooool0003ooooo00_ooooo
0014ooooo`03o`000?oooooo000000?o00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`001_l0000<ooooo`00A?ooool00ol0003oooooo`000003o`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool000Co000000?oooooo`000?ooool02oooool0
04Cooooo00?o0000ooooool000000ol00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo0004o`000003ooooool0003ooooo00_ooooo000hooooo`05oiRHV?l@413o0000o`00
0?mVIVH01oooool00ol0003oooooooooo`03o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool000?o00000_ooool00ol0003oooooooooo`0:ooooo`00>?ooool01_l@413o
QhN7ooooooooooooMgMgofIVIPKooooo00?o0000ooooooooool00ol00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo0003o`0000;ooooo00?o0000ooooooooool02_ooool0
03gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03o`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool000?o00000_ooool00ol0003oooooooooo`0:oooo
o`00??ooool00oo^k^ko0000ooooo`05ooooo`;o000000Coooooo`000?l0003o00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`000ol000000ooooooo0000o`00000<oooo
o`00>?ooool01_l@413oV9RHooooooooooooMgMgofIVIPKooooo00?o0000ooooooooool00ol00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0003o`0000;ooooo00?o0000
ooooooooool02_ooool003Sooooo00Go0000ob4Q8Ol0003o0000ofIVIP07ooooo`03o`000?oooooo
oooo00?o00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`000ol00002
ooooo`03o`000?oooooooooo00[ooooo000hooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00ol00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0003o`00
00;ooooo00?o0000ooooooooool02_ooool003Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`03o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool000?o
00000_ooool00ol0003oooooooooo`0:ooooo`00>?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00?o00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
0ol00002ooooo`03o`000?oooooooooo00[ooooo000hooooo`Go00001oooool00ol0003ooooooooo
o`03o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00001?l0003oo`00ool00?oo0004o`000003oooo
ool0003o000000cooooo0014ooooo`03o`000?oooooooooo00?o00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00004o`000?oo003oo`00ool000Co00000_ooool00ol0003oooooooooo`0:ooooo`00A?oo
ool00ol0003oooooooooo`04o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001?l0003oo`00ool0
0?oo0003o`0000?ooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool01?l0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Co0000ool00?oo003oo`000ol00003ooooo`03o`00
0?oooooooooo00[ooooo0014ooooo`04o`000?ooooooooooooooo`?o00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00004o`000?oo003oo`00ool000?o00000oooool00ol0003oooooooooo`0:ooooo`00
A?ooool01?l0003oooooooooooooool3o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00004o`0000?ooooo00?o0000ooooooooool02_ooool004Cooooo00Co0000oooooooooooo
oooo0ol00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00001?l00002ooooo`;o
00003?ooool004Cooooo00Co0000oooooooooooooooo0ol00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000ol00004ooooo`03o`000?oooooooooo00[ooooo0014ooooo`04o`00
0?ooooooooooooooo`Co000000?oo`00o`000?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00003o`0000Co
oooo00?o0000ooooooooool02_ooool004Cooooo00Co0000oooooooooooooooo1?l000000ooo003o
0000ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000?o00001?ooool00ol0003oooooooooo`0:ooooo`00
A?ooool00ol0003oooooooooo`02ooooo`?o000000?oo`00o`000?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
o`000003o`0000Cooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool00_oo
ool3o`000003ool00?l0003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?l000000ol00004ooooo`03o`000?oo
oooooooo00[ooooo0014ooooo`03o`000?oooooooooo00;ooooo0ol000000ooo003o0000ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003o000000?o00000oooool2o`0000cooooo0014ooooo`03o`000?oooooooooo
00;ooooo1Ol00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003o000000?o00001?ooool00ol0003oooooooooo`0:oooo
o`00A?ooool00ol0003oooooooooo`02ooooo`Go00001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00o`000003o`0000Co
oooo00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool00_ooool5o`0000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
1_l00004ooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooooooo00?ooooo1?l0
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool000Go00001Oooool00ol0003oooooooooo`0:ooooo`00A?ooool00ol0003oooooooooo`03
ooooo`Co00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo0004o`0000Kooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000oooo
ooooool00oooool4o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`001?l00005ooooo`;o00003?ooool004Cooooo00?o0000oooooooo
ool00oooool4o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`001?l00006ooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`00
0?oooooooooo00?ooooo1?l00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool000Co00001_ooool00ol0003oooooooooo`0:ooooo`00;ooo
ool4o`000003oa0@4?oooooooooo00Cooooo00CoV9RHo`000?l0003oV9RH1_ooool00ol0003ooooo
ooooo`04ooooo`?o00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo0004o`0000Kooooo00?o0000ooooooooool02_ooool0037ooooo00?o
0000ooooooooool01Oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00?o0000oooooooo
ool01?ooool3o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`001?l00006ooooo`03o`000?oooooooooo00[ooooo000aooooo`03o`00
0?oooooooooo00Gooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03o`000?oooooooooo
00Cooooo0ol00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool000?o00001oooool00ol0003oooooooooo`0:ooooo`00<Oooool00ol0003o
ooooooooo`05ooooo`06o`000?o^k^koooooooooooo^k^ko00001Oooool2o`0000Gooooo1?l00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool000?o00001_ooool2o`0000cooooo000aooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo1?l00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
00?o00001oooool00ol0003oooooooooo`0:ooooo`00<Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`?o
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo0003o`0000Oooooo00?o0000ooooooooool02_ooool0037ooooo00?o0000ooooooooool0
1Oooool01_l0003ok^k^ooooooooooook^k^o`0000Gooooo00?o0000ooooooooool01Oooool3o`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00?oo`001?l00007ooooo`03o`000?oooooooooo00[ooooo000aooooo`03o`000?oooooooooo00Go
oooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03o`000?oooooooooo00Gooooo1?l00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000003
ool000Co00001oooool00ol0003oooooooooo`0:ooooo`00;oooool00ol0003oA4A4o`000007oooo
o`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool00ol0003oooooooooo`05ooooo`Co00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000000ooo
0003o`0000Sooooo00?o0000ooooooooool02_ooool002oooooo00?oc<c<oeEEEOl000002?ooool0
1?nHV9So0000o`000?nHV9P6ooooo`03o`000?oooooooooo00Kooooo0ol00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000002ool000Co00001ooo
ool2o`0000cooooo0014ooooo`03o`000?oooooooooo00Kooooo0ol00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000002ool000Co00002?ooool0
0ol0003oooooooooo`0:ooooo`004?ooool00onj^[[o<S8booooo`0>ooooo`03oc8b<_nj^[[ooooo
023ooooo00?o0000ooooooooool01_ooool3o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000;oo`000ol00009ooooo`03o`000?oooooooooo
00[ooooo0003ooooo`03o`000?oooooooooo00[ooooo00?o<S8bokZj^_ooool03_ooool00onj^[[o
<S8booooo`0Pooooo`03o`000?oooooooooo00Kooooo1?l000000ooo003o0000ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000000_oo0003o`0000Wooooo00?o0000oooooooo
ool02_ooool000?ooooo00?o<S8bokZj^_ooool02Oooool00oo<c<co<S8booooo`0@ooooo`03oc8b
<_o<c<cooooo01oooooo00?o0000ooooooooool01_ooool4o`000003ool00?l0003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Ko0000ool00?oo003oo`00o`000?oo0004o`0000Wooooo00?o0000oooooooo
ool02_ooool000?ooooo00?oMgMgohN7QomgMgL00_l000000om4A4Coc<c<ooooo`04ooooo`03ofIV
I_nYZJWooooo00Cooooo2?l00004ooooo`03oiRHV?mVIVKooooo01oooooo00?o0000ooooooooool0
1_ooool4o`000003ool00?l0003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Ko0000ool00?oo003oo`00
o`000?oo0004o`0000Wooooo00?o0000ooooooooool02_ooool000?ooooo00SoV9RHoa0@4?n7QhOo
k^k^oooooonHV9So410@olc<c0Cooooo00?o<S8booooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?ok^k^oc8b<_ooool07oooool00ol0003oooooooooo`06
ooooo`Ko00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001?l0003oo`00ool00?oo0006o`0000Sooooo0_l0000<
ooooo`000oooool00onj^[[o<S8booooo`03ooooo`03oiRHV?m4A4Cooooo00?ooooo00?o<S8boooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03oa0@4?oooooooooo00?ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`06ooooo`Ko00001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001_l0003o
o`00ool00?oo003o0000ooooo`?o00002_ooool00ol0003oooooooooo`0:ooooo`001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o<S8booooooooool01Oooool01?l0
003oooooooooool@4108ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool4
o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Co0000ool00?oo003oo`001Ol0000:ooooo`03o`000?oooooo
oooo00[ooooo0004ooooo`03odA4A?nHV9Sooooo00;ooooo00?ok^k^o`000?ooool00oooool00olQ
8B7oooooooooo`05ooooo`Co00002?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Sooooo1?l00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00004o`000?oo003oo`00ool000Go00002_ooool00ol0
003oooooooooo`0:ooooo`001?ooool01onj^[[o0000okZj^_ooooook^k^ofIVI_mEEED01?ooool0
0olb<S;ok^k^ooooo`05ooooo`04o`000?oooooooooooa0@40Oooooo00?ogMgMoc8b<_ooool07ooo
ool00ol0003oooooooooo`08ooooo`Co00001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001?l0003oo`00ool00?oo
0004o`0000_ooooo00?o0000ooooooooool02_ooool000Gooooo00KoZJVYob4Q8Ol0003o0000oeEE
EOo^k^h4ooooo`03ofIVI_nHV9Sooooo00Gooooo00?o0000ooooooooool00oooool00ol@413ooooo
ooooo`02ooooo`03oiRHV?mVIVKooooo01oooooo00?o0000ooooooooool02Oooool3o`0000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Co0000ool00?oo003oo`001?l0000;ooooo`03o`000?oooooooooo00[ooooo
000?ooooo`03omgMgOlQ8B7ooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03oa0@4?o<c<cooooo01oooooo00?o0000ooooooooool02Oooool4o`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Co0000ool00?oo003oo`001?l0000:ooooo`;o00003?ooool0013ooooo00?o<S8b
okZj^_ooool00oooool8o`0000?ooooo00?o^[Zjoc8b<_ooool08?ooool00ol0003oooooooooo`09
ooooo`Co00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001?l0003oo`00ool00?oo0003o`0000cooooo00?o0000
ooooooooool02_ooool0013ooooo00?o^[Zjoc8b<_ooool03_ooool00olb<S;o^[Zjooooo`0Poooo
o`03o`000?oooooooooo00[ooooo0ol00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00004o`000?oo003oo`00ool0
00?o00003?ooool00ol0003oooooooooo`0:ooooo`00A?ooool00ol0003oooooooooo`0:ooooo`Co
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00004o`0000cooooo00?o0000ooooooooool0
2_ooool004Cooooo00?o0000ooooooooool02_ooool4o`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00001?l0000<ooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooooooo
00_ooooo1?l000000ooo003o0000ool00003ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003o`0000gooooo00?o0000oooooooo
ool02_ooool004Cooooo00?o0000ooooooooool02oooool4o`000003ool00?l0003oo`0000?oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003o000000?o00003?ooool2o`0000cooooo0014ooooo`03o`000?oooooooooo00_ooooo1?l00000
0ooo003o0000ool00003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00o`000003o`0000gooooo00?o0000ooooooooool02_ooool004Co
oooo00?o0000ooooooooool02oooool6o`0000Coo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003o000000;o00003_ooool00ol0003ooooo
ooooo`0:ooooo`00;oooool4o`000003oa0@4?oooooooooo00?ooooo00GoV9RHoa0@4?l0003o0000
ofIVIP06ooooo`03o`000?oooooooooo00_ooooo1_l00004ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo0005o`0000kooooo00?o0000ooooooooool02_oo
ool0037ooooo00?o0000ooooooooool01Oooool01_l@413oQhN7ooooooooooooMgMgofIVIPGooooo
00?o0000ooooooooool03Oooool4o`0000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool000Go00003_ooool00ol0003oooooooooo`0:ooooo`00<Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool4
o`0000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
00Co00003oooool00ol0003oooooooooo`0:ooooo`00<Oooool00ol0003oooooooooo`09ooooo`03
onk^k_l0003ooooo00Cooooo0_l0000>ooooo`Co00001?oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`001?l0000>ooooo`;o00003?ooool0037ooooo00?o
0000ooooooooool01Oooool01_l@413oV9RHooooooooooooMgMgofIVIPGooooo00?o0000oooooooo
ool03_ooool4o`0000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool000?o00004?ooool00ol0003oooooooooo`0:ooooo`00<Oooool00ol0003ooooooooo
o`05ooooo`05o`000?lQ8B7o0000o`000?mVIVH01_ooool00ol0003oooooooooo`0>ooooo`Co0000
0ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00004o`000?oo003oo`00ool000Co0000
4?ooool00ol0003oooooooooo`0:ooooo`00<Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool03oooool3o`0000?oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001?l0003oo`00ool00?oo0004o`00013ooooo00?o0000ooooooooool02_oo
ool0037ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00oooooo1?l00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00001?l0000Aooooo`03o`000?oooooooooo00[ooooo000_ooooo`03o`000?m4A4Co000000Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`Co00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000Co00004Oooool00ol0003ooooo
ooooo`0:ooooo`00;oooool00oo<c<coEEEEo`000007ooooo`Go00001_ooool00ol0003ooooooooo
o`0@ooooo`?o00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?o00004Oooool2o`0000cooooo0014ooooo`03o`000?oooooooooo013ooooo1?l000000ooo
003o0000ool00003ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool000Ko00004_ooool00ol0003oooooooooo`0:ooooo`00
A?ooool00ol0003oooooooooo`0@ooooo`Co000000?oo`00o`000?oo00000ooo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oooooo`000003o`0001;ooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000
ooooooooool04?ooool6o`0000Coo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`001Ol0000Cooooo`03o`000?oooooooooo
00[ooooo0014ooooo`03o`000?oooooooooo017ooooo1Ol00004ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000Go0000
4oooool00ol0003oooooooooo`0:ooooo`00A?ooool00ol0003oooooooooo`0Booooo`Co00001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo0004o`0001?ooooo0_l0000<ooooo`00A?ooool00ol0003oooooooooo`0Boooo
o`Co00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000Co0000ool00?oo003oo`001Ol0000Dooooo`03o`000?oooooooooo00[ooooo0014ooooo`03
o`000?oooooooooo01?ooooo1?l00003ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00001?l0003oo`00ool00?oo0004o`0001Gooooo00?o0000oooooooo
ool02_ooool004Cooooo00?o0000ooooooooool04oooool4o`0000?oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000Co00005_oo
ool00ol0003oooooooooo`0:ooooo`00A?ooool00ol0003oooooooooo`0Dooooo`Co00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00001?l0000Fooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooooooo01Co
oooo1ol00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?l000000ol0000Gooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooo
oooo01Gooooo1?l000000ooooooo0000ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`001_l0000Fooooo`;o00003?ooool004Cooooo00?o0000ooooooooool0
5Oooool4o`000003ooooool0003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo0006o`0001Oooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000oooo
ooooool05_ooool5o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo0006o`0001Oooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool05_oo
ool5o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0004o`00
01Wooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool05oooool4o`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Co0000ool00?oo003oo`001?l0000Jooooo`03o`00
0?oooooooooo00[ooooo0014ooooo`03o`000?oooooooooo01Oooooo1Ol00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000Go00006_ooool00ol0003oooooooooo`0:oooo
o`00A?ooool00ol0003oooooooooo`0Hooooo`Co00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00004o`0001[ooooo0_l0000<ooooo`00A?ooool00ol0003oooooooooo`0I
ooooo`Co000000?oo`00o`000?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?l000000ol0000Looooo`03
o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooooooo01Wooooo1_l00004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00o`000003o`0001cooooo00?o0000ooooooooool02_ooool002kooooo1_l00006oooo
o`04oiRHV?l0003o0000oiRHV0Kooooo00?o0000ooooooooool06_ooool5o`0000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool000Ko
00007?ooool00ol0003oooooooooo`0:ooooo`00;_ooool00onHV9So0000omgMg@02ooooo`03oa0@
4?oooooooooo00?ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`03o`000?oooooooooo
01_ooooo1?l00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo0006o`0001cooooo00?o0000ooooooooool02_ooool002oooooo00?o
QhN7ob4Q8Oo^k^h01oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?o0000oooooooo
ool06oooool5o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool000Co00007_ooool00ol0003oooooooooo`0:ooooo`00<?ooool0
0onYZJWo8B4Qonk^kP06ooooo`06o`000?o^k^koooooooooooo^k^ko00001Oooool2o`0001gooooo
1?l00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000000ooo0004o`0001kooooo0_l0000<ooooo`00<Oooool00onHV9So<S8booooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Moooo
o`Co00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000?oo`001?l0000Oooooo`03o`000?oooooooooo00[ooooo000booooo`03odA4A?mg
MgOooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01gooooo1Ol000000ooo003o0000ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000;oo`001?l0000Pooooo`03o`000?oooooooooo00[ooooo000booooo`03
omgMgOl@413ooooo00Cooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooo`03o`000?oooooo
oooo01kooooo1_l00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001_l0003oo`00ool00?oo003o0000ool0
00Go00008?ooool00ol0003oooooooooo`0:ooooo`00<oooool00ol0003oooooooooo`03ooooo`06
odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00ol0003oooooooooo`0Nooooo`Ko00001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Co0000ool00?oo003oo`001_l0000Qooooo`03o`000?oooooooooo00[o
oooo000^ooooo`06o`000?n7QhOok^k^oooooonHV9SoEEEE1Oooool01_nj^[[o8B4QomgMgOoMgMgo
8B4QokZj^PGooooo00?o0000ooooooooool07_ooool7o`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00004
o`000?oo003oo`00ool000Go00008_ooool00ol0003oooooooooo`0:ooooo`00;_ooool01_nYZJWo
<S8bo`000?l0003oEEEEonk^kPKooooo00CoV9RHo`000?l0003oV9RH1_ooool00ol0003ooooooooo
o`0Qooooo`Go00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00001Ol0000Rooooo`;o
00003?ooool004Cooooo00?o0000ooooooooool08_ooool5o`000003ool00?l0003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00o`000004o`0002Cooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000oooooooo
ool08oooool4o`000003ool00?l0003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00o`000003o`0002Gooooo00?o0000
ooooooooool02_ooool004Cooooo00?o0000ooooooooool08oooool6o`0000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0005o`0002Kooooo00?o
0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool08oooool6o`0000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0005o`0002Kooooo
00?o0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool09Oooool5o`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Co0000ool00?oo003oo`001Ol0000Woooo
o`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooooooo02Kooooo1Ol00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000Go00009oooool2
o`0000cooooo0014ooooo`03o`000?oooooooooo02Oooooo1ol00004ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00o`000004o`0002Wooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000
ooooooooool0:?ooool6o`0000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000Ko0000:_ooool00ol0003ooooo
ooooo`0:ooooo`00A?ooool00ol0003oooooooooo`0Yooooo`Ko00000ooo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00004o`000?oo003oo`00ool0
00Ko0000:oooool00ol0003oooooooooo`0:ooooo`00A?ooool00ol0003oooooooooo`0Zooooo`Ko
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003o000000Ko0000;?ooool00ol0003oooooooooo`0:ooooo`00A?ooool00ol0
003oooooooooo`0/ooooo`Go000000?oo`00o`000?oo00000ooo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo0007o`0002kooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000
ooooooooool0;Oooool6o`0000Coo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
1_l0000^ooooo`;o00003?ooool004Cooooo00?o0000ooooooooool0;_ooool6o`0000?oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000Ko0000<Oooool00ol0003oooooooooo`0:ooooo`00
A?ooool00ol0003oooooooooo`0_ooooo`Ko00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`002?l0000boooo
o`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooooooo033ooooo2?l00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00004o`000?oo003oo`00
ool000So0000<oooool00ol0003oooooooooo`0:ooooo`00A?ooool00ol0003oooooooooo`0boooo
o`So000000?oo`00o`000?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?l000002?l0000dooooo`03o`000?oooooooooo00[ooooo0014ooooo`03o`000?oooooooooo
03?ooooo2Ol00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo000;o`0003Cooooo00?o0000
ooooooooool02_ooool004Cooooo00?o0000ooooooooool0=_ooool8o`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000003ool000Oo0000>?ooool2o`0000cooooo0014ooooo`03o`000?oooooooooo
03Sooooo2Ol00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001?l0
003oo`00ool00?oo0009o`0003_ooooo00?o0000ooooooooool02_ooool004Cooooo00?o0000oooo
ooooool0>_oooolAo`0000?oo`003Ol0000looooo`03o`000?oooooooooo00[ooooo000^ooooo`Ko
00001Oooool01OnHV9So410@o`000?l0003oIVIV00Kooooo00?o0000ooooooooool0>ooooolNo`00
03kooooo00?o0000ooooooooool02_ooool002kooooo00?oV9RHo`000?oMgMd00_ooool00ol@413o
ooooooooo`03ooooo`06oa0@4?n7QhOooooooooooomgMgOoIVIV1Oooool00ol0003oooooooooo`0o
oooooaOo0000@Oooool00ol0003oooooooooo`0:ooooo`00;oooool00on7QhOo8B4Qonk^kP0<oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool;o`0004Oooooo00?o0000oooo
ooooool02_ooool0033ooooo00?oZJVYob4Q8Oo^k^h02_ooool00oo^k^ko0000ooooo`04ooooo`;o
0000Uoooool2o`0000cooooo000aooooo`03oiRHV?lb<S;ooooo00Gooooo00Ko410@oiRHV?oooooo
ooooogMgMomVIVH5ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0:ooooo`00<_ooool00om4A4CoMgMgooooo`04ooooo`05o`000?lQ8B7o0000o`00
0?mVIVH01_oooonKo`0000cooooo000booooo`03omgMgOl@413ooooo00Cooooo00?o0000oooooooo
ool0[oooool003?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2_ooooo`00;_oo
ool01_l0003oQhN7onk^k_ooooooV9RHoeEEE@Gooooo00?o0000ooooooooool0[oooool002kooooo
00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h5ooooo`Go0000[Oooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-150.848, -10.0147, 1.03781, \
0.168904}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  " The code below calculates the unfolded sequence of eigenvalues (using the \
same unfolding procedure as for the GOE matrix above) and then determines the \
spacings for these eigenvalues and generates a hisogram of the spacings.  ",
  "As with the GOE matrix above, watch out for eigenvalues with absolute \
value greater than ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(2  N\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(UGUEev = 
      Table[\((GUEev[\([i]\)]*Sqrt[2*n - GUEev[\([i]\)]^2] + 
              2*n*ArcSin[GUEev[\([i]\)]/Sqrt[2*n]] + n*Pi)\)/\((2*Pi)\), {i, 
          1, n}]; SpcGUEev = 
      Table[UGUEev[\([i + 1]\)] - UGUEev[\([i]\)], {i, 1, n - 1}];\n
    \(int\  = \ Table[0 + i/10, {i, 0, 50}];\)\n
    GUEHist = 
      Histogram[SpcGUEev, HistogramCategories \[Rule] int, 
        HistogramScale \[Rule] 1, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<s\>", "\<P(s)\>"}, 
        RotateLabel \[Rule] False]\)\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(UGUEev\\)\\\" is similar to existing symbol \
\\\"\\!\\(GUEev\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.3125 0.0147151 0.612925 [
[.15625 -0.0125 -16.3438 -18 ]
[.15625 -0.0125 16.3438 0 ]
[.3125 -0.0125 -6.78125 -18 ]
[.3125 -0.0125 6.78125 0 ]
[.46875 -0.0125 -16.3438 -18 ]
[.46875 -0.0125 16.3438 0 ]
[.625 -0.0125 -6.78125 -18 ]
[.625 -0.0125 6.78125 0 ]
[.78125 -0.0125 -16.3438 -18 ]
[.78125 -0.0125 16.3438 0 ]
[.9375 -0.0125 -6.78125 -18 ]
[.9375 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .1373 -32.6875 -9 ]
[-0.0125 .1373 0 9 ]
[-0.0125 .25988 -32.6875 -9 ]
[-0.0125 .25988 0 9 ]
[-0.0125 .38247 -32.6875 -9 ]
[-0.0125 .38247 0 9 ]
[-0.0125 .50505 -32.6875 -9 ]
[-0.0125 .50505 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -74.9375 -9 ]
[-0.01875 .30902 -32.6875 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15625 0 m
.15625 .00625 L
s
gsave
.15625 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.3125 0 m
.3125 .00625 L
s
gsave
.3125 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.46875 0 m
.46875 .00625 L
s
gsave
.46875 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.625 0 m
.625 .00625 L
s
gsave
.625 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.78125 0 m
.78125 .00625 L
s
gsave
.78125 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.9375 0 m
.9375 .00625 L
s
gsave
.9375 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.03125 0 m
.03125 .00375 L
s
.0625 0 m
.0625 .00375 L
s
.09375 0 m
.09375 .00375 L
s
.125 0 m
.125 .00375 L
s
.1875 0 m
.1875 .00375 L
s
.21875 0 m
.21875 .00375 L
s
.25 0 m
.25 .00375 L
s
.28125 0 m
.28125 .00375 L
s
.34375 0 m
.34375 .00375 L
s
.375 0 m
.375 .00375 L
s
.40625 0 m
.40625 .00375 L
s
.4375 0 m
.4375 .00375 L
s
.5 0 m
.5 .00375 L
s
.53125 0 m
.53125 .00375 L
s
.5625 0 m
.5625 .00375 L
s
.59375 0 m
.59375 .00375 L
s
.65625 0 m
.65625 .00375 L
s
.6875 0 m
.6875 .00375 L
s
.71875 0 m
.71875 .00375 L
s
.75 0 m
.75 .00375 L
s
.8125 0 m
.8125 .00375 L
s
.84375 0 m
.84375 .00375 L
s
.875 0 m
.875 .00375 L
s
.90625 0 m
.90625 .00375 L
s
.96875 0 m
.96875 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .1373 m
.00625 .1373 L
s
gsave
-0.0125 .1373 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .25988 m
.00625 .25988 L
s
gsave
-0.0125 .25988 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .38247 m
.00625 .38247 L
s
gsave
-0.0125 .38247 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .50505 m
.00625 .50505 L
s
gsave
-0.0125 .50505 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04536 m
.00375 .04536 L
s
0 .07601 m
.00375 .07601 L
s
0 .10665 m
.00375 .10665 L
s
0 .16795 m
.00375 .16795 L
s
0 .19859 m
.00375 .19859 L
s
0 .22924 m
.00375 .22924 L
s
0 .29053 m
.00375 .29053 L
s
0 .32118 m
.00375 .32118 L
s
0 .35182 m
.00375 .35182 L
s
0 .41312 m
.00375 .41312 L
s
0 .44376 m
.00375 .44376 L
s
0 .47441 m
.00375 .47441 L
s
0 .5357 m
.00375 .5357 L
s
0 .56635 m
.00375 .56635 L
s
0 .59699 m
.00375 .59699 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.15625 .61178 m
.15625 .61803 L
s
.3125 .61178 m
.3125 .61803 L
s
.46875 .61178 m
.46875 .61803 L
s
.625 .61178 m
.625 .61803 L
s
.78125 .61178 m
.78125 .61803 L
s
.9375 .61178 m
.9375 .61803 L
s
.125 Mabswid
.03125 .61428 m
.03125 .61803 L
s
.0625 .61428 m
.0625 .61803 L
s
.09375 .61428 m
.09375 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.1875 .61428 m
.1875 .61803 L
s
.21875 .61428 m
.21875 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.28125 .61428 m
.28125 .61803 L
s
.34375 .61428 m
.34375 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.40625 .61428 m
.40625 .61803 L
s
.4375 .61428 m
.4375 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.53125 .61428 m
.53125 .61803 L
s
.5625 .61428 m
.5625 .61803 L
s
.59375 .61428 m
.59375 .61803 L
s
.65625 .61428 m
.65625 .61803 L
s
.6875 .61428 m
.6875 .61803 L
s
.71875 .61428 m
.71875 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.8125 .61428 m
.8125 .61803 L
s
.84375 .61428 m
.84375 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.90625 .61428 m
.90625 .61803 L
s
.96875 .61428 m
.96875 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1373 m
1 .1373 L
s
.99375 .25988 m
1 .25988 L
s
.99375 .38247 m
1 .38247 L
s
.99375 .50505 m
1 .50505 L
s
.125 Mabswid
.99625 .04536 m
1 .04536 L
s
.99625 .07601 m
1 .07601 L
s
.99625 .10665 m
1 .10665 L
s
.99625 .16795 m
1 .16795 L
s
.99625 .19859 m
1 .19859 L
s
.99625 .22924 m
1 .22924 L
s
.99625 .29053 m
1 .29053 L
s
.99625 .32118 m
1 .32118 L
s
.99625 .35182 m
1 .35182 L
s
.99625 .41312 m
1 .41312 L
s
.99625 .44376 m
1 .44376 L
s
.99625 .47441 m
1 .47441 L
s
.99625 .5357 m
1 .5357 L
s
.99625 .56635 m
1 .56635 L
s
.99625 .59699 m
1 .59699 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .02085 L
.03125 .02085 L
.03125 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02085 L
.03125 .02085 L
.03125 .01472 L
0 .01472 L
s
1 0 0 r
.03125 .01472 m
.03125 .06581 L
.0625 .06581 L
.0625 .01472 L
F
0 g
.03125 .01472 m
.03125 .06581 L
.0625 .06581 L
.0625 .01472 L
.03125 .01472 L
s
1 0 0 r
.0625 .01472 m
.0625 .12099 L
.09375 .12099 L
.09375 .01472 L
F
0 g
.0625 .01472 m
.0625 .12099 L
.09375 .12099 L
.09375 .01472 L
.0625 .01472 L
s
1 0 0 r
.09375 .01472 m
.09375 .22727 L
.125 .22727 L
.125 .01472 L
F
0 g
.09375 .01472 m
.09375 .22727 L
.125 .22727 L
.125 .01472 L
.09375 .01472 L
s
1 0 0 r
.125 .01472 m
.125 .32128 L
.15625 .32128 L
.15625 .01472 L
F
0 g
.125 .01472 m
.125 .32128 L
.15625 .32128 L
.15625 .01472 L
.125 .01472 L
s
1 0 0 r
.15625 .01472 m
.15625 .47661 L
.1875 .47661 L
.1875 .01472 L
F
0 g
.15625 .01472 m
.15625 .47661 L
.1875 .47661 L
.1875 .01472 L
.15625 .01472 L
s
1 0 0 r
.1875 .01472 m
.1875 .51339 L
.21875 .51339 L
.21875 .01472 L
F
0 g
.1875 .01472 m
.1875 .51339 L
.21875 .51339 L
.21875 .01472 L
.1875 .01472 L
s
1 0 0 r
.21875 .01472 m
.21875 .55018 L
.25 .55018 L
.25 .01472 L
F
0 g
.21875 .01472 m
.21875 .55018 L
.25 .55018 L
.25 .01472 L
.21875 .01472 L
s
1 0 0 r
.25 .01472 m
.25 .51339 L
.28125 .51339 L
.28125 .01472 L
F
0 g
.25 .01472 m
.25 .51339 L
.28125 .51339 L
.28125 .01472 L
.25 .01472 L
s
1 0 0 r
.28125 .01472 m
.28125 .5604 L
.3125 .5604 L
.3125 .01472 L
F
0 g
.28125 .01472 m
.28125 .5604 L
.3125 .5604 L
.3125 .01472 L
.28125 .01472 L
s
1 0 0 r
.3125 .01472 m
.3125 .60332 L
.34375 .60332 L
.34375 .01472 L
F
0 g
.3125 .01472 m
.3125 .60332 L
.34375 .60332 L
.34375 .01472 L
.3125 .01472 L
s
1 0 0 r
.34375 .01472 m
.34375 .48069 L
.375 .48069 L
.375 .01472 L
F
0 g
.34375 .01472 m
.34375 .48069 L
.375 .48069 L
.375 .01472 L
.34375 .01472 L
s
1 0 0 r
.375 .01472 m
.375 .44391 L
.40625 .44391 L
.40625 .01472 L
F
0 g
.375 .01472 m
.375 .44391 L
.40625 .44391 L
.40625 .01472 L
.375 .01472 L
s
1 0 0 r
.40625 .01472 m
.40625 .34989 L
.4375 .34989 L
.4375 .01472 L
F
0 g
.40625 .01472 m
.40625 .34989 L
.4375 .34989 L
.4375 .01472 L
.40625 .01472 L
s
1 0 0 r
.4375 .01472 m
.4375 .31719 L
.46875 .31719 L
.46875 .01472 L
F
0 g
.4375 .01472 m
.4375 .31719 L
.46875 .31719 L
.46875 .01472 L
.4375 .01472 L
s
1 0 0 r
.46875 .01472 m
.46875 .22727 L
.5 .22727 L
.5 .01472 L
F
0 g
.46875 .01472 m
.46875 .22727 L
.5 .22727 L
.5 .01472 L
.46875 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .19661 L
.53125 .19661 L
.53125 .01472 L
F
0 g
.5 .01472 m
.5 .19661 L
.53125 .19661 L
.53125 .01472 L
.5 .01472 L
s
1 0 0 r
.53125 .01472 m
.53125 .13121 L
.5625 .13121 L
.5625 .01472 L
F
0 g
.53125 .01472 m
.53125 .13121 L
.5625 .13121 L
.5625 .01472 L
.53125 .01472 L
s
1 0 0 r
.5625 .01472 m
.5625 .12508 L
.59375 .12508 L
.59375 .01472 L
F
0 g
.5625 .01472 m
.5625 .12508 L
.59375 .12508 L
.59375 .01472 L
.5625 .01472 L
s
1 0 0 r
.59375 .01472 m
.59375 .07807 L
.625 .07807 L
.625 .01472 L
F
0 g
.59375 .01472 m
.59375 .07807 L
.625 .07807 L
.625 .01472 L
.59375 .01472 L
s
1 0 0 r
.625 .01472 m
.625 .05559 L
.65625 .05559 L
.65625 .01472 L
F
0 g
.625 .01472 m
.625 .05559 L
.65625 .05559 L
.65625 .01472 L
.625 .01472 L
s
1 0 0 r
.65625 .01472 m
.65625 .03515 L
.6875 .03515 L
.6875 .01472 L
F
0 g
.65625 .01472 m
.65625 .03515 L
.6875 .03515 L
.6875 .01472 L
.65625 .01472 L
s
1 0 0 r
.6875 .01472 m
.6875 .03924 L
.71875 .03924 L
.71875 .01472 L
F
0 g
.6875 .01472 m
.6875 .03924 L
.71875 .03924 L
.71875 .01472 L
.6875 .01472 L
s
1 0 0 r
.71875 .01472 m
.71875 .02289 L
.75 .02289 L
.75 .01472 L
F
0 g
.71875 .01472 m
.71875 .02289 L
.75 .02289 L
.75 .01472 L
.71875 .01472 L
s
1 0 0 r
.75 .01472 m
.75 .01472 L
.78125 .01472 L
.78125 .01472 L
F
0 g
.75 .01472 m
.75 .01472 L
.78125 .01472 L
.78125 .01472 L
.75 .01472 L
s
1 0 0 r
.78125 .01472 m
.78125 .0188 L
.8125 .0188 L
.8125 .01472 L
F
0 g
.78125 .01472 m
.78125 .0188 L
.8125 .0188 L
.8125 .01472 L
.78125 .01472 L
s
1 0 0 r
.8125 .01472 m
.8125 .01472 L
.84375 .01472 L
.84375 .01472 L
F
0 g
.8125 .01472 m
.8125 .01472 L
.84375 .01472 L
.84375 .01472 L
.8125 .01472 L
s
1 0 0 r
.84375 .01472 m
.84375 .01472 L
.875 .01472 L
.875 .01472 L
F
0 g
.84375 .01472 m
.84375 .01472 L
.875 .01472 L
.875 .01472 L
.84375 .01472 L
s
1 0 0 r
.875 .01472 m
.875 .01472 L
.90625 .01472 L
.90625 .01472 L
F
0 g
.875 .01472 m
.875 .01472 L
.90625 .01472 L
.90625 .01472 L
.875 .01472 L
s
1 0 0 r
.90625 .01472 m
.90625 .01472 L
.9375 .01472 L
.9375 .01472 L
F
0 g
.90625 .01472 m
.90625 .01472 L
.9375 .01472 L
.9375 .01472 L
.90625 .01472 L
s
1 0 0 r
.9375 .01472 m
.9375 .01472 L
.96875 .01472 L
.96875 .01472 L
F
0 g
.9375 .01472 m
.9375 .01472 L
.96875 .01472 L
.96875 .01472 L
.9375 .01472 L
s
1 0 0 r
.96875 .01472 m
.96875 .01676 L
1 .01676 L
1 .01472 L
F
0 g
.96875 .01472 m
.96875 .01676 L
1 .01676 L
1 .01472 L
.96875 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo002Hooooo`03oa0@4?lb<S;o410@00;o000000?oA4A4olc<
c?ooool0Boooool009Sooooo00?o0000oiRHV?o^k^h00_ooool00on7QhOo410@ooooo`1;ooooo`00
WOooool00onj^[[o0000ooooo`1;ooooo`00V?ooool00oo<c<coA4A4o`000003o`000003oiRHV?oo
oooooooo04[ooooo002Hooooo`05o`000?n7QhOo^[ZjokZj^_o<c<`0C_ooool009Sooooo00?o0000
oiRHV?ooool00_ooool00oo<c<co410@ooooo`1;ooooo`00V?ooool01oo<c<coA4A4o`000?l0003o
410@oc8b<_l00000C?ooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00F_ooool01?nHV9So0000o`000?nHV9P6
ooooo`03oeEEEOl0003oEEEE00Kooooo00GoV9RHoa0@4?l0003o0000ofIVIP09ooooo`Co000000?o
410@ooooooooool02?ooool4o`000003oa0@4?oooooooooo00Cooooo00?oEEEEo`000?mEEED01_oo
ool01OnHV9So410@o`000?l0003oIVIV00Sooooo1_l00009ooooo`Ko00001_ooool00omEEEGo0000
oeEEE@06ooooo`05oiRHV?l@413o0000o`000?mVIVH02Oooool01OnYZJWo8B4Qo`000?l0003oIVIV
00Wooooo001Iooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo00Ko410@
ohN7QoooooooooooogMgMomVIVH:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1_ooool3o`0000Kooooo00Ko410@ohN7QoooooooooooogMgMomVIVH7ooooo`03oiRHV?l0003ogMgM
00;ooooo00?o410@ooooooooool01oooool00onHV9So0000omgMg@02ooooo`03oa0@4?oooooooooo
00Cooooo0ol00006ooooo`06oa0@4?n7QhOooooooooooomgMgOoIVIV2?ooool01_l@413oc<c<oooo
ooooooooMgMgofIVIPSooooo001Iooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omE
EEGo0000oeEEE@0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`06ooooo`03oeEEEOl0003oEEEE00_ooooo00?o0000ooooooooool01_ooool00on7
QhOo8B4Qonk^kP0<ooooo`03ohN7QolQ8B7ok^k^00Sooooo00?oEEEEo`000?mEEED02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo001Iooooo`06o`000?o^k^kooooooooo
ooo^k^ko00004_ooool00oo^k^ko0000ooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool04oooool00oo^k^ko0000ooooo`08ooooo`03ojVYZOlQ8B7ok^k^00cooooo00?oZJVY
ob4Q8Oo^k^h05?ooool00oo^k^ko0000ooooo`0<ooooo`03o`000?oooooooooo00Kooooo001Ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01_l@413oV9RHoooooooooooo
MgMgofIVIP[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`06oa0@4?nH
V9SooooooooooomgMgOoIVIV2_ooool00onHV9So<S8booooo`0<ooooo`03oiRHV?lb<S;ooooo00oo
oooo00Ko410@oiRHV?ooooooooooogMgMomVIVH<ooooo`03ojVYZOm4A4Cooooo00Oooooo001Ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01Ol0003o8B4Qo`000?l0003o
IVIV00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`05o`000?lQ8B7o
0000o`000?mVIVH03?ooool00om4A4CoMgMgooooo`0<ooooo`03odA4A?mgMgOooooo00kooooo00Go
0000ob4Q8Ol0003o0000ofIVIP0;ooooo`04ob4Q8Ol0003o0000omgMg@Sooooo001Iooooo`06o`00
0?o^k^koooooooooooo^k^ko00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03omgMgOl@413ooooo
00cooooo00?ogMgMoa0@4?ooool03_ooool00ol0003oooooooooo`0?ooooo`03ojVYZOlb<S;ooooo
00Oooooo001Iooooo`06odA4A?nHV9SooooooooooonHV9SoA4A43_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Kooooo001Iooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?m4A4Co000000cooooo00?o0000odA4A?l000004Ooo
ool00ol0003oooooooooo`0:ooooo`06o`000?n7QhOok^k^oooooonHV9SoEEEE2Oooool01_l0003o
QhN7onk^k_ooooooV9RHoeEEE@oooooo00?o0000ooooooooool02oooool01_lQ8B7o^[Zjoooooooo
ooooIVIVoc8b<PSooooo001Jooooo`04oiRHV?l0003o0000oiRHV0oooooo1Ol00009ooooo`03olc<
c?mEEEGo000000cooooo00?oc<c<oeEEEOl000004Oooool5o`0000Sooooo00KoZJVYoc8b<_l0003o
0000oeEEEOo^k^h9ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^3oooool5o`0000Wooooo00Ko
^[ZjodA4A?l0003o0000odA4A?o^k^h8ooooo`00joooool00>_ooooo003[ooooo`00joooool004?o
oooo00CoV9RHo`000?l0003oV9RH1_oooonMo`00007ooooo0012ooooo`06okZj^_lQ8B7ogMgMomgM
gOlQ8B7o^[Zj1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000Oooool004;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5
ooooo`03o`000?oooooooooo07?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000007ooooo
0012ooooo`06o`000?o^k^koooooooooooo^k^ko00001OoooonMo`00007ooooo0012ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool6o`0000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0004o`000?oo003oo`00ool000Ko00009_ooool1o`00007ooooo0012ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000:oooool1o`00007ooooo
0012ooooo`06o`000?o^k^koooooooooooo^k^ko00001Oooool00ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo000:o`0002_ooooo0Ol00001ooooo`00@_ooool01_m4A4CoV9RHoooooooooooo
V9RHodA4A0Gooooo0_l00003ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0booooo`7o
00000Oooool004;ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`03o`000?oooooooooo
00;ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oooooooooo03;ooooo0Ol00001ooooo`00@oooool0
1?nHV9So0000o`000?nHV9P6ooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0006o`0003Cooooo0Ol00001ooooo`00
COooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0=oooool1o`00007ooooo001=ooooo`03
o`000?oooooooooo00;ooooo1_l00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0g
ooooo`7o00000Oooool004gooooo0_l00008ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0006o`0003Wooooo0Ol0
0001ooooo`00COooool00ol0003oooooooooo`07ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`0looooo`7o00000Oooool004gooooo00?o0000ooooooooool01oooool00ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0??ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00Oooooo
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oooooooooo03cooooo0Ol00001ooooo`00COooool00ol0003o
ooooooooo`07ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0looooo`7o00000Oooool0
04gooooo0_l00008ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0looooo`7o00000Ooo
ool004gooooo00?o0000ooooooooool01oooool00ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
??ooool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED0
1Oooool6o`0000Gooooo00?o0000ooooooooool01oooool6o`0000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0??ooool1o`00007ooooo000_ooooo`06
okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Gooooo00?oV9RHo`000?oMgMd00_ooool0
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`001_l0000nooooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oooooooooo
oiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?oQhN7ob4Q8Oo^k^h01oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo0006o`0004?ooooo0Ol00001ooooo`00;oooool01_l0
003ok^k^ooooooooooook^k^o`0000oooooo00?oZJVYob4Q8Oo^k^h01_ooool2o`0000gooooo00?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oooooooooo04Gooooo0_l00001ooooo`00;oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00kooooo00?oV9RHoc8b<_ooool01Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`16ooooo`7o00000Oooool002oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03odA4A?mgMgOooooo00Co
oooo00?o0000ooooooooool03?ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0A_ooool1
o`00007ooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00004Oooool00ooMgMgo410@oooo
o`04ooooo`03o`000?oooooooooo00cooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo04Ko
oooo0Ol00001ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A1;ooooo00?o0000oooo
ooooool00oooool2o`0000gooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo04Kooooo0Ol0
0001ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pgooooo00Ko0000ohN7Qoo^k^ko
oooooiRHV?mEEED5ooooo`03o`000?oooooooooo00cooooo00?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
oooooooo04Kooooo0Ol00001ooooo`00<?ooool01?nHV9So0000o`000?nHV9P>ooooo`06ojVYZOlb
<S;o0000o`000?mEEEGok^k^1Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`16ooooo`7o00000Oooool004gooooo00?o0000ooooooooool03?ooool00ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0A_ooool1o`00007ooooo001=ooooo`03o`000?oooooo
oooo00cooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo04Kooooo0Ol00001ooooo`00COoo
ool2o`0000gooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo0006o`0004Sooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0<ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000oooo
ooooool0Boooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00cooooo00?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`1;
ooooo`7o00000Oooool004gooooo00?o0000ooooooooool03?ooool00ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooooooo04_ooooo0Ol0
0001ooooo`00COooool00ol0003oooooooooo`0<ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool0Boooool1o`00007ooooo
001=ooooo`;o00003Oooool6o`0000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Co0000ool00?oo003oo`001_l0001=ooooo`7o00000Oooool004gooooo
00?o0000ooooooooool04Oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000D_ooool1o`00
007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED02Oooool2o`00
0003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l00000D_ooool1o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj
1Oooool3o`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`00001Booooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oo
oooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo1_l00004ooooo`03o`000?oooooo
oooo017ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000005;ooooo0Ol00001ooooo`00;ooo
ool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00GoA4A4okZj^_ooooooooooo`000005oooo
o`;o00004_ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000DOooool2o`00007ooooo000@
ooooo`03okZj^_lb<S;ooooo00kooooo00?o<S8bokZj^_ooool02oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00cooooo00GogMgMob4Q8Oooooooooooo`000005ooooo`03o`000?oo
oooooooo017ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000005;ooooo0Ol00001ooooo`00
4?ooool00olb<S;o^[Zjooooo`0>ooooo`03okZj^_lb<S;ooooo00_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0=ooooo`04ogMgMonHV9Soooooo`0000Gooooo00?o0000oooooooo
ool04Oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000D_ooool1o`00007ooooo000?oooo
o`03olc<c?lb<S;ooooo013ooooo00?o<S8bolc<c?ooool02_ooool01_l0003ok^k^oooooooooooo
k^k^o`0000oooooo00Cok^k^ob4Q8Ooooooo00001Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`00001Booooo`7o00000Oooool000;ooooo00Go410@o`000?l0
003o0000oa0@4008ooooo`03ofIVI_nYZJWooooo00Cooooo00?o410@oc8b<_l@41000_l000000om4
A4Coc<c<ooooo`04ooooo`03oiRHV?mVIVKooooo00[ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4
A4@@ooooo`03ogMgMonHV9So000000Gooooo00?o0000ooooooooool04Oooool00ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l00000D_ooool1o`00007ooooo0004ooooo`03o`000?oooooooooo00Sooooo
00?o<S8booooooooool01?ooool00ol0003oV9RHonk^kP02ooooo`03ohN7Qol@413ooooo00Cooooo
00?ok^k^oc8b<_ooool02_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Q3ooooo00?ok^k^oc8b
<_l000001Oooool2o`0001;ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000005;ooooo0Ol0
0001ooooo`001?ooool00ol0003oooooooooo`08ooooo`03oc8b<_oooooooooo00Wooooo00?o^[Zj
o`000?ooool01Oooool00ol0003oooooooooo`0:ooooo`04oiRHV?l0003o0000oiRHV1;ooooo00?o
V9RHoa0@4?ooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`00001Booooo`7o00000Oooool000Cooooo0ol000000ol@413oMgMgonk^kP05ooooo`03oc8b
<_oooooooooo00Cooooo00?oc<c<odA4A?l000000ol000000onHV9Soooooooooo`04ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool04Oooool00ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l00000D_ooool1o`00007ooooo0004ooooo`06o`000?ooooooooooonk^k_mgMgOoEEEE1Oooool0
0olQ8B7oooooooooo`04ooooo`05o`000?n7QhOo^[ZjokZj^_o<c<`02?ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo017ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000005;o
oooo0Ol00001ooooo`001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o<S8bonk^k_ooool01?ooool00ol0003oV9RHooooo`02ooooo`03olc<c?l@413ooooo00Cooooo
00?ogMgMoc8b<_ooool0:?ooool2o`0001;ooooo1_l00004ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo0005o`0005;ooooo0Ol00001ooooo`001?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?oIVIVoiRHV?ooool01?ooool01oo<c<coA4A4o`000?l0003o410@oc8b
<_l000001Oooool00onHV9SoIVIVooooo`0Xooooo`03o`000?oooooooooo01Kooooo00?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0E?ooool1
o`00007ooooo0004ooooo`06o`000?ooooooooooonk^k_mgMgOoEEEE1Oooool00ooMgMgo8B4Qoooo
o`0@ooooo`03oa0@4?o<c<cooooo02Sooooo00?o0000ooooooooool05_ooool00ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`1Dooooo`7o0000
0Oooool000;ooooo00?o410@o`000?l000000_l000000ol@413oMgMgonk^kP06ooooo`03oc8b<_nj
^[[ooooo00kooooo00?o^[Zjoc8b<_ooool0:Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo05Cooooo
0Ol00001ooooo`004?ooool00onj^[[o<S8booooo`0>ooooo`03oc8b<_nj^[[ooooo02Wooooo00?o
0000ooooooooool05_ooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`1Dooooo`7o00000Oooool004gooooo0_l0000Gooooo`03o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo0006o`0005Kooooo0Ol00001ooooo`00COooool00ol0003ooooooooo
o`0Fooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`1Iooooo`7o0000
0Oooool0033ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@06ooooo`06onk^
k_mEEEGo0000o`000?mEEEGok^k^1?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oooooooooo`1Iooooo`7o00000Oooool002oooooo00Ko^[Zjob4Q
8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001_ooool2ogMgM`;ooooo00?oMgMgoeEEEOooool00ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`1Iooooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03
oeEEEOl0003oEEEE00Kooooo00?o8B4Qooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Kooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo
05Wooooo0Ol00001ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooooooo`02ooooo`;o00005oooool00ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0F?ooool2o`00007ooooo000_ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03?ooool01_l0003oEEEEonk^k_ooooooMgMgoeEEE@Cooooo
00?o0000ooooooooool05_ooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool0FOooool1o`00007ooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3?ooool01_l0003oMgMgo`000?l0003oEEEEonk^kPCooooo00?o0000ooooooooool05_ooool00ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0FOooool1o`00007ooooo000_oooo
o`06o`000?o^k^koooooooooooo^k^ko00003_ooool00om4A4CoV9RHooooo`07ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo05Wooooo
0Ol00001ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0kooooo00?o^[Zjob4Q8Ooo
ool01oooool00ol0003oooooooooo`0Fooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oooooooooo`1Iooooo`7o00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X?
ooooo`03oeEEEOlb<S;ogMgM00Kooooo0_l0000Gooooo`03o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oooooooooo`1Iooooo`7o00000Oooool0033ooooo00CoV9RHo`000?l0003oV9RH4Ooo
ool01?nHV9So8B4Qo`000?lQ8B44ooooo`03o`000?oooooooooo01Kooooo00?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oooooooooo05Wooooo0Ol00001ooooo`00COooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`1Iooooo`7o
00000Oooool004gooooo00?o0000ooooooooool05_ooool00ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0FOooool1o`00007ooooo001=ooooo`;o00005oooool00ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0FOooool1o`00007ooooo001=ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo0006o`0005_ooooo0Ol00001ooooo`00COooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0G_ooool1o`00007ooooo001=ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`1Nooooo`7o00000Oooool004gooooo
00?o0000ooooooooool05_ooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo05kooooo0Ol00001ooooo`00
COooool2o`0001Oooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`1Nooooo`7o00000Oooool004gooooo
00?o0000ooooooooool05_ooool6o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0006o`00063ooooo
0Ol00001ooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Kooooo
00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h4ooooo`03o`000?oooooooooo01_ooooo00Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oooooooooo06?ooooo0Ol00001ooooo`00;oooool01_nj
^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`06oeEEEOmgMgOooooooooooomgMgOo
EEEE1?ooool00ol0003oooooooooo`0Kooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oooooooooo`1Sooooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5
ooooo`03oeEEEOl0003oEEEE00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01_ooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
oooooooo06?ooooo0Ol00001ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00007?ooool01Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0H_ooool2o`00007ooooo000_ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01_mEEEGoMgMgooooooooooooMgMgoeEE
E@Cooooo00?o0000ooooooooool06oooool5o`0000Coo`001_l00004ool00003o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0Hoooool1o`00007ooooo000_ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03?ooool00ooMgMgo0000o`000002o`000003omgMgOoooooooooo00;o
oooo00?o0000ooooooooool07oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo06?o
oooo0Ol00001ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00Ko<S8bofIV
I_o^k^kok^k^ofIVI_lb<S84ooooo`03o`000?oooooooooo01oooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oooooooooo`1Sooooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRH
V?m4A4@>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0Hoooool1o`00007ooooo
000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool01_lb<S;oIVIVonk^k_o^k^koIVIV
oc8b<PCooooo0_l0000Pooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00_ooool0
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0Hoooool1
o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0oooooo00Kok^k^odA4A?l0003o0000odA4
A?o^k^h4ooooo`03o`000?oooooooooo01oooooo00?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`02ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`1Sooooo`7o00000Oooool004gooooo00?o0000ooooooooool07oooool6o`0000Cooooo00?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo06?ooooo0Ol0
0001ooooo`00COooool00ol0003oooooooooo`0Yooooo`03o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oooooooooo`1Sooooo`7o00000Oooool004gooooo00?o0000oooo
ooooool0:Oooool6o`0000Coo`0000?o0000ooooooooool0Hoooool1o`00007ooooo001=ooooo`;o
0000;oooool00ol0003oo`00ool00002ool00003o`000?oooooooooo06?ooooo0Ol00001ooooo`00
COooool00ol0003oooooooooo`0^ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
Hoooool1o`00007ooooo001=ooooo`03o`000?oooooooooo02kooooo00?o0000ool00?oo00000_oo
00000ol0003oooooooooo`1Sooooo`7o00000Oooool004gooooo00?o0000ooooooooool0;_ooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo06?ooooo0Ol00001ooooo`00COooool2o`00
02oooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`1Sooooo`7o00000Oooool004go
oooo00?o0000ooooooooool0;_ooool6o`0006Gooooo0Ol00001ooooo`00COooool00ol0003ooooo
ooooo`2Iooooo`7o00000Oooool004gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000007ooooo001=oooooigo00000Oooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-1.59709, -0.941837, 0.0205114, \
0.0104577}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The plot below compares the level spacing hisogram of our random \
complex Hermitian matrix to the GUE distribution.  We see that that agreement \
is very good.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[GUEHist, GUE, AspectRatio \[Rule] 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.3125 0.0238095 0.991733 [
[.15625 -0.0125 -16.3438 -18 ]
[.15625 -0.0125 16.3438 0 ]
[.3125 -0.0125 -6.78125 -18 ]
[.3125 -0.0125 6.78125 0 ]
[.46875 -0.0125 -16.3438 -18 ]
[.46875 -0.0125 16.3438 0 ]
[.625 -0.0125 -6.78125 -18 ]
[.625 -0.0125 6.78125 0 ]
[.78125 -0.0125 -16.3438 -18 ]
[.78125 -0.0125 16.3438 0 ]
[.9375 -0.0125 -6.78125 -18 ]
[.9375 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .02381 -13.5625 -9 ]
[-0.0125 .02381 0 9 ]
[-0.0125 .22216 -32.6875 -9 ]
[-0.0125 .22216 0 9 ]
[-0.0125 .4205 -32.6875 -9 ]
[-0.0125 .4205 0 9 ]
[-0.0125 .61885 -32.6875 -9 ]
[-0.0125 .61885 0 9 ]
[-0.0125 .8172 -32.6875 -9 ]
[-0.0125 .8172 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -74.9375 -9 ]
[-0.01875 .5 -32.6875 9 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15625 0 m
.15625 .00625 L
s
gsave
.15625 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.3125 0 m
.3125 .00625 L
s
gsave
.3125 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.46875 0 m
.46875 .00625 L
s
gsave
.46875 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.625 0 m
.625 .00625 L
s
gsave
.625 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.78125 0 m
.78125 .00625 L
s
gsave
.78125 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.9375 0 m
.9375 .00625 L
s
gsave
.9375 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.03125 0 m
.03125 .00375 L
s
.0625 0 m
.0625 .00375 L
s
.09375 0 m
.09375 .00375 L
s
.125 0 m
.125 .00375 L
s
.1875 0 m
.1875 .00375 L
s
.21875 0 m
.21875 .00375 L
s
.25 0 m
.25 .00375 L
s
.28125 0 m
.28125 .00375 L
s
.34375 0 m
.34375 .00375 L
s
.375 0 m
.375 .00375 L
s
.40625 0 m
.40625 .00375 L
s
.4375 0 m
.4375 .00375 L
s
.5 0 m
.5 .00375 L
s
.53125 0 m
.53125 .00375 L
s
.5625 0 m
.5625 .00375 L
s
.59375 0 m
.59375 .00375 L
s
.65625 0 m
.65625 .00375 L
s
.6875 0 m
.6875 .00375 L
s
.71875 0 m
.71875 .00375 L
s
.75 0 m
.75 .00375 L
s
.8125 0 m
.8125 .00375 L
s
.84375 0 m
.84375 .00375 L
s
.875 0 m
.875 .00375 L
s
.90625 0 m
.90625 .00375 L
s
.96875 0 m
.96875 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02381 m
.00625 .02381 L
s
gsave
-0.0125 .02381 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .22216 m
.00625 .22216 L
s
gsave
-0.0125 .22216 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .4205 m
.00625 .4205 L
s
gsave
-0.0125 .4205 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .61885 m
.00625 .61885 L
s
gsave
-0.0125 .61885 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .8172 m
.00625 .8172 L
s
gsave
-0.0125 .8172 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0734 m
.00375 .0734 L
s
0 .12298 m
.00375 .12298 L
s
0 .17257 m
.00375 .17257 L
s
0 .27174 m
.00375 .27174 L
s
0 .32133 m
.00375 .32133 L
s
0 .37092 m
.00375 .37092 L
s
0 .47009 m
.00375 .47009 L
s
0 .51968 m
.00375 .51968 L
s
0 .56926 m
.00375 .56926 L
s
0 .66844 m
.00375 .66844 L
s
0 .71802 m
.00375 .71802 L
s
0 .76761 m
.00375 .76761 L
s
0 .86678 m
.00375 .86678 L
s
0 .91637 m
.00375 .91637 L
s
0 .96596 m
.00375 .96596 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.15625 .99375 m
.15625 1 L
s
.3125 .99375 m
.3125 1 L
s
.46875 .99375 m
.46875 1 L
s
.625 .99375 m
.625 1 L
s
.78125 .99375 m
.78125 1 L
s
.9375 .99375 m
.9375 1 L
s
.125 Mabswid
.03125 .99625 m
.03125 1 L
s
.0625 .99625 m
.0625 1 L
s
.09375 .99625 m
.09375 1 L
s
.125 .99625 m
.125 1 L
s
.1875 .99625 m
.1875 1 L
s
.21875 .99625 m
.21875 1 L
s
.25 .99625 m
.25 1 L
s
.28125 .99625 m
.28125 1 L
s
.34375 .99625 m
.34375 1 L
s
.375 .99625 m
.375 1 L
s
.40625 .99625 m
.40625 1 L
s
.4375 .99625 m
.4375 1 L
s
.5 .99625 m
.5 1 L
s
.53125 .99625 m
.53125 1 L
s
.5625 .99625 m
.5625 1 L
s
.59375 .99625 m
.59375 1 L
s
.65625 .99625 m
.65625 1 L
s
.6875 .99625 m
.6875 1 L
s
.71875 .99625 m
.71875 1 L
s
.75 .99625 m
.75 1 L
s
.8125 .99625 m
.8125 1 L
s
.84375 .99625 m
.84375 1 L
s
.875 .99625 m
.875 1 L
s
.90625 .99625 m
.90625 1 L
s
.96875 .99625 m
.96875 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .22216 m
1 .22216 L
s
.99375 .4205 m
1 .4205 L
s
.99375 .61885 m
1 .61885 L
s
.99375 .8172 m
1 .8172 L
s
.125 Mabswid
.99625 .0734 m
1 .0734 L
s
.99625 .12298 m
1 .12298 L
s
.99625 .17257 m
1 .17257 L
s
.99625 .27174 m
1 .27174 L
s
.99625 .32133 m
1 .32133 L
s
.99625 .37092 m
1 .37092 L
s
.99625 .47009 m
1 .47009 L
s
.99625 .51968 m
1 .51968 L
s
.99625 .56926 m
1 .56926 L
s
.99625 .66844 m
1 .66844 L
s
.99625 .71802 m
1 .71802 L
s
.99625 .76761 m
1 .76761 L
s
.99625 .86678 m
1 .86678 L
s
.99625 .91637 m
1 .91637 L
s
.99625 .96596 m
1 .96596 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .02381 m
1 .02381 L
s
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
0 .02381 m
0 .03373 L
.03125 .03373 L
.03125 .02381 L
F
0 g
.5 Mabswid
0 .02381 m
0 .03373 L
.03125 .03373 L
.03125 .02381 L
0 .02381 L
s
1 0 0 r
.03125 .02381 m
.03125 .10648 L
.0625 .10648 L
.0625 .02381 L
F
0 g
.03125 .02381 m
.03125 .10648 L
.0625 .10648 L
.0625 .02381 L
.03125 .02381 L
s
1 0 0 r
.0625 .02381 m
.0625 .19577 L
.09375 .19577 L
.09375 .02381 L
F
0 g
.0625 .02381 m
.0625 .19577 L
.09375 .19577 L
.09375 .02381 L
.0625 .02381 L
s
1 0 0 r
.09375 .02381 m
.09375 .36772 L
.125 .36772 L
.125 .02381 L
F
0 g
.09375 .02381 m
.09375 .36772 L
.125 .36772 L
.125 .02381 L
.09375 .02381 L
s
1 0 0 r
.125 .02381 m
.125 .51984 L
.15625 .51984 L
.15625 .02381 L
F
0 g
.125 .02381 m
.125 .51984 L
.15625 .51984 L
.15625 .02381 L
.125 .02381 L
s
1 0 0 r
.15625 .02381 m
.15625 .77116 L
.1875 .77116 L
.1875 .02381 L
F
0 g
.15625 .02381 m
.15625 .77116 L
.1875 .77116 L
.1875 .02381 L
.15625 .02381 L
s
1 0 0 r
.1875 .02381 m
.1875 .83069 L
.21875 .83069 L
.21875 .02381 L
F
0 g
.1875 .02381 m
.1875 .83069 L
.21875 .83069 L
.21875 .02381 L
.1875 .02381 L
s
1 0 0 r
.21875 .02381 m
.21875 .89021 L
.25 .89021 L
.25 .02381 L
F
0 g
.21875 .02381 m
.21875 .89021 L
.25 .89021 L
.25 .02381 L
.21875 .02381 L
s
1 0 0 r
.25 .02381 m
.25 .83069 L
.28125 .83069 L
.28125 .02381 L
F
0 g
.25 .02381 m
.25 .83069 L
.28125 .83069 L
.28125 .02381 L
.25 .02381 L
s
1 0 0 r
.28125 .02381 m
.28125 .90675 L
.3125 .90675 L
.3125 .02381 L
F
0 g
.28125 .02381 m
.28125 .90675 L
.3125 .90675 L
.3125 .02381 L
.28125 .02381 L
s
1 0 0 r
.3125 .02381 m
.3125 .97619 L
.34375 .97619 L
.34375 .02381 L
F
0 g
.3125 .02381 m
.3125 .97619 L
.34375 .97619 L
.34375 .02381 L
.3125 .02381 L
s
1 0 0 r
.34375 .02381 m
.34375 .77778 L
.375 .77778 L
.375 .02381 L
F
0 g
.34375 .02381 m
.34375 .77778 L
.375 .77778 L
.375 .02381 L
.34375 .02381 L
s
1 0 0 r
.375 .02381 m
.375 .71825 L
.40625 .71825 L
.40625 .02381 L
F
0 g
.375 .02381 m
.375 .71825 L
.40625 .71825 L
.40625 .02381 L
.375 .02381 L
s
1 0 0 r
.40625 .02381 m
.40625 .56614 L
.4375 .56614 L
.4375 .02381 L
F
0 g
.40625 .02381 m
.40625 .56614 L
.4375 .56614 L
.4375 .02381 L
.40625 .02381 L
s
1 0 0 r
.4375 .02381 m
.4375 .51323 L
.46875 .51323 L
.46875 .02381 L
F
0 g
.4375 .02381 m
.4375 .51323 L
.46875 .51323 L
.46875 .02381 L
.4375 .02381 L
s
1 0 0 r
.46875 .02381 m
.46875 .36772 L
.5 .36772 L
.5 .02381 L
F
0 g
.46875 .02381 m
.46875 .36772 L
.5 .36772 L
.5 .02381 L
.46875 .02381 L
s
1 0 0 r
.5 .02381 m
.5 .31812 L
.53125 .31812 L
.53125 .02381 L
F
0 g
.5 .02381 m
.5 .31812 L
.53125 .31812 L
.53125 .02381 L
.5 .02381 L
s
1 0 0 r
.53125 .02381 m
.53125 .2123 L
.5625 .2123 L
.5625 .02381 L
F
0 g
.53125 .02381 m
.53125 .2123 L
.5625 .2123 L
.5625 .02381 L
.53125 .02381 L
s
1 0 0 r
.5625 .02381 m
.5625 .20238 L
.59375 .20238 L
.59375 .02381 L
F
0 g
.5625 .02381 m
.5625 .20238 L
.59375 .20238 L
.59375 .02381 L
.5625 .02381 L
s
1 0 0 r
.59375 .02381 m
.59375 .12632 L
.625 .12632 L
.625 .02381 L
F
0 g
.59375 .02381 m
.59375 .12632 L
.625 .12632 L
.625 .02381 L
.59375 .02381 L
s
1 0 0 r
.625 .02381 m
.625 .08995 L
.65625 .08995 L
.65625 .02381 L
F
0 g
.625 .02381 m
.625 .08995 L
.65625 .08995 L
.65625 .02381 L
.625 .02381 L
s
1 0 0 r
.65625 .02381 m
.65625 .05688 L
.6875 .05688 L
.6875 .02381 L
F
0 g
.65625 .02381 m
.65625 .05688 L
.6875 .05688 L
.6875 .02381 L
.65625 .02381 L
s
1 0 0 r
.6875 .02381 m
.6875 .06349 L
.71875 .06349 L
.71875 .02381 L
F
0 g
.6875 .02381 m
.6875 .06349 L
.71875 .06349 L
.71875 .02381 L
.6875 .02381 L
s
1 0 0 r
.71875 .02381 m
.71875 .03704 L
.75 .03704 L
.75 .02381 L
F
0 g
.71875 .02381 m
.71875 .03704 L
.75 .03704 L
.75 .02381 L
.71875 .02381 L
s
1 0 0 r
.75 .02381 m
.75 .02381 L
.78125 .02381 L
.78125 .02381 L
F
0 g
.75 .02381 m
.75 .02381 L
.78125 .02381 L
.78125 .02381 L
.75 .02381 L
s
1 0 0 r
.78125 .02381 m
.78125 .03042 L
.8125 .03042 L
.8125 .02381 L
F
0 g
.78125 .02381 m
.78125 .03042 L
.8125 .03042 L
.8125 .02381 L
.78125 .02381 L
s
1 0 0 r
.8125 .02381 m
.8125 .02381 L
.84375 .02381 L
.84375 .02381 L
F
0 g
.8125 .02381 m
.8125 .02381 L
.84375 .02381 L
.84375 .02381 L
.8125 .02381 L
s
1 0 0 r
.84375 .02381 m
.84375 .02381 L
.875 .02381 L
.875 .02381 L
F
0 g
.84375 .02381 m
.84375 .02381 L
.875 .02381 L
.875 .02381 L
.84375 .02381 L
s
1 0 0 r
.875 .02381 m
.875 .02381 L
.90625 .02381 L
.90625 .02381 L
F
0 g
.875 .02381 m
.875 .02381 L
.90625 .02381 L
.90625 .02381 L
.875 .02381 L
s
1 0 0 r
.90625 .02381 m
.90625 .02381 L
.9375 .02381 L
.9375 .02381 L
F
0 g
.90625 .02381 m
.90625 .02381 L
.9375 .02381 L
.9375 .02381 L
.90625 .02381 L
s
1 0 0 r
.9375 .02381 m
.9375 .02381 L
.96875 .02381 L
.96875 .02381 L
F
0 g
.9375 .02381 m
.9375 .02381 L
.96875 .02381 L
.96875 .02381 L
.9375 .02381 L
s
1 0 0 r
.96875 .02381 m
.96875 .02712 L
1 .02712 L
1 .02381 L
F
0 g
.96875 .02381 m
.96875 .02712 L
1 .02712 L
1 .02381 L
.96875 .02381 L
s
.015 w
0 .02381 m
.00193 .02393 L
.00368 .02426 L
.00571 .02488 L
.00762 .02572 L
.01103 .02781 L
.01473 .03093 L
.0188 .03539 L
.02311 .04128 L
.03086 .05477 L
.04634 .09255 L
.06339 .14935 L
.09908 .3082 L
.13251 .48368 L
.16293 .64214 L
.19612 .79083 L
.2141 .8541 L
.2308 .89958 L
.23901 .91694 L
.24675 .93018 L
.25104 .9362 L
.25567 .94167 L
.25957 .94542 L
.26376 .94859 L
.26592 .94988 L
.26798 .95089 L
.26982 .95162 L
.27182 .95222 L
.27372 .95261 L
.27573 .95283 L
.27745 .95286 L
.27935 .95272 L
.28043 .95257 L
.28157 .95235 L
.2836 .9518 L
.28579 .95099 L
.28818 .94985 L
.29247 .94714 L
.29647 .94388 L
.30522 .93429 L
.31318 .92282 L
.33103 .88838 L
.3625 .8038 L
.39662 .68994 L
.46376 .45268 L
.49715 .34816 L
.5284 .26508 L
.56029 .19633 L
.59056 .1455 L
.62384 .10398 L
Mistroke
.65426 .07693 L
.67003 .06624 L
.68682 .05694 L
.717 .04459 L
.73392 .03962 L
.7522 .03546 L
.76945 .03247 L
.78531 .03035 L
.80132 .0287 L
.81626 .02751 L
.83264 .02652 L
.85018 .02573 L
.86691 .02518 L
.88509 .02476 L
.90226 .02447 L
.91812 .02428 L
.93396 .02414 L
.94881 .02405 L
.96509 .02397 L
.97425 .02394 L
.98263 .02392 L
.99043 .0239 L
.99876 .02388 L
Mfstroke
.99876 .02388 m
1 .02388 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00V?ooool00ol@413o<S8boa0@4002o`000003odA4A?o<c<cooooo04_ooooo002Hooooo`03o`00
0?nHV9Sok^k^00;ooooo00?oQhN7oa0@4?ooool0Boooool009gooooo00?o^[Zjo`000?ooool0Booo
ool009Sooooo00?oc<c<odA4A?l000000ol000000onHV9Soooooooooo`1:ooooo`00V?ooool01Ol0
003oQhN7okZj^_nj^[[oc<c<04kooooo002Hooooo`03o`000?nHV9Sooooo00;ooooo00?oc<c<oa0@
4?ooool0Boooool009Sooooo00Ooc<c<odA4A?l0003o0000oa0@4?lb<S;o000004cooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool005[ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@06oooo
o`05oiRHV?l@413o0000o`000?mVIVH02Oooool4o`000003oa0@4?oooooooooo00Sooooo1?l00000
0ol@413oooooooooo`04ooooo`03oeEEEOl0003oEEEE00Kooooo00GoV9RHoa0@4?l0003o0000ofIV
IP08ooooo`Ko00002Oooool6o`0000Kooooo00?oEEEEo`000?mEEED01_ooool01OnHV9So410@o`00
0?l0003oIVIV00Wooooo00GoZJVYob4Q8Ol0003o0000ofIVIP09ooooo`00FOooool01_nj^[[o8B4Q
omgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`06oa0@4?n7QhOooooooooooomgMgOoIVIV2_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo0ol00006ooooo`06oa0@4?n7
QhOooooooooooomgMgOoIVIV1oooool00onHV9So0000omgMg@02ooooo`03oa0@4?oooooooooo00Oo
oooo00?oV9RHo`000?oMgMd00_ooool00ol@413oooooooooo`04ooooo`?o00001_ooool01_l@413o
QhN7ooooooooooooMgMgofIVIPSooooo00Ko410@olc<c?ooooooooooogMgMomVIVH8ooooo`00FOoo
ool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED02oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00omEEEGo
0000oeEEE@0;ooooo`03o`000?oooooooooo00Kooooo00?oQhN7ob4Q8Oo^k^h03?ooool00on7QhOo
8B4Qonk^kP08ooooo`03oeEEEOl0003oEEEE00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`06ooooo`00FOooool01_l0003ok^k^ooooooooooook^k^o`0001;ooooo00?ok^k^o`00
0?ooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01?ooooo00?ok^k^o`00
0?ooool02?ooool00onYZJWo8B4Qonk^kP0<ooooo`03ojVYZOlQ8B7ok^k^01Cooooo00?ok^k^o`00
0?ooool03?ooool00ol0003oooooooooo`06ooooo`00FOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00cooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH:ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03oooool01_l@413oV9RHooooooooooooMgMgofIVIP[ooooo
00?oV9RHoc8b<_ooool03?ooool00onHV9So<S8booooo`0?ooooo`06oa0@4?nHV9Sooooooooooomg
MgOoIVIV3?ooool00onYZJWoA4A4ooooo`07ooooo`00FOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00cooooo00Go0000ob4Q8Ol0003o0000ofIVIP0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03oooool01Ol0003o8B4Qo`000?l0003oIVIV00cooooo00?oA4A4
ogMgMoooool03?ooool00om4A4CoMgMgooooo`0>ooooo`05o`000?lQ8B7o0000o`000?mVIVH02ooo
ool01?lQ8B7o0000o`000?oMgMd8ooooo`00FOooool01_l0003ok^k^ooooooooooook^k^o`0000ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03_ooool00ooMgMgo410@ooooo`0<ooooo`03omgMgOl@413ooooo00ko
oooo00?o0000ooooooooool03oooool00onYZJWo<S8booooo`07ooooo`00FOooool01_m4A4CoV9RH
ooooooooooooV9RHodA4A0kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06oooo
o`00FOooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00?o0000ooooooooool02oooool0
0ol0003oA4A4o`00000<ooooo`03o`000?m4A4Co0000017ooooo00?o0000ooooooooool02_ooool0
1_l0003oQhN7onk^k_ooooooV9RHoeEEE@Wooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED?oooo
o`03o`000?oooooooooo00_ooooo00Ko8B4QokZj^_ooooooooooofIVI_lb<S88ooooo`00F_ooool0
1?nHV9So0000o`000?nHV9P?ooooo`Go00002Oooool00oo<c<coEEEEo`00000<ooooo`03olc<c?mE
EEGo0000017ooooo1Ol00008ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^2Oooool01_nYZJWo
<S8bo`000?l0003oEEEEonk^kPoooooo1Ol00009ooooo`06okZj^_m4A4Co0000o`000?m4A4Cok^k^
2?ooool00>_ooooo003[ooooo`00joooool004goooooWOl00001ooooo`00@oooool01?nHV9So0000
o`000?nHV9P6ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000001ooooo`00@_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGo
oooo00?o0000ooooooooool0VOooool1o`00007ooooo0012ooooo`06odA4A?nHV9SooooooooooonH
V9SoA4A41Oooool00ol0003oooooooooo`2Iooooo`7o00000Oooool004;ooooo00Ko0000onk^k_oo
ooooooooonk^k_l00005oooooigo00000Oooool004;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`Co000000?oo`00o`000?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00004o`000?ooooooooooooooobCo00000Oooool004;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Ko00001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Co0000ool00?oo003oo`005?l0000Hooooo`7o00000Oooool004;ooooo00Ko0000onk^
k_ooooooooooonk^k_l00005ooooo`03o`000?oooooo000000?o00001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?l000002ol0000Rooooo`7o00000Oooool004;ooooo00KoA4A4oiRHV?oooooo
oooooiRHV?m4A4@5ooooo`03o`000?oooooooooo00?o00001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`002Ol0
000Wooooo`7o00000Oooool004;ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`03o`00
0?oooooooooo00?o00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool000So000000?oo`00o`000?ooool0:_ooool1o`00007ooooo0013ooooo`04
oiRHV?l0003o0000oiRHV0Kooooo00Co0000oooooooooooooooo0_l00004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooool00000
1ol0000[ooooo`7o00000Oooool004gooooo00Co0000oooooooooooooooo0ol00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`001?l0000aoooo
o`7o00000Oooool004gooooo0_l00003ooooo`;o00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00005o`0003;ooooo0Ol00001ooooo`00COooool00ol0
003oooooooooo`02ooooo`?o00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003o`0003Cooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`02
ooooo`?o00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
o`000003o`0003Cooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`02ooooo`Co000000?o
o`00o`000?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`001_l0000dooooo`7o00000Oooool004gooooo
00?o0000ooooooooool00_ooool01_l0003oo`00o`000?l0003oo`00o`0000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool000?o0000=oooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00;ooooo1_l00004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Co0000ool00?oo003oo`000ol0000hooooo`7o00000Oooool004gooooo00?o0000ooooooooool0
1?ooool4o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003o`0003Wooooo0Ol00001ooooo`00COooool00ol0003o
ooooooooo`05ooooo`?o00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003o000000?o0000>Oooool1o`00007ooooo001=oooo
o`;o00001_ooool3o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo0006o`0003Wooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`05
ooooo`?o00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool000?o0000??ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00Gooooo0ol0
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00004o`000?oo003oo`00ool0
00?o0000?Oooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00Gooooo0ol00004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o0000?_ooool1
o`00007ooooo001=ooooo`03o`000?oooooooooo00Kooooo0_l00004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o0000?_ooool1o`00007ooooo001=
ooooo`03o`000?oooooooooo00Kooooo0_l00004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003o000000?o0000?_ooool1o`00007ooooo001=ooooo`03o`000?oo
oooooooo00Kooooo0_l00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00006
o`000?oo003o0000o`000?oo003o0000?_ooool1o`00007ooooo001=ooooo`;o00001oooool3o`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`001?l000000ooo003o0000oooo
o`0mooooo`7o00000Oooool004gooooo00?o0000ooooooooool01oooool2o`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`000ol00002ool00003o`000?oooooooooo03cooooo
0Ol00001ooooo`00COooool00ol0003oooooooooo`07ooooo`;o00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo0003o`0000;oo`0000?o0000ooooooooool0??ooool1o`00007o
oooo001=ooooo`03o`000?oooooooooo00Oooooo0_l00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool000;o00000ooo00000ol0003oooooooooo`0looooo`7o00000Oooool004go
oooo00?o0000ooooooooool01oooool6o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00001?l0003oo`00ool00?oo0003o`0000?oo`0000?o
0000ooooooooool0??ooool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?o
EEEEo`000?mEEED01Oooool6o`0000Gooooo00?o0000ooooooooool02?ooool2o`0000;ooooo00?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00004o`000?oo003oo`00ool000Oo0000?_ooool1o`00007ooooo000_ooooo`06
okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Gooooo00?oV9RHo`000?oMgMd00_ooool0
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003o`0004?ooooo0Ol00001ooooo`00;oooool01_m4A4CoV9RHoooo
ooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool00on7QhOo8B4Qonk^kP07ooooo`03
o`000?oooooooooo00Sooooo0_l00002ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0006o`0004?ooooo0Ol00001
ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000oooooo00?oZJVYob4Q8Oo^k^h01_oo
ool2o`0000Wooooo0ol000000ooooooo0000ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooool000000_l00013ooooo`;o
00000Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03oiRH
V?lb<S;ooooo00Gooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001?l0
003oooooo`000?l00015ooooo`7o00000Oooool002oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0?ooooo`03odA4A?mgMgOooooo00Cooooo00?o0000ooooooooool02Oooool2o`00
0003ooooool0003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo0004o`0004Gooooo0Ol00001ooooo`00;oooool01_l0003ok^k^oooooooo
ooook^k^o`00017ooooo00?ogMgMoa0@4?ooool01?ooool00ol0003oooooooooo`09ooooo`;o0000
00?oooooo`000?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool000?o0000A_ooool1o`00007ooooo000_ooooo`06odA4A?nHV9Sooooooooo
oonHV9SoA4A44_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo0_l00000
0ooooooo0000ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`000ol00016ooooo`7o00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgM
ob4Q8Onj^[X=ooooo`06o`000?n7QhOok^k^oooooonHV9SoEEEE1Oooool00ol0003oooooooooo`09
ooooo`Co00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool000?o0000A_ooool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0kooooo
00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h5ooooo`03o`000?oooooooooo00[ooooo0ol00004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`000_l0
0017ooooo`7o00000Oooool004gooooo00?o0000ooooooooool02_ooool3o`0000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Co0000ool00?oo003oo`000ol00017ooooo`7o
00000Oooool004gooooo0_l0000;ooooo`?o00001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00001?l0003oo`00ool00?oo0002o`0004Sooooo0Ol00001ooooo`00COooool00ol0
003oooooooooo`0:ooooo`?o00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00003o`0004Sooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0;
ooooo`;o00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00003o`0004Sooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0;ooooo`;o00001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00003o`0004So
oooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0;ooooo`;o00001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00o`000003o`0004Sooooo0Ol00001oooo
o`00COooool00ol0003oooooooooo`0;ooooo`?o00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00001_l0003oo`00o`000?l0003oo`00o`0004Sooooo0Ol00001ooooo`00COoo
ool00ol0003oooooooooo`0<ooooo`;o00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo0004o`000003ool00?l0003ooooo04Oooooo0Ol00001ooooo`00COooool00ol0003ooooo
ooooo`0<ooooo`;o00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0006o`00
04Sooooo0Ol00001ooooo`00COooool2o`0000gooooo0_l00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool000?o0000Boooool1o`00007ooooo001=ooooo`03o`000?oooooooooo
00cooooo0_l00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool000?o0000Booo
ool1o`00007ooooo001=ooooo`03o`000?oooooooooo00cooooo0ol00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool000;o0000C?ooool1o`00007ooooo001=ooooo`03o`000?oo
oooooooo00cooooo0ol00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool000;o
0000C?ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00cooooo0ol00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000003ool000?o0000C?ooool1o`00007ooooo001=ooooo`03
o`000?oooooooooo00cooooo0ol00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000003
ool000;o0000COooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00cooooo0ol00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000003ool000;o0000COooool1o`00007ooooo001=
ooooo`;o00003Oooool6o`0000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Co0000ool00?oo003oo`001_l0001=ooooo`7o00000Oooool004gooooo00?o
0000ooooooooool03_ooool2o`000003ooooool0003oo`0000?oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000002ooooo`;o
0000C_ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00kooooo0_l000000ooooooo0000
ool00003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000000_ooool2o`0004kooooo0Ol00001ooooo`00COooool00ol0003o
ooooooooo`0>ooooo`;o000000?oooooo`000?oo00000ooo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001_l0003oo`00ool00?oo003o0000ooooo`?o0000C_oo
ool1o`00007ooooo001=ooooo`03o`000?oooooooooo00kooooo0_l000000ooooooo0000ool00003
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00006o`000?oo
003oo`00ool00?l0003ooooo0_l0001?ooooo`7o00000Oooool0033ooooo00CoV9RHo`000?l0003o
V9RH1_ooool00omEEEGo0000oeEEE@09ooooo`;o000000?o410@ooooooooool00_ooool00ol0003o
ooooooooo`0>ooooo`Co00001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001_l0003oo`00ool00?oo003o0000ooooo`;o0000Coooool1o`00007ooooo000_
ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000[ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0?ooooo`?o00001?oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001?l0003oo`00ool00?oo0004o`0004oooooo0Ol00001oooo
o`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool6
o`0000Cooooo00?o0000ooooooooool03oooool3o`0000Coo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Co0000ool00?oo003oo`000ol0001@ooooo`7o0000
0Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`05odA4A?nj^[[ooooooooo
ool000001Oooool2o`00013ooooo0ol00004ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00004o`000?oo003oo`00ool000?o0000Coooool2o`00007ooooo000_
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01OoMgMgo8B4Qoooooooo
oooo000000Gooooo00?o0000ooooooooool03oooool3o`0000Coo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Co0000ool00?oo003oo`000ol0001@ooooo`7o
00000Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`04ogMg
MonHV9Soooooo`0000Gooooo00?o0000ooooooooool03oooool3o`0000Coo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Co0000ool00?oo003oo`000_l0001A
ooooo`7o00000Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000?ooooo`04onk^k_lQ
8B7oooooo`0000Gooooo00?o0000ooooooooool03oooool3o`0000Coo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Co0000ool00?oo003oo`000_l0001Aoooo
o`7o00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@@ooooo`03ogMgMonHV9So
000000Gooooo00?o0000ooooooooool04?ooool2o`0000Coo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ol0001Aooooo`7o00000Ooo
ool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X@ooooo`03onk^k_lb<S;o000000Gooooo
00?o0000ooooooooool04?ooool2o`0000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_l0001Booooo`7o00000Oooool0013ooooo
00?o^[Zjoc8b<_ooool03_ooool00olb<S;o^[Zjooooo`0<ooooo`04oiRHV?l0003o0000oiRHV1;o
oooo00?oV9RHoa0@4?ooool01?ooool00ol0003oooooooooo`0@ooooo`;o00001?oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002o`00
05;ooooo0Ol00001ooooo`004?ooool00olb<S;o^[Zjooooo`0>ooooo`03okZj^_lb<S;ooooo02Wo
oooo00?o0000ooooooooool04?ooool2o`0000Coo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_l0001Booooo`7o00000Oooool000oo
oooo00?oc<c<oc8b<_ooool04?ooool00olb<S;oc<c<ooooo`0Xooooo`;o00004Oooool3o`0000?o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?l000000_l0001Booooo`7o00000Oooool000;ooooo00Go410@o`000?l0003o0000oa0@4008oooo
o`03ofIVI_nYZJWooooo00Cooooo00?o410@oc8b<_l@41000_l000000om4A4Coc<c<ooooo`04oooo
o`03oiRHV?mVIVKooooo02Sooooo00?o0000ooooooooool04Oooool2o`0000?oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?l000000_l0001B
ooooo`7o00000Oooool000Cooooo00?o0000ooooooooool02?ooool00olb<S;oooooooooo`04oooo
o`03o`000?nHV9Sok^k^00;ooooo00?oQhN7oa0@4?ooool01?ooool00oo^k^ko<S8booooo`0Xoooo
o`03o`000?oooooooooo017ooooo0_l00003ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003o000000;o0000D_ooool1o`00007ooooo0004oooo
o`03o`000?oooooooooo00Sooooo00?o<S8booooooooool02Oooool00onj^[[o0000ooooo`05oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool2o`0000?oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`001Ol0001Booooo`7o00000Oooool0
00Cooooo0ol000000ol@413oMgMgonk^kP05ooooo`03oc8b<_oooooooooo00Cooooo00?oc<c<odA4
A?l000000ol000000onHV9Soooooooooo`04ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool04Oooool2o`0000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`000ol000000ooo003o0000ooooo`1Aooooo`7o00000Oooool000Cooooo00Ko0000oooo
ooooooook^k^ogMgMomEEED5ooooo`03ob4Q8Ooooooooooo00Cooooo00Go0000ohN7Qonj^[[o^[Zj
olc<c008ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool3o`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`000ol000000ooo003o
0000ooooo`1Aooooo`7o00000Oooool000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03oc8b<_o^k^kooooo00Cooooo00?o0000oiRHV?ooool00_ooool00oo<c<co410@
ooooo`04ooooo`03omgMgOlb<S;ooooo02Sooooo00?o0000ooooooooool04Oooool3o`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`000ol000000ooo003o
0000ooooo`1Aooooo`7o00000Oooool000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03ofIVI_nHV9Sooooo00Cooooo00Ooc<c<odA4A?l0003o0000oa0@4?lb<S;o0000
00Gooooo00?oV9RHofIVI_ooool0:?ooool00ol0003oooooooooo`0Aooooo`?o00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0005o`0005;ooooo0Ol00001
ooooo`001?ooool01_l0003oooooooooooo^k^koMgMgoeEEE@Gooooo00?ogMgMob4Q8Oooool04?oo
ool00ol@413oc<c<ooooo`0Xooooo`;o00004_ooool6o`0000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool000;o0000EOooool1o`00007ooooo0002ooooo`03oa0@4?l0003o000000;o000000?o
410@ogMgMoo^k^h01_ooool00olb<S;o^[Zjooooo`0>ooooo`03okZj^_lb<S;ooooo02Wooooo00?o
0000ooooooooool04_ooool2o`0000;ooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`000_l0001Eooooo`7o00000Oooool0013ooooo00?o^[Zjoc8b<_ooool03_oo
ool00olb<S;o^[Zjooooo`0Yooooo`03o`000?oooooooooo01;ooooo0ol000000ooooooo0000ool0
0003ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Co0000ool00?oo003oo`000ol0001Eooooo`7o00000Oooool004gooooo
00?o0000ooooooooool04oooool2o`000003ooooool0003oo`0000?oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001?l0003o
o`00ool00?oo0002o`0005Kooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Cooooo`;o
000000?oooooo`000?oo00000ooo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00004o`000?oo003oo`00ool000;o0000E_ooool1
o`00007ooooo001=ooooo`03o`000?oooooooooo01?ooooo0_l000000ooooooo0000ool00003ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ol0001Fooooo`7o00000Oooool004gooooo00?o0000oooo
ooooool04oooool2o`000003ooooool0003oo`0000?oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
o`0005Kooooo0Ol00001ooooo`00COooool2o`0001Cooooo1?l00004ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`001_l0001F
ooooo`7o00000Oooool004gooooo00?o0000ooooooooool05?ooool3o`0000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oooooo`000002o`0005Oooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Doooo
o`?o00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00004o`000?oooooo0000o`0005Sooooo0Ol00001ooooo`00COooool0
0ol0003oooooooooo`0Dooooo`?o00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00004o`000?oooooo0000o`0005Sooooo
0Ol00001ooooo`00COooool00ol0003oooooooooo`0Dooooo`?o00001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00004o`00
0?oooooo0000o`0005Sooooo0Ol00001ooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03
oeEEEOl0003oEEEE00Kooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h4ooooo`03o`000?oooooo
oooo01Cooooo0ol00004ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`001?l0001Hooooo`7o00000Oooool002oooooo00Ko^[Zj
ob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001_ooool2ogMgM`;ooooo00?oMgMgoeEEEOooool0
0oooool00ol0003oooooooooo`0Eooooo`;o00001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000?o0000FOooool1o`00007o
oooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06oooo
o`03ob4Q8Ooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eoooo
o`;o00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool000?o0000FOooool1o`00007ooooo000_ooooo`06o`000?o^k^kooooo
ooooooo^k^ko00003_ooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l0
000Fooooo`;o00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool000?o0000F?ooool2o`00007ooooo000_ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03?ooool01_l0003oEEEEonk^k_ooooooMgMgoeEEE@Co
oooo00?o0000ooooooooool05Oooool2o`0000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0002o`0005[ooooo0Ol00001oooo
o`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Ko0000ogMgMol0
003o0000oeEEEOo^k^h4ooooo`03o`000?oooooooooo01Gooooo0ol00003ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`000_l0
001Jooooo`7o00000Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`03odA4
A?nHV9Sooooo00Oooooo00?o0000ooooooooool05_ooool2o`0000?oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0002o`0005[o
oooo0Ol00001ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0kooooo00?o^[Zjob4Q
8Oooool01oooool00ol0003oooooooooo`0Fooooo`;o00000ooo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001?l0003oo`00ool00?oo0003o`0005[ooooo0Ol0
0001ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Poooooo00?oEEEEoc8b<_oMgMd0
1_ooool00ol0003oooooooooo`0Fooooo`;o00000ooo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001?l0003oo`00ool00?oo0002o`0005_ooooo0Ol00001oooo
o`00<?ooool01?nHV9So0000o`000?nHV9PAooooo`04oiRHV?lQ8B7o0000ob4Q8@Cooooo00?o0000
ooooooooool05_ooool2o`0000?oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Co0000ool00?oo003oo`000_l0001Kooooo`7o00000Oooool004gooooo00?o
0000ooooooooool05_ooool3o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ol0001Kooooo`7o00000Oooool004gooooo0_l0
000Gooooo`?o00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003o`0005_ooooo0Ol00001ooooo`00COooool00ol0003ooooooooo
o`0Fooooo`?o00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003o`0005_ooooo0Ol00001ooooo`00COooool00ol0003ooooooooo
o`0Fooooo`?o00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00o`000003o`0005_ooooo0Ol00001ooooo`00COooool00ol0003ooooooooo
o`0Fooooo`?o00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001_l0003oo`00o`000?l0003oo`00o`0005_ooooo0Ol00001ooooo`00COooool00ol0003o
ooooooooo`0Fooooo`Co000000?oo`00o`000?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Ko0000ool00?l0003o0000ool00?l0001Kooooo`7o00000Oooool0
04gooooo00?o0000ooooooooool05_ooool01_l0003oo`00o`000?l0003oo`00o`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00006o`000?oo003o0000o`000?oo003o
0000Foooool1o`00007ooooo001=ooooo`03o`000?oooooooooo01Kooooo00Ko0000ool00?l0003o
0000ool00?l00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0004o`00
0003ool00?l0003ooooo05[ooooo0Ol00001ooooo`00COooool2o`0001Oooooo00Ko0000ool00?l0
003o0000ool00?l00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0003
o`0000;oo`0000?o0000ooooooooool0FOooool1o`00007ooooo001=ooooo`03o`000?oooooooooo
01Kooooo00?o0000ool00?l000000ol00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo0006o`0005_ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Fooooo`03
o`000?oo003oo`0000?o00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`000ol0001Nooooo`7o00000Oooool004gooooo00?o0000ooooooooool05_ooool00ol0003oo`00
ool00003o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000;o0000
Goooool1o`00007ooooo001=ooooo`03o`000?oooooooooo01Kooooo00?o0000ool00?oo00000ol0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0002o`0005oooooo0Ol0
0001ooooo`00COooool00ol0003oooooooooo`0Fooooo`03o`000?oo003oo`0000?o00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`000_l0001Oooooo`7o00000Oooool0
04gooooo00?o0000ooooooooool05_ooool00ol0003oo`00ool00003o`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001?l0003oo`00ool00?oo0003o`0005oooooo0Ol00001ooooo`00COooool00ol0
003oooooooooo`0Fooooo`04o`000?oo003oo`00ool000;o00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00004o`000?oo003oo`00ool000;o0000H?ooool1o`00007ooooo001=ooooo`;o00005oooool0
1?l0003oo`00ool00?oo0002o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001?l0003oo`00ool0
0?oo0002o`00063ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Fooooo`Ko00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00004o`000?oo003oo`00ool000;o0000H?ooool1o`00007ooooo
001=ooooo`03o`000?oooooooooo01[ooooo0_l00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`001_l0
001Pooooo`7o00000Oooool004gooooo00?o0000ooooooooool06_ooool3o`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oooooooooo`02o`00067ooooo0Ol00001ooooo`00COooool00ol0
003oooooooooo`0Kooooo`;o00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo
00;o0000HOooool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`00
0?mEEED01_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPCooooo00?o0000ooooooooool06ooo
ool2o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oooooo`000002o`00067ooooo0Ol0
0001ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`06oeEE
EOmgMgOooooooooooomgMgOoEEEE1?ooool00ol0003oooooooooo`0Kooooo`;o00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00004o`000?oooooo0000o`0006;ooooo0Ol00001ooooo`00;oooool01_m4
A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool3o`000003ool00?l0
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Co0000ooooool0003o0000H_ooool1o`00007ooooo000_ooooo`06o`000?o^
k^koooooooooooo^k^ko00003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo0_l0000Looooo`?o000000?oo`00o`000?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0004o`00067ooooo0_l00001ooooo`00
;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00KoEEEEogMgMooooooo
ooooogMgMomEEED4ooooo`03o`000?oooooooooo01_ooooo0ol000000ooo003o0000ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
00?o0000Hoooool1o`00007ooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03?ooool00ooMgMgo0000o`000002o`000003omgMgOoooooooooo00;ooooo00?o0000oooooooo
ool06oooool5o`0000Coo`001_l00004ool00003o`000?oo003oo`0000;oo`000ol0001Sooooo`7o
00000Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`06oc8b<_mVIVKok^k^
onk^k_mVIVKo<S8b1?ooool00ol0003oooooooooo`0Mooooo`?o00001?oo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0003o`0006?ooooo0Ol0
0001ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo0ol00004ool00003o`00
0?oooooooooo00;ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000;o0000
I?ooool1o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool01_lb<S;o
IVIVonk^k_o^k^koIVIVoc8b<PCooooo00?o0000ooooooooool07Oooool3o`0000Coo`0000?o0000
ooooooooool00_ooool00ol0003oo`00ool00002ool00004o`000?oo003oo`00ool000?o0000I?oo
ool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0oooooo00Kok^k^odA4A?l0003o0000
odA4A?o^k^h4ooooo`03o`000?oooooooooo01kooooo0_l00004ool00003o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000_oo00001?l0003oo`00ool00?oo0002o`0006Gooooo0Ol00001oooo
o`00COooool00ol0003oooooooooo`0Nooooo`;o00001?oo00000ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000;oo`0000Co0000ool00?oo003oo`000_l0001Uooooo`7o00000Oooool004go
oooo0_l0000Oooooo`;o00001?oo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ol0001Uooooo`7o00000Oooool004gooooo00?o0000ooooooooool0
7_ooool3o`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?o0000IOooool1o`00007ooooo001=ooooo`03o`000?oooooooooo01oooooo0_l0
0003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003o`0006Gooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Oooooo`Ko00001?ooool0
0ol0003oo`00ool00002ool00003o`000?oo003o000000?o0000IOooool1o`00007ooooo001=oooo
o`03o`000?oooooooooo01oooooo0ol00007ooooo`03o`000?oo003oo`0000;oo`0000Ko0000ool0
0?l0003o0000ool00?l0001Uooooo`7o00000Oooool004gooooo00?o0000ooooooooool08?ooool2
o`0000Oooooo00?o0000ool00?oo00000_oo0004o`000003ool00?l0003ooooo06Cooooo0Ol00001
ooooo`00COooool00ol0003oooooooooo`0Pooooo`;o00001oooool8o`0000;oo`0000?o0000oooo
ooooool0Hoooool1o`00007ooooo001=ooooo`;o00008Oooool3o`0000_ooooo0_l00003ool00003
o`000?oooooooooo06?ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Qooooo`?o0000
2Oooool3o`0000?oo`0000?o0000ooooooooool0Hoooool1o`00007ooooo001=ooooo`03o`000?oo
oooooooo02;ooooo0_l00009ooooo`;o00001?oo00000ol0003oooooooooo`1Sooooo`7o00000Ooo
ool004gooooo00?o0000ooooooooool08_ooool3o`0000Oooooo0ol00004ool00003o`000?oooooo
oooo06?ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Sooooo`?o00001_ooool3o`00
00Coo`0000?o0000ooooooooool0Hoooool1o`00007ooooo001=ooooo`03o`000?oooooooooo02Co
oooo1?l00002ooooo`Go00001?oo00000ol0003oooooooooo`1Sooooo`7o00000Oooool004gooooo
00?o0000ooooooooool09Oooool8o`000003ooooool0003oo`0000?oo`0000?o0000ooooooooool0
Hoooool1o`00007ooooo001=ooooo`03o`000?oooooooooo02Kooooo1Ol00003ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0Hoooool1o`00007ooooo001=ooooo`;o0000;oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo06?ooooo0Ol00001ooooo`00COooool00ol0
003oooooooooo`0^ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0Hoooool1o`00
007ooooo001=ooooo`03o`000?oooooooooo02kooooo1_l0001Uooooo`7o00000Oooool004gooooo
00?o0000ooooooooool0VOooool1o`00007ooooo001=ooooo`03o`000?oooooooooo09Wooooo0Ol0
0001ooooo`00COoooonMo`00007ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00001\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-1.59709, -0.398681, 0.0205114, \
0.00646325}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classical Standard Map", "Section"],

Cell[TextData[{
  "We begin with the code for plotting orbits of the standard map.  This \
gives us an overal picture of the classical dynamics of this map.  See \"A \
computational approach to teaching conservative chaos\" by T. Timberlake (Am. \
J. Phys. ",
  StyleBox["72",
    FontWeight->"Bold"],
  ", 1002-1007, August 2004) for more details.  Note that the names of the \
variables change from (\[Theta],r) in the aforementioned paper to (q,p) \
here."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(K = 7; n = 400; q1 = 0; q2 = 0.5; np = 20;\), "\n", 
    \(\(f[{q_, p_}] := 
        N[{Mod[q + p - \((K/\((2*Pi)\))\)*Sin[2*Pi*q], 1], 
            Mod[p - \((K/\((2*Pi)\))\)*Sin[2*Pi*q], 1]}];\)\), "\n", 
    \(\(MapData\  = \ 
        Flatten[Table[
            Join[NestList[f, {q1, i/np}, n], NestList[f, {q2, i/np}, n]], {i, 
              0, np}], 1];\)\), "\n", 
    \(LP1 = 
      ListPlot[MapData, PlotStyle \[Rule] PointSize[0.005], 
        PlotRange \[Rule] {{0, 1}, {0, 1}}, Frame \[Rule] True, 
        RotateLabel \[Rule] 
          False, \[IndentingNewLine]TextStyle \[Rule] {"\<Times\>", 
            FontSize \[Rule] 16}, 
        FrameLabel \[Rule] {"\<q\>", "\<p\>", "\<\>", "\<\>"}, 
        Axes \[Rule] False, AspectRatio \[Rule] 1]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 1 [
[.2 -0.0125 -16.3438 -18 ]
[.2 -0.0125 16.3438 0 ]
[.4 -0.0125 -16.3438 -18 ]
[.4 -0.0125 16.3438 0 ]
[.6 -0.0125 -16.3438 -18 ]
[.6 -0.0125 16.3438 0 ]
[.8 -0.0125 -16.3438 -18 ]
[.8 -0.0125 16.3438 0 ]
[1 -0.0125 -6.78125 -18 ]
[1 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .2 -32.6875 -9 ]
[-0.0125 .2 0 9 ]
[-0.0125 .4 -32.6875 -9 ]
[-0.0125 .4 0 9 ]
[-0.0125 .6 -32.6875 -9 ]
[-0.0125 .6 0 9 ]
[-0.0125 .8 -32.6875 -9 ]
[-0.0125 .8 0 9 ]
[-0.0125 1 -13.5625 -9 ]
[-0.0125 1 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -46.25 -9 ]
[-0.01875 .5 -32.6875 9 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
gsave
.2 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.4 0 m
.4 .00625 L
s
gsave
.4 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.6 0 m
.6 .00625 L
s
gsave
.6 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.8 0 m
.8 .00625 L
s
gsave
.8 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
gsave
-0.0125 .2 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .4 m
.00625 .4 L
s
gsave
-0.0125 .4 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .6 m
.00625 .6 L
s
gsave
-0.0125 .6 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .8 m
.00625 .8 L
s
gsave
-0.0125 .8 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 1 m
.00625 1 L
s
gsave
-0.0125 1 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -107.25 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.2 .99375 m
.2 1 L
s
.4 .99375 m
.4 1 L
s
.6 .99375 m
.6 1 L
s
.8 .99375 m
.8 1 L
s
.125 Mabswid
.05 .99625 m
.05 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.25 .99625 m
.25 1 L
s
.3 .99625 m
.3 1 L
s
.35 .99625 m
.35 1 L
s
.45 .99625 m
.45 1 L
s
.5 .99625 m
.5 1 L
s
.55 .99625 m
.55 1 L
s
.65 .99625 m
.65 1 L
s
.7 .99625 m
.7 1 L
s
.75 .99625 m
.75 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .2 m
1 .2 L
s
.99375 .4 m
1 .4 L
s
.99375 .6 m
1 .6 L
s
.99375 .8 m
1 .8 L
s
.125 Mabswid
.99625 .05 m
1 .05 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .25 m
1 .25 L
s
.99625 .3 m
1 .3 L
s
.99625 .35 m
1 .35 L
s
.99625 .45 m
1 .45 L
s
.99625 .5 m
1 .5 L
s
.99625 .55 m
1 .55 L
s
.99625 .65 m
1 .65 L
s
.99625 .7 m
1 .7 L
s
.99625 .75 m
1 .75 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .95 m
1 .95 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.005 w
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
.5 0 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.49996 .99997 Mdot
.49967 .9997 Mdot
.49703 .99736 Mdot
.47358 .97656 Mdot
.26607 .79249 Mdot
.95015 .68408 Mdot
.97748 .02733 Mdot
.1619 .18442 Mdot
.3986 .23669 Mdot
.97253 .57393 Mdot
.73782 .7653 Mdot
.61394 .87612 Mdot
.22126 .60731 Mdot
.7326 .51135 Mdot
.35139 .61878 Mdot
.07461 .72322 Mdot
.29447 .21986 Mdot
.44347 .14899 Mdot
.20499 .76152 Mdot
.89669 .6917 Mdot
.26185 .36517 Mdot
.51602 .25417 Mdot
.88217 .36614 Mdot
.99983 .11766 Mdot
.11868 .11885 Mdot
.48164 .36296 Mdot
.71637 .23473 Mdot
.04041 .32404 Mdot
.08459 .04417 Mdot
.56413 .47954 Mdot
.48054 .91641 Mdot
.26107 .78053 Mdot
.93021 .66914 Mdot
.07237 .14216 Mdot
.72522 .65285 Mdot
.47868 .75346 Mdot
.08337 .60468 Mdot
.13081 .04745 Mdot
.36225 .23144 Mdot
.74538 .38313 Mdot
.24213 .49675 Mdot
.62615 .38403 Mdot
.80363 .17748 Mdot
.03254 .22891 Mdot
.03526 .00272 Mdot
.79319 .75793 Mdot
.62444 .83125 Mdot
.24066 .61623 Mdot
.74472 .50406 Mdot
.36226 .61753 Mdot
.13153 .76927 Mdot
.08137 .94984 Mdot
.48611 .40474 Mdot
.79372 .30761 Mdot
.17365 .37993 Mdot
.56526 .39161 Mdot
.40097 .83572 Mdot
.58737 .1864 Mdot
.35511 .76774 Mdot
.24303 .88792 Mdot
.01794 .7749 Mdot
.66754 .64961 Mdot
.28503 .61748 Mdot
.8153 .53027 Mdot
.3672 .5519 Mdot
.09367 .72647 Mdot
.20166 .108 Mdot
.24656 .0449 Mdot
.17763 .93107 Mdot
.10782 .93018 Mdot
.3397 .23189 Mdot
.62981 .29011 Mdot
.73117 .10135 Mdot
.93881 .20765 Mdot
.56429 .62548 Mdot
.62766 .06337 Mdot
.49184 .86418 Mdot
.29891 .80707 Mdot
.04408 .74517 Mdot
.48462 .44054 Mdot
.81771 .33308 Mdot
.16557 .34787 Mdot
.55246 .38689 Mdot
.29998 .74752 Mdot
.9879 .68792 Mdot
.76042 .77252 Mdot
.64464 .88422 Mdot
.40761 .76297 Mdot
.55959 .15198 Mdot
.11904 .55945 Mdot
.92076 .80172 Mdot
.25454 .33379 Mdot
.4747 .22016 Mdot
.51849 .04379 Mdot
.69145 .17296 Mdot
.90396 .21251 Mdot
.74868 .84471 Mdot
.70744 .95876 Mdot
.74068 .03324 Mdot
.8861 .14542 Mdot
.76249 .87639 Mdot
.74954 .98705 Mdot
.85067 .10113 Mdot
.85036 .9997 Mdot
.74988 .89952 Mdot
.76348 .0136 Mdot
.88718 .12369 Mdot
.73613 .84895 Mdot
.69494 .95881 Mdot
.70183 .00689 Mdot
.77218 .07035 Mdot
.94581 .17363 Mdot
.49149 .54568 Mdot
.97759 .48611 Mdot
.62004 .64245 Mdot
.02533 .40529 Mdot
.25404 .2287 Mdot
.36901 .11497 Mdot
.66712 .29811 Mdot
.93164 .26452 Mdot
.6601 .72846 Mdot
.3296 .6695 Mdot
.02148 .69188 Mdot
.56347 .54199 Mdot
.53807 .9746 Mdot
.7766 .23853 Mdot
.11369 .33709 Mdot
.72092 .60722 Mdot
.42367 .70275 Mdot
.61236 .18869 Mdot
.52386 .91149 Mdot
.60172 .07786 Mdot
.34411 .74239 Mdot
.16158 .81747 Mdot
.03252 .87095 Mdot
.67739 .64486 Mdot
.32238 .645 Mdot
.96655 .64416 Mdot
.84315 .87661 Mdot
.6484 .80525 Mdot
.34833 .69993 Mdot
.1401 .79177 Mdot
.07301 .93291 Mdot
.51257 .43956 Mdot
.04004 .52747 Mdot
.29019 .25015 Mdot
.46158 .17139 Mdot
.36662 .90504 Mdot
.4435 .07688 Mdot
.13314 .68964 Mdot
.99576 .86263 Mdot
.88804 .89227 Mdot
.50099 .61295 Mdot
.12085 .61986 Mdot
.97373 .85288 Mdot
.00964 .03591 Mdot
.97809 .96845 Mdot
.09942 .12133 Mdot
.56918 .46976 Mdot
.50811 .93892 Mdot
.50375 .99564 Mdot
.52562 .02187 Mdot
.72602 .20041 Mdot
.02789 .30187 Mdot
.13552 .10763 Mdot
.40505 .26953 Mdot
.04866 .64361 Mdot
.35695 .30829 Mdot
.79337 .43642 Mdot
.30277 .5094 Mdot
.75875 .45599 Mdot
.32714 .56839 Mdot
.90977 .58262 Mdot
.09073 .18096 Mdot
.67043 .57971 Mdot
.22788 .55745 Mdot
.68198 .4541 Mdot
.14998 .46799 Mdot
.71675 .56677 Mdot
.37338 .65663 Mdot
.23425 .86087 Mdot
.98649 .75224 Mdot
.83319 .8467 Mdot
.64522 .81203 Mdot
.33849 .69327 Mdot
.0855 .74701 Mdot
.26237 .17687 Mdot
.32852 .06615 Mdot
.41346 .08494 Mdot
.92205 .50858 Mdot
.95475 .03271 Mdot
.29994 .34519 Mdot
.58545 .28551 Mdot
.44081 .85535 Mdot
.89129 .45049 Mdot
.04493 .15363 Mdot
.88824 .84331 Mdot
.45115 .56291 Mdot
.67747 .22632 Mdot
.90418 .22671 Mdot
.76185 .85767 Mdot
.73052 .96867 Mdot
.80494 .07442 Mdot
.92773 .12279 Mdot
.53922 .6115 Mdot
.42251 .88328 Mdot
.78453 .36202 Mdot
.23452 .44999 Mdot
.57569 .34117 Mdot
.42696 .85126 Mdot
.78467 .35772 Mdot
.23014 .44547 Mdot
.57019 .34004 Mdot
.38576 .81557 Mdot
.46854 .08279 Mdot
.33257 .86402 Mdot
.22909 .89652 Mdot
.02113 .79204 Mdot
.66568 .64455 Mdot
.27161 .60592 Mdot
.77369 .50209 Mdot
.37754 .60385 Mdot
.2063 .82876 Mdot
.96271 .75641 Mdot
.97779 .01508 Mdot
.14785 .17006 Mdot
.42553 .27768 Mdot
.20073 .7752 Mdot
.91481 .71408 Mdot
.19717 .28236 Mdot
.42627 .2291 Mdot
.15749 .73122 Mdot
.9576 .80011 Mdot
.05103 .09344 Mdot
.79333 .74229 Mdot
.60868 .81535 Mdot
.12701 .51833 Mdot
.84769 .72068 Mdot
.4791 .63141 Mdot
.96464 .48554 Mdot
.69568 .73104 Mdot
.47653 .78086 Mdot
.09373 .61719 Mdot
.09211 .99838 Mdot
.48114 .38903 Mdot
.73844 .2573 Mdot
.10689 .36845 Mdot
.78211 .67522 Mdot
.54882 .76671 Mdot
.65193 .10311 Mdot
.66425 .01232 Mdot
.63283 .96858 Mdot
.42695 .79413 Mdot
.72752 .30057 Mdot
.13107 .40356 Mdot
.71737 .58629 Mdot
.39441 .67704 Mdot
.38533 .99093 Mdot
.64126 .25593 Mdot
.76121 .11995 Mdot
.99248 .23127 Mdot
.27637 .28389 Mdot
.46142 .18505 Mdot
.37904 .91762 Mdot
.52913 .15009 Mdot
.88199 .35286 Mdot
.98728 .10529 Mdot
.18153 .19425 Mdot
.36322 .18168 Mdot
.701 .33779 Mdot
.1005 .39949 Mdot
.84234 .74184 Mdot
.51596 .67362 Mdot
.3011 .78514 Mdot
.02909 .72799 Mdot
.5546 .52551 Mdot
.45484 .90024 Mdot
.04316 .58832 Mdot
.33305 .28989 Mdot
.65712 .32407 Mdot
.91086 .25375 Mdot
.75647 .8456 Mdot
.71523 .95877 Mdot
.76162 .04638 Mdot
.91912 .1575 Mdot
.61875 .69963 Mdot
.07462 .45587 Mdot
.02708 .95246 Mdot
.79088 .7638 Mdot
.63221 .84133 Mdot
.2962 .66399 Mdot
.89273 .59653 Mdot
.18457 .29184 Mdot
.45515 .27059 Mdot
.41595 .9608 Mdot
.81538 .39943 Mdot
.23621 .42083 Mdot
.54713 .31093 Mdot
.1832 .63607 Mdot
.80188 .61867 Mdot
.47597 .6741 Mdot
.98253 .50656 Mdot
.61111 .62857 Mdot
.95577 .34467 Mdot
.60606 .65028 Mdot
.945 .33894 Mdot
.66134 .71635 Mdot
.32336 .66201 Mdot
.98754 .66419 Mdot
.73884 .7513 Mdot
.60149 .86265 Mdot
.12738 .52589 Mdot
.85381 .72643 Mdot
.46562 .61181 Mdot
.83866 .37303 Mdot
.15735 .31869 Mdot
.54546 .38811 Mdot
.2475 .70204 Mdot
.83559 .58809 Mdot
.38051 .54491 Mdot
.16536 .78485 Mdot
.99 .82464 Mdot
.88462 .89462 Mdot
.518 .63338 Mdot
.27712 .75912 Mdot
.93828 .66116 Mdot
.02073 .08245 Mdot
.95849 .93777 Mdot
.18352 .22503 Mdot
.39025 .20672 Mdot
.88816 .49791 Mdot
.1061 .21794 Mdot
.63515 .52905 Mdot
.00056 .36542 Mdot
.36203 .36146 Mdot
.8742 .51217 Mdot
.17811 .30391 Mdot
.47968 .30157 Mdot
.63937 .15969 Mdot
.65466 .01529 Mdot
.59005 .93539 Mdot
.1227 .53265 Mdot
.87904 .75634 Mdot
.40291 .52388 Mdot
.28856 .88564 Mdot
.09265 .8041 Mdot
.28419 .19153 Mdot
.38724 .10305 Mdot
.76539 .37815 Mdot
.25242 .48703 Mdot
.62549 .37307 Mdot
.78876 .16327 Mdot
.03324 .24448 Mdot
.04674 .0135 Mdot
.73775 .69101 Mdot
.53954 .80179 Mdot
.61527 .07573 Mdot
.42916 .81389 Mdot
.76334 .33419 Mdot
.2077 .44436 Mdot
.57709 .36939 Mdot
.46525 .88816 Mdot
.11205 .6468 Mdot
.03771 .92566 Mdot
.70185 .66413 Mdot
.42946 .72761 Mdot
.67929 .24984 Mdot
.93507 .25578 Mdot
.63284 .69776 Mdot
.15619 .52336 Mdot
.75344 .59725 Mdot
.46452 .71108 Mdot
.92928 .46476 Mdot
.87294 .94366 Mdot
.61449 .74155 Mdot
.09012 .47563 Mdot
.96807 .87795 Mdot
.06802 .09995 Mdot
.70617 .63815 Mdot
.41643 .71026 Mdot
.56824 .1518 Mdot
.18319 .61495 Mdot
.78079 .5976 Mdot
.47169 .6909 Mdot
.9655 .4938 Mdot
.69893 .73343 Mdot
.48959 .79066 Mdot
.20744 .71785 Mdot
0 .05 Mdot
.05 .05 Mdot
.75573 .70573 Mdot
.57482 .81909 Mdot
.89858 .32376 Mdot
.8852 .98663 Mdot
.60752 .72231 Mdot
.02649 .41898 Mdot
.26087 .23438 Mdot
.38376 .12289 Mdot
.76338 .37963 Mdot
.25316 .48977 Mdot
.62907 .37591 Mdot
.81262 .18355 Mdot
.02513 .21251 Mdot
.06245 .03732 Mdot
.67373 .61128 Mdot
.27362 .59989 Mdot
.77167 .49805 Mdot
.37349 .60182 Mdot
.18011 .80661 Mdot
.97835 .79825 Mdot
.92767 .94932 Mdot
.36605 .43838 Mdot
.97364 .60759 Mdot
.76491 .79127 Mdot
.66538 .90047 Mdot
.52615 .86077 Mdot
.56917 .04302 Mdot
.08132 .51214 Mdot
.04868 .96736 Mdot
.68057 .6319 Mdot
.32223 .64165 Mdot
.96257 .64034 Mdot
.86249 .89992 Mdot
.6096 .7471 Mdot
.06467 .45507 Mdot
.07941 .01474 Mdot
.56107 .48166 Mdot
.45977 .8987 Mdot
.07982 .62005 Mdot
.16427 .08445 Mdot
.2924 .12813 Mdot
.34575 .05335 Mdot
.4806 .13485 Mdot
.47997 .99937 Mdot
.33948 .85951 Mdot
.25638 .9169 Mdot
.06008 .80371 Mdot
.45313 .39304 Mdot
.52278 .06965 Mdot
.75135 .22857 Mdot
.09396 .34261 Mdot
.81642 .72246 Mdot
.55736 .74094 Mdot
.69115 .13379 Mdot
.86373 .17258 Mdot
.87784 .01411 Mdot
.66554 .7877 Mdot
.41408 .74854 Mdot
.58999 .1759 Mdot
.36277 .77278 Mdot
.28961 .92684 Mdot
.13668 .84707 Mdot
.14034 .00366 Mdot
.28407 .14373 Mdot
.33914 .05507 Mdot
.45037 .11122 Mdot
.21975 .76939 Mdot
.89512 .67536 Mdot
.25267 .35755 Mdot
.49629 .24362 Mdot
.71396 .21767 Mdot
.01728 .30332 Mdot
.19987 .18258 Mdot
.32318 .12332 Mdot
.44813 .12495 Mdot
.21642 .76828 Mdot
.89533 .67891 Mdot
.25526 .35993 Mdot
.50172 .24646 Mdot
.7602 .25848 Mdot
.13048 .37028 Mdot
.68633 .55585 Mdot
.26829 .58196 Mdot
.74351 .47522 Mdot
.33189 .58838 Mdot
.95045 .61856 Mdot
.91027 .95982 Mdot
.46545 .55518 Mdot
.78069 .31524 Mdot
.18936 .40868 Mdot
.56384 .37448 Mdot
.3733 .80946 Mdot
.38661 .01331 Mdot
.67165 .28504 Mdot
.93847 .26683 Mdot
.62534 .68686 Mdot
.10164 .4763 Mdot
.91384 .8122 Mdot
.30012 .38627 Mdot
.62709 .32697 Mdot
.7521 .12501 Mdot
.99109 .239 Mdot
.2924 .3013 Mdot
.51892 .22652 Mdot
.87754 .35862 Mdot
.01128 .13374 Mdot
.06614 .05487 Mdot
.67122 .60507 Mdot
.25665 .58543 Mdot
.72896 .47232 Mdot
.30565 .57668 Mdot
.83564 .53 Mdot
.32228 .48663 Mdot
.80775 .48547 Mdot
.33477 .52701 Mdot
.90201 .56724 Mdot
.11268 .21067 Mdot
.59886 .48618 Mdot
.73341 .13455 Mdot
.97601 .24259 Mdot
.38591 .4099 Mdot
.06381 .67791 Mdot
.30691 .2431 Mdot
.5064 .19949 Mdot
.75065 .24425 Mdot
.10897 .35833 Mdot
.76271 .65374 Mdot
.52699 .76427 Mdot
.47927 .95228 Mdot
.28683 .80756 Mdot
.01 .72317 Mdot
.66321 .65321 Mdot
.26891 .6057 Mdot
.76837 .49946 Mdot
.37451 .60614 Mdot
.19042 .81592 Mdot
.96941 .77898 Mdot
.96123 .99183 Mdot
.22175 .26051 Mdot
.38568 .16394 Mdot
.81647 .43078 Mdot
.26559 .44912 Mdot
.60596 .34037 Mdot
.63445 .02849 Mdot
.49609 .86163 Mdot
.33032 .83424 Mdot
.18936 .85904 Mdot
.0142 .82484 Mdot
.73975 .72555 Mdot
.57707 .83732 Mdot
.93305 .35597 Mdot
.744 .81095 Mdot
.66825 .92425 Mdot
.56281 .89456 Mdot
.88569 .32288 Mdot
.94171 .05602 Mdot
.3967 .45499 Mdot
.17829 .78159 Mdot
.95698 .77869 Mdot
.03316 .07618 Mdot
.87891 .84575 Mdot
.49285 .61394 Mdot
.05676 .56391 Mdot
.23171 .17494 Mdot
.29992 .06821 Mdot
.30839 .00847 Mdot
.27692 .96853 Mdot
.14726 .87034 Mdot
.12771 .98045 Mdot
.3071 .17939 Mdot
.44334 .13624 Mdot
.19127 .74793 Mdot
.90011 .70884 Mdot
.26316 .36305 Mdot
.51594 .25278 Mdot
.88011 .36417 Mdot
.00636 .12625 Mdot
.08812 .08176 Mdot
.5841 .49598 Mdot
.64173 .05764 Mdot
.56547 .92373 Mdot
.93465 .36918 Mdot
.74855 .8139 Mdot
.67648 .92794 Mdot
.60175 .92526 Mdot
.19172 .58997 Mdot
.74147 .54976 Mdot
.40372 .66224 Mdot
.43233 .02862 Mdot
.00142 .56909 Mdot
.56055 .55912 Mdot
.53335 .97281 Mdot
.73793 .20457 Mdot
.05338 .31545 Mdot
.00215 .94877 Mdot
.93589 .93374 Mdot
.30636 .37047 Mdot
.63187 .32551 Mdot
.77845 .14657 Mdot
.02136 .24291 Mdot
.11521 .09386 Mdot
.47119 .35597 Mdot
.62658 .15539 Mdot
.57752 .95094 Mdot
.0499 .47238 Mdot
.17868 .12878 Mdot
.30337 .12469 Mdot
.37604 .07267 Mdot
.66613 .29008 Mdot
.91915 .25302 Mdot
.71411 .79496 Mdot
.59494 .88083 Mdot
.1016 .50667 Mdot
.94439 .84279 Mdot
.16859 .2242 Mdot
.42131 .25272 Mdot
.14536 .72405 Mdot
.98758 .84222 Mdot
.91668 .9291 Mdot
.40275 .48607 Mdot
.24966 .84691 Mdot
.98249 .73283 Mdot
.83764 .85515 Mdot
.64219 .80455 Mdot
.31485 .67266 Mdot
.96462 .64977 Mdot
.86004 .89542 Mdot
.61371 .75368 Mdot
.09736 .48365 Mdot
.9412 .84384 Mdot
.18733 .24613 Mdot
.40463 .2173 Mdot
.99359 .58896 Mdot
.62738 .63379 Mdot
.06066 .43327 Mdot
.07953 .01887 Mdot
.56457 .48504 Mdot
.48932 .92475 Mdot
.33939 .85007 Mdot
.24651 .90713 Mdot
.03982 .79331 Mdot
.55727 .51744 Mdot
.46698 .90971 Mdot
.14721 .68023 Mdot
.93774 .79053 Mdot
.15305 .21531 Mdot
.45466 .3016 Mdot
.44313 .98847 Mdot
.0419 .59878 Mdot
.35074 .30884 Mdot
.76131 .41057 Mdot
.28315 .52184 Mdot
.71499 .43184 Mdot
.23406 .51907 Mdot
.64463 .41057 Mdot
.93392 .28929 Mdot
.67258 .73866 Mdot
.39609 .72351 Mdot
.44279 .0467 Mdot
.09755 .65477 Mdot
.11142 .01387 Mdot
.40752 .2961 Mdot
.09205 .68453 Mdot
.16756 .07551 Mdot
.27513 .10757 Mdot
.28247 .00734 Mdot
.19884 .91637 Mdot
.05819 .85935 Mdot
.51924 .46105 Mdot
.11462 .59539 Mdot
.97523 .8606 Mdot
.00854 .03332 Mdot
.98209 .97355 Mdot
.08074 .09865 Mdot
.63814 .5574 Mdot
.04559 .40745 Mdot
.13825 .09265 Mdot
.38036 .24212 Mdot
.86168 .48132 Mdot
.19387 .33219 Mdot
.48054 .28668 Mdot
.63137 .15083 Mdot
.60087 .9695 Mdot
.23015 .62928 Mdot
.754 .52385 Mdot
.39158 .63758 Mdot
.32757 .93599 Mdot
.27917 .95161 Mdot
.13536 .85619 Mdot
.15418 .01882 Mdot
.25479 .10061 Mdot
.24183 .98703 Mdot
.11624 .87442 Mdot
.24739 .13115 Mdot
.26461 .01721 Mdot
.17243 .90782 Mdot
.0959 .92347 Mdot
.38798 .29208 Mdot
.95907 .57109 Mdot
.81352 .85444 Mdot
.6945 .88098 Mdot
.6225 .92801 Mdot
.32584 .70333 Mdot
.03919 .71335 Mdot
.48098 .44179 Mdot
.78996 .30898 Mdot
.17809 .38813 Mdot
.56393 .38584 Mdot
.38534 .82141 Mdot
.47176 .08642 Mdot
.36153 .88977 Mdot
.39974 .03822 Mdot
.78167 .38193 Mdot
.2557 .47402 Mdot
.61635 .36065 Mdot
.72083 .10448 Mdot
.92074 .19991 Mdot
.65283 .73209 Mdot
.29774 .64491 Mdot
.8783 .58056 Mdot
.23014 .35185 Mdot
.47656 .24642 Mdot
.55953 .08296 Mdot
.04951 .48999 Mdot
.19846 .14895 Mdot
.29123 .09276 Mdot
.30708 .01585 Mdot
.27971 .97264 Mdot
.15762 .87791 Mdot
.10391 .94629 Mdot
.37343 .26952 Mdot
.84742 .47399 Mdot
.23323 .38582 Mdot
.51114 .27791 Mdot
.86699 .35585 Mdot
.04924 .18224 Mdot
.8923 .84306 Mdot
.43304 .54074 Mdot
.51878 .08574 Mdot
.73565 .21688 Mdot
.06209 .32644 Mdot
.96482 .90273 Mdot
.11178 .14696 Mdot
.53902 .42724 Mdot
.23669 .69766 Mdot
.82416 .58748 Mdot
.40695 .58279 Mdot
.37484 .9679 Mdot
.55418 .17934 Mdot
.10551 .55132 Mdot
.9712 .8657 Mdot
.03738 .06617 Mdot
.84431 .80694 Mdot
.57538 .73106 Mdot
.81459 .23921 Mdot
.0774 .26281 Mdot
.81953 .74213 Mdot
.57111 .75158 Mdot
.80408 .23297 Mdot
.08743 .28335 Mdot
.78908 .70165 Mdot
.5714 .78231 Mdot
.8369 .2655 Mdot
.05451 .21762 Mdot
.89797 .84345 Mdot
.40773 .50977 Mdot
.30719 .89946 Mdot
.16373 .85654 Mdot
.06588 .90215 Mdot
.51992 .45404 Mdot
.11301 .59309 Mdot
.97985 .86684 Mdot
.98736 .00751 Mdot
.08326 .09591 Mdot
.62255 .53928 Mdot
.93737 .31482 Mdot
.67938 .74202 Mdot
.42761 .74823 Mdot
.68641 .2588 Mdot
.97155 .28514 Mdot
.45478 .48323 Mdot
.6257 .17092 Mdot
.58785 .96215 Mdot
.13417 .54632 Mdot
.84866 .71449 Mdot
.46995 .62129 Mdot
.88214 .41219 Mdot
.04599 .16385 Mdot
.89238 .84639 Mdot
.43601 .54364 Mdot
.5437 .10769 Mdot
.9535 .40979 Mdot
.68419 .73069 Mdot
.43505 .75087 Mdot
.74379 .30874 Mdot
.16577 .42198 Mdot
.62607 .4603 Mdot
.87945 .25338 Mdot
.89827 .01881 Mdot
.5 .05 Mdot
.55 .05 Mdot
.94427 .39427 Mdot
.72072 .77645 Mdot
.59246 .87174 Mdot
.07561 .48315 Mdot
.04917 .97355 Mdot
.68401 .63484 Mdot
.33853 .65452 Mdot
.04692 .70839 Mdot
.43159 .38467 Mdot
.35199 .9204 Mdot
.37935 .02736 Mdot
.64073 .26139 Mdot
.7638 .12306 Mdot
.99676 .23296 Mdot
.2524 .25564 Mdot
.39408 .14168 Mdot
.84788 .45379 Mdot
.21164 .36376 Mdot
.49352 .28188 Mdot
.73006 .23654 Mdot
.07196 .3419 Mdot
.9271 .85514 Mdot
.27486 .34776 Mdot
.52211 .24724 Mdot
.92361 .4015 Mdot
.83957 .91596 Mdot
.6978 .85824 Mdot
.61074 .91294 Mdot
.23783 .62709 Mdot
.75409 .51626 Mdot
.38406 .62997 Mdot
.27238 .88832 Mdot
.05761 .78523 Mdot
.44833 .39072 Mdot
.4837 .03537 Mdot
.40514 .92145 Mdot
.70122 .29607 Mdot
.05944 .35823 Mdot
.01117 .95172 Mdot
.88478 .87362 Mdot
.4963 .61151 Mdot
.08188 .58559 Mdot
.11924 .03735 Mdot
.39785 .27861 Mdot
.0095 .61165 Mdot
.55471 .54522 Mdot
.47543 .92072 Mdot
.22488 .74944 Mdot
.87409 .64921 Mdot
.31557 .44149 Mdot
.73621 .42063 Mdot
.26674 .53054 Mdot
.68935 .42261 Mdot
.14613 .45678 Mdot
.71777 .57164 Mdot
.38074 .66297 Mdot
.28485 .90411 Mdot
.10147 .81662 Mdot
.25494 .15347 Mdot
.29487 .03992 Mdot
.26468 .96982 Mdot
.12515 .86047 Mdot
.1971 .07195 Mdot
.21594 .01884 Mdot
.14611 .93017 Mdot
.19123 .04512 Mdot
.19736 .00612 Mdot
.14979 .95243 Mdot
.20178 .052 Mdot
.19043 .98865 Mdot
.14212 .95169 Mdot
.22601 .08389 Mdot
.20844 .98244 Mdot
.11456 .90612 Mdot
.28624 .17168 Mdot
.37258 .08635 Mdot
.65927 .28669 Mdot
.88388 .22461 Mdot
.85111 .96723 Mdot
.71507 .86396 Mdot
.6664 .95133 Mdot
.58161 .91521 Mdot
.04335 .46174 Mdot
.2054 .16206 Mdot
.29683 .09143 Mdot
.32205 .02522 Mdot
.34539 .02334 Mdot
.44883 .10344 Mdot
.20026 .75142 Mdot
.89157 .69131 Mdot
.28453 .39297 Mdot
.58954 .305 Mdot
.48875 .89921 Mdot
.30929 .82054 Mdot
.09214 .78286 Mdot
.26544 .1733 Mdot
.3299 .06446 Mdot
.41772 .08783 Mdot
.95493 .5372 Mdot
.80344 .84852 Mdot
.70382 .90038 Mdot
.67172 .9679 Mdot
.62163 .94991 Mdot
.34247 .72084 Mdot
.13206 .78958 Mdot
.09972 .96766 Mdot
.41414 .31443 Mdot
.15629 .74215 Mdot
.97195 .81566 Mdot
.98292 .01097 Mdot
.1132 .13027 Mdot
.51623 .40303 Mdot
.03266 .51643 Mdot
.32207 .28941 Mdot
.60967 .2876 Mdot
.60562 .99595 Mdot
.28784 .68222 Mdot
.88731 .59947 Mdot
.21132 .32401 Mdot
.45398 .24266 Mdot
.37901 .92502 Mdot
.53634 .15734 Mdot
.94589 .40954 Mdot
.72697 .78108 Mdot
.61049 .88352 Mdot
.20676 .59628 Mdot
.72981 .52305 Mdot
.358 .62819 Mdot
.11892 .76092 Mdot
.12272 .0038 Mdot
.35011 .22739 Mdot
.67664 .32653 Mdot
.00096 .32433 Mdot
.31855 .31759 Mdot
.62382 .30527 Mdot
.71099 .08717 Mdot
.87895 .16796 Mdot
.81488 .93592 Mdot
.7736 .95872 Mdot
.83418 .06058 Mdot
.85662 .02244 Mdot
.75238 .89576 Mdot
.7621 .00972 Mdot
.88269 .12059 Mdot
.75211 .86942 Mdot
.73552 .98341 Mdot
.8284 .09288 Mdot
.90291 .0745 Mdot
.61569 .71278 Mdot
.06884 .45315 Mdot
.055 .98616 Mdot
.66377 .60877 Mdot
.22705 .56329 Mdot
.68781 .46076 Mdot
.1787 .49088 Mdot
.66544 .48675 Mdot
.11271 .44727 Mdot
.83532 .72261 Mdot
.51573 .68041 Mdot
.30606 .79033 Mdot
.05071 .74465 Mdot
.44636 .39564 Mdot
.47356 .0272 Mdot
.31652 .84296 Mdot
.14129 .82477 Mdot
.10192 .96063 Mdot
.39688 .29496 Mdot
.01948 .6226 Mdot
.50607 .48659 Mdot
.0351 .52904 Mdot
.32042 .28532 Mdot
.59893 .27851 Mdot
.52618 .92725 Mdot
.63587 .10969 Mdot
.58523 .94937 Mdot
.10312 .51789 Mdot
.94862 .84551 Mdot
.14754 .19892 Mdot
.45536 .30782 Mdot
.4548 .99943 Mdot
.14203 .68724 Mdot
.96185 .81982 Mdot
.04615 .0843 Mdot
.8119 .76575 Mdot
.60853 .79663 Mdot
.10734 .49881 Mdot
.91045 .80311 Mdot
.30785 .3974 Mdot
.66397 .35612 Mdot
.97536 .31138 Mdot
.45855 .4832 Mdot
.6549 .19634 Mdot
.77226 .11737 Mdot
.99283 .22057 Mdot
.26355 .27072 Mdot
.42422 .16067 Mdot
.07422 .65 Mdot
.22333 .14911 Mdot
.27396 .05064 Mdot
.22311 .94915 Mdot
.07404 .85093 Mdot
.42518 .35114 Mdot
.27166 .84648 Mdot
.01434 .74269 Mdot
.65676 .64241 Mdot
.22746 .5707 Mdot
.69523 .46777 Mdot
.21177 .51654 Mdot
.64621 .43444 Mdot
.96612 .31991 Mdot
.52139 .55527 Mdot
.22594 .70455 Mdot
.82911 .60317 Mdot
.41155 .58244 Mdot
.40624 .99468 Mdot
.78189 .37565 Mdot
.24934 .46745 Mdot
.60271 .35337 Mdot
.62619 .02348 Mdot
.44332 .81713 Mdot
.87198 .42867 Mdot
.10321 .23123 Mdot
.66153 .55832 Mdot
.16621 .50468 Mdot
.70766 .54145 Mdot
.32401 .61635 Mdot
.94458 .62057 Mdot
.94531 .00074 Mdot
.32137 .37606 Mdot
.69352 .37214 Mdot
.11033 .41681 Mdot
.81523 .70491 Mdot
.54195 .72671 Mdot
.55891 .01696 Mdot
.97886 .41995 Mdot
.54636 .56751 Mdot
.43385 .88749 Mdot
.87151 .43766 Mdot
.11402 .24251 Mdot
.62492 .5109 Mdot
.92322 .2983 Mdot
.73835 .81513 Mdot
.66459 .92623 Mdot
.54828 .88369 Mdot
.76475 .21647 Mdot
.09053 .32578 Mdot
.81623 .72571 Mdot
.56094 .7447 Mdot
.72184 .1609 Mdot
.97943 .25759 Mdot
.38063 .4012 Mdot
.02238 .64175 Mdot
.50801 .48563 Mdot
.04968 .54167 Mdot
.24923 .19955 Mdot
.33471 .08548 Mdot
.46023 .12552 Mdot
.31026 .85003 Mdot
.12509 .81484 Mdot
.15169 .0266 Mdot
.27007 .11838 Mdot
.28321 .01314 Mdot
.20643 .92322 Mdot
.05705 .85063 Mdot
.5168 .45975 Mdot
.09397 .57717 Mdot
.0509 .95693 Mdot
.65758 .60668 Mdot
.19573 .53815 Mdot
.68394 .48821 Mdot
.19163 .50769 Mdot
.65933 .4677 Mdot
.06516 .40583 Mdot
.02752 .96236 Mdot
.79821 .77069 Mdot
.63226 .83405 Mdot
.28922 .65695 Mdot
.86574 .57652 Mdot
.27452 .40878 Mdot
.5824 .30789 Mdot
.44168 .85928 Mdot
.90181 .46013 Mdot
.00649 .10468 Mdot
.06575 .05926 Mdot
.67774 .61199 Mdot
.29093 .61319 Mdot
.82667 .53574 Mdot
.34971 .52305 Mdot
.97027 .62056 Mdot
.79774 .82747 Mdot
.68955 .89181 Mdot
.61605 .9265 Mdot
.28483 .66878 Mdot
.86609 .58126 Mdot
.27796 .41187 Mdot
.5929 .31494 Mdot
.52182 .92892 Mdot
.60299 .08117 Mdot
.35579 .7528 Mdot
.23169 .8759 Mdot
.00087 .76918 Mdot
.76399 .76312 Mdot
.63689 .87291 Mdot
.35419 .71729 Mdot
.1877 .83351 Mdot
.9914 .8037 Mdot
.85527 .86387 Mdot
.59828 .74301 Mdot
.98633 .38806 Mdot
.46993 .4836 Mdot
.74429 .27436 Mdot
.13201 .38772 Mdot
.69804 .56604 Mdot
.31933 .62128 Mdot
.93057 .61124 Mdot
.01257 .08201 Mdot
.00666 .99409 Mdot
.95413 .94747 Mdot
.21825 .26412 Mdot
.39038 .17213 Mdot
.8544 .46402 Mdot
.2013 .3469 Mdot
.48587 .28457 Mdot
.67166 .18579 Mdot
.83928 .16762 Mdot
.95025 .11097 Mdot
.40384 .45359 Mdot
.22452 .82068 Mdot
.94537 .72084 Mdot
.04118 .09582 Mdot
.85193 .81075 Mdot
.55598 .70404 Mdot
.64383 .08786 Mdot
.60696 .96313 Mdot
.26374 .65678 Mdot
.81058 .54684 Mdot
.39176 .58118 Mdot
.27237 .8806 Mdot
.04986 .7775 Mdot
.484 .43414 Mdot
.80634 .32234 Mdot
.17369 .36735 Mdot
.55259 .3789 Mdot
.29294 .74035 Mdot
.9595 .66656 Mdot
.90653 .94703 Mdot
.47088 .56435 Mdot
.83256 .36167 Mdot
.16176 .3292 Mdot
.54376 .382 Mdot
.22827 .6845 Mdot
.80905 .58079 Mdot
.42811 .61906 Mdot
.56088 .13277 Mdot
.10952 .54864 Mdot
.9506 .84107 Mdot
.13197 .18137 Mdot
.49183 .35986 Mdot
.79455 .30272 Mdot
.16799 .37344 Mdot
.572 .40401 Mdot
.46301 .89101 Mdot
.09745 .63444 Mdot
.09156 .9941 Mdot
.47954 .38798 Mdot
.72468 .24514 Mdot
.06983 .34515 Mdot
.94169 .87186 Mdot
.21264 .27095 Mdot
.40006 .18742 Mdot
.93297 .53291 Mdot
.92134 .98836 Mdot
.4382 .51686 Mdot
.53326 .09506 Mdot
.85941 .32616 Mdot
.0466 .18718 Mdot
.91224 .86564 Mdot
.36156 .44932 Mdot
.95946 .5979 Mdot
.83807 .87861 Mdot
.6645 .82642 Mdot
.44805 .78356 Mdot
.87441 .42635 Mdot
.09147 .21707 Mdot
.70291 .61144 Mdot
.38002 .67711 Mdot
.29459 .91457 Mdot
.13852 .84393 Mdot
.13068 .99216 Mdot
.30747 .17679 Mdot
.44202 .13455 Mdot
.17965 .73763 Mdot
.91027 .73061 Mdot
.23626 .326 Mdot
.45232 .21606 Mdot
.33959 .88727 Mdot
.28469 .94509 Mdot
.14205 .85736 Mdot
.13193 .98989 Mdot
0 .1 Mdot
.1 .1 Mdot
.54516 .44516 Mdot
.30219 .75704 Mdot
.00452 .70232 Mdot
.67523 .67071 Mdot
.33932 .6641 Mdot
.06024 .72092 Mdot
.36947 .30922 Mdot
.864 .49454 Mdot
.19883 .33482 Mdot
.47666 .27783 Mdot
.5917 .11504 Mdot
.31369 .72199 Mdot
.00961 .69592 Mdot
.6383 .62869 Mdot
.11775 .47945 Mdot
.84612 .72838 Mdot
.49149 .64537 Mdot
.07735 .58585 Mdot
.14284 .06549 Mdot
.33739 .19455 Mdot
.58162 .24424 Mdot
.37251 .79089 Mdot
.3634 .99089 Mdot
.51123 .14783 Mdot
.73765 .22641 Mdot
.07479 .33714 Mdot
.90747 .83268 Mdot
.35199 .44452 Mdot
.90344 .55145 Mdot
.09012 .18669 Mdot
.67913 .58901 Mdot
.2736 .59447 Mdot
.76621 .49261 Mdot
.36713 .60092 Mdot
.14228 .77515 Mdot
.04893 .90665 Mdot
.61844 .56952 Mdot
.94263 .32419 Mdot
.65975 .71712 Mdot
.3166 .65684 Mdot
.95547 .63887 Mdot
.902 .94653 Mdot
.49199 .58999 Mdot
.02596 .53396 Mdot
.37902 .35307 Mdot
.96448 .58546 Mdot
.79652 .83204 Mdot
.69539 .89887 Mdot
.64341 .94802 Mdot
.46486 .82145 Mdot
.04234 .57748 Mdot
.3269 .28455 Mdot
.6249 .298 Mdot
.71015 .08525 Mdot
.87475 .1646 Mdot
.82837 .95362 Mdot
.76372 .93535 Mdot
.80902 .0453 Mdot
.89267 .08365 Mdot
.67195 .77927 Mdot
.43399 .76205 Mdot
.74712 .31313 Mdot
.17416 .42703 Mdot
.61123 .43707 Mdot
.76503 .1538 Mdot
.02795 .26292 Mdot
.09623 .06827 Mdot
.53122 .43499 Mdot
.18332 .6521 Mdot
.81769 .63437 Mdot
.46689 .64919 Mdot
.88596 .41908 Mdot
.03672 .15076 Mdot
.93269 .89597 Mdot
.2859 .3532 Mdot
.55323 .26734 Mdot
.1863 .63307 Mdot
.79333 .60702 Mdot
.47341 .68008 Mdot
.9682 .49479 Mdot
.68412 .71593 Mdot
.42006 .73593 Mdot
.61964 .19958 Mdot
.57999 .96036 Mdot
.077 .49701 Mdot
.05578 .97878 Mdot
.65205 .59627 Mdot
.15799 .50594 Mdot
.7309 .57291 Mdot
.40989 .67899 Mdot
.49124 .08136 Mdot
.51133 .02009 Mdot
.61067 .09934 Mdot
.42377 .8131 Mdot
.72346 .29969 Mdot
.12178 .39832 Mdot
.74842 .62665 Mdot
.4891 .74068 Mdot
.15354 .66444 Mdot
.90232 .74878 Mdot
.29272 .3904 Mdot
.60893 .31621 Mdot
.6295 .02057 Mdot
.45978 .83028 Mdot
.01149 .55171 Mdot
.48286 .47137 Mdot
.83446 .3516 Mdot
.14693 .31247 Mdot
.5709 .42397 Mdot
.47489 .90399 Mdot
.20381 .72892 Mdot
.86524 .66143 Mdot
.36125 .49601 Mdot
.00443 .64318 Mdot
.61659 .61216 Mdot
.97384 .35725 Mdot
.51339 .53955 Mdot
.14654 .63315 Mdot
.89283 .74629 Mdot
.33388 .44105 Mdot
.81204 .47816 Mdot
.3207 .50866 Mdot
.82342 .50272 Mdot
.32376 .50034 Mdot
.82754 .50378 Mdot
.31577 .48822 Mdot
.78369 .46792 Mdot
.34083 .55714 Mdot
.96043 .6196 Mdot
.85418 .89375 Mdot
.63174 .77756 Mdot
.22969 .59796 Mdot
.72262 .49293 Mdot
.31319 .59057 Mdot
.87635 .56316 Mdot
.22056 .34421 Mdot
.46969 .24913 Mdot
.5079 .03822 Mdot
.60142 .09351 Mdot
.35776 .75635 Mdot
.2458 .88804 Mdot
.02015 .77434 Mdot
.65384 .63369 Mdot
.20439 .55055 Mdot
.68629 .4819 Mdot
.1942 .50791 Mdot
.6558 .4616 Mdot
.04197 .38617 Mdot
.13774 .09577 Mdot
.38526 .24751 Mdot
.89736 .5121 Mdot
.07917 .18182 Mdot
.72935 .65018 Mdot
.48425 .7549 Mdot
.1291 .64485 Mdot
.96614 .83704 Mdot
.03841 .07227 Mdot
.84442 .80601 Mdot
.57415 .72973 Mdot
.80434 .23019 Mdot
.08431 .27997 Mdot
.80133 .71703 Mdot
.57499 .77366 Mdot
.85441 .27941 Mdot
.01666 .16225 Mdot
.06251 .04585 Mdot
.68196 .61945 Mdot
.31522 .63326 Mdot
.92664 .61142 Mdot
.0336 .10696 Mdot
.90711 .87351 Mdot
.39457 .48746 Mdot
.19682 .80225 Mdot
.9466 .74979 Mdot
.06319 .11659 Mdot
.74898 .68579 Mdot
.54883 .79985 Mdot
.68512 .13629 Mdot
.84419 .15907 Mdot
.92788 .08369 Mdot
.49931 .57142 Mdot
.06587 .56656 Mdot
.18441 .11855 Mdot
.28214 .09773 Mdot
.28843 .00628 Mdot
.21294 .92451 Mdot
.05344 .8405 Mdot
.52687 .47343 Mdot
.18751 .66064 Mdot
.81884 .63133 Mdot
.46165 .64281 Mdot
.83862 .37697 Mdot
.16138 .32276 Mdot
.53834 .37696 Mdot
.18112 .64277 Mdot
.81253 .63141 Mdot
.47314 .66061 Mdot
.94662 .47348 Mdot
.78677 .84015 Mdot
.7114 .92463 Mdot
.71751 .00611 Mdot
.81456 .09705 Mdot
.93529 .12073 Mdot
.49661 .56132 Mdot
.03422 .53761 Mdot
.33414 .29992 Mdot
.67206 .33792 Mdot
.99313 .32107 Mdot
.36227 .36914 Mdot
.88324 .52096 Mdot
.15017 .26694 Mdot
.51509 .36491 Mdot
.98545 .47037 Mdot
.55751 .57205 Mdot
.5234 .96589 Mdot
.65249 .12909 Mdot
.693 .04052 Mdot
.77692 .08392 Mdot
.95903 .1821 Mdot
.42479 .46576 Mdot
.38344 .95865 Mdot
.59715 .21372 Mdot
.4495 .85234 Mdot
.95424 .50474 Mdot
.7749 .82065 Mdot
.69603 .92114 Mdot
.66781 .97178 Mdot
.60841 .94059 Mdot
.25052 .64211 Mdot
.77855 .52803 Mdot
.40279 .62424 Mdot
.38809 .9853 Mdot
.65297 .26488 Mdot
.83123 .17826 Mdot
.98159 .15035 Mdot
.26054 .27896 Mdot
.42786 .16732 Mdot
.10733 .67947 Mdot
.09116 .98383 Mdot
.47119 .38003 Mdot
.65066 .17947 Mdot
.73415 .08349 Mdot
.92621 .19206 Mdot
.61649 .69028 Mdot
.05132 .43483 Mdot
.13309 .08176 Mdot
.38808 .25499 Mdot
.92263 .53455 Mdot
.9777 .05507 Mdot
.18838 .21068 Mdot
.36744 .17907 Mdot
.72223 .35479 Mdot
.17418 .45195 Mdot
.63609 .46191 Mdot
.93873 .30263 Mdot
.65976 .72103 Mdot
.32053 .66077 Mdot
.97483 .6543 Mdot
.80458 .82975 Mdot
.68354 .87896 Mdot
.58086 .89732 Mdot
.02014 .43928 Mdot
.31881 .29867 Mdot
.60591 .2871 Mdot
.58088 .97497 Mdot
.09799 .5171 Mdot
.9717 .87371 Mdot
.04247 .07077 Mdot
.81948 .77701 Mdot
.60609 .78661 Mdot
.08155 .47546 Mdot
.01082 .92928 Mdot
.86439 .85357 Mdot
.55646 .69206 Mdot
.63547 .07901 Mdot
.55234 .91687 Mdot
.82899 .27665 Mdot
.08531 .25633 Mdot
.77263 .68732 Mdot
.56279 .79016 Mdot
.78117 .21838 Mdot
.09234 .31117 Mdot
.7928 .70046 Mdot
.56731 .77451 Mdot
.79903 .23173 Mdot
.09239 .29336 Mdot
.77473 .68234 Mdot
.55773 .783 Mdot
.73608 .17834 Mdot
.02424 .28816 Mdot
.14339 .11915 Mdot
.3892 .24582 Mdot
.9206 .53139 Mdot
.98503 .06443 Mdot
.15409 .16906 Mdot
.4053 .25121 Mdot
.03204 .62674 Mdot
.43603 .40399 Mdot
.40418 .96815 Mdot
.74141 .33723 Mdot
.1911 .44969 Mdot
.60213 .41102 Mdot
.67997 .07785 Mdot
.76579 .08582 Mdot
.96022 .19442 Mdot
.43022 .47 Mdot
.42727 .99705 Mdot
.93277 .5055 Mdot
.89501 .96224 Mdot
.54002 .64501 Mdot
.46224 .92222 Mdot
.12258 .66034 Mdot
.00721 .88463 Mdot
.84137 .83415 Mdot
.61101 .76964 Mdot
.09623 .48522 Mdot
.94814 .85191 Mdot
.15669 .20855 Mdot
.43721 .28051 Mdot
.28947 .85227 Mdot
.06175 .77228 Mdot
.41253 .35078 Mdot
.18138 .76885 Mdot
.9381 .75672 Mdot
.11727 .17917 Mdot
.54783 .43056 Mdot
.30822 .76039 Mdot
.02825 .72002 Mdot
.55157 .52332 Mdot
.42962 .87805 Mdot
.83089 .40127 Mdot
.20543 .37454 Mdot
.50929 .30386 Mdot
.87811 .36883 Mdot
.01915 .14104 Mdot
.02644 .00729 Mdot
.84948 .82303 Mdot
.57597 .7265 Mdot
.81432 .23835 Mdot
.077 .26269 Mdot
.82144 .74444 Mdot
.56959 .74815 Mdot
.78951 .21991 Mdot
.08936 .29985 Mdot
.79605 .70669 Mdot
.57052 .77447 Mdot
.8226 .25209 Mdot
.07485 .25225 Mdot
.82224 .74738 Mdot
.57091 .74867 Mdot
.79968 .22877 Mdot
.0887 .28902 Mdot
.78847 .69977 Mdot
.56994 .78147 Mdot
.82538 .25544 Mdot
.07227 .2469 Mdot
.83047 .7582 Mdot
.56336 .73289 Mdot
.72813 .16478 Mdot
.99649 .26836 Mdot
.28939 .2929 Mdot
.50215 .21276 Mdot
.72997 .22782 Mdot
.06307 .3331 Mdot
.96612 .90305 Mdot
.10452 .1384 Mdot
.56273 .45821 Mdot
.4488 .88606 Mdot
.98259 .53379 Mdot
.63803 .65544 Mdot
.14303 .505 Mdot
.77625 .63322 Mdot
.50844 .73219 Mdot
.29964 .7912 Mdot
.0305 .73087 Mdot
.54915 .51865 Mdot
.40641 .85726 Mdot
.64565 .23924 Mdot
.76794 .1223 Mdot
.99725 .22931 Mdot
.24579 .24853 Mdot
.38062 .13484 Mdot
.75601 .37539 Mdot
.24469 .48868 Mdot
.6199 .37521 Mdot
.75724 .13734 Mdot
.00751 .25027 Mdot
.20523 .19772 Mdot
.33265 .12743 Mdot
.49288 .16023 Mdot
.60327 .11039 Mdot
.3869 .78363 Mdot
.4438 .0569 Mdot
.11539 .6716 Mdot
.04817 .93278 Mdot
.64887 .6007 Mdot
.14623 .49736 Mdot
.75804 .61181 Mdot
.48251 .72447 Mdot
.5 .1 Mdot
.6 .1 Mdot
.35484 .75484 Mdot
.22871 .87387 Mdot
.99845 .76974 Mdot
.77906 .78061 Mdot
.65524 .87618 Mdot
.45379 .79855 Mdot
.93343 .47963 Mdot
.8656 .93217 Mdot
.63068 .76508 Mdot
.21114 .58046 Mdot
.71056 .49942 Mdot
.29003 .57947 Mdot
.79048 .50044 Mdot
.36917 .57869 Mdot
.13176 .76259 Mdot
.07382 .94206 Mdot
.51746 .44364 Mdot
.08309 .56563 Mdot
.09316 .01007 Mdot
.48773 .39458 Mdot
.79654 .30881 Mdot
.17214 .37559 Mdot
.56433 .3922 Mdot
.3947 .83037 Mdot
.54057 .14587 Mdot
.96734 .42677 Mdot
.62112 .65378 Mdot
.04325 .42213 Mdot
.16635 .1231 Mdot
.32574 .15939 Mdot
.49483 .16909 Mdot
.62777 .13294 Mdot
.56209 .93432 Mdot
.92011 .35802 Mdot
.81417 .89406 Mdot
.73298 .91881 Mdot
.75951 .02653 Mdot
.89813 .13862 Mdot
.70214 .80401 Mdot
.57026 .86811 Mdot
.91436 .3441 Mdot
.82942 .91506 Mdot
.72271 .89329 Mdot
.71373 .99103 Mdot
.79005 .07631 Mdot
.94536 .15532 Mdot
.47567 .53031 Mdot
.83637 .3607 Mdot
.15109 .31472 Mdot
.56004 .40895 Mdot
.37936 .81933 Mdot
.43281 .05344 Mdot
.02974 .59693 Mdot
.4197 .38996 Mdot
.27109 .85139 Mdot
.01815 .74707 Mdot
.63842 .62026 Mdot
.10998 .47157 Mdot
.8715 .76152 Mdot
.43792 .56641 Mdot
.58069 .14278 Mdot
.26444 .68374 Mdot
.83867 .57424 Mdot
.35851 .51984 Mdot
.01331 .6548 Mdot
.57504 .56173 Mdot
.64278 .06774 Mdot
.58122 .93844 Mdot
.06387 .48265 Mdot
.11133 .04746 Mdot
.4415 .33017 Mdot
.37132 .92982 Mdot
.49535 .12404 Mdot
.58688 .09152 Mdot
.25677 .6699 Mdot
.81359 .55682 Mdot
.39675 .58316 Mdot
.30677 .91002 Mdot
.17283 .86606 Mdot
.05322 .88039 Mdot
.56797 .51475 Mdot
.54415 .97618 Mdot
.82544 .28129 Mdot
.09799 .27255 Mdot
.72715 .62917 Mdot
.45894 .73179 Mdot
.9065 .44756 Mdot
.97155 .06505 Mdot
.23468 .26313 Mdot
.38888 .1542 Mdot
.82692 .43804 Mdot
.25144 .42452 Mdot
.56193 .31048 Mdot
.29504 .73311 Mdot
.95838 .66334 Mdot
.90975 .95137 Mdot
.45956 .54981 Mdot
.72935 .26979 Mdot
.10385 .37451 Mdot
.80188 .69803 Mdot
.55532 .75344 Mdot
.68826 .13294 Mdot
.85251 .16425 Mdot
.90764 .05513 Mdot
.57362 .66599 Mdot
.73679 .16316 Mdot
.0102 .27341 Mdot
.21227 .20207 Mdot
.33142 .11915 Mdot
.4791 .14768 Mdot
.48089 .00179 Mdot
.34924 .86835 Mdot
.31313 .9639 Mdot
.24944 .93631 Mdot
.07168 .82224 Mdot
.40894 .33726 Mdot
.143 .73406 Mdot
.0054 .86239 Mdot
.83002 .82462 Mdot
.63086 .80085 Mdot
.24795 .61709 Mdot
.75105 .5031 Mdot
.36821 .61716 Mdot
.16473 .79652 Mdot
.00327 .83854 Mdot
.81891 .81564 Mdot
.64583 .82692 Mdot
.35658 .71075 Mdot
.19385 .83727 Mdot
.98566 .79181 Mdot
.87774 .89208 Mdot
.54392 .66619 Mdot
.5137 .96977 Mdot
.57923 .06553 Mdot
.17672 .59749 Mdot
.77615 .59943 Mdot
.47466 .69851 Mdot
.99652 .52186 Mdot
.54276 .54625 Mdot
.38475 .84199 Mdot
.48866 .10391 Mdot
.51328 .02462 Mdot
.63074 .11746 Mdot
.56388 .93314 Mdot
.9323 .36842 Mdot
.76044 .82813 Mdot
.70026 .93982 Mdot
.7002 .99994 Mdot
.76011 .05992 Mdot
.93187 .17175 Mdot
.56611 .63424 Mdot
.64993 .08382 Mdot
.63478 .98485 Mdot
.45432 .81954 Mdot
.95849 .50417 Mdot
.74993 .79143 Mdot
.65544 .90552 Mdot
.48414 .8287 Mdot
.20199 .71785 Mdot
.85606 .65407 Mdot
.38586 .52979 Mdot
.18339 .79754 Mdot
.96299 .7796 Mdot
.99931 .03631 Mdot
.04048 .04117 Mdot
.80136 .76089 Mdot
.61882 .81746 Mdot
.19289 .57407 Mdot
.72383 .53095 Mdot
.35384 .63001 Mdot
.09861 .74477 Mdot
.19644 .09783 Mdot
.24268 .04624 Mdot
.17602 .93334 Mdot
.11349 .93747 Mdot
.32218 .2087 Mdot
.52943 .20725 Mdot
.9415 .41207 Mdot
.7539 .8124 Mdot
.68005 .92615 Mdot
.61439 .93434 Mdot
.28227 .66788 Mdot
.85888 .57661 Mdot
.29889 .44001 Mdot
.67696 .37807 Mdot
.05385 .37689 Mdot
.06092 .00706 Mdot
.65189 .59097 Mdot
.15188 .49999 Mdot
.74289 .59101 Mdot
.44686 .70398 Mdot
.78576 .3389 Mdot
.21074 .42498 Mdot
.55536 .34462 Mdot
.27973 .72437 Mdot
.90939 .62966 Mdot
.13961 .23022 Mdot
.51316 .37355 Mdot
.97871 .46555 Mdot
.59286 .61415 Mdot
.82074 .22788 Mdot
.05447 .23373 Mdot
.91433 .85986 Mdot
.34535 .43102 Mdot
.8563 .51095 Mdot
.24195 .38565 Mdot
.51493 .27299 Mdot
.89231 .37737 Mdot
.96731 .07501 Mdot
.26953 .30221 Mdot
.46603 .1965 Mdot
.42654 .96051 Mdot
.89093 .46439 Mdot
.06042 .16948 Mdot
.81707 .75666 Mdot
.59034 .77327 Mdot
.96255 .37222 Mdot
.59448 .63192 Mdot
.84959 .25511 Mdot
.0077 .1581 Mdot
.11195 .10426 Mdot
.49559 .38363 Mdot
.84832 .35274 Mdot
.10923 .2609 Mdot
.66417 .55494 Mdot
.17509 .51092 Mdot
.69307 .51799 Mdot
.25463 .56156 Mdot
.70257 .44794 Mdot
.21551 .51293 Mdot
.64042 .42491 Mdot
.9256 .28518 Mdot
.71282 .78722 Mdot
.58385 .87103 Mdot
.01507 .43122 Mdot
.34097 .3259 Mdot
.72986 .38889 Mdot
.22393 .49407 Mdot
.61883 .3949 Mdot
.77036 .15153 Mdot
.02687 .25651 Mdot
.09618 .06931 Mdot
.53247 .4363 Mdot
.19451 .66204 Mdot
.80949 .61498 Mdot
.46163 .65213 Mdot
.84774 .38611 Mdot
.14438 .29665 Mdot
.56338 .419 Mdot
.41442 .85104 Mdot
.69487 .28045 Mdot
.02323 .32836 Mdot
.18957 .16634 Mdot
.32117 .1316 Mdot
.44825 .12708 Mdot
.21945 .77119 Mdot
.89702 .67758 Mdot
.24619 .34917 Mdot
.48159 .2354 Mdot
.58843 .10684 Mdot
.28293 .6945 Mdot
.8871 .60417 Mdot
.21693 .32983 Mdot
.45664 .23971 Mdot
.39655 .93991 Mdot
.66224 .26569 Mdot
.87689 .21465 Mdot
.86992 .99303 Mdot
.67547 .80555 Mdot
.47516 .79969 Mdot
.1017 .62653 Mdot
.06382 .96212 Mdot
.59108 .52726 Mdot
.72165 .13057 Mdot
.94868 .22703 Mdot
.52875 .58007 Mdot
.309 .78025 Mdot
.05085 .74185 Mdot
.44276 .39191 Mdot
.44258 .99982 Mdot
.04915 .60656 Mdot
.31712 .26797 Mdot
.56862 .2515 Mdot
.28571 .71709 Mdot
.91665 .63094 Mdot
.10474 .1881 Mdot
.61143 .50669 Mdot
.83597 .22453 Mdot
.01598 .18001 Mdot
.08434 .06836 Mdot
.58959 .50525 Mdot
.68936 .09977 Mdot
.82333 .13397 Mdot
.9552 .13187 Mdot
.39653 .44133 Mdot
.16351 .76698 Mdot
.97691 .8134 Mdot
.95139 .97448 Mdot
.26089 .30951 Mdot
.45893 .19803 Mdot
.37263 .9137 Mdot
.48689 .11426 Mdot
.50949 .0226 Mdot
.59847 .08898 Mdot
.33357 .7351 Mdot
.10466 .77109 Mdot
.19481 .09015 Mdot
.23719 .04238 Mdot
.16909 .9319 Mdot
.12779 .95869 Mdot
.28503 .15724 Mdot
.35506 .07003 Mdot
.54505 .18999 Mdot
.04621 .50116 Mdot
.22843 .18222 Mdot
.30678 .07835 Mdot
.3412 .03442 Mdot
.43947 .09828 Mdot
.12421 .68474 Mdot
.02508 .90087 Mdot
.75112 .72604 Mdot
.59121 .84009 Mdot
.03541 .44419 Mdot
.2338 .19839 Mdot
.32388 .09008 Mdot
.41775 .09387 Mdot
.96117 .54342 Mdot
.7737 .81253 Mdot
.68798 .91428 Mdot
.63283 .94485 Mdot
.40321 .77039 Mdot
.53709 .13388 Mdot
.92827 .39118 Mdot
.80474 .87647 Mdot
.73005 .92531 Mdot
.7607 .03065 Mdot
.90292 .14222 Mdot
.68335 .78044 Mdot
.48161 .79826 Mdot
.1514 .66979 Mdot
.91415 .76275 Mdot
.24912 .33497 Mdot
.47002 .2209 Mdot
.48226 .01225 Mdot
.37062 .88836 Mdot
.44982 .0792 Mdot
.18357 .73375 Mdot
.89887 .7153 Mdot
.27538 .3765 Mdot
.55193 .27655 Mdot
.18558 .63365 Mdot
.79517 .6096 Mdot
.47428 .67911 Mdot
.97413 .49985 Mdot
.65427 .68014 Mdot
.25294 .59868 Mdot
.73773 .48478 Mdot
.33329 .59556 Mdot
.96386 .63058 Mdot
.84522 .88136 Mdot
.64714 .80192 Mdot
.33846 .69132 Mdot
.08342 .74496 Mdot
.27081 .18739 Mdot
.35361 .08281 Mdot
.55021 .1966 Mdot
.09247 .54226 Mdot
.02325 .93078 Mdot
.79188 .76863 Mdot
.63625 .84437 Mdot
.32206 .68582 Mdot
.00606 .684 Mdot
.64764 .64157 Mdot
.1807 .53306 Mdot
.70364 .52294 Mdot
.29372 .59008 Mdot
.81148 .51776 Mdot
.36124 .54976 Mdot
.05814 .6969 Mdot
.35707 .29893 Mdot
.78466 .42759 Mdot
.30002 .51536 Mdot
.75587 .45585 Mdot
.32504 .56917 Mdot
.90169 .57665 Mdot
.12356 .22187 Mdot
.5648 .44123 Mdot
.44718 .88239 Mdot
.9666 .51942 Mdot
.71808 .75148 Mdot
.56132 .84324 Mdot
.82325 .26193 Mdot
.08334 .2601 Mdot
.78634 .703 Mdot
.57451 .78817 Mdot
.86538 .29088 Mdot
.99017 .12479 Mdot
.18372 .19355 Mdot
.3584 .17468 Mdot
0 .15 Mdot
.15 .15 Mdot
.39869 .24869 Mdot
.98512 .58643 Mdot
.67558 .69047 Mdot
.36056 .68498 Mdot
.18964 .82908 Mdot
.9838 .79415 Mdot
.89118 .90739 Mdot
.50231 .61113 Mdot
.12961 .6273 Mdot
.94664 .81702 Mdot
.13025 .18361 Mdot
.50054 .37029 Mdot
.87458 .37404 Mdot
.03847 .16389 Mdot
.93567 .8972 Mdot
.27101 .33534 Mdot
.50196 .23095 Mdot
.74665 .24469 Mdot
.10518 .35853 Mdot
.77986 .67468 Mdot
.54907 .76921 Mdot
.65638 .1073 Mdot
.69049 .03412 Mdot
.76172 .07123 Mdot
.94402 .18229 Mdot
.51016 .56614 Mdot
.14733 .63718 Mdot
.8943 .74697 Mdot
.32797 .43367 Mdot
.7786 .45063 Mdot
.32537 .54677 Mdot
.88068 .55531 Mdot
.19515 .31446 Mdot
.46104 .2659 Mdot
.45696 .99591 Mdot
.15523 .69827 Mdot
.93116 .77593 Mdot
.17408 .24292 Mdot
.42728 .25319 Mdot
.18895 .76167 Mdot
.9175 .72855 Mdot
.19804 .28054 Mdot
.42334 .22531 Mdot
.13257 .70923 Mdot
.01744 .88487 Mdot
.78045 .763 Mdot
.63721 .85676 Mdot
.33982 .7026 Mdot
.10108 .76126 Mdot
.2014 .10032 Mdot
.23918 .03777 Mdot
.16544 .92626 Mdot
.1312 .96576 Mdot
.2791 .1479 Mdot
.33148 .05238 Mdot
.41261 .08113 Mdot
.91226 .49966 Mdot
.99544 .08318 Mdot
.11051 .11506 Mdot
.51269 .40218 Mdot
.00357 .49088 Mdot
.46949 .46592 Mdot
.72314 .25365 Mdot
.07505 .35191 Mdot
.92088 .84583 Mdot
.29803 .37716 Mdot
.61146 .31343 Mdot
.6429 .03144 Mdot
.54556 .90266 Mdot
.76283 .21727 Mdot
.09057 .32773 Mdot
.81801 .72744 Mdot
.55936 .74136 Mdot
.70671 .14734 Mdot
.92717 .22046 Mdot
.63984 .71267 Mdot
.21019 .57036 Mdot
.70113 .49094 Mdot
.25404 .55291 Mdot
.69323 .43919 Mdot
.17638 .48315 Mdot
.66252 .48614 Mdot
.09864 .43612 Mdot
.88766 .78902 Mdot
.39938 .51172 Mdot
.25276 .85338 Mdot
.99223 .73947 Mdot
.78607 .79384 Mdot
.66551 .87944 Mdot
.50568 .84017 Mdot
.38558 .8799 Mdot
.53176 .14618 Mdot
.8988 .36704 Mdot
.92746 .02866 Mdot
.44649 .51902 Mdot
.59794 .15145 Mdot
.3925 .79456 Mdot
.49048 .09799 Mdot
.5219 .03142 Mdot
.70617 .18427 Mdot
.96254 .25637 Mdot
.47873 .51619 Mdot
.84648 .36775 Mdot
.12981 .28334 Mdot
.60191 .4721 Mdot
.73963 .13772 Mdot
.98908 .24944 Mdot
.31492 .32585 Mdot
.6181 .30317 Mdot
.67414 .05604 Mdot
.72008 .04594 Mdot
.86047 .14039 Mdot
.85719 .99672 Mdot
.72474 .86755 Mdot
.69237 .96763 Mdot
.70185 .00948 Mdot
.77483 .07298 Mdot
.94836 .17353 Mdot
.47706 .5287 Mdot
.84575 .36869 Mdot
.13291 .28716 Mdot
.59413 .46121 Mdot
.67647 .08235 Mdot
.75612 .07965 Mdot
.94903 .19291 Mdot
.49265 .54362 Mdot
.98485 .4922 Mdot
.58293 .59808 Mdot
.73561 .15268 Mdot
.99783 .26222 Mdot
.27524 .27741 Mdot
.45253 .1773 Mdot
.30247 .84994 Mdot
.09834 .79586 Mdot
.24881 .15047 Mdot
.28522 .03642 Mdot
.23473 .9495 Mdot
.07527 .84055 Mdot
.40834 .33307 Mdot
.13466 .72632 Mdot
.02687 .89222 Mdot
.73186 .70499 Mdot
.54371 .81185 Mdot
.65773 .11401 Mdot
.70376 .04604 Mdot
.8172 .11344 Mdot
.94688 .12968 Mdot
.44153 .49465 Mdot
.53607 .09453 Mdot
.8809 .34484 Mdot
.98377 .10287 Mdot
.20006 .21629 Mdot
.35666 .15661 Mdot
.64016 .28349 Mdot
.78278 .14262 Mdot
.01594 .23316 Mdot
.1377 .12176 Mdot
.41138 .27368 Mdot
.09631 .68493 Mdot
.14746 .05114 Mdot
.30787 .16041 Mdot
.42702 .11916 Mdot
.05305 .62603 Mdot
.31457 .26152 Mdot
.55245 .23788 Mdot
.15087 .59842 Mdot
.84441 .69355 Mdot
.4617 .61728 Mdot
.81343 .35173 Mdot
.19194 .37851 Mdot
.52968 .33775 Mdot
.07399 .54431 Mdot
.1188 .04481 Mdot
.40709 .28829 Mdot
.08136 .67426 Mdot
.2106 .12924 Mdot
.25972 .04912 Mdot
.19684 .93712 Mdot
.08145 .88461 Mdot
.42049 .33905 Mdot
.22587 .80537 Mdot
.92994 .70407 Mdot
.10876 .17883 Mdot
.58414 .47537 Mdot
.62141 .03727 Mdot
.42848 .80707 Mdot
.75162 .32314 Mdot
.18879 .43716 Mdot
.59326 .40447 Mdot
.61382 .02056 Mdot
.36491 .75109 Mdot
.27991 .915 Mdot
.10043 .82052 Mdot
.26368 .16325 Mdot
.31696 .05328 Mdot
.35332 .03636 Mdot
.50224 .14892 Mdot
.66683 .16459 Mdot
.79682 .12999 Mdot
.99303 .19621 Mdot
.238 .24496 Mdot
.37204 .13405 Mdot
.7038 .33176 Mdot
.10304 .39924 Mdot
.83033 .72729 Mdot
.53278 .70245 Mdot
.4631 .93032 Mdot
.13742 .67432 Mdot
.96494 .82752 Mdot
.03589 .07095 Mdot
.85771 .82182 Mdot
.54807 .69036 Mdot
.56983 .02176 Mdot
.06484 .49502 Mdot
.11841 .05357 Mdot
.41747 .29906 Mdot
.16439 .74692 Mdot
.95455 .79016 Mdot
.05856 .10401 Mdot
.76183 .70327 Mdot
.5761 .81428 Mdot
.90303 .32693 Mdot
.86751 .96448 Mdot
.65595 .78844 Mdot
.36954 .71359 Mdot
.26878 .89924 Mdot
.06169 .79291 Mdot
.43349 .3718 Mdot
.35319 .91969 Mdot
.38487 .03168 Mdot
.67912 .29425 Mdot
.9788 .29967 Mdot
.42646 .44767 Mdot
.37748 .95101 Mdot
.55306 .17559 Mdot
.09325 .54019 Mdot
.0174 .92415 Mdot
.82 .8026 Mdot
.63066 .81065 Mdot
.25657 .62592 Mdot
.76936 .51278 Mdot
.388 .61864 Mdot
.28574 .89775 Mdot
.09738 .81164 Mdot
.26909 .17171 Mdot
.33472 .06563 Mdot
.4404 .10568 Mdot
.13854 .69814 Mdot
.98482 .84628 Mdot
.93719 .95237 Mdot
.3179 .38071 Mdot
.6844 .3665 Mdot
.0717 .38729 Mdot
.97391 .90221 Mdot
.05793 .08401 Mdot
.74535 .68743 Mdot
.54639 .80104 Mdot
.6676 .12121 Mdot
.7569 .0893 Mdot
.95923 .20233 Mdot
.44383 .48459 Mdot
.54331 .09949 Mdot
.94225 .39894 Mdot
.7366 .79435 Mdot
.64109 .90449 Mdot
.40886 .76777 Mdot
.57298 .16412 Mdot
.23027 .65729 Mdot
.78202 .55175 Mdot
.42538 .64336 Mdot
.56535 .13997 Mdot
.15003 .58468 Mdot
.83327 .68325 Mdot
.48155 .64828 Mdot
.00097 .51942 Mdot
.51358 .5126 Mdot
.12112 .60754 Mdot
.96032 .8392 Mdot
.07442 .1141 Mdot
.68636 .61193 Mdot
.32448 .63812 Mdot
.96829 .64381 Mdot
.83262 .86433 Mdot
.66427 .83165 Mdot
.45223 .78797 Mdot
.91082 .45859 Mdot
.96151 .05069 Mdot
.27901 .3175 Mdot
.50089 .22188 Mdot
.72903 .22813 Mdot
.06159 .33256 Mdot
.97372 .91213 Mdot
.069 .09528 Mdot
.69629 .62729 Mdot
.37482 .67853 Mdot
.26467 .88986 Mdot
.04518 .7805 Mdot
.51367 .46849 Mdot
.07773 .56406 Mdot
.11905 .04132 Mdot
.40259 .28354 Mdot
.04603 .64344 Mdot
.37176 .32573 Mdot
.89382 .52207 Mdot
.10521 .21139 Mdot
.63261 .5274 Mdot
.98454 .35193 Mdot
.44452 .45998 Mdot
.52394 .07942 Mdot
.77031 .24637 Mdot
.12171 .3514 Mdot
.70178 .58007 Mdot
.34521 .64342 Mdot
.06802 .72281 Mdot
.32907 .26106 Mdot
.61073 .28166 Mdot
.6065 .99576 Mdot
.29335 .68685 Mdot
.90719 .61384 Mdot
.1345 .22731 Mdot
.52845 .39395 Mdot
.12046 .59201 Mdot
.94749 .82703 Mdot
.13545 .18796 Mdot
.48563 .35018 Mdot
.73538 .24975 Mdot
.09451 .35913 Mdot
.83025 .73574 Mdot
.54142 .71116 Mdot
.53922 .99781 Mdot
.80883 .26961 Mdot
.11727 .30844 Mdot
.6771 .55983 Mdot
.23617 .55907 Mdot
.68536 .44919 Mdot
.15802 .47266 Mdot
.69752 .5395 Mdot
.29108 .59356 Mdot
.80747 .51639 Mdot
.36609 .55862 Mdot
.09411 .72802 Mdot
.20107 .10696 Mdot
.24618 .04511 Mdot
.17753 .93135 Mdot
.10831 .93079 Mdot
.33809 .22978 Mdot
.62013 .28203 Mdot
.66545 .04532 Mdot
.6713 .00585 Mdot
.6578 .9865 Mdot
.5766 .9188 Mdot
.01114 .43454 Mdot
.36779 .35665 Mdot
.90178 .534 Mdot
.08048 .17869 Mdot
.71953 .63905 Mdot
.4523 .73278 Mdot
.85617 .40387 Mdot
.13529 .27912 Mdot
.57737 .44208 Mdot
.53997 .9626 Mdot
.7794 .23943 Mdot
.11396 .33456 Mdot
.71724 .60328 Mdot
.41108 .69384 Mdot
.51438 .10329 Mdot
.71816 .20379 Mdot
.01381 .29565 Mdot
.21291 .19909 Mdot
.32804 .11513 Mdot
.46035 .13231 Mdot
.31799 .85764 Mdot
.16166 .84367 Mdot
.0585 .89684 Mdot
.55501 .49651 Mdot
.42894 .87393 Mdot
.82178 .39285 Mdot
.2173 .39552 Mdot
.52217 .30486 Mdot
.98168 .45952 Mdot
.56914 .58746 Mdot
.62553 .05639 Mdot
.47231 .84678 Mdot
.12619 .65389 Mdot
.98642 .86022 Mdot
.9416 .95519 Mdot
.29646 .35486 Mdot
.58436 .2879 Mdot
.43549 .85114 Mdot
.84735 .41186 Mdot
.17129 .32393 Mdot
.51463 .34334 Mdot
.96024 .44561 Mdot
.68127 .72103 Mdot
.41412 .73284 Mdot
.57453 .16042 Mdot
.23783 .6633 Mdot
.7903 .55247 Mdot
.42133 .63103 Mdot
.5 .15 Mdot
.65 .15 Mdot
.70131 .05131 Mdot
.81499 .11368 Mdot
.95115 .13616 Mdot
.42391 .47276 Mdot
.3841 .96019 Mdot
.60282 .21872 Mdot
.49227 .88945 Mdot
.32761 .83534 Mdot
.17871 .8511 Mdot
.02564 .84694 Mdot
.69386 .66822 Mdot
.40758 .71372 Mdot
.5101 .10252 Mdot
.68325 .17316 Mdot
.87395 .19069 Mdot
.85762 .98367 Mdot
.71024 .85263 Mdot
.64238 .93213 Mdot
.44343 .80105 Mdot
.85676 .41333 Mdot
.1428 .28604 Mdot
.55807 .41528 Mdot
.37091 .81284 Mdot
.376 .00509 Mdot
.5983 .22229 Mdot
.46574 .86745 Mdot
.09525 .6295 Mdot
.09711 .00186 Mdot
.4606 .36349 Mdot
.55109 .09049 Mdot
.9931 .44201 Mdot
.4834 .4903 Mdot
.85771 .37431 Mdot
.10056 .24284 Mdot
.68541 .58486 Mdot
.29387 .60845 Mdot
.83029 .53642 Mdot
.34202 .51173 Mdot
.92074 .57872 Mdot
.03164 .1109 Mdot
.92254 .8909 Mdot
.33451 .41197 Mdot
.78581 .45129 Mdot
.32311 .5373 Mdot
.86182 .53871 Mdot
.25077 .38895 Mdot
.52565 .27488 Mdot
.97927 .45363 Mdot
.57757 .5983 Mdot
.69762 .12005 Mdot
.87198 .17435 Mdot
.84892 .97694 Mdot
.7316 .88268 Mdot
.72093 .98933 Mdot
.80581 .08488 Mdot
.93698 .13116 Mdot
.49787 .56089 Mdot
.04386 .54599 Mdot
.28672 .24287 Mdot
.44503 .1583 Mdot
.22612 .7811 Mdot
.90565 .67953 Mdot
.20762 .30197 Mdot
.43477 .22715 Mdot
.21799 .78322 Mdot
.90958 .69159 Mdot
.20058 .291 Mdot
.43077 .23019 Mdot
.19148 .76071 Mdot
.91257 .72109 Mdot
.21535 .30278 Mdot
.43034 .215 Mdot
.17316 .74282 Mdot
.92923 .75607 Mdot
.16452 .23529 Mdot
.44258 .27806 Mdot
.32739 .88481 Mdot
.22725 .89986 Mdot
.02439 .79714 Mdot
.65147 .62709 Mdot
.1859 .53443 Mdot
.69538 .50948 Mdot
.254 .55861 Mdot
.69888 .44488 Mdot
.20086 .50198 Mdot
.64144 .44058 Mdot
.94684 .3054 Mdot
.61749 .67065 Mdot
.03785 .42036 Mdot
.19577 .15792 Mdot
.30366 .10789 Mdot
.36019 .05653 Mdot
.55915 .19896 Mdot
.16267 .60352 Mdot
.81566 .65299 Mdot
.48926 .6736 Mdot
.08777 .59851 Mdot
.10256 .0148 Mdot
.44808 .34552 Mdot
.43659 .98851 Mdot
.99288 .55629 Mdot
.59899 .60612 Mdot
.85425 .25525 Mdot
.99302 .13877 Mdot
.18064 .18762 Mdot
.35831 .17766 Mdot
.67004 .31173 Mdot
.95819 .28815 Mdot
.53566 .57747 Mdot
.36064 .82498 Mdot
.33005 .96941 Mdot
.32336 .99331 Mdot
.31887 .9955 Mdot
.30296 .9841 Mdot
.2341 .93114 Mdot
.05671 .82261 Mdot
.49072 .43401 Mdot
.8598 .36908 Mdot
.08818 .22838 Mdot
.73039 .64221 Mdot
.47825 .74786 Mdot
.07434 .59609 Mdot
.16878 .09444 Mdot
.29109 .12231 Mdot
.33622 .04514 Mdot
.42681 .09059 Mdot
.02295 .59614 Mdot
.45899 .43604 Mdot
.61113 .15214 Mdot
.47952 .86839 Mdot
.20496 .72544 Mdot
.86063 .65567 Mdot
.37191 .51128 Mdot
.08024 .70834 Mdot
.25038 .17014 Mdot
.30644 .05606 Mdot
.31773 .01129 Mdot
.31431 .99658 Mdot
.28652 .97221 Mdot
.17386 .88733 Mdot
.07219 .89834 Mdot
.48233 .41014 Mdot
.76903 .2867 Mdot
.16187 .39283 Mdot
.60711 .44525 Mdot
.7468 .13969 Mdot
.00036 .25355 Mdot
.25141 .25105 Mdot
.38842 .13701 Mdot
.80683 .41841 Mdot
.26905 .46222 Mdot
.62515 .3561 Mdot
.76976 .14461 Mdot
.01988 .25012 Mdot
.13118 .11129 Mdot
.42472 .29354 Mdot
.21074 .78602 Mdot
.9164 .70566 Mdot
.18072 .26432 Mdot
.43485 .25414 Mdot
.2456 .81074 Mdot
.94269 .69709 Mdot
.03236 .08967 Mdot
.89708 .86472 Mdot
.43307 .53598 Mdot
.5142 .08114 Mdot
.69462 .18041 Mdot
.92234 .22772 Mdot
.67238 .75004 Mdot
.4066 .73423 Mdot
.52393 .11732 Mdot
.80811 .28418 Mdot
.13294 .32483 Mdot
.63169 .49875 Mdot
.95062 .31893 Mdot
.60971 .65909 Mdot
.97736 .36765 Mdot
.50295 .52559 Mdot
.04923 .54627 Mdot
.25638 .20715 Mdot
.35035 .09396 Mdot
.54442 .19407 Mdot
.0454 .50099 Mdot
.23285 .18745 Mdot
.31268 .07982 Mdot
.36369 .05101 Mdot
.57298 .20929 Mdot
.27539 .70242 Mdot
.87788 .60248 Mdot
.25377 .37589 Mdot
.51589 .26212 Mdot
.88904 .37316 Mdot
.97749 .08844 Mdot
.223 .24551 Mdot
.37042 .14742 Mdot
.70772 .3373 Mdot
.12003 .41231 Mdot
.76954 .64951 Mdot
.52475 .75521 Mdot
.45251 .92776 Mdot
.05278 .60027 Mdot
.2903 .23752 Mdot
.44927 .15897 Mdot
.25915 .80987 Mdot
.95678 .69763 Mdot
.95327 .99649 Mdot
.2722 .31893 Mdot
.48786 .21567 Mdot
.61866 .1308 Mdot
.50525 .88659 Mdot
.42856 .92332 Mdot
.86844 .43988 Mdot
.12788 .25944 Mdot
.58541 .45753 Mdot
.61255 .02713 Mdot
.36346 .75091 Mdot
.27159 .90813 Mdot
.07588 .80429 Mdot
.3689 .29302 Mdot
.84453 .47563 Mdot
.24345 .39892 Mdot
.52923 .28578 Mdot
.01845 .48922 Mdot
.37881 .36036 Mdot
.97049 .59167 Mdot
.76758 .79709 Mdot
.67197 .90439 Mdot
.5592 .88723 Mdot
.85132 .29212 Mdot
.0393 .18799 Mdot
.95495 .91565 Mdot
.18174 .22679 Mdot
.39535 .21361 Mdot
.92805 .5327 Mdot
.94741 .01936 Mdot
.32822 .3808 Mdot
.72678 .39857 Mdot
.22759 .50081 Mdot
.62535 .39775 Mdot
.81258 .18724 Mdot
.02888 .2163 Mdot
.04413 .01525 Mdot
.7544 .71027 Mdot
.57833 .82393 Mdot
.92868 .35035 Mdot
.76174 .83307 Mdot
.70587 .94412 Mdot
.72151 .01564 Mdot
.83343 .11192 Mdot
.90983 .0764 Mdot
.58418 .67434 Mdot
.82066 .23648 Mdot
.06322 .24256 Mdot
.87477 .81155 Mdot
.47522 .60045 Mdot
.90292 .4277 Mdot
.96881 .06589 Mdot
.25163 .28282 Mdot
.42043 .1688 Mdot
.05515 .63472 Mdot
.3115 .25635 Mdot
.53593 .22442 Mdot
.00971 .47378 Mdot
.41556 .40585 Mdot
.25766 .84211 Mdot
.98698 .72931 Mdot
.80735 .82038 Mdot
.67026 .8629 Mdot
.5103 .84005 Mdot
.42242 .91212 Mdot
.81275 .39033 Mdot
.23169 .41893 Mdot
.5439 .31222 Mdot
.15956 .61565 Mdot
.83622 .67667 Mdot
.46744 .63122 Mdot
.87234 .4049 Mdot
.07806 .20571 Mdot
.75901 .68095 Mdot
.55226 .79325 Mdot
.70476 .1525 Mdot
.92662 .22187 Mdot
.64412 .71749 Mdot
.23812 .594 Mdot
.72114 .48302 Mdot
.29998 .57884 Mdot
.8192 .51923 Mdot
.34885 .52965 Mdot
.97246 .62362 Mdot
.78787 .8154 Mdot
.68597 .8981 Mdot
.6092 .92323 Mdot
.23826 .62906 Mdot
.75627 .518 Mdot
.38749 .63123 Mdot
.29514 .90765 Mdot
.13321 .83807 Mdot
.14392 .0107 Mdot
.27898 .13507 Mdot
.31839 .0394 Mdot
.34498 .02659 Mdot
.45005 .10507 Mdot
.21119 .76114 Mdot
.89121 .68001 Mdot
.27484 .38363 Mdot
.55793 .28309 Mdot
.23763 .6797 Mdot
.80662 .56898 Mdot
.41993 .61332 Mdot
.49613 .07619 Mdot
.54522 .04909 Mdot
.90661 .36139 Mdot
.88486 .97825 Mdot
.60061 .71575 Mdot
.97462 .37402 Mdot
.52553 .55091 Mdot
.25438 .72885 Mdot
.86958 .61519 Mdot
.29893 .42935 Mdot
.66643 .3675 Mdot
.99795 .33151 Mdot
.34384 .34589 Mdot
.76376 .41992 Mdot
.2936 .52984 Mdot
.7509 .4573 Mdot
.32227 .57137 Mdot
.89247 .57019 Mdot
.15942 .26695 Mdot
.48791 .32849 Mdot
.73182 .24392 Mdot
.08257 .35074 Mdot
.88093 .79836 Mdot
.43719 .55626 Mdot
.56511 .12792 Mdot
.13619 .57108 Mdot
.86609 .72989 Mdot
.42661 .56052 Mdot
.49144 .06483 Mdot
.49638 .00494 Mdot
.47598 .9796 Mdot
.28804 .81206 Mdot
.01768 .72964 Mdot
.62384 .60616 Mdot
.01202 .38818 Mdot
.31616 .30414 Mdot
.60108 .28492 Mdot
.54695 .94587 Mdot
.81669 .26974 Mdot
.10414 .28745 Mdot
.71353 .6094 Mdot
.4079 .69437 Mdot
.49295 .08505 Mdot
.52868 .03573 Mdot
.76409 .23541 Mdot
.10922 .34513 Mdot
.74843 .63921 Mdot
.50167 .75324 Mdot
.26664 .76497 Mdot
.92361 .65697 Mdot
.09503 .17142 Mdot
.64007 .54504 Mdot
.04385 .40378 Mdot
.14453 .10068 Mdot
.36692 .22239 Mdot
.76258 .39566 Mdot
.26885 .50626 Mdot
.66883 .39998 Mdot
.0411 .37228 Mdot
.12885 .08775 Mdot
.40999 .28114 Mdot
.09412 .68412 Mdot
.15716 .06305 Mdot
.29035 .13318 Mdot
.34505 .05471 Mdot
.47854 .13349 Mdot
.46227 .98373 Mdot
.18435 .72208 Mdot
.88579 .70143 Mdot
.31984 .43405 Mdot
.74535 .42551 Mdot
.28447 .53912 Mdot
.73552 .45106 Mdot
.29606 .56054 Mdot
.78883 .49278 Mdot
.36269 .57386 Mdot
.09028 .72759 Mdot
.21924 .12896 Mdot
.25486 .03561 Mdot
.1769 .92205 Mdot
.10032 .92341 Mdot
.3671 .26678 Mdot
.80797 .44087 Mdot
.28984 .48187 Mdot
.69235 .40251 Mdot
.13665 .4443 Mdot
.73766 .60101 Mdot
.44942 .71175 Mdot
.81303 .36361 Mdot
.2045 .39147 Mdot
0 .2 Mdot
.2 .2 Mdot
.34044 .14044 Mdot
.5419 .20145 Mdot
.03325 .49135 Mdot
.29356 .26031 Mdot
.48125 .18769 Mdot
.53802 .05677 Mdot
.85841 .32039 Mdot
.04426 .18585 Mdot
.92427 .88001 Mdot
.31462 .39035 Mdot
.68145 .36683 Mdot
.06062 .37917 Mdot
.02565 .96504 Mdot
.8119 .78624 Mdot
.62903 .81713 Mdot
.25363 .6246 Mdot
.76445 .51081 Mdot
.38476 .62031 Mdot
.26702 .88227 Mdot
.04157 .77455 Mdot
.5284 .48683 Mdot
.21301 .68461 Mdot
.81349 .60047 Mdot
.44058 .62709 Mdot
.6613 .22072 Mdot
.8275 .16621 Mdot
.97829 .15079 Mdot
.28058 .30229 Mdot
.48928 .2087 Mdot
.623 .13372 Mdot
.53454 .91154 Mdot
.68594 .1514 Mdot
.8624 .17646 Mdot
.88646 .02406 Mdot
.63958 .75312 Mdot
.24922 .60964 Mdot
.74479 .49557 Mdot
.35385 .60906 Mdot
.0777 .72385 Mdot
.27898 .20128 Mdot
.3846 .10561 Mdot
.75133 .36673 Mdot
.23211 .48078 Mdot
.60583 .37373 Mdot
.667 .06116 Mdot
.69414 .02715 Mdot
.76747 .07332 Mdot
.94817 .1807 Mdot
.4853 .53713 Mdot
.91968 .43438 Mdot
.89275 .97307 Mdot
.56104 .66829 Mdot
.64618 .08514 Mdot
.61666 .97048 Mdot
.33261 .71594 Mdot
.0812 .74859 Mdot
.28574 .20454 Mdot
.40416 .11842 Mdot
.89152 .48736 Mdot
.08079 .18926 Mdot
.72852 .64773 Mdot
.4802 .75168 Mdot
.09367 .61347 Mdot
.08864 .99497 Mdot
.49471 .40607 Mdot
.86374 .36903 Mdot
.07428 .21054 Mdot
.78355 .70927 Mdot
.58225 .7987 Mdot
.93138 .34913 Mdot
.74612 .81474 Mdot
.67462 .9285 Mdot
.59456 .91994 Mdot
.13819 .54362 Mdot
.83154 .69336 Mdot
.49593 .66439 Mdot
.13183 .6359 Mdot
.94687 .81504 Mdot
.12694 .18006 Mdot
.5097 .38276 Mdot
.96029 .45059 Mdot
.68599 .7257 Mdot
.43688 .75089 Mdot
.7574 .32052 Mdot
.1908 .4334 Mdot
.58631 .39551 Mdot
.5568 .97049 Mdot
.91649 .35969 Mdot
.83429 .9178 Mdot
.71355 .87926 Mdot
.67779 .96425 Mdot
.64341 .96562 Mdot
.48248 .83907 Mdot
.1992 .71671 Mdot
.8581 .65891 Mdot
.38383 .52573 Mdot
.16668 .78285 Mdot
.98465 .81797 Mdot
.9099 .92525 Mdot
.43271 .52281 Mdot
.49836 .06565 Mdot
.55252 .05416 Mdot
.9677 .41518 Mdot
.60743 .63973 Mdot
.94333 .3359 Mdot
.66759 .72426 Mdot
.35991 .69232 Mdot
.19342 .83351 Mdot
.9825 .78908 Mdot
.89381 .91131 Mdot
.4945 .60069 Mdot
.05673 .56223 Mdot
.23019 .17346 Mdot
.29818 .06799 Mdot
.30275 .00457 Mdot
.25387 .95112 Mdot
.09123 .83736 Mdot
.32437 .23314 Mdot
.56286 .23849 Mdot
.22998 .66712 Mdot
.79182 .56184 Mdot
.42951 .63768 Mdot
.5897 .1602 Mdot
.34508 .75538 Mdot
.17934 .83426 Mdot
.00753 .82819 Mdot
.78306 .77553 Mdot
.64873 .86567 Mdot
.41045 .76173 Mdot
.57791 .16746 Mdot
.26921 .6913 Mdot
.85453 .58532 Mdot
.32216 .46763 Mdot
.78827 .46611 Mdot
.33641 .54814 Mdot
.93068 .59426 Mdot
.99501 .06434 Mdot
.09426 .09925 Mdot
.5716 .47734 Mdot
.5334 .9618 Mdot
.72725 .19386 Mdot
.02383 .29658 Mdot
.1542 .13037 Mdot
.36629 .21209 Mdot
.74866 .38238 Mdot
.24509 .49642 Mdot
.62796 .38287 Mdot
.8131 .18515 Mdot
.02591 .2128 Mdot
.05817 .03226 Mdot
.69227 .6341 Mdot
.36796 .6757 Mdot
.22184 .85388 Mdot
.97903 .75718 Mdot
.88261 .90358 Mdot
.53543 .65282 Mdot
.43421 .89878 Mdot
.88543 .45123 Mdot
.07114 .1857 Mdot
.77529 .70416 Mdot
.5795 .8042 Mdot
.91731 .33782 Mdot
.80824 .89093 Mdot
.73949 .93124 Mdot
.78238 .0429 Mdot
.91638 .134 Mdot
.60914 .69276 Mdot
.00743 .39828 Mdot
.35374 .34632 Mdot
.81439 .46065 Mdot
.29919 .4848 Mdot
.72268 .42349 Mdot
.24388 .5212 Mdot
.65182 .40794 Mdot
.96849 .31667 Mdot
.5043 .53581 Mdot
.0702 .5659 Mdot
.16048 .09028 Mdot
.30831 .14782 Mdot
.41597 .10766 Mdot
.96237 .5464 Mdot
.76971 .80734 Mdot
.6826 .91289 Mdot
.61117 .92857 Mdot
.25618 .64501 Mdot
.78795 .53177 Mdot
.40228 .61433 Mdot
.37475 .97247 Mdot
.5582 .18345 Mdot
.14 .5818 Mdot
.8634 .7234 Mdot
.42986 .56646 Mdot
.52109 .09123 Mdot
.75956 .23847 Mdot
.1101 .35054 Mdot
.74996 .63985 Mdot
.50389 .75394 Mdot
.28509 .7812 Mdot
.97917 .69408 Mdot
.81863 .83946 Mdot
.67019 .85155 Mdot
.49864 .82846 Mdot
.31759 .81895 Mdot
.12143 .80383 Mdot
.15537 .03394 Mdot
.26643 .11106 Mdot
.26933 .0029 Mdot
.16635 .89702 Mdot
.09965 .9333 Mdot
.38009 .28044 Mdot
.89834 .51825 Mdot
.0808 .18246 Mdot
.72164 .64084 Mdot
.45892 .73728 Mdot
.91181 .45289 Mdot
.95093 .03912 Mdot
.32812 .37719 Mdot
.72277 .39465 Mdot
.21523 .49246 Mdot
.62009 .40486 Mdot
.78804 .16795 Mdot
.03841 .25037 Mdot
.02253 .98413 Mdot
.84945 .82691 Mdot
.57994 .7305 Mdot
.8468 .26686 Mdot
.02796 .18116 Mdot
.01442 .98646 Mdot
.9001 .88568 Mdot
.44006 .53996 Mdot
.57031 .13025 Mdot
.1769 .60658 Mdot
.78487 .60797 Mdot
.48029 .69543 Mdot
.03812 .55783 Mdot
.33165 .29353 Mdot
.65452 .32287 Mdot
.89693 .24241 Mdot
.81144 .91451 Mdot
.75804 .9466 Mdot
.81731 .05926 Mdot
.89251 .0752 Mdot
.66425 .77174 Mdot
.39224 .72799 Mdot
.42224 .03 Mdot
.92931 .50707 Mdot
.91509 .98578 Mdot
.46742 .55233 Mdot
.79332 .32589 Mdot
.19228 .39897 Mdot
.54962 .35734 Mdot
.24873 .69911 Mdot
.83379 .58506 Mdot
.38207 .54828 Mdot
.17831 .79625 Mdot
.97159 .79327 Mdot
.96269 .99111 Mdot
.21256 .24986 Mdot
.37902 .16647 Mdot
.77789 .39886 Mdot
.27378 .49589 Mdot
.66799 .39421 Mdot
.03161 .36362 Mdot
.17542 .14381 Mdot
.32525 .14983 Mdot
.4832 .15795 Mdot
.52377 .04057 Mdot
.73011 .20634 Mdot
.04186 .31174 Mdot
.06397 .02211 Mdot
.65027 .58631 Mdot
.13901 .48874 Mdot
.77376 .63475 Mdot
.5102 .73644 Mdot
.31799 .80779 Mdot
.11183 .79384 Mdot
.18569 .07386 Mdot
.23518 .04949 Mdot
.17542 .94023 Mdot
.12167 .94625 Mdot
.29679 .17512 Mdot
.40564 .10884 Mdot
.89195 .48632 Mdot
.07784 .18589 Mdot
.74032 .66249 Mdot
.51484 .77451 Mdot
.39308 .87824 Mdot
.57791 .18483 Mdot
.28657 .70866 Mdot
.91042 .62385 Mdot
.12874 .21831 Mdot
.541 .41226 Mdot
.23709 .69609 Mdot
.82276 .58567 Mdot
.40812 .58536 Mdot
.38542 .97731 Mdot
.6282 .24278 Mdot
.67444 .04624 Mdot
.71154 .0371 Mdot
.83035 .11881 Mdot
.92427 .09392 Mdot
.52854 .60428 Mdot
.33157 .80302 Mdot
.16364 .83208 Mdot
.04165 .878 Mdot
.63144 .58979 Mdot
.04023 .40879 Mdot
.17041 .13019 Mdot
.32293 .15252 Mdot
.4763 .15337 Mdot
.46435 .98805 Mdot
.20493 .74058 Mdot
.8758 .67087 Mdot
.33048 .45468 Mdot
.81049 .48001 Mdot
.32508 .51459 Mdot
.84728 .5222 Mdot
.28184 .43456 Mdot
.62455 .3427 Mdot
.75278 .12823 Mdot
.99493 .24215 Mdot
.27258 .27766 Mdot
.44735 .17477 Mdot
.26023 .81288 Mdot
.96133 .7011 Mdot
.93045 .96912 Mdot
.37106 .44061 Mdot
.00466 .63359 Mdot
.60566 .60101 Mdot
.89318 .28751 Mdot
.87356 .98038 Mdot
.64881 .77525 Mdot
.32048 .67167 Mdot
.98554 .66505 Mdot
.7517 .76616 Mdot
.63188 .88018 Mdot
.33316 .70127 Mdot
.06899 .73583 Mdot
.33689 .26791 Mdot
.65268 .31578 Mdot
.88066 .22798 Mdot
.86791 .98724 Mdot
.67725 .80934 Mdot
.48628 .80904 Mdot
.19941 .71313 Mdot
.85426 .65486 Mdot
.39257 .5383 Mdot
.23465 .84209 Mdot
.96783 .73318 Mdot
.92466 .95683 Mdot
.38938 .46472 Mdot
.14063 .75125 Mdot
.03066 .89003 Mdot
.70739 .67673 Mdot
.45853 .75114 Mdot
.92268 .46414 Mdot
.90704 .98436 Mdot
.50576 .59872 Mdot
.14479 .63903 Mdot
.90443 .75964 Mdot
.29359 .38916 Mdot
.61019 .3166 Mdot
.63792 .02774 Mdot
.51474 .87682 Mdot
.49461 .97986 Mdot
.43673 .94212 Mdot
.94751 .51078 Mdot
.81911 .87161 Mdot
.7014 .88229 Mdot
.64623 .94483 Mdot
.47663 .8304 Mdot
.14401 .66738 Mdot
.93536 .79136 Mdot
.16684 .23148 Mdot
.43288 .26604 Mdot
.24289 .81001 Mdot
.93993 .69704 Mdot
.04756 .10763 Mdot
.82722 .77966 Mdot
.59239 .76517 Mdot
.96859 .3762 Mdot
.56323 .59464 Mdot
.58897 .02573 Mdot
.20555 .61658 Mdot
.75122 .54566 Mdot
.41093 .65971 Mdot
.47919 .06826 Mdot
.4022 .92301 Mdot
.68288 .28068 Mdot
.98002 .29714 Mdot
.41668 .43666 Mdot
.29635 .87967 Mdot
.10884 .8125 Mdot
.21745 .1086 Mdot
.23519 .01774 Mdot
.14367 .90848 Mdot
.1776 .03394 Mdot
.21075 .03315 Mdot
.16352 .95277 Mdot
.5 .2 Mdot
.7 .2 Mdot
.95956 .25956 Mdot
.49918 .53962 Mdot
.03303 .53385 Mdot
.33734 .30432 Mdot
.69118 .35383 Mdot
.08386 .39268 Mdot
.91633 .83247 Mdot
.3079 .39157 Mdot
.65829 .35039 Mdot
.94286 .28457 Mdot
.61886 .676 Mdot
.05168 .43282 Mdot
.12908 .0774 Mdot
.39878 .26971 Mdot
.00678 .608 Mdot
.56731 .56052 Mdot
.58507 .01776 Mdot
.17039 .58532 Mdot
.77811 .60772 Mdot
.48258 .70447 Mdot
.06534 .58277 Mdot
.20344 .1381 Mdot
.27479 .07134 Mdot
.24553 .97074 Mdot
.10262 .8571 Mdot
.29012 .1875 Mdot
.39874 .10862 Mdot
.84538 .44664 Mdot
.21197 .36659 Mdot
.49613 .28416 Mdot
.75323 .2571 Mdot
.12418 .37095 Mdot
.71141 .58722 Mdot
.38012 .66871 Mdot
.28681 .90669 Mdot
.10908 .82227 Mdot
.22617 .11708 Mdot
.24163 .01547 Mdot
.14456 .90292 Mdot
.16909 .02453 Mdot
.22043 .05134 Mdot
.17686 .95643 Mdot
.13479 .95793 Mdot
.25801 .12322 Mdot
.26856 .01055 Mdot
.17258 .90403 Mdot
.09175 .91916 Mdot
.40367 .31192 Mdot
.0817 .67803 Mdot
.21261 .13091 Mdot
.26004 .04742 Mdot
.19559 .93556 Mdot
.08153 .88593 Mdot
.4214 .33987 Mdot
.23316 .81176 Mdot
.93707 .70391 Mdot
.07009 .13302 Mdot
.72817 .65808 Mdot
.48987 .7617 Mdot
.18067 .6908 Mdot
.86143 .68076 Mdot
.39418 .53275 Mdot
.2396 .84542 Mdot
.97331 .73371 Mdot
.89299 .91968 Mdot
.50658 .6136 Mdot
.16623 .65965 Mdot
.86259 .69636 Mdot
.4057 .54312 Mdot
.3267 .92099 Mdot
.26048 .93378 Mdot
.08259 .82211 Mdot
.35216 .26957 Mdot
.72938 .37722 Mdot
.21136 .48198 Mdot
.61192 .40056 Mdot
.73296 .12103 Mdot
.9617 .22874 Mdot
.45598 .49429 Mdot
.64605 .19007 Mdot
.72089 .07484 Mdot
.89122 .17034 Mdot
.76509 .87387 Mdot
.74804 .98295 Mdot
.84499 .09695 Mdot
.86342 .01844 Mdot
.7248 .86138 Mdot
.68634 .96154 Mdot
.67402 .98768 Mdot
.65123 .97721 Mdot
.5348 .88357 Mdot
.66002 .12522 Mdot
.72595 .06593 Mdot
.89327 .16732 Mdot
.75296 .85969 Mdot
.72654 .97358 Mdot
.80213 .07559 Mdot
.93257 .13044 Mdot
.52101 .58844 Mdot
.25611 .7351 Mdot
.87795 .62184 Mdot
.27284 .3949 Mdot
.56511 .29226 Mdot
.3005 .7354 Mdot
.97744 .67693 Mdot
.81178 .83434 Mdot
.67732 .86554 Mdot
.54278 .86546 Mdot
.70412 .16134 Mdot
.93359 .22946 Mdot
.61457 .68099 Mdot
.03008 .41551 Mdot
.23628 .2062 Mdot
.33253 .09625 Mdot
.46114 .12861 Mdot
.32043 .85929 Mdot
.17297 .85254 Mdot
.03937 .8664 Mdot
.63296 .59358 Mdot
.0527 .41974 Mdot
.11025 .05755 Mdot
.45631 .34606 Mdot
.50034 .04403 Mdot
.54671 .04637 Mdot
.91537 .36866 Mdot
.84891 .93354 Mdot
.68823 .83932 Mdot
.55877 .87054 Mdot
.83142 .27265 Mdot
.07552 .2441 Mdot
.81058 .73506 Mdot
.57998 .7694 Mdot
.886 .30601 Mdot
.92352 .03752 Mdot
.47605 .55253 Mdot
.86154 .38549 Mdot
.09854 .237 Mdot
.689 .59047 Mdot
.31273 .62373 Mdot
.90778 .59506 Mdot
.11283 .20505 Mdot
.59257 .47974 Mdot
.6844 .09183 Mdot
.79701 .11261 Mdot
.97546 .17845 Mdot
.32502 .34956 Mdot
.682 .35698 Mdot
.05292 .37092 Mdot
.0602 .00729 Mdot
.65605 .59585 Mdot
.17744 .52139 Mdot
.69854 .5211 Mdot
.276 .57746 Mdot
.75419 .4782 Mdot
.34609 .5919 Mdot
.02086 .67477 Mdot
.55004 .52919 Mdot
.42378 .87374 Mdot
.78418 .36039 Mdot
.23307 .44889 Mdot
.57417 .3411 Mdot
.41587 .8417 Mdot
.69574 .27986 Mdot
.02555 .32982 Mdot
.17726 .15171 Mdot
.32923 .15196 Mdot
.50231 .17309 Mdot
.69158 .18927 Mdot
.92071 .22913 Mdot
.68219 .76148 Mdot
.45815 .77596 Mdot
.94455 .48639 Mdot
.81131 .86677 Mdot
.71051 .8992 Mdot
.68968 .97916 Mdot
.70385 .01418 Mdot
.7856 .08175 Mdot
.95368 .16808 Mdot
.44144 .48776 Mdot
.52843 .087 Mdot
.8134 .28496 Mdot
.12522 .31183 Mdot
.64817 .52294 Mdot
.06483 .41666 Mdot
.04014 .97531 Mdot
.73745 .69731 Mdot
.54538 .80793 Mdot
.66671 .12133 Mdot
.75303 .08632 Mdot
.95323 .2002 Mdot
.47611 .52288 Mdot
.83237 .35626 Mdot
.15681 .32443 Mdot
.55276 .39595 Mdot
.31127 .75852 Mdot
.03725 .72598 Mdot
.50485 .46759 Mdot
.00636 .50151 Mdot
.46339 .45703 Mdot
.66637 .20299 Mdot
.83315 .16677 Mdot
.9654 .13226 Mdot
.33794 .37254 Mdot
.76219 .42425 Mdot
.29725 .53507 Mdot
.76698 .46972 Mdot
.34445 .57748 Mdot
.99835 .65389 Mdot
.66382 .66547 Mdot
.28398 .62016 Mdot
.81535 .53137 Mdot
.36821 .55286 Mdot
.10039 .73218 Mdot
.17553 .07514 Mdot
.25634 .08081 Mdot
.22394 .9676 Mdot
.09236 .86842 Mdot
.34994 .25758 Mdot
.70597 .35603 Mdot
.13371 .42774 Mdot
.73176 .59805 Mdot
.4366 .70483 Mdot
.70926 .27266 Mdot
.05971 .35045 Mdot
.00193 .94222 Mdot
.93064 .92871 Mdot
.32964 .399 Mdot
.75115 .42151 Mdot
.28672 .53557 Mdot
.73772 .451 Mdot
.2995 .56177 Mdot
.80063 .50113 Mdot
.35995 .55932 Mdot
.06062 .70067 Mdot
.34714 .28652 Mdot
.72071 .37357 Mdot
.18954 .46884 Mdot
.62371 .43417 Mdot
.83925 .21554 Mdot
.99824 .15899 Mdot
.16954 .1713 Mdot
.36611 .19656 Mdot
.73214 .36603 Mdot
.20525 .47311 Mdot
.60803 .40278 Mdot
.71025 .10222 Mdot
.89198 .18173 Mdot
.77312 .88114 Mdot
.75661 .98349 Mdot
.85323 .09661 Mdot
.83769 .98447 Mdot
.77136 .93367 Mdot
.80909 .03773 Mdot
.88499 .0759 Mdot
.69769 .8127 Mdot
.56484 .86715 Mdot
.87338 .30855 Mdot
.97767 .10429 Mdot
.23776 .26009 Mdot
.38705 .1493 Mdot
.81043 .42338 Mdot
.26855 .45812 Mdot
.62014 .35159 Mdot
.73509 .11495 Mdot
.95923 .22415 Mdot
.46563 .50639 Mdot
.73329 .26766 Mdot
.10891 .37562 Mdot
.78029 .67138 Mdot
.54564 .76535 Mdot
.62609 .08046 Mdot
.49972 .87362 Mdot
.37137 .87165 Mdot
.43746 .06609 Mdot
.07696 .6395 Mdot
.1985 .12155 Mdot
.26378 .06527 Mdot
.21914 .95536 Mdot
.08129 .86216 Mdot
.39882 .31752 Mdot
.05482 .656 Mdot
.33465 .27983 Mdot
.65428 .31964 Mdot
.89252 .23824 Mdot
.82722 .93469 Mdot
.74743 .92021 Mdot
.78158 .03415 Mdot
.90796 .12638 Mdot
.64332 .73536 Mdot
.2517 .60838 Mdot
.74606 .49436 Mdot
.35417 .60811 Mdot
.07842 .72425 Mdot
.27567 .19724 Mdot
.37328 .09761 Mdot
.67464 .30136 Mdot
.96752 .29288 Mdot
.4862 .51868 Mdot
.9084 .4222 Mdot
.937 .0286 Mdot
.39519 .4582 Mdot
.17163 .77644 Mdot
.96634 .79471 Mdot
.99491 .02856 Mdot
.05912 .06421 Mdot
.71895 .65983 Mdot
.47172 .75278 Mdot
.02761 .55589 Mdot
.39118 .36357 Mdot
.05102 .65984 Mdot
.35979 .30877 Mdot
.80923 .44943 Mdot
.29649 .48727 Mdot
.71687 .42038 Mdot
.22727 .51041 Mdot
.63494 .40766 Mdot
.87798 .24305 Mdot
.89391 .01593 Mdot
.59869 .70478 Mdot
.95085 .35216 Mdot
.64164 .6908 Mdot
.19813 .55649 Mdot
.69918 .50104 Mdot
.25798 .55881 Mdot
.70411 .44612 Mdot
.21833 .51422 Mdot
.64045 .42212 Mdot
.92298 .28253 Mdot
.72384 .80086 Mdot
.62378 .89994 Mdot
.30543 .68165 Mdot
.93987 .63444 Mdot
.98529 .04542 Mdot
.13353 .14824 Mdot
.45291 .31938 Mdot
.44746 .99455 Mdot
.08087 .63341 Mdot
.17223 .09136 Mdot
.27988 .10765 Mdot
.29302 .01314 Mdot
.23254 .93951 Mdot
.06467 .83213 Mdot
.45648 .39181 Mdot
.54745 .09096 Mdot
.96563 .41818 Mdot
.62254 .65691 Mdot
.05496 .43242 Mdot
.11026 .0553 Mdot
.454 .34374 Mdot
.48023 .02623 Mdot
.36842 .88819 Mdot
.43697 .06855 Mdot
.07579 .63881 Mdot
.20391 .12812 Mdot
.26434 .06043 Mdot
.2152 .95086 Mdot
.0785 .8633 Mdot
.4143 .33579 Mdot
.17875 .76445 Mdot
.93891 .76016 Mdot
.11628 .17737 Mdot
.5502 .43392 Mdot
.3297 .77951 Mdot
.13193 .80223 Mdot
.11284 .98091 Mdot
.36841 .25558 Mdot
.8043 .43588 Mdot
.29006 .48576 Mdot
.69683 .40677 Mdot
.1561 .45927 Mdot
.68963 .53353 Mdot
.25804 .56841 Mdot
.71379 .45575 Mdot
.2549 .54112 Mdot
.68246 .42756 Mdot
.1253 .44283 Mdot
.77889 .65359 Mdot
.52826 .74937 Mdot
.47442 .94616 Mdot
.24226 .76784 Mdot
.89734 .65508 Mdot
.22225 .32491 Mdot
.44997 .22772 Mdot
.33322 .88325 Mdot
.25127 .91805 Mdot
.05527 .804 Mdot
.48011 .42484 Mdot
.76611 .28599 Mdot
.16048 .39438 Mdot
.6124 .45192 Mdot
.78732 .17492 Mdot
.04584 .25852 Mdot
.98792 .94209 Mdot
.01448 .02656 Mdot
.93983 .92535 Mdot
.27642 .3366 Mdot
.51425 .23783 Mdot
.85171 .33746 Mdot
.08339 .23168 Mdot
0 .25 Mdot
.25 .25 Mdot
.38592 .13592 Mdot
.78989 .40398 Mdot
.27314 .48325 Mdot
.65406 .38092 Mdot
.95269 .29863 Mdot
.57763 .62494 Mdot
.72473 .14709 Mdot
.97188 .24716 Mdot
.41484 .44296 Mdot
.28971 .87487 Mdot
.085 .79529 Mdot
.31316 .22816 Mdot
.51381 .20065 Mdot
.81105 .29723 Mdot
.14141 .33036 Mdot
.6071 .4657 Mdot
.7672 .1601 Mdot
.03488 .26768 Mdot
.06035 .02547 Mdot
.67342 .61307 Mdot
.27408 .60066 Mdot
.77337 .49929 Mdot
.37476 .60139 Mdot
.18719 .81243 Mdot
.97118 .78399 Mdot
.95584 .98466 Mdot
.24569 .28986 Mdot
.42188 .17618 Mdot
.0729 .65102 Mdot
.2313 .1584 Mdot
.2833 .052 Mdot
.2455 .96221 Mdot
.09407 .84857 Mdot
.32182 .22774 Mdot
.54698 .22517 Mdot
.09626 .54928 Mdot
.01207 .91581 Mdot
.84348 .83141 Mdot
.60227 .7588 Mdot
.02872 .42645 Mdot
.2552 .22648 Mdot
.36819 .11299 Mdot
.66044 .29225 Mdot
.89501 .23457 Mdot
.81233 .91732 Mdot
.75938 .94705 Mdot
.81857 .0592 Mdot
.89003 .07146 Mdot
.67146 .78142 Mdot
.43403 .76258 Mdot
.74794 .31391 Mdot
.17584 .4279 Mdot
.60843 .43258 Mdot
.74263 .1342 Mdot
.98972 .24709 Mdot
.3087 .31897 Mdot
.5885 .2798 Mdot
.45636 .86786 Mdot
.02252 .56617 Mdot
.43156 .40903 Mdot
.37611 .94455 Mdot
.5384 .16229 Mdot
.96685 .42845 Mdot
.62569 .65884 Mdot
.07573 .45004 Mdot
.01542 .93969 Mdot
.84732 .8319 Mdot
.59143 .74411 Mdot
.94093 .3495 Mdot
.69447 .75354 Mdot
.49497 .8005 Mdot
.26024 .76527 Mdot
.91373 .65349 Mdot
.14199 .22827 Mdot
.50302 .36103 Mdot
.88522 .3822 Mdot
.003 .11778 Mdot
.09977 .09677 Mdot
.54301 .44324 Mdot
.28367 .74066 Mdot
.93508 .65141 Mdot
.02842 .09334 Mdot
.92386 .89544 Mdot
.33218 .40832 Mdot
.77165 .43947 Mdot
.31492 .54326 Mdot
.8355 .52058 Mdot
.31324 .47774 Mdot
.76369 .45045 Mdot
.32411 .56042 Mdot
.88905 .56494 Mdot
.16925 .2802 Mdot
.47571 .30647 Mdot
.61284 .13712 Mdot
.47529 .86246 Mdot
.16549 .69019 Mdot
.89501 .72953 Mdot
.3073 .41228 Mdot
.67692 .36962 Mdot
.04523 .36831 Mdot
.10119 .05596 Mdot
.49559 .3944 Mdot
.85909 .3635 Mdot
.08506 .22597 Mdot
.74356 .6585 Mdot
.51522 .77167 Mdot
.3933 .87808 Mdot
.57918 .18588 Mdot
.29672 .71754 Mdot
.94783 .65111 Mdot
.95763 .0098 Mdot
.26054 .30291 Mdot
.45181 .19127 Mdot
.31084 .85904 Mdot
.13622 .82537 Mdot
.12029 .98408 Mdot
.34023 .21994 Mdot
.62038 .28015 Mdot
.66508 .0447 Mdot
.66899 .00391 Mdot
.64574 .97675 Mdot
.50595 .86021 Mdot
.40778 .90183 Mdot
.6996 .29182 Mdot
.05009 .3505 Mdot
.0557 .0056 Mdot
.67933 .62364 Mdot
.30903 .6297 Mdot
.9004 .59137 Mdot
.14433 .24393 Mdot
.51084 .36651 Mdot
.95315 .44232 Mdot
.71868 .76552 Mdot
.57678 .8581 Mdot
.95172 .37494 Mdot
.65945 .70773 Mdot
.30576 .64631 Mdot
.90568 .59991 Mdot
.12787 .22219 Mdot
.54821 .42034 Mdot
.30088 .75267 Mdot
.99591 .69503 Mdot
.71955 .72364 Mdot
.53696 .81741 Mdot
.61077 .07381 Mdot
.39885 .78808 Mdot
.5256 .12675 Mdot
.83081 .30521 Mdot
.10955 .27874 Mdot
.68058 .57103 Mdot
.26138 .5808 Mdot
.73095 .46957 Mdot
.30664 .57568 Mdot
.83803 .5314 Mdot
.31739 .47936 Mdot
.78105 .46366 Mdot
.33766 .55661 Mdot
.94495 .60729 Mdot
.92997 .98502 Mdot
.38955 .45958 Mdot
.13654 .74699 Mdot
.04075 .90421 Mdot
.6628 .62205 Mdot
.23587 .57306 Mdot
.69924 .46337 Mdot
.2205 .52126 Mdot
.64676 .42626 Mdot
.96082 .31406 Mdot
.54636 .58554 Mdot
.45187 .90551 Mdot
.02562 .57374 Mdot
.42081 .39519 Mdot
.28428 .86347 Mdot
.05941 .77513 Mdot
.42828 .36887 Mdot
.3119 .88362 Mdot
.16465 .85275 Mdot
.05971 .89506 Mdot
.54653 .48682 Mdot
.35445 .80792 Mdot
.2797 .92525 Mdot
.11021 .83051 Mdot
.22943 .11922 Mdot
.24386 .01442 Mdot
.14502 .90117 Mdot
.16579 .02076 Mdot
.22481 .05903 Mdot
.18368 .95886 Mdot
.1238 .94012 Mdot
.28212 .15832 Mdot
.34897 .06685 Mdot
.51026 .16129 Mdot
.74332 .23306 Mdot
.08948 .34616 Mdot
.84178 .7523 Mdot
.52801 .68623 Mdot
.40926 .88125 Mdot
.68919 .27993 Mdot
.00286 .31367 Mdot
.2965 .29363 Mdot
.52325 .22675 Mdot
.91217 .38892 Mdot
.88516 .97299 Mdot
.59407 .70891 Mdot
.92381 .32974 Mdot
.76674 .84292 Mdot
.71759 .95086 Mdot
.75951 .04192 Mdot
.91353 .15402 Mdot
.6435 .72997 Mdot
.24728 .60378 Mdot
.73715 .48986 Mdot
.33746 .60032 Mdot
.98772 .65026 Mdot
.72385 .73613 Mdot
.55906 .83521 Mdot
.79829 .23922 Mdot
.10071 .30243 Mdot
.74427 .64355 Mdot
.50118 .75691 Mdot
.26635 .76517 Mdot
.92331 .65696 Mdot
.09657 .17326 Mdot
.63456 .53799 Mdot
.00622 .37166 Mdot
.33434 .32812 Mdot
.70116 .36682 Mdot
.13003 .42886 Mdot
.74664 .61661 Mdot
.47708 .73045 Mdot
.04765 .57057 Mdot
.28964 .24199 Mdot
.45192 .16228 Mdot
.2827 .83079 Mdot
.02284 .74014 Mdot
.60365 .58081 Mdot
.85981 .25616 Mdot
.97524 .11543 Mdot
.26331 .28807 Mdot
.44119 .17788 Mdot
.2167 .77551 Mdot
.90242 .68572 Mdot
.22918 .32676 Mdot
.45137 .22219 Mdot
.33846 .88709 Mdot
.27917 .94071 Mdot
.12444 .84528 Mdot
.18471 .06027 Mdot
.22333 .03862 Mdot
.16347 .94014 Mdot
.15016 .98669 Mdot
.23487 .08471 Mdot
.21053 .97566 Mdot
.10619 .89566 Mdot
.31247 .20629 Mdot
.4894 .17693 Mdot
.59218 .10278 Mdot
.30477 .71259 Mdot
.96861 .66383 Mdot
.85077 .88216 Mdot
.63107 .7803 Mdot
.2286 .59753 Mdot
.7221 .4935 Mdot
.31262 .59051 Mdot
.87416 .56154 Mdot
.22763 .35348 Mdot
.47801 .25037 Mdot
.57492 .09691 Mdot
.17713 .60221 Mdot
.78 .60286 Mdot
.47722 .69722 Mdot
.01549 .53827 Mdot
.44553 .43004 Mdot
.50167 .05614 Mdot
.56952 .06785 Mdot
.10867 .53915 Mdot
.94488 .83621 Mdot
.15928 .21441 Mdot
.43574 .27645 Mdot
.27447 .83873 Mdot
.01225 .73779 Mdot
.66435 .6521 Mdot
.27309 .60874 Mdot
.77945 .50636 Mdot
.38087 .60143 Mdot
.22412 .84325 Mdot
.96798 .74386 Mdot
.93447 .96649 Mdot
.34682 .41235 Mdot
.84496 .49814 Mdot
.2647 .41974 Mdot
.57509 .3104 Mdot
.39184 .81675 Mdot
.50842 .11658 Mdot
.68394 .17551 Mdot
.87892 .19499 Mdot
.84204 .96312 Mdot
.73809 .89605 Mdot
.7451 .00702 Mdot
.86568 .12057 Mdot
.8188 .95312 Mdot
.78353 .96473 Mdot
.83771 .05418 Mdot
.84104 .00333 Mdot
.78111 .94007 Mdot
.81405 .03294 Mdot
.87207 .05802 Mdot
.73223 .86016 Mdot
.69953 .9673 Mdot
.72538 .02584 Mdot
.85199 .12662 Mdot
.87165 .01966 Mdot
.69549 .82384 Mdot
.56869 .8732 Mdot
.90793 .33924 Mdot
.85632 .94839 Mdot
.67932 .82299 Mdot
.50831 .829 Mdot
.39547 .88715 Mdot
.60237 .20691 Mdot
.4775 .87513 Mdot
.19566 .71816 Mdot
.86404 .66839 Mdot
.37253 .50849 Mdot
.08111 .70858 Mdot
.24619 .16508 Mdot
.2975 .05132 Mdot
.28399 .98649 Mdot
.1817 .89771 Mdot
.06634 .88464 Mdot
.49992 .43357 Mdot
.93291 .43299 Mdot
.82177 .88886 Mdot
.71335 .89159 Mdot
.68962 .97627 Mdot
.70075 .01113 Mdot
.77306 .07231 Mdot
.94778 .17472 Mdot
.48151 .53373 Mdot
.88609 .40458 Mdot
.0217 .13561 Mdot
.00589 .9842 Mdot
.94884 .94295 Mdot
.24377 .29493 Mdot
.42546 .1817 Mdot
.10426 .6788 Mdot
.10431 5e-05 Mdot
.42534 .32102 Mdot
.24268 .81735 Mdot
.94712 .70444 Mdot
.01492 .0678 Mdot
.97841 .96348 Mdot
.09258 .11417 Mdot
.59464 .50206 Mdot
.72083 .12619 Mdot
.94244 .22161 Mdot
.55823 .61579 Mdot
.5726 .01437 Mdot
.07776 .50515 Mdot
.06 .98225 Mdot
.6321 .5721 Mdot
.02632 .39422 Mdot
.23712 .21079 Mdot
.33748 .10036 Mdot
.48783 .15035 Mdot
.55306 .06523 Mdot
.98288 .42982 Mdot
.53231 .54943 Mdot
.30639 .77407 Mdot
.03557 .72918 Mdot
.51784 .48227 Mdot
.12472 .60689 Mdot
.9452 .82047 Mdot
.14175 .19656 Mdot
.47212 .33037 Mdot
.60835 .13623 Mdot
.44582 .83746 Mdot
.91127 .46545 Mdot
.96617 .0549 Mdot
.25612 .28996 Mdot
.43282 .1767 Mdot
.15308 .72026 Mdot
.95953 .80645 Mdot
.04625 .08672 Mdot
.81378 .76754 Mdot
.60713 .79335 Mdot
.09503 .4879 Mdot
.95656 .86154 Mdot
.11839 .16183 Mdot
.52583 .40744 Mdot
.11325 .58743 Mdot
.97314 .85989 Mdot
.02015 .04701 Mdot
.92648 .90633 Mdot
.32932 .40284 Mdot
.75362 .42429 Mdot
.2917 .53809 Mdot
.75374 .46203 Mdot
.32955 .57581 Mdot
.5 .25 Mdot
.75 .25 Mdot
.11408 .36408 Mdot
.74623 .63215 Mdot
.49215 .74592 Mdot
.18313 .69098 Mdot
.85692 .67379 Mdot
.4027 .54577 Mdot
.309 .9063 Mdot
.1769 .8679 Mdot
.04618 .86928 Mdot
.59674 .55056 Mdot
.78354 .1868 Mdot
.05978 .27624 Mdot
.92735 .86757 Mdot
.286 .35865 Mdot
.55895 .27295 Mdot
.23516 .67621 Mdot
.80213 .56697 Mdot
.42396 .62183 Mdot
.53351 .10955 Mdot
.87589 .34238 Mdot
.00164 .12576 Mdot
.11589 .11425 Mdot
.48872 .37283 Mdot
.78262 .2939 Mdot
.16729 .38467 Mdot
.58496 .41767 Mdot
.5695 .98454 Mdot
.02524 .45574 Mdot
.30502 .27978 Mdot
.53664 .23161 Mdot
.02245 .48581 Mdot
.35164 .32919 Mdot
.78632 .43468 Mdot
.3062 .51988 Mdot
.78073 .47453 Mdot
.34864 .56791 Mdot
.0097 .66105 Mdot
.60291 .59321 Mdot
.86733 .26442 Mdot
.95657 .08925 Mdot
.34605 .38948 Mdot
.81824 .47219 Mdot
.30366 .48542 Mdot
.73773 .43407 Mdot
.28258 .54485 Mdot
.73661 .45402 Mdot
.30077 .56417 Mdot
.80706 .50629 Mdot
.35659 .54953 Mdot
.03271 .67612 Mdot
.48146 .44875 Mdot
.80072 .31926 Mdot
.17797 .37725 Mdot
.5533 .37533 Mdot
.29477 .74148 Mdot
.96596 .67119 Mdot
.87361 .90765 Mdot
.57589 .70228 Mdot
.78948 .21359 Mdot
.08305 .29358 Mdot
.82128 .73823 Mdot
.56371 .74243 Mdot
.74031 .1766 Mdot
.02893 .28862 Mdot
.11615 .08722 Mdot
.46059 .34444 Mdot
.53196 .07137 Mdot
.82556 .2936 Mdot
.11003 .28447 Mdot
.6842 .57417 Mdot
.27859 .59439 Mdot
.77681 .49822 Mdot
.37335 .59654 Mdot
.17399 .80064 Mdot
.98521 .81122 Mdot
.89983 .91462 Mdot
.47026 .57043 Mdot
.83374 .36348 Mdot
.16062 .32688 Mdot
.54453 .38391 Mdot
.2361 .69157 Mdot
.81783 .58173 Mdot
.41399 .59616 Mdot
.43698 .02299 Mdot
.03024 .59327 Mdot
.41307 .38283 Mdot
.21719 .80412 Mdot
.93082 .71362 Mdot
.11361 .18279 Mdot
.56697 .45336 Mdot
.47542 .90845 Mdot
.21249 .73707 Mdot
.86627 .65379 Mdot
.34982 .48355 Mdot
.93133 .58151 Mdot
.97875 .04742 Mdot
.17447 .19572 Mdot
.37922 .20475 Mdot
.81736 .43814 Mdot
.27129 .45393 Mdot
.62108 .3498 Mdot
.73903 .11795 Mdot
.96842 .22939 Mdot
.4174 .44898 Mdot
.31381 .8964 Mdot
.18447 .87066 Mdot
.03416 .84969 Mdot
.64657 .61242 Mdot
.146 .49942 Mdot
.76086 .61486 Mdot
.48721 .72635 Mdot
.12413 .63692 Mdot
.97758 .85345 Mdot
.98745 .00987 Mdot
.08508 .09763 Mdot
.61512 .53005 Mdot
.88257 .26745 Mdot
.89945 .01688 Mdot
.57429 .67484 Mdot
.75048 .17619 Mdot
.04076 .29027 Mdot
.04884 .00808 Mdot
.72039 .67155 Mdot
.4868 .76641 Mdot
.16089 .67409 Mdot
.89101 .73012 Mdot
.32582 .43482 Mdot
.77061 .44479 Mdot
.32016 .54954 Mdot
.86211 .54196 Mdot
.25299 .39088 Mdot
.52998 .27699 Mdot
.01555 .48558 Mdot
.39244 .37688 Mdot
.0724 .67996 Mdot
.26287 .19047 Mdot
.3429 .08003 Mdot
.4933 .1504 Mdot
.59683 .10353 Mdot
.33715 .74032 Mdot
.1263 .78914 Mdot
.12127 .99497 Mdot
.34716 .22589 Mdot
.66018 .31302 Mdot
.91453 .25435 Mdot
.73884 .82432 Mdot
.67451 .93567 Mdot
.60127 .92676 Mdot
.19006 .58879 Mdot
.74284 .55279 Mdot
.40859 .66575 Mdot
.46907 .06048 Mdot
.31444 .84536 Mdot
.13578 .82134 Mdot
.11785 .98207 Mdot
.34834 .23049 Mdot
.67071 .32238 Mdot
.97177 .30106 Mdot
.46938 .49761 Mdot
.75396 .28458 Mdot
.15229 .39832 Mdot
.63998 .48769 Mdot
.98599 .34601 Mdot
.42995 .44396 Mdot
.39926 .96931 Mdot
.70953 .31027 Mdot
.09805 .38852 Mdot
.84284 .74479 Mdot
.51749 .67466 Mdot
.31436 .79687 Mdot
.087 .77264 Mdot
.2805 .1935 Mdot
.38031 .09981 Mdot
.71909 .33878 Mdot
.15101 .43192 Mdot
.67747 .52646 Mdot
.20431 .52684 Mdot
.66266 .45834 Mdot
.0715 .40884 Mdot
.99652 .92502 Mdot
.94591 .9494 Mdot
.26667 .32076 Mdot
.47946 .21278 Mdot
.54885 .06939 Mdot
.95484 .40599 Mdot
.67274 .71791 Mdot
.37603 .70329 Mdot
.29666 .92063 Mdot
.15076 .85409 Mdot
.10043 .94968 Mdot
.39281 .29238 Mdot
.99032 .59751 Mdot
.65555 .66523 Mdot
.24438 .58883 Mdot
.71982 .47544 Mdot
.28937 .56955 Mdot
.77874 .48937 Mdot
.36408 .58534 Mdot
.1095 .74541 Mdot
.14749 .038 Mdot
.2946 .14711 Mdot
.3711 .0765 Mdot
.64075 .26965 Mdot
.77217 .13142 Mdot
.00688 .23471 Mdot
.19343 .18655 Mdot
.33553 .1421 Mdot
.52058 .18505 Mdot
.84929 .32871 Mdot
.08223 .23294 Mdot
.76484 .68261 Mdot
.55669 .79186 Mdot
.73705 .18036 Mdot
.0278 .29075 Mdot
.12494 .09714 Mdot
.4346 .30967 Mdot
.29927 .86467 Mdot
.10281 .80354 Mdot
.23569 .13288 Mdot
.25898 .02329 Mdot
.16996 .91098 Mdot
.10479 .93483 Mdot
.35795 .25316 Mdot
.74362 .38567 Mdot
.24248 .49886 Mdot
.6285 .38602 Mdot
.81944 .19094 Mdot
.02009 .20065 Mdot
.08048 .06039 Mdot
.60121 .52073 Mdot
.78365 .18243 Mdot
.05536 .27171 Mdot
.94732 .89196 Mdot
.20134 .25402 Mdot
.39294 .1916 Mdot
.89038 .49744 Mdot
.09591 .20553 Mdot
.66997 .57405 Mdot
.22018 .55022 Mdot
.67581 .45563 Mdot
.12666 .45085 Mdot
.78157 .65491 Mdot
.52872 .74715 Mdot
.47583 .94711 Mdot
.25437 .77854 Mdot
.91924 .66488 Mdot
.12547 .20622 Mdot
.54161 .41614 Mdot
.24571 .7041 Mdot
.83613 .59042 Mdot
.38144 .54531 Mdot
.17148 .79004 Mdot
.98029 .80881 Mdot
.92671 .94642 Mdot
.36823 .44152 Mdot
.98916 .62093 Mdot
.68594 .69679 Mdot
.40778 .72184 Mdot
.51958 .1118 Mdot
.76811 .24853 Mdot
.12352 .35541 Mdot
.69852 .575 Mdot
.32982 .6313 Mdot
.98422 .6544 Mdot
.74892 .7647 Mdot
.62768 .87876 Mdot
.30734 .67966 Mdot
.94445 .63711 Mdot
.96259 .01814 Mdot
.24022 .27764 Mdot
.40588 .16565 Mdot
.95042 .54454 Mdot
.83645 .88603 Mdot
.67621 .83976 Mdot
.51247 .83625 Mdot
.4359 .92343 Mdot
.92267 .48677 Mdot
.92969 .00701 Mdot
.41304 .48336 Mdot
.31753 .90449 Mdot
.20674 .88921 Mdot
.02276 .81603 Mdot
.67998 .65722 Mdot
.34521 .66522 Mdot
.0898 .7446 Mdot
.23861 .1488 Mdot
.27618 .03757 Mdot
.2147 .93852 Mdot
.06643 .85173 Mdot
.46654 .40011 Mdot
.63416 .16762 Mdot
.63358 .99942 Mdot
.46208 .8285 Mdot
.02767 .56559 Mdot
.40053 .37286 Mdot
.12159 .72105 Mdot
.07194 .95036 Mdot
.53568 .46374 Mdot
.2471 .71142 Mdot
.84462 .59752 Mdot
.36508 .52046 Mdot
.0502 .68512 Mdot
.38973 .33954 Mdot
.0177 .62796 Mdot
.52204 .50435 Mdot
.18021 .65816 Mdot
.8297 .64949 Mdot
.45648 .62678 Mdot
.78242 .32594 Mdot
.19941 .41699 Mdot
.55812 .35871 Mdot
.31471 .75659 Mdot
.04806 .73334 Mdot
.4501 .40204 Mdot
.50851 .05841 Mdot
.62647 .11796 Mdot
.53946 .91299 Mdot
.72586 .1864 Mdot
.01356 .2877 Mdot
.20643 .19287 Mdot
.3267 .12027 Mdot
.45976 .13306 Mdot
.31415 .85439 Mdot
.14372 .82957 Mdot
.09851 .95479 Mdot
.40692 .30841 Mdot
.10027 .69335 Mdot
.13725 .03698 Mdot
.3282 .19095 Mdot
.53688 .20867 Mdot
.00137 .4645 Mdot
.45627 .4549 Mdot
.6089 .15263 Mdot
.46574 .85684 Mdot
.08464 .6189 Mdot
.13859 .05396 Mdot
.34044 .20184 Mdot
.60327 .26283 Mdot
.53934 .93607 Mdot
.74802 .20868 Mdot
.07069 .32267 Mdot
.91464 .84394 Mdot
.32789 .41326 Mdot
.75784 .42995 Mdot
.30052 .54268 Mdot
.78478 .48426 Mdot
.35663 .57185 Mdot
.0552 .69857 Mdot
.37507 .31987 Mdot
.90751 .53244 Mdot
.05156 .14406 Mdot
.84095 .78939 Mdot
.5674 .72645 Mdot
.75171 .18431 Mdot
.05004 .29833 Mdot
.00385 .95382 Mdot
.9307 .92685 Mdot
.32745 .39675 Mdot
.73945 .412 Mdot
.26309 .52364 Mdot
.67641 .41332 Mdot
.08682 .41042 Mdot
.91917 .83234 Mdot
.29332 .37415 Mdot
.59441 .30109 Mdot
.51828 .92387 Mdot
.56985 .05156 Mdot
.09478 .52494 Mdot
.99477 .89998 Mdot
.93138 .93661 Mdot
.33361 .40223 Mdot
.77197 .43836 Mdot
.31382 .54185 Mdot
.82997 .51614 Mdot
.32251 .49254 Mdot
.81459 .49208 Mdot
.33027 .51568 Mdot
.87056 .54029 Mdot
.2203 .34974 Mdot
.4753 .255 Mdot
.55808 .08278 Mdot
.03843 .48035 Mdot
.25238 .21395 Mdot
.35237 .09999 Mdot
.56089 .20852 Mdot
.18535 .62446 Mdot
.78638 .60103 Mdot
.47251 .68614 Mdot
.96721 .49469 Mdot
.68982 .72261 Mdot
.44779 .75798 Mdot
.84685 .39906 Mdot
.16 .31315 Mdot
.53249 .37249 Mdot
.13084 .59835 Mdot
.91305 .78221 Mdot
.27409 .36104 Mdot
.53377 .25969 Mdot
.02812 .49434 Mdot
0 .3 Mdot
.3 .3 Mdot
.54044 .24044 Mdot
.06095 .5205 Mdot
.16518 .10423 Mdot
.30984 .14466 Mdot
.41824 .1084 Mdot
.97916 .56092 Mdot
.68552 .70636 Mdot
.41579 .73027 Mdot
.5837 .16791 Mdot
.31085 .72715 Mdot
.00435 .69351 Mdot
.66738 .66303 Mdot
.29773 .63035 Mdot
.86371 .56598 Mdot
.27133 .40762 Mdot
.57486 .30353 Mdot
.38328 .80842 Mdot
.44593 .06266 Mdot
.13735 .69142 Mdot
.98229 .84495 Mdot
.95092 .96863 Mdot
.25768 .30676 Mdot
.45166 .19397 Mdot
.31241 .86075 Mdot
.14364 .83123 Mdot
.10043 .95679 Mdot
.39994 .29951 Mdot
.04429 .64435 Mdot
.38258 .33829 Mdot
.97149 .58891 Mdot
.75892 .78744 Mdot
.6587 .89977 Mdot
.4942 .8355 Mdot
.28908 .79488 Mdot
.00329 .71421 Mdot
.69449 .69121 Mdot
.43271 .73822 Mdot
.71383 .28112 Mdot
.08038 .36655 Mdot
.90788 .8275 Mdot
.34481 .43693 Mdot
.85955 .51474 Mdot
.2347 .37515 Mdot
.50091 .26621 Mdot
.77345 .27255 Mdot
.14801 .37456 Mdot
.62951 .4815 Mdot
.92081 .29129 Mdot
.74386 .82305 Mdot
.68017 .93631 Mdot
.62504 .94487 Mdot
.35788 .73284 Mdot
.22291 .86503 Mdot
.98995 .76705 Mdot
.82728 .83733 Mdot
.64992 .82263 Mdot
.37351 .7236 Mdot
.30201 .9285 Mdot
.17539 .87338 Mdot
.05487 .87947 Mdot
.55782 .50295 Mdot
.4567 .89887 Mdot
.05619 .59949 Mdot
.27047 .21429 Mdot
.37988 .10941 Mdot
.72605 .34617 Mdot
.17371 .44766 Mdot
.63285 .45915 Mdot
.91767 .28482 Mdot
.75342 .83575 Mdot
.70299 .94957 Mdot
.71842 .01542 Mdot
.82606 .10764 Mdot
.92297 .09692 Mdot
.53827 .6153 Mdot
.41892 .88064 Mdot
.75621 .3373 Mdot
.20675 .45053 Mdot
.58408 .37734 Mdot
.52301 .93893 Mdot
.62248 .09947 Mdot
.49714 .87466 Mdot
.35181 .85467 Mdot
.3127 .96088 Mdot
.24484 .93214 Mdot
.06348 .81864 Mdot
.44946 .38599 Mdot
.48761 .03815 Mdot
.43915 .95154 Mdot
.97505 .5359 Mdot
.6849 .70985 Mdot
.41691 .73201 Mdot
.59334 .17643 Mdot
.38635 .79301 Mdot
.4497 .06335 Mdot
.16675 .71705 Mdot
.91869 .75194 Mdot
.21537 .29668 Mdot
.42424 .20887 Mdot
.12257 .69833 Mdot
.04526 .92269 Mdot
.6554 .61015 Mdot
.18858 .53318 Mdot
.68961 .50103 Mdot
.22546 .53586 Mdot
.66045 .43499 Mdot
.03776 .37732 Mdot
.15321 .11544 Mdot
.35433 .20112 Mdot
.67228 .31795 Mdot
.9741 .30182 Mdot
.45643 .48233 Mdot
.63758 .18115 Mdot
.66624 .02866 Mdot
.65824 .992 Mdot
.58425 .92601 Mdot
.07284 .48859 Mdot
.06919 .99635 Mdot
.59634 .52716 Mdot
.75745 .16111 Mdot
.03143 .27397 Mdot
.08685 .05542 Mdot
.56406 .47721 Mdot
.4777 .91363 Mdot
.23571 .75802 Mdot
.88413 .64842 Mdot
.27386 .38973 Mdot
.56201 .28815 Mdot
.27335 .71133 Mdot
.88256 .60921 Mdot
.24125 .35869 Mdot
.48754 .24629 Mdot
.64668 .15914 Mdot
.69327 .04659 Mdot
.7839 .09063 Mdot
.96344 .17954 Mdot
.39665 .43321 Mdot
.15621 .75956 Mdot
.9896 .83339 Mdot
.89574 .90614 Mdot
.48061 .58487 Mdot
.93006 .44945 Mdot
.85351 .92345 Mdot
.66363 .81012 Mdot
.42775 .76412 Mdot
.70331 .27556 Mdot
.04537 .34205 Mdot
.07414 .02877 Mdot
.60251 .52838 Mdot
.79988 .19737 Mdot
.05706 .25718 Mdot
.9233 .86624 Mdot
.30587 .38257 Mdot
.64231 .33644 Mdot
.84738 .20507 Mdot
.96441 .11703 Mdot
.32848 .36407 Mdot
.71121 .38272 Mdot
.17509 .46388 Mdot
.64603 .47095 Mdot
.00169 .35566 Mdot
.34552 .34382 Mdot
.76993 .42442 Mdot
.29971 .52978 Mdot
.7693 .46959 Mdot
.3448 .57549 Mdot
.99805 .65325 Mdot
.66496 .66691 Mdot
.29067 .62571 Mdot
.83848 .54781 Mdot
.3326 .49413 Mdot
.85936 .52675 Mdot
.24739 .38803 Mdot
.52148 .27409 Mdot
.94548 .424 Mdot
.74368 .7982 Mdot
.65509 .91141 Mdot
.48828 .83319 Mdot
.23947 .75119 Mdot
.87901 .63955 Mdot
.28622 .40721 Mdot
.60807 .32185 Mdot
.6296 .02153 Mdot
.46132 .83173 Mdot
.02496 .56363 Mdot
.41461 .38965 Mdot
.2348 .82019 Mdot
.94598 .71118 Mdot
.02807 .08209 Mdot
.91467 .8866 Mdot
.37035 .45568 Mdot
.01558 .64523 Mdot
.55192 .53634 Mdot
.44527 .89335 Mdot
.96302 .51775 Mdot
.73729 .77426 Mdot
.62208 .88479 Mdot
.28007 .65799 Mdot
.8438 .56373 Mdot
.33367 .48988 Mdot
.85992 .52624 Mdot
.24495 .38504 Mdot
.51647 .27151 Mdot
.90304 .38657 Mdot
.92713 .02409 Mdot
.44369 .51657 Mdot
.57428 .13059 Mdot
.20616 .63188 Mdot
.76595 .5598 Mdot
.43424 .66829 Mdot
.6552 .22096 Mdot
.7984 .1432 Mdot
.00456 .20616 Mdot
.1788 .17423 Mdot
.34859 .1698 Mdot
.61133 .26274 Mdot
.59138 .98004 Mdot
.17649 .58511 Mdot
.76426 .58777 Mdot
.46164 .69739 Mdot
.89313 .43149 Mdot
.01774 .12461 Mdot
.01844 .0007 Mdot
.89037 .87194 Mdot
.47044 .58007 Mdot
.8448 .37435 Mdot
.14139 .29659 Mdot
.5734 .43202 Mdot
.50122 .92781 Mdot
.43753 .93632 Mdot
.94772 .51018 Mdot
.81734 .86962 Mdot
.70281 .88547 Mdot
.65375 .95094 Mdot
.52115 .86741 Mdot
.53621 .01506 Mdot
.80257 .26636 Mdot
.12279 .32022 Mdot
.66625 .54346 Mdot
.17308 .50683 Mdot
.69342 .52034 Mdot
.25818 .56476 Mdot
.71032 .45215 Mdot
.24212 .53179 Mdot
.66119 .41907 Mdot
.02535 .36416 Mdot
.21283 .18748 Mdot
.31647 .10364 Mdot
.40181 .08533 Mdot
.84256 .44075 Mdot
.21425 .37169 Mdot
.49984 .2856 Mdot
.78434 .2845 Mdot
.15709 .37275 Mdot
.60026 .44317 Mdot
.69974 .09948 Mdot
.85821 .15847 Mdot
.88303 .02482 Mdot
.6549 .77187 Mdot
.3478 .6929 Mdot
.13041 .78262 Mdot
.09891 .9685 Mdot
.41874 .31982 Mdot
.19412 .77539 Mdot
.92338 .72926 Mdot
.16849 .24511 Mdot
.44246 .27397 Mdot
.32234 .87989 Mdot
.20128 .87893 Mdot
.01792 .81665 Mdot
.70937 .69145 Mdot
.47879 .76942 Mdot
.10021 .62142 Mdot
.0656 .96539 Mdot
.5847 .51911 Mdot
.66914 .08444 Mdot
.72695 .05781 Mdot
.88718 .16023 Mdot
.77267 .88549 Mdot
.76096 .9883 Mdot
.8607 .09974 Mdot
.81572 .95502 Mdot
.79118 .97546 Mdot
.84364 .05246 Mdot
.82285 .97922 Mdot
.80145 .9786 Mdot
.83642 .03497 Mdot
.82523 .9888 Mdot
.80597 .98074 Mdot
.83262 .02665 Mdot
.82659 .99397 Mdot
.80812 .98153 Mdot
.83027 .02215 Mdot
.82778 .99751 Mdot
.80895 .98117 Mdot
.82865 .01969 Mdot
.82915 .0005 Mdot
.80879 .97964 Mdot
.82737 .01858 Mdot
.83097 .0036 Mdot
.80756 .9766 Mdot
.82617 .0186 Mdot
.83369 .00753 Mdot
.80479 .97109 Mdot
.82461 .01982 Mdot
.83833 .01372 Mdot
.79892 .96059 Mdot
.82138 .02246 Mdot
.84775 .02637 Mdot
.78461 .93686 Mdot
.80932 .02471 Mdot
.87162 .06231 Mdot
.73824 .86661 Mdot
.71589 .97765 Mdot
.78214 .06625 Mdot
.93984 .15769 Mdot
.50872 .56889 Mdot
.13864 .62992 Mdot
.91623 .77758 Mdot
.25351 .33728 Mdot
.47698 .22347 Mdot
.53988 .0629 Mdot
.87904 .33916 Mdot
.98572 .10667 Mdot
.19224 .20652 Mdot
.35725 .16501 Mdot
.65168 .29443 Mdot
.85427 .20259 Mdot
.94029 .08603 Mdot
.43453 .49424 Mdot
.48333 .04879 Mdot
.41563 .93231 Mdot
.78465 .36902 Mdot
.24145 .4568 Mdot
.58577 .34432 Mdot
.50187 .9161 Mdot
.43106 .92919 Mdot
.89262 .46156 Mdot
.05009 .15746 Mdot
.8627 .81261 Mdot
.52156 .65887 Mdot
.33091 .80935 Mdot
.16707 .83616 Mdot
.03699 .86992 Mdot
.65031 .61332 Mdot
.16621 .5159 Mdot
.71889 .55269 Mdot
.36445 .64556 Mdot
.17178 .80733 Mdot
.99689 .82511 Mdot
.84377 .84689 Mdot
.61689 .77312 Mdot
.13666 .51976 Mdot
.81311 .67645 Mdot
.5172 .70409 Mdot
.34147 .82427 Mdot
.23064 .88917 Mdot
.01396 .78332 Mdot
.69969 .68574 Mdot
.44433 .74463 Mdot
.80715 .36282 Mdot
.213 .40585 Mdot
.53474 .32174 Mdot
.09772 .56298 Mdot
.01884 .92112 Mdot
.8084 .78956 Mdot
.63788 .82949 Mdot
.31627 .67838 Mdot
.97575 .65948 Mdot
.80432 .82857 Mdot
.68271 .87839 Mdot
.57709 .89438 Mdot
.99025 .41316 Mdot
.47163 .48138 Mdot
.75543 .28381 Mdot
.15267 .39724 Mdot
.63773 .48506 Mdot
.97099 .33326 Mdot
.50621 .53522 Mdot
.08487 .57866 Mdot
.0972 .01232 Mdot
.47066 .37347 Mdot
.63992 .16926 Mdot
.66723 .02731 Mdot
.66135 .99412 Mdot
.60114 .9398 Mdot
.20225 .6011 Mdot
.73904 .53679 Mdot
.38727 .64823 Mdot
.31071 .92345 Mdot
.20016 .88945 Mdot
.0297 .82954 Mdot
.65253 .62282 Mdot
.18695 .53442 Mdot
.69357 .50663 Mdot
.245 .55142 Mdot
.68289 .43789 Mdot
.13726 .45438 Mdot
.74556 .6083 Mdot
.5 .3 Mdot
.8 .3 Mdot
.15956 .35956 Mdot
.58013 .42057 Mdot
.53818 .95805 Mdot
.76094 .22276 Mdot
.09515 .33421 Mdot
.8023 .70715 Mdot
.56392 .76163 Mdot
.76109 .19717 Mdot
.06964 .30855 Mdot
.90612 .83649 Mdot
.3623 .45617 Mdot
.97039 .60809 Mdot
.78456 .81417 Mdot
.68665 .90209 Mdot
.61574 .92909 Mdot
.28549 .66974 Mdot
.86872 .58324 Mdot
.27019 .40146 Mdot
.56651 .29633 Mdot
.31498 .74847 Mdot
.04094 .72596 Mdot
.48347 .44252 Mdot
.81046 .32699 Mdot
.17212 .36166 Mdot
.55045 .37833 Mdot
.27601 .72557 Mdot
.90234 .62633 Mdot
.17019 .26785 Mdot
.46112 .29093 Mdot
.48259 .02147 Mdot
.38245 .89986 Mdot
.53225 .1498 Mdot
.90626 .37401 Mdot
.89916 .9929 Mdot
.55166 .6525 Mdot
.55945 .00779 Mdot
.97377 .41432 Mdot
.57086 .59709 Mdot
.64777 .0769 Mdot
.6167 .96893 Mdot
.33125 .71456 Mdot
.07379 .74254 Mdot
.31811 .24432 Mdot
.5488 .2307 Mdot
.11579 .56699 Mdot
.94187 .82608 Mdot
.16587 .224 Mdot
.42785 .26198 Mdot
.20188 .77404 Mdot
.91236 .71048 Mdot
.20577 .29341 Mdot
.42784 .22207 Mdot
.16191 .73407 Mdot
.94824 .78634 Mdot
.09054 .1423 Mdot
.6327 .54216 Mdot
.99982 .36712 Mdot
.36822 .3684 Mdot
.91601 .54779 Mdot
.02481 .1088 Mdot
.96065 .93584 Mdot
.16916 .20851 Mdot
.40424 .23508 Mdot
.00871 .60447 Mdot
.55226 .54355 Mdot
.4551 .90284 Mdot
.04783 .59272 Mdot
.31078 .26295 Mdot
.53991 .22913 Mdot
.04548 .50557 Mdot
.237 .19151 Mdot
.31814 .08115 Mdot
.38576 .06762 Mdot
.72062 .33486 Mdot
.15064 .43002 Mdot
.67672 .52608 Mdot
.20085 .52413 Mdot
.6636 .46275 Mdot
.08027 .41667 Mdot
.95856 .87829 Mdot
.12364 .16507 Mdot
.5077 .38406 Mdot
.94565 .43795 Mdot
.7567 .81105 Mdot
.68085 .92415 Mdot
.61558 .93473 Mdot
.29008 .6745 Mdot
.88563 .59556 Mdot
.21461 .32898 Mdot
.45693 .24232 Mdot
.40144 .94451 Mdot
.69926 .29782 Mdot
.05503 .35577 Mdot
.03323 .97821 Mdot
.78049 .74726 Mdot
.62145 .84096 Mdot
.23244 .61098 Mdot
.73611 .50368 Mdot
.34963 .61352 Mdot
.06034 .7107 Mdot
.35873 .29839 Mdot
.79307 .43434 Mdot
.30095 .50788 Mdot
.75134 .45039 Mdot
.31578 .56444 Mdot
.85993 .54416 Mdot
.2628 .40287 Mdot
.55518 .29238 Mdot
.22616 .67097 Mdot
.79552 .56937 Mdot
.43371 .63819 Mdot
.62117 .18746 Mdot
.57721 .95604 Mdot
.05275 .47555 Mdot
.16575 .11299 Mdot
.31715 .1514 Mdot
.45217 .13502 Mdot
.25736 .8052 Mdot
.94967 .6923 Mdot
.98846 .03879 Mdot
.10796 .1195 Mdot
.52838 .42043 Mdot
.14645 .61807 Mdot
.87803 .73158 Mdot
.38225 .50422 Mdot
.13536 .75311 Mdot
.05113 .91577 Mdot
.61512 .56399 Mdot
.91648 .30136 Mdot
.77601 .85953 Mdot
.73478 .95877 Mdot
.80254 .06776 Mdot
.92423 .12168 Mdot
.55651 .63228 Mdot
.57611 .0196 Mdot
.10837 .53226 Mdot
.93933 .83096 Mdot
.18478 .24546 Mdot
.40839 .2236 Mdot
.02552 .61714 Mdot
.46476 .43924 Mdot
.65934 .19458 Mdot
.79212 .13277 Mdot
.00019 .20808 Mdot
.20693 .20673 Mdot
.34013 .1332 Mdot
.53316 .19303 Mdot
.95666 .4235 Mdot
.67978 .72312 Mdot
.41032 .73053 Mdot
.54576 .13545 Mdot
.99717 .4514 Mdot
.46839 .47122 Mdot
.7198 .25141 Mdot
.0653 .3455 Mdot
.9664 .90109 Mdot
.10096 .13457 Mdot
.57524 .47428 Mdot
.55681 .98157 Mdot
.92767 .37086 Mdot
.7876 .85994 Mdot
.73067 .94307 Mdot
.77962 .04895 Mdot
.92342 .14379 Mdot
.58285 .65943 Mdot
.79638 .21353 Mdot
.07703 .28065 Mdot
.8393 .76227 Mdot
.54485 .70555 Mdot
.56019 .01534 Mdot
.98688 .42669 Mdot
.50532 .51844 Mdot
.06098 .55566 Mdot
.20015 .13917 Mdot
.27944 .07929 Mdot
.26365 .98421 Mdot
.13787 .87422 Mdot
.16325 .02538 Mdot
.23598 .07273 Mdot
.19895 .96297 Mdot
.10466 .90571 Mdot
.32944 .22479 Mdot
.57607 .24663 Mdot
.33514 .75907 Mdot
.13577 .80063 Mdot
.09716 .96139 Mdot
.4199 .32274 Mdot
.2053 .7854 Mdot
.92027 .71497 Mdot
.1703 .25003 Mdot
.44304 .27274 Mdot
.32552 .88248 Mdot
.21702 .89149 Mdot
.01826 .80125 Mdot
.69194 .67367 Mdot
.40638 .71444 Mdot
.50266 .09627 Mdot
.61752 .11486 Mdot
.48226 .86474 Mdot
.2231 .74084 Mdot
.86573 .64263 Mdot
.34067 .47494 Mdot
.87747 .5368 Mdot
.18973 .31226 Mdot
.46684 .27711 Mdot
.51348 .04664 Mdot
.65438 .1409 Mdot
.71428 .05989 Mdot
.86031 .14603 Mdot
.86339 .00308 Mdot
.70958 .84619 Mdot
.63411 .92453 Mdot
.39017 .75607 Mdot
.43702 .04684 Mdot
.05439 .61737 Mdot
.29842 .24403 Mdot
.47953 .18111 Mdot
.51775 .03822 Mdot
.68 .16224 Mdot
.85029 .17029 Mdot
.92071 .07042 Mdot
.5235 .6028 Mdot
.29022 .76672 Mdot
.97824 .68802 Mdot
.81812 .83989 Mdot
.67159 .85346 Mdot
.50663 .83505 Mdot
.38809 .88146 Mdot
.54917 .16107 Mdot
.04895 .49978 Mdot
.21146 .16252 Mdot
.29239 .08093 Mdot
.29852 .00613 Mdot
.24195 .94343 Mdot
.07272 .83077 Mdot
.412 .33928 Mdot
.16618 .75419 Mdot
.95724 .79105 Mdot
.04404 .0868 Mdot
.82648 .78245 Mdot
.59683 .77034 Mdot
.0039 .40708 Mdot
.38367 .37977 Mdot
.01975 .63607 Mdot
.51795 .4982 Mdot
.1415 .62355 Mdot
.89999 .7585 Mdot
.31338 .41338 Mdot
.69984 .38646 Mdot
.14551 .44567 Mdot
.7087 .56319 Mdot
.34868 .63998 Mdot
.08196 .73328 Mdot
.26654 .18458 Mdot
.34304 .0765 Mdot
.49049 .14744 Mdot
.57137 .08089 Mdot
.13531 .56393 Mdot
.86213 .72682 Mdot
.43779 .57566 Mdot
.58896 .15117 Mdot
.3309 .74194 Mdot
.0996 .7687 Mdot
.21572 .11612 Mdot
.2435 .02778 Mdot
.15812 .91462 Mdot
.13921 .98109 Mdot
.26542 .12621 Mdot
.28278 .01736 Mdot
.2096 .92682 Mdot
.05804 .84844 Mdot
.50916 .45113 Mdot
.02441 .51525 Mdot
.36944 .34502 Mdot
.89963 .53019 Mdot
.08676 .18712 Mdot
.69622 .60947 Mdot
.35677 .66055 Mdot
.14468 .78791 Mdot
.05367 .90899 Mdot
.59407 .5404 Mdot
.75528 .16121 Mdot
.02996 .27468 Mdot
.09615 .06619 Mdot
.52948 .43332 Mdot
.16795 .63847 Mdot
.83714 .66919 Mdot
.45756 .62042 Mdot
.7844 .32684 Mdot
.1994 .415 Mdot
.55615 .35675 Mdot
.29783 .74168 Mdot
.97536 .67753 Mdot
.82467 .84931 Mdot
.66768 .84301 Mdot
.47903 .81136 Mdot
.14405 .66502 Mdot
.93285 .7888 Mdot
.17787 .24502 Mdot
.42127 .24339 Mdot
.13575 .71449 Mdot
.01107 .87531 Mdot
.80897 .7979 Mdot
.64536 .83639 Mdot
.36357 .71822 Mdot
.23953 .87596 Mdot
.00381 .76428 Mdot
.74141 .73759 Mdot
.59146 .85006 Mdot
.04709 .45563 Mdot
.17788 .13079 Mdot
.30703 .12915 Mdot
.39285 .08582 Mdot
.78403 .39118 Mdot
.26392 .47989 Mdot
.63399 .37007 Mdot
.83505 .20106 Mdot
.99487 .15981 Mdot
.19061 .19574 Mdot
.34894 .15833 Mdot
.60162 .25268 Mdot
.51829 .91667 Mdot
.56273 .04444 Mdot
.03502 .47228 Mdot
.26416 .22914 Mdot
.38362 .11946 Mdot
.75912 .3755 Mdot
.24688 .48776 Mdot
.62076 .37388 Mdot
.76117 .14041 Mdot
.01292 .25175 Mdot
.17432 .1614 Mdot
.34523 .1709 Mdot
.59559 .25036 Mdot
.47558 .87999 Mdot
.18526 .70969 Mdot
.87176 .6865 Mdot
.36189 .49013 Mdot
.00212 .64023 Mdot
.6275 .62537 Mdot
.0529 .42541 Mdot
.11477 .06186 Mdot
.4411 .32633 Mdot
.36446 .92336 Mdot
.44961 .08516 Mdot
.18792 .73831 Mdot
.89582 .7079 Mdot
.28199 .38616 Mdot
.57649 .2945 Mdot
.38606 .80957 Mdot
.46448 .07841 Mdot
.29629 .83181 Mdot
.06081 .76452 Mdot
.40996 .34915 Mdot
.16192 .75196 Mdot
.9661 .80418 Mdot
.00581 .03971 Mdot
.00488 .99907 Mdot
.96982 .96494 Mdot
.14476 .17494 Mdot
.44043 .29567 Mdot
.32876 .88833 Mdot
.23664 .90788 Mdot
.03436 .79772 Mdot
.59344 .55909 Mdot
.7697 .17626 Mdot
.05152 .28182 Mdot
.97896 .92743 Mdot
.05327 .07432 Mdot
.7616 .70833 Mdot
.58106 .81946 Mdot
.94372 .36266 Mdot
.69217 .74845 Mdot
.48198 .78981 Mdot
.14591 .66393 Mdot
.92565 .77974 Mdot
.20712 .28148 Mdot
.4147 .20758 Mdot
.05335 .63865 Mdot
.32552 .27217 Mdot
.60669 .28117 Mdot
.57997 .97328 Mdot
.08977 .50981 Mdot
.00396 .91419 Mdot
.89043 .88647 Mdot
.48471 .59428 Mdot
.97215 .48744 Mdot
.65355 .6814 Mdot
.25062 .59708 Mdot
.73362 .483 Mdot
.32481 .59119 Mdot
.92275 .59794 Mdot
.04046 .11771 Mdot
.87801 .83755 Mdot
.4883 .61029 Mdot
.01678 .52848 Mdot
.42802 .41125 Mdot
.35243 .92441 Mdot
.38565 .03322 Mdot
0 .35 Mdot
.35 .35 Mdot
.79869 .44869 Mdot
.30974 .51105 Mdot
.78425 .47452 Mdot
.34715 .5629 Mdot
.99717 .65002 Mdot
.66698 .6698 Mdot
.30268 .6357 Mdot
.88477 .58209 Mdot
.20481 .32003 Mdot
.45537 .25056 Mdot
.39759 .94222 Mdot
.67138 .27379 Mdot
.92604 .25467 Mdot
.67997 .75393 Mdot
.44188 .7619 Mdot
.80591 .36403 Mdot
.21599 .41008 Mdot
.53733 .32134 Mdot
.11755 .58022 Mdot
.94772 .83017 Mdot
.13729 .18957 Mdot
.48066 .34337 Mdot
.68895 .20829 Mdot
.93036 .24141 Mdot
.64385 .71349 Mdot
.2327 .58885 Mdot
.71404 .48134 Mdot
.28114 .5671 Mdot
.75542 .47428 Mdot
.34314 .58772 Mdot
.00218 .65903 Mdot
.64597 .64379 Mdot
.17422 .52825 Mdot
.7123 .53809 Mdot
.33337 .62107 Mdot
.98975 .65638 Mdot
.71784 .72809 Mdot
.53734 .8195 Mdot
.61581 .07847 Mdot
.43528 .81947 Mdot
.81412 .37884 Mdot
.21784 .40372 Mdot
.53015 .3123 Mdot
.05221 .52206 Mdot
.21534 .16313 Mdot
.2907 .07536 Mdot
.28821 .99751 Mdot
.2036 .91539 Mdot
.05191 .84831 Mdot
.54324 .49133 Mdot
.33357 .79033 Mdot
.15991 .82634 Mdot
.04593 .88602 Mdot
.61489 .56896 Mdot
.92003 .30514 Mdot
.7617 .84168 Mdot
.71445 .95275 Mdot
.75361 .03916 Mdot
.90657 .15296 Mdot
.67661 .77004 Mdot
.44439 .76778 Mdot
.83076 .38637 Mdot
.19083 .36007 Mdot
.51292 .32209 Mdot
.92536 .41244 Mdot
.84133 .91597 Mdot
.69293 .8516 Mdot
.58775 .89482 Mdot
.06617 .47842 Mdot
.09462 .02844 Mdot
.49907 .40446 Mdot
.89706 .39798 Mdot
.96644 .06939 Mdot
.269 .30256 Mdot
.46541 .19641 Mdot
.42156 .95615 Mdot
.8506 .42904 Mdot
.17848 .32788 Mdot
.50288 .3244 Mdot
.84746 .34458 Mdot
.10368 .25622 Mdot
.68439 .58072 Mdot
.28588 .60148 Mdot
.80146 .51559 Mdot
.3734 .57193 Mdot
.14965 .77626 Mdot
.02603 .87638 Mdot
.72101 .69497 Mdot
.51163 .79062 Mdot
.38358 .87195 Mdot
.51132 .12774 Mdot
.7182 .20688 Mdot
.017 .2988 Mdot
.19701 .18 Mdot
.32411 .12711 Mdot
.45576 .13165 Mdot
.28173 .82597 Mdot
.01568 .73395 Mdot
.64003 .62434 Mdot
.1229 .48288 Mdot
.82844 .70554 Mdot
.51546 .68702 Mdot
.31055 .79509 Mdot
.07121 .76066 Mdot
.34986 .27865 Mdot
.72664 .37677 Mdot
.20551 .47887 Mdot
.61355 .40803 Mdot
.75067 .13712 Mdot
.00187 .2512 Mdot
.24001 .23814 Mdot
.36626 .12625 Mdot
.66269 .29643 Mdot
.90971 .24702 Mdot
.7554 .84569 Mdot
.71454 .95914 Mdot
.76022 .04568 Mdot
.91769 .15747 Mdot
.62598 .70829 Mdot
.1269 .50092 Mdot
.83069 .70379 Mdot
.50842 .67773 Mdot
.24508 .73666 Mdot
.86818 .6231 Mdot
.31207 .44389 Mdot
.72553 .41346 Mdot
.23993 .5144 Mdot
.64248 .40255 Mdot
.91441 .27193 Mdot
.75701 .8426 Mdot
.71261 .9556 Mdot
.75171 .03909 Mdot
.90482 .15311 Mdot
.68517 .78035 Mdot
.48844 .80327 Mdot
.21084 .7224 Mdot
.85271 .64187 Mdot
.38461 .5319 Mdot
.17771 .7931 Mdot
.96969 .79198 Mdot
.97258 .00289 Mdot
.16647 .19389 Mdot
.39623 .22976 Mdot
.94995 .55372 Mdot
.84829 .89834 Mdot
.65493 .80664 Mdot
.38271 .72779 Mdot
.36181 .97909 Mdot
.4906 .1288 Mdot
.55367 .06307 Mdot
.98536 .43169 Mdot
.51938 .53403 Mdot
.18877 .66938 Mdot
.82551 .63674 Mdot
.45329 .62778 Mdot
.75874 .30546 Mdot
.1766 .41786 Mdot
.59676 .42016 Mdot
.65331 .05655 Mdot
.62459 .97128 Mdot
.38161 .75702 Mdot
.38422 .00262 Mdot
.64601 .26178 Mdot
.79239 .14638 Mdot
.01358 .22118 Mdot
.13985 .12627 Mdot
.40838 .26853 Mdot
.07041 .66203 Mdot
.25547 .18505 Mdot
.3271 .07163 Mdot
.41282 .08572 Mdot
.91834 .50552 Mdot
.97074 .0524 Mdot
.22682 .25608 Mdot
.38061 .15379 Mdot
.77488 .39427 Mdot
.26965 .49477 Mdot
.65881 .38916 Mdot
.98413 .32532 Mdot
.42038 .43625 Mdot
.32225 .90187 Mdot
.22285 .9006 Mdot
.02554 .80269 Mdot
.65021 .62467 Mdot
.17709 .52687 Mdot
.70476 .52767 Mdot
.3018 .59704 Mdot
.84324 .54144 Mdot
.31299 .46975 Mdot
.75477 .44178 Mdot
.31013 .55536 Mdot
.82998 .51985 Mdot
.32617 .49619 Mdot
.83347 .50729 Mdot
.30512 .47165 Mdot
.72884 .42372 Mdot
.25681 .52797 Mdot
.67171 .4149 Mdot
.06862 .39691 Mdot
.99993 .93131 Mdot
.93173 .9318 Mdot
.3269 .39517 Mdot
.73553 .40863 Mdot
.25365 .51812 Mdot
.65797 .40432 Mdot
.99527 .3373 Mdot
.36566 .37039 Mdot
.90345 .53779 Mdot
.07639 .17293 Mdot
.73492 .65853 Mdot
.50253 .76761 Mdot
.28785 .78532 Mdot
.99046 .7026 Mdot
.75982 .76936 Mdot
.64115 .88133 Mdot
.386 .74485 Mdot
.39935 .01335 Mdot
.75416 .35481 Mdot
.22267 .46851 Mdot
.59349 .37081 Mdot
.58171 .98823 Mdot
.11711 .5354 Mdot
.90474 .78763 Mdot
.32009 .41536 Mdot
.72767 .40758 Mdot
.23839 .51072 Mdot
.63799 .3996 Mdot
.88698 .24899 Mdot
.86228 .9753 Mdot
.68574 .82346 Mdot
.5337 .84796 Mdot
.61584 .08213 Mdot
.43912 .82328 Mdot
.84658 .40746 Mdot
.16922 .32264 Mdot
.51823 .34901 Mdot
.99457 .47634 Mdot
.50891 .51434 Mdot
.08555 .57665 Mdot
.09175 .0062 Mdot
.49068 .39893 Mdot
.82443 .33375 Mdot
.15264 .32821 Mdot
.5688 .41616 Mdot
.45169 .88289 Mdot
.00159 .5499 Mdot
.54036 .53877 Mdot
.35861 .81825 Mdot
.31229 .95368 Mdot
.23611 .92383 Mdot
.05009 .81398 Mdot
.51918 .46909 Mdot
.12225 .60306 Mdot
.95128 .82903 Mdot
.11606 .16479 Mdot
.53852 .42246 Mdot
.22801 .68949 Mdot
.81403 .58602 Mdot
.42518 .61114 Mdot
.53163 .10645 Mdot
.85801 .32638 Mdot
.05163 .19363 Mdot
.89013 .8385 Mdot
.43806 .54793 Mdot
.56326 .12521 Mdot
.11975 .55649 Mdot
.91486 .79511 Mdot
.27793 .36307 Mdot
.54401 .26609 Mdot
.11429 .57027 Mdot
.95155 .83727 Mdot
.12273 .17118 Mdot
.51744 .39471 Mdot
.034 .51656 Mdot
.31436 .28036 Mdot
.57049 .25613 Mdot
.30405 .73356 Mdot
.98715 .6831 Mdot
.76013 .77298 Mdot
.64494 .88481 Mdot
.40979 .76485 Mdot
.57644 .16665 Mdot
.2578 .68137 Mdot
.82643 .56862 Mdot
.38313 .55671 Mdot
.19333 .8102 Mdot
.95932 .76599 Mdot
.00696 .04764 Mdot
.00588 .99892 Mdot
.96366 .95778 Mdot
.17364 .20998 Mdot
.39533 .22169 Mdot
.936 .54068 Mdot
.91268 .97667 Mdot
.4704 .55772 Mdot
.82209 .35169 Mdot
.17552 .35343 Mdot
.53465 .35913 Mdot
.13438 .59973 Mdot
.90131 .76693 Mdot
.31565 .41434 Mdot
.70935 .3937 Mdot
.181 .47165 Mdot
.64163 .46063 Mdot
.96792 .32629 Mdot
.51725 .54933 Mdot
.18708 .66983 Mdot
.82876 .64168 Mdot
.45087 .62211 Mdot
.73452 .28364 Mdot
.12698 .39246 Mdot
.72194 .59496 Mdot
.41371 .69177 Mdot
.53058 .11688 Mdot
.86024 .32965 Mdot
.04725 .18701 Mdot
.90836 .86112 Mdot
.37608 .46771 Mdot
.06135 .68528 Mdot
.32771 .26635 Mdot
.61016 .28245 Mdot
.60363 .99347 Mdot
.27236 .66873 Mdot
.83798 .56562 Mdot
.35174 .51376 Mdot
.97142 .61968 Mdot
.79007 .81864 Mdot
.68768 .89761 Mdot
.61504 .92737 Mdot
.2794 .66436 Mdot
.84863 .56923 Mdot
.32477 .47614 Mdot
.80751 .48274 Mdot
.33239 .52488 Mdot
.88916 .55677 Mdot
.1606 .27145 Mdot
.48914 .32854 Mdot
.74171 .25257 Mdot
.10685 .36514 Mdot
.77899 .67214 Mdot
.54678 .7678 Mdot
.63738 .09059 Mdot
.57458 .9372 Mdot
.01491 .44034 Mdot
.35102 .3361 Mdot
.79001 .43899 Mdot
.30807 .51806 Mdot
.78538 .47731 Mdot
.34936 .56398 Mdot
.00941 .66005 Mdot
.60362 .59421 Mdot
.873 .26938 Mdot
.94 .067 Mdot
.41714 .47715 Mdot
.34013 .92299 Mdot
.32295 .98282 Mdot
.30669 .98374 Mdot
.24628 .93959 Mdot
.07209 .82581 Mdot
.41034 .33825 Mdot
.15363 .74329 Mdot
.9809 .82727 Mdot
.94152 .96062 Mdot
.30233 .3608 Mdot
.60873 .3064 Mdot
.61838 .00965 Mdot
.38237 .76399 Mdot
.39589 .01352 Mdot
.73153 .33564 Mdot
.17377 .44224 Mdot
.62729 .45352 Mdot
.87982 .25253 Mdot
.89591 .01609 Mdot
.58977 .69386 Mdot
.87922 .28945 Mdot
.93528 .05606 Mdot
.43199 .49671 Mdot
.46702 .03502 Mdot
.27279 .80578 Mdot
.9759 .7031 Mdot
.84709 .87119 Mdot
.63143 .78434 Mdot
.23471 .60329 Mdot
.72905 .49434 Mdot
.32783 .59878 Mdot
.94311 .61528 Mdot
.94821 .00511 Mdot
.30946 .36125 Mdot
.63349 .32402 Mdot
.78616 .15268 Mdot
.02429 .23812 Mdot
.09306 .06877 Mdot
.5469 .45384 Mdot
.32434 .77743 Mdot
.10702 .78268 Mdot
.19575 .08873 Mdot
.23449 .03874 Mdot
.16443 .92994 Mdot
.13746 .97303 Mdot
.5 .35 Mdot
.85 .35 Mdot
.10131 .25131 Mdot
.69037 .58906 Mdot
.31622 .62585 Mdot
.92304 .60682 Mdot
.04781 .12477 Mdot
.84291 .7951 Mdot
.56758 .72467 Mdot
.75124 .18365 Mdot
.04894 .29771 Mdot
.00943 .96048 Mdot
.90396 .89454 Mdot
.4307 .52673 Mdot
.48749 .0568 Mdot
.45683 .96934 Mdot
.12767 .67084 Mdot
.99762 .86995 Mdot
.88422 .8866 Mdot
.51166 .62743 Mdot
.22061 .70895 Mdot
.83442 .61381 Mdot
.40923 .57482 Mdot
.38257 .97334 Mdot
.6065 .22393 Mdot
.52155 .91505 Mdot
.587 .06545 Mdot
.23154 .64455 Mdot
.76949 .53794 Mdot
.41318 .64369 Mdot
.4788 .06562 Mdot
.39642 .91763 Mdot
.63912 .2427 Mdot
.73632 .09719 Mdot
.94348 .20716 Mdot
.53803 .59455 Mdot
.39622 .8582 Mdot
.57837 .18214 Mdot
.28717 .70881 Mdot
.91215 .62497 Mdot
.12134 .20919 Mdot
.56109 .43976 Mdot
.41809 .85699 Mdot
.72668 .30859 Mdot
.13742 .41074 Mdot
.70138 .56396 Mdot
.32783 .62646 Mdot
.97079 .64296 Mdot
.81707 .84628 Mdot
.67997 .8629 Mdot
.55082 .87086 Mdot
.77144 .22061 Mdot
.09605 .32461 Mdot
.7884 .69236 Mdot
.56257 .77417 Mdot
.76353 .20096 Mdot
.07456 .31102 Mdot
.88257 .80802 Mdot
.44001 .55744 Mdot
.58743 .14742 Mdot
.31653 .7291 Mdot
.02749 .71095 Mdot
.54699 .5195 Mdot
.39063 .84364 Mdot
.5275 .13688 Mdot
.85593 .32843 Mdot
.06066 .20473 Mdot
.851 .79034 Mdot
.53853 .68754 Mdot
.49318 .95465 Mdot
.40009 .90691 Mdot
.65269 .2526 Mdot
.81753 .16484 Mdot
.99766 .18013 Mdot
.19415 .19649 Mdot
.34445 .15029 Mdot
.57112 .22668 Mdot
.27926 .70814 Mdot
.89209 .61283 Mdot
.20373 .31163 Mdot
.44803 .24431 Mdot
.33502 .88698 Mdot
.26311 .9281 Mdot
.08091 .81779 Mdot
.35643 .27552 Mdot
.75782 .40139 Mdot
.27195 .51413 Mdot
.68257 .41062 Mdot
.10879 .42622 Mdot
.8314 .7226 Mdot
.52553 .69414 Mdot
.39764 .87211 Mdot
.60162 .20398 Mdot
.4696 .86798 Mdot
.12608 .65648 Mdot
.98945 .86337 Mdot
.92662 .93718 Mdot
.35943 .43281 Mdot
.93129 .57186 Mdot
.96934 .03805 Mdot
.22071 .25137 Mdot
.37681 .1561 Mdot
.75415 .37734 Mdot
.2452 .49105 Mdot
.62267 .37747 Mdot
.77629 .15362 Mdot
.02883 .25254 Mdot
.08067 .05184 Mdot
.59171 .51105 Mdot
.70979 .11808 Mdot
.9066 .1968 Mdot
.72034 .81374 Mdot
.62887 .90853 Mdot
.34408 .71521 Mdot
.13423 .79016 Mdot
.09226 .95803 Mdot
.44003 .34778 Mdot
.37791 .93788 Mdot
.54257 .16466 Mdot
.00166 .4591 Mdot
.44911 .44745 Mdot
.54637 .09726 Mdot
.96369 .41731 Mdot
.63298 .66929 Mdot
.12855 .49557 Mdot
.81897 .69043 Mdot
.52049 .70152 Mdot
.36505 .84456 Mdot
.37416 .00911 Mdot
.59137 .2172 Mdot
.41357 .82221 Mdot
.66009 .24652 Mdot
.8476 .18751 Mdot
.94619 .09859 Mdot
.4143 .4681 Mdot
.31106 .89677 Mdot
.17475 .86368 Mdot
.04658 .87183 Mdot
.59699 .55041 Mdot
.78507 .18808 Mdot
.0603 .27523 Mdot
.92345 .86316 Mdot
.30201 .37855 Mdot
.62543 .32342 Mdot
.73875 .11332 Mdot
.96338 .22463 Mdot
.44209 .47871 Mdot
.52435 .08226 Mdot
.7764 .25205 Mdot
.12724 .35084 Mdot
.67928 .55203 Mdot
.2372 .55792 Mdot
.68463 .44744 Mdot
.15351 .46888 Mdot
.70685 .55334 Mdot
.33357 .62672 Mdot
.99629 .66272 Mdot
.68496 .68867 Mdot
.39598 .71102 Mdot
.42962 .03364 Mdot
.98652 .5569 Mdot
.63765 .65113 Mdot
.13664 .49899 Mdot
.79238 .65574 Mdot
.52294 .73055 Mdot
.41349 .89056 Mdot
.72788 .31438 Mdot
.1456 .41772 Mdot
.68046 .53485 Mdot
.22472 .54426 Mdot
.66892 .44421 Mdot
.08575 .41682 Mdot
.93097 .84522 Mdot
.2444 .31343 Mdot
.44444 .20004 Mdot
.26338 .81894 Mdot
.97217 .70879 Mdot
.87477 .9026 Mdot
.56629 .69152 Mdot
.7085 .14222 Mdot
.92715 .21865 Mdot
.63813 .71098 Mdot
.19914 .56101 Mdot
.70247 .50332 Mdot
.27055 .56809 Mdot
.73383 .46328 Mdot
.30544 .57161 Mdot
.82988 .52444 Mdot
.33101 .50114 Mdot
.8593 .52829 Mdot
.24912 .38982 Mdot
.52487 .27575 Mdot
.97397 .4491 Mdot
.60449 .63053 Mdot
.91504 .31055 Mdot
.79247 .87743 Mdot
.74456 .95209 Mdot
.81007 .06552 Mdot
.91125 .10118 Mdot
.60197 .69072 Mdot
.95867 .35669 Mdot
.60145 .64278 Mdot
.90726 .30581 Mdot
.82612 .91885 Mdot
.73405 .90794 Mdot
.75048 .01643 Mdot
.881 .13051 Mdot
.76905 .88806 Mdot
.76322 .99417 Mdot
.86763 .10441 Mdot
.79543 .9278 Mdot
.79223 .9968 Mdot
.86413 .07189 Mdot
.77574 .91161 Mdot
.7869 .01116 Mdot
.88233 .09543 Mdot
.72842 .84608 Mdot
.67835 .94994 Mdot
.63138 .95303 Mdot
.40315 .77176 Mdot
.53801 .13487 Mdot
.93645 .39844 Mdot
.76801 .83156 Mdot
.70653 .93852 Mdot
.71785 .01132 Mdot
.8206 .10275 Mdot
.92961 .10901 Mdot
.51545 .58584 Mdot
.20923 .69378 Mdot
.82528 .61606 Mdot
.43309 .60781 Mdot
.58624 .15314 Mdot
.31393 .7277 Mdot
.01623 .7023 Mdot
.60509 .58885 Mdot
.87726 .27217 Mdot
.92593 .04867 Mdot
.47456 .54863 Mdot
.8459 .37134 Mdot
.13511 .28921 Mdot
.58812 .453 Mdot
.62689 .03878 Mdot
.46276 .83587 Mdot
.04033 .57757 Mdot
.33859 .29825 Mdot
.69092 .35233 Mdot
.08144 .39052 Mdot
.92646 .84502 Mdot
.26815 .3417 Mdot
.50301 .23485 Mdot
.75889 .25589 Mdot
.12713 .36823 Mdot
.69713 .57001 Mdot
.32032 .62319 Mdot
.93639 .61608 Mdot
.98595 .04956 Mdot
.13372 .14777 Mdot
.45176 .31804 Mdot
.43726 .9855 Mdot
.99488 .55762 Mdot
.58832 .59344 Mdot
.76879 .18047 Mdot
.05558 .28679 Mdot
.96115 .90556 Mdot
.13598 .17484 Mdot
.47059 .33461 Mdot
.60052 .12993 Mdot
.38822 .7877 Mdot
.4562 .06799 Mdot
.22147 .76527 Mdot
.8905 .66903 Mdot
.26697 .37646 Mdot
.53567 .2687 Mdot
.05196 .51629 Mdot
.21096 .159 Mdot
.28922 .07827 Mdot
.28707 .99784 Mdot
.20091 .91384 Mdot
.05324 .85233 Mdot
.53979 .48655 Mdot
.30199 .7622 Mdot
.00904 .70704 Mdot
.65284 .64381 Mdot
.20952 .55668 Mdot
.68795 .47843 Mdot
.19687 .50892 Mdot
.6532 .45633 Mdot
.02385 .37064 Mdot
.22818 .20434 Mdot
.32889 .1007 Mdot
.44958 .12069 Mdot
.22318 .7736 Mdot
.89848 .6753 Mdot
.23722 .33874 Mdot
.46546 .22825 Mdot
.45383 .98837 Mdot
.12351 .66968 Mdot
.01283 .88932 Mdot
.81243 .7996 Mdot
.64149 .82906 Mdot
.3356 .69411 Mdot
.07291 .73731 Mdot
.3175 .24459 Mdot
.54672 .22921 Mdot
.09826 .55155 Mdot
.00485 .90659 Mdot
.87749 .87264 Mdot
.52547 .64798 Mdot
.351 .82552 Mdot
.27933 .92833 Mdot
.11244 .83311 Mdot
.22234 .1099 Mdot
.23494 .0126 Mdot
.13844 .9035 Mdot
.19053 .05209 Mdot
.20541 .01489 Mdot
.14965 .94424 Mdot
.19402 .04437 Mdot
.19251 .9985 Mdot
.14881 .9563 Mdot
.20871 .0599 Mdot
.19181 .9831 Mdot
.13447 .94266 Mdot
.24392 .10945 Mdot
.24009 .99618 Mdot
.12434 .88425 Mdot
.22407 .09972 Mdot
.22446 .00039 Mdot
.12508 .90062 Mdot
.23752 .11243 Mdot
.23929 .00177 Mdot
.1295 .89021 Mdot
.20998 .08048 Mdot
.21141 .00143 Mdot
.13135 .91993 Mdot
.23273 .10138 Mdot
.22658 .99385 Mdot
.11839 .89181 Mdot
.25581 .13742 Mdot
.2799 .02408 Mdot
.20949 .9296 Mdot
.06089 .8514 Mdot
.49636 .43547 Mdot
.90636 .41 Mdot
.93469 .02833 Mdot
.40749 .4728 Mdot
.26855 .86106 Mdot
.02308 .75453 Mdot
.61662 .59354 Mdot
.95537 .33876 Mdot
.60244 .64706 Mdot
.91806 .31563 Mdot
.78225 .86419 Mdot
.73773 .95548 Mdot
.80398 .06625 Mdot
.92085 .11687 Mdot
.56921 .64836 Mdot
.68691 .1177 Mdot
.83232 .14541 Mdot
.94608 .11376 Mdot
.43011 .48403 Mdot
.44046 .01035 Mdot
.04366 .6032 Mdot
.34507 .30141 Mdot
.72529 .38022 Mdot
.2062 .48091 Mdot
.61495 .40875 Mdot
.76019 .14524 Mdot
.01723 .25704 Mdot
.15392 .13669 Mdot
.37345 .21953 Mdot
.79755 .42411 Mdot
.28638 .48883 Mdot
.69011 .40373 Mdot
.12998 .43987 Mdot
.7578 .62781 Mdot
.49836 .74056 Mdot
.2274 .72905 Mdot
.85358 .62617 Mdot
.36612 .51254 Mdot
.04819 .68207 Mdot
.39806 .34987 Mdot
.08213 .68407 Mdot
.21647 .13434 Mdot
.26136 .04489 Mdot
.195 .93364 Mdot
.08042 .88542 Mdot
.42655 .34613 Mdot
.27659 .85004 Mdot
.02807 .75148 Mdot
.58408 .55601 Mdot
.70164 .11757 Mdot
.88227 .18062 Mdot
.81389 .93162 Mdot
.77103 .95714 Mdot
.83254 .06151 Mdot
.86163 .02909 Mdot
.7418 .88017 Mdot
.73458 .99278 Mdot
.83622 .10164 Mdot
.89243 .05621 Mdot
0 .4 Mdot
.4 .4 Mdot
.14516 .74516 Mdot
.00934 .86418 Mdot
.80818 .79884 Mdot
.64749 .83931 Mdot
.37769 .7302 Mdot
.33352 .95583 Mdot
.32518 .99166 Mdot
.32476 .99958 Mdot
.33092 .00616 Mdot
.36392 .033 Mdot
.55625 .19233 Mdot
.13422 .57797 Mdot
.88011 .74589 Mdot
.38807 .50796 Mdot
.17556 .78749 Mdot
.96861 .79305 Mdot
.97995 .01134 Mdot
.13125 .1513 Mdot
.46444 .33318 Mdot
.55075 .08632 Mdot
.98635 .4356 Mdot
.51738 .53103 Mdot
.16981 .65243 Mdot
.8466 .67679 Mdot
.43848 .59188 Mdot
.61038 .1719 Mdot
.4945 .88412 Mdot
.34015 .84564 Mdot
.24569 .90554 Mdot
.03755 .79187 Mdot
.56898 .53142 Mdot
.56825 .99928 Mdot
.03077 .46252 Mdot
.27922 .24845 Mdot
.43231 .15309 Mdot
.12575 .69344 Mdot
.0277 .90195 Mdot
.73672 .70902 Mdot
.55596 .81923 Mdot
.75888 .20292 Mdot
.07416 .31527 Mdot
.88891 .81475 Mdot
.41967 .53076 Mdot
.4117 .99203 Mdot
.81683 .40513 Mdot
.23926 .42243 Mdot
.55015 .31088 Mdot
.20628 .65613 Mdot
.7901 .58382 Mdot
.45283 .66273 Mdot
.79016 .33734 Mdot
.2063 .41613 Mdot
.55008 .34379 Mdot
.2387 .68862 Mdot
.81604 .57734 Mdot
.41292 .59687 Mdot
.43017 .01725 Mdot
.97411 .54395 Mdot
.69848 .72437 Mdot
.47908 .7806 Mdot
.11366 .63458 Mdot
.01854 .90487 Mdot
.79395 .77542 Mdot
.64124 .84729 Mdot
.35245 .71121 Mdot
.17256 .82011 Mdot
.00788 .83532 Mdot
.78807 .78019 Mdot
.65063 .86255 Mdot
.41707 .76644 Mdot
.62889 .21182 Mdot
.6475 .01861 Mdot
.55704 .90954 Mdot
.85736 .30032 Mdot
.02776 .1704 Mdot
.00484 .97708 Mdot
.94807 .94324 Mdot
.2484 .30033 Mdot
.43469 .1863 Mdot
.17657 .74188 Mdot
.92084 .74427 Mdot
.19665 .27581 Mdot
.42038 .22373 Mdot
.10974 .68936 Mdot
.09037 .98064 Mdot
.47186 .38149 Mdot
.65737 .18551 Mdot
.77354 .11617 Mdot
.99163 .21809 Mdot
.26827 .27664 Mdot
.43816 .16989 Mdot
.18595 .7478 Mdot
.90866 .72271 Mdot
.23622 .32756 Mdot
.45387 .21765 Mdot
.35307 .89921 Mdot
.36377 .0107 Mdot
.53312 .16935 Mdot
.93267 .39955 Mdot
.78958 .8569 Mdot
.7263 .93672 Mdot
.76477 .03847 Mdot
.91253 .14776 Mdot
.64222 .72969 Mdot
.24015 .59793 Mdot
.72612 .48598 Mdot
.31367 .58755 Mdot
.87511 .56144 Mdot
.22378 .34867 Mdot
.47345 .24967 Mdot
.53814 .06469 Mdot
.86723 .32909 Mdot
.02161 .15438 Mdot
.02517 .00356 Mdot
.85325 .82808 Mdot
.56908 .71583 Mdot
.75344 .18436 Mdot
.05162 .29818 Mdot
.99476 .94314 Mdot
.97458 .97982 Mdot
.13158 .15699 Mdot
.46893 .33735 Mdot
.59014 .12121 Mdot
.30911 .71897 Mdot
.98995 .68084 Mdot
.74108 .75113 Mdot
.60455 .86347 Mdot
.14839 .54383 Mdot
.79759 .6492 Mdot
.51144 .71385 Mdot
.30532 .79388 Mdot
.05174 .74642 Mdot
.44232 .39057 Mdot
.43789 .99557 Mdot
.00965 .57176 Mdot
.51392 .50427 Mdot
.11552 .60159 Mdot
.97765 .86213 Mdot
.99572 .01807 Mdot
.04374 .04802 Mdot
.78943 .74569 Mdot
.61519 .82576 Mdot
.17871 .56352 Mdot
.73806 .55935 Mdot
.40835 .6703 Mdot
.47198 .06363 Mdot
.34046 .86848 Mdot
.27 .92954 Mdot
.09424 .82424 Mdot
.2967 .20246 Mdot
.43269 .13599 Mdot
.11144 .67875 Mdot
.07229 .96085 Mdot
.54433 .47204 Mdot
.32265 .77832 Mdot
.10094 .77829 Mdot
.2191 .11816 Mdot
.24411 .02501 Mdot
.1558 .91169 Mdot
.14292 .98712 Mdot
.25874 .11582 Mdot
.26216 .00342 Mdot
.15474 .89258 Mdot
.1269 .97216 Mdot
.30193 .17503 Mdot
.42167 .11973 Mdot
.01495 .59328 Mdot
.50375 .4888 Mdot
.01878 .51504 Mdot
.40264 .38386 Mdot
.14669 .74405 Mdot
.00325 .85656 Mdot
.83708 .83384 Mdot
.62235 .78527 Mdot
.18219 .55984 Mdot
.72754 .54535 Mdot
.37591 .64837 Mdot
.241 .86509 Mdot
.99379 .75279 Mdot
.79004 .79625 Mdot
.66531 .87526 Mdot
.50059 .83529 Mdot
.34004 .83945 Mdot
.239 .89896 Mdot
.02654 .78753 Mdot
.62918 .60264 Mdot
.04 .41082 Mdot
.17377 .13377 Mdot
.31883 .14506 Mdot
.45236 .13353 Mdot
.25735 .805 Mdot
.94946 .6921 Mdot
.98945 .03999 Mdot
.10325 .1138 Mdot
.54394 .44069 Mdot
.28832 .74438 Mdot
.95074 .66242 Mdot
.95253 .00179 Mdot
.28172 .32919 Mdot
.51887 .23716 Mdot
.88784 .36897 Mdot
.97853 .09069 Mdot
.21906 .24053 Mdot
.36649 .14743 Mdot
.68517 .31868 Mdot
.02678 .34161 Mdot
.18184 .15506 Mdot
.32344 .1416 Mdot
.46746 .14402 Mdot
.38528 .91782 Mdot
.5678 .18252 Mdot
.21071 .6429 Mdot
.77331 .5626 Mdot
.43807 .66476 Mdot
.68018 .24211 Mdot
.93089 .25071 Mdot
.6503 .7194 Mdot
.27224 .62194 Mdot
.79094 .51871 Mdot
.38707 .59613 Mdot
.2574 .87032 Mdot
.01484 .75744 Mdot
.66854 .6537 Mdot
.29358 .62503 Mdot
.84602 .55245 Mdot
.31586 .46984 Mdot
.76566 .4498 Mdot
.32415 .55849 Mdot
.88731 .56316 Mdot
.17501 .28769 Mdot
.47002 .29501 Mdot
.55642 .0864 Mdot
.02955 .47313 Mdot
.29703 .26748 Mdot
.49871 .20168 Mdot
.6914 .19268 Mdot
.9235 .2321 Mdot
.67073 .74723 Mdot
.39668 .72595 Mdot
.4491 .05242 Mdot
.15123 .70213 Mdot
.94702 .79579 Mdot
.10688 .15986 Mdot
.57358 .4667 Mdot
.53718 .9636 Mdot
.75871 .22152 Mdot
.09265 .33394 Mdot
.81407 .72142 Mdot
.56052 .74645 Mdot
.72047 .15995 Mdot
.97538 .25491 Mdot
.40194 .42656 Mdot
.18468 .78274 Mdot
.94586 .76118 Mdot
.07876 .1329 Mdot
.68258 .60382 Mdot
.302 .61942 Mdot
.86628 .56428 Mdot
.26029 .394 Mdot
.54253 .28225 Mdot
.11897 .57644 Mdot
.93803 .81906 Mdot
.17999 .24195 Mdot
.41393 .23394 Mdot
.07429 .66036 Mdot
.2333 .15901 Mdot
.28435 .05105 Mdot
.24717 .96282 Mdot
.09609 .84891 Mdot
.31252 .21643 Mdot
.49972 .1872 Mdot
.68494 .18522 Mdot
.89245 .20751 Mdot
.79682 .90438 Mdot
.76742 .9706 Mdot
.84543 .07801 Mdot
.84318 .99775 Mdot
.76947 .92629 Mdot
.80152 .03205 Mdot
.88979 .08827 Mdot
.68933 .79954 Mdot
.52297 .83364 Mdot
.51686 .99389 Mdot
.62856 .1117 Mdot
.54549 .91693 Mdot
.77653 .23104 Mdot
.10621 .32968 Mdot
.74638 .64017 Mdot
.50035 .75397 Mdot
.25678 .75643 Mdot
.90013 .64335 Mdot
.19758 .29745 Mdot
.44083 .24325 Mdot
.27935 .83852 Mdot
.02267 .74332 Mdot
.60784 .58517 Mdot
.89145 .28361 Mdot
.87735 .98589 Mdot
.63932 .76197 Mdot
.25666 .61734 Mdot
.7609 .50424 Mdot
.37661 .61571 Mdot
.21255 .83594 Mdot
.96511 .75255 Mdot
.95996 .99485 Mdot
.23215 .27219 Mdot
.39726 .16511 Mdot
.89211 .49485 Mdot
.08567 .19356 Mdot
.7081 .62243 Mdot
.40624 .69813 Mdot
.48533 .0791 Mdot
.46188 .97655 Mdot
.17416 .71227 Mdot
.89647 .72231 Mdot
.29346 .39699 Mdot
.61765 .32419 Mdot
.69242 .07477 Mdot
.80917 .11675 Mdot
.96389 .15471 Mdot
.36922 .40534 Mdot
.95872 .5895 Mdot
.83395 .87523 Mdot
.67184 .83789 Mdot
.49214 .8203 Mdot
.25748 .76533 Mdot
.90996 .65248 Mdot
.15965 .2497 Mdot
.47 .31035 Mdot
.57162 .10161 Mdot
.15779 .58618 Mdot
.81169 .65389 Mdot
.49703 .68534 Mdot
.16155 .66452 Mdot
.87965 .7181 Mdot
.36217 .48252 Mdot
.99604 .63387 Mdot
.65761 .66157 Mdot
.25078 .59316 Mdot
.72987 .47909 Mdot
.31415 .58428 Mdot
.87363 .55948 Mdot
.22764 .35401 Mdot
.47854 .2509 Mdot
.5797 .10116 Mdot
.21573 .63603 Mdot
.7634 .54768 Mdot
.42121 .65781 Mdot
.54978 .12856 Mdot
.02113 .47135 Mdot
.34501 .32388 Mdot
.74748 .40247 Mdot
.2639 .51642 Mdot
.67049 .40658 Mdot
.05498 .3845 Mdot
.0622 .00722 Mdot
.64501 .5828 Mdot
.10813 .46313 Mdot
.87123 .76309 Mdot
.44054 .56931 Mdot
.60327 .16273 Mdot
.43925 .83598 Mdot
.86027 .42101 Mdot
.13851 .27824 Mdot
.56503 .42652 Mdot
.43419 .86916 Mdot
.85568 .42149 Mdot
.15456 .29888 Mdot
.53375 .37919 Mdot
.1474 .61365 Mdot
.87056 .72315 Mdot
.40318 .53262 Mdot
.29907 .89589 Mdot
.13341 .83434 Mdot
.13947 .00606 Mdot
.28948 .15001 Mdot
.35952 .07004 Mdot
.56902 .2095 Mdot
.24668 .67766 Mdot
.81049 .56381 Mdot
.40888 .59839 Mdot
.40374 .99485 Mdot
.76509 .36135 Mdot
.23552 .47043 Mdot
.59648 .36096 Mdot
.59215 .99568 Mdot
.19746 .60531 Mdot
.74884 .55137 Mdot
.41426 .66543 Mdot
.50814 .09387 Mdot
.65893 .15079 Mdot
.74633 .0874 Mdot
.94752 .20119 Mdot
.50943 .5619 Mdot
.13728 .62785 Mdot
.91899 .78171 Mdot
.24361 .32462 Mdot
.45504 .21143 Mdot
.3559 .90086 Mdot
.5 .4 Mdot
.9 .4 Mdot
.95484 .05484 Mdot
.32156 .36672 Mdot
.68494 .36337 Mdot
.0706 .38566 Mdot
.97813 .90753 Mdot
.03829 .06016 Mdot
.833 .79471 Mdot
.5937 .76071 Mdot
.97309 .37939 Mdot
.53995 .56686 Mdot
.38355 .84359 Mdot
.48278 .09923 Mdot
.4617 .97892 Mdot
.17508 .71338 Mdot
.89555 .72047 Mdot
.29579 .40024 Mdot
.62775 .33196 Mdot
.76097 .13322 Mdot
.00563 .24466 Mdot
.21087 .20524 Mdot
.33553 .12465 Mdot
.50312 .16759 Mdot
.69256 .18944 Mdot
.92431 .23175 Mdot
.66615 .74184 Mdot
.37102 .70487 Mdot
.26866 .89764 Mdot
.05985 .7912 Mdot
.44189 .38204 Mdot
.42615 .98426 Mdot
.91181 .48566 Mdot
.98368 .07187 Mdot
.16957 .18589 Mdot
.38062 .21105 Mdot
.83223 .4516 Mdot
.2525 .42028 Mdot
.55884 .30633 Mdot
.26771 .70888 Mdot
.8694 .60168 Mdot
.2861 .4167 Mdot
.61725 .33115 Mdot
.69692 .07967 Mdot
.82928 .13236 Mdot
.94034 .11107 Mdot
.45929 .51895 Mdot
.69637 .23708 Mdot
.98488 .28851 Mdot
.37908 .3942 Mdot
.00598 .62689 Mdot
.59105 .58507 Mdot
.77927 .18822 Mdot
.06279 .28352 Mdot
.91811 .85532 Mdot
.32172 .40361 Mdot
.72245 .40074 Mdot
.22063 .49818 Mdot
.62364 .40301 Mdot
.80765 .18401 Mdot
.03345 .22581 Mdot
.0268 .99334 Mdot
.83344 .80664 Mdot
.60453 .77109 Mdot
.05586 .45133 Mdot
.12414 .06828 Mdot
.40891 .28478 Mdot
.09034 .68142 Mdot
.17282 .08248 Mdot
.26967 .09685 Mdot
.26093 .99126 Mdot
.14073 .8798 Mdot
.15885 .01812 Mdot
.24064 .08179 Mdot
.21027 .96963 Mdot
.10035 .89007 Mdot
.33362 .23328 Mdot
.60308 .26946 Mdot
.54472 .94164 Mdot
.79531 .25059 Mdot
.11514 .31983 Mdot
.69748 .58234 Mdot
.33379 .63631 Mdot
.00689 .6731 Mdot
.63178 .6249 Mdot
.07731 .44553 Mdot
.00268 .92537 Mdot
.90928 .9066 Mdot
.41707 .50779 Mdot
.3703 .95322 Mdot
.51282 .14252 Mdot
.74497 .23215 Mdot
.09066 .34568 Mdot
.8355 .74485 Mdot
.53749 .70199 Mdot
.49949 .962 Mdot
.45791 .95842 Mdot
.12509 .66719 Mdot
.00404 .87895 Mdot
.8547 .85065 Mdot
.58695 .73226 Mdot
.89805 .3111 Mdot
.87499 .97694 Mdot
.63976 .76478 Mdot
.2619 .62214 Mdot
.77306 .51116 Mdot
.38663 .61357 Mdot
.27206 .88543 Mdot
.0541 .78203 Mdot
.4647 .4106 Mdot
.63018 .16549 Mdot
.60869 .9785 Mdot
.29022 .68153 Mdot
.89305 .60283 Mdot
.18945 .2964 Mdot
.45143 .26198 Mdot
.37864 .92721 Mdot
.53629 .15765 Mdot
.94575 .40947 Mdot
.72763 .78188 Mdot
.61261 .88498 Mdot
.22174 .60913 Mdot
.7343 .51256 Mdot
.35553 .62123 Mdot
.09871 .74319 Mdot
.19436 .09564 Mdot
.24331 .04895 Mdot
.17916 .93585 Mdot
.10947 .93031 Mdot
.33249 .22301 Mdot
.58773 .25524 Mdot
.42645 .83872 Mdot
.76845 .342 Mdot
.21705 .44861 Mdot
.57536 .35831 Mdot
.4417 .86634 Mdot
.90902 .46731 Mdot
.97909 .07008 Mdot
.19511 .21602 Mdot
.36265 .16754 Mdot
.68371 .32106 Mdot
.0236 .33989 Mdot
.19892 .17532 Mdot
.31705 .11813 Mdot
.4185 .10145 Mdot
.97405 .55555 Mdot
.71046 .73641 Mdot
.52674 .81628 Mdot
.52932 .00258 Mdot
.736 .20668 Mdot
.05245 .31645 Mdot
.00835 .9559 Mdot
.90583 .89749 Mdot
.42469 .51886 Mdot
.43586 .01117 Mdot
.01011 .57425 Mdot
.51363 .50352 Mdot
.11247 .59884 Mdot
.98791 .87544 Mdot
.94789 .95998 Mdot
.26615 .31826 Mdot
.47605 .2099 Mdot
.51891 .04286 Mdot
.69385 .17494 Mdot
.91427 .22042 Mdot
.70619 .79192 Mdot
.57025 .86406 Mdot
.91027 .34002 Mdot
.84564 .93537 Mdot
.69992 .85429 Mdot
.6136 .91368 Mdot
.25666 .64306 Mdot
.78661 .52995 Mdot
.4013 .61469 Mdot
.36852 .96722 Mdot
.51657 .14805 Mdot
.78041 .26384 Mdot
.13806 .35765 Mdot
.64602 .50796 Mdot
.03862 .3926 Mdot
.16354 .12493 Mdot
.33476 .17122 Mdot
.54619 .21143 Mdot
.07647 .53027 Mdot
.09183 .01537 Mdot
.49944 .40761 Mdot
.90316 .40371 Mdot
.94371 .04055 Mdot
.37013 .42642 Mdot
.98504 .61491 Mdot
.70453 .7195 Mdot
.49297 .78843 Mdot
.23218 .73921 Mdot
.86428 .6321 Mdot
.33539 .47111 Mdot
.84897 .51358 Mdot
.26807 .41909 Mdot
.58025 .31218 Mdot
.43069 .85044 Mdot
.81117 .38048 Mdot
.22446 .41329 Mdot
.53798 .31352 Mdot
.11483 .57685 Mdot
.95581 .84097 Mdot
.10217 .14636 Mdot
.58146 .47929 Mdot
.60639 .02493 Mdot
.32179 .71541 Mdot
.03455 .71276 Mdot
.50733 .47278 Mdot
.03141 .52408 Mdot
.33704 .30563 Mdot
.69108 .35404 Mdot
.08375 .39266 Mdot
.91686 .83311 Mdot
.30585 .389 Mdot
.64867 .34281 Mdot
.88728 .23861 Mdot
.85061 .96334 Mdot
.71273 .86212 Mdot
.65852 .94579 Mdot
.53939 .88087 Mdot
.69318 .15379 Mdot
.89082 .19764 Mdot
.79417 .90335 Mdot
.76897 .97481 Mdot
.84996 .08098 Mdot
.83243 .98247 Mdot
.78287 .95044 Mdot
.82372 .04085 Mdot
.86126 .03754 Mdot
.75158 .89032 Mdot
.75593 .00435 Mdot
.87359 .11766 Mdot
.78599 .9124 Mdot
.78411 .99813 Mdot
.87083 .08672 Mdot
.76569 .89486 Mdot
.76923 .00354 Mdot
.87873 .1095 Mdot
.75733 .8786 Mdot
.74884 .99151 Mdot
.8544 .10556 Mdot
.84283 .98843 Mdot
.76115 .91833 Mdot
.79083 .02968 Mdot
.89813 .1073 Mdot
.67082 .77269 Mdot
.42252 .75171 Mdot
.65306 .23054 Mdot
.79734 .14428 Mdot
.00678 .20944 Mdot
.16876 .16198 Mdot
.35866 .1899 Mdot
.68421 .32554 Mdot
.02999 .34578 Mdot
.1671 .13711 Mdot
.33787 .17077 Mdot
.5601 .22223 Mdot
.19313 .63303 Mdot
.78244 .58931 Mdot
.46277 .68033 Mdot
.88489 .42212 Mdot
.04433 .15943 Mdot
.89747 .85314 Mdot
.4197 .52223 Mdot
.40337 .98367 Mdot
.7514 .34803 Mdot
.21347 .46207 Mdot
.59068 .37721 Mdot
.56882 .97815 Mdot
.01387 .44505 Mdot
.36194 .34807 Mdot
.86032 .49838 Mdot
.21568 .35536 Mdot
.48276 .26708 Mdot
.62937 .14662 Mdot
.58512 .95575 Mdot
.10873 .5236 Mdot
.92908 .82036 Mdot
.2296 .30052 Mdot
.42518 .19557 Mdot
.11607 .69089 Mdot
.06461 .94855 Mdot
.57319 .50858 Mdot
.57622 .00303 Mdot
.09261 .51639 Mdot
.99671 .9041 Mdot
.92383 .92712 Mdot
.36401 .44018 Mdot
.96395 .59994 Mdot
.8141 .85015 Mdot
.68919 .87509 Mdot
.59805 .90886 Mdot
.15066 .55261 Mdot
.79925 .64858 Mdot
.50901 .70976 Mdot
.28179 .77278 Mdot
.96263 .68084 Mdot
.90266 .94003 Mdot
.48237 .57971 Mdot
.93896 .45658 Mdot
.81244 .87348 Mdot
.71536 .90292 Mdot
.70609 .99073 Mdot
.76877 .06268 Mdot
.93779 .16903 Mdot
.53126 .59346 Mdot
.3421 .81085 Mdot
.22027 .87817 Mdot
.00373 .78346 Mdot
.76106 .75733 Mdot
.62978 .86872 Mdot
.3096 .67982 Mdot
.95254 .64294 Mdot
.9228 .97025 Mdot
.41254 .48974 Mdot
.32038 .90784 Mdot
.22131 .90093 Mdot
.02621 .8049 Mdot
.64849 .62229 Mdot
.16586 .51737 Mdot
.72123 .55536 Mdot
.37252 .65129 Mdot
.22385 .85133 Mdot
.9761 .75225 Mdot
.89502 .91892 Mdot
.49667 .60166 Mdot
.07504 .57837 Mdot
.14738 .07235 Mdot
.3293 .18192 Mdot
.53259 .20329 Mdot
.9624 .42981 Mdot
.65299 .69059 Mdot
.25701 .60402 Mdot
.74803 .49102 Mdot
.35305 .60502 Mdot
.06947 .71642 Mdot
.31489 .24542 Mdot
.53754 .22265 Mdot
.02055 .48301 Mdot
.36012 .33957 Mdot
.84181 .48169 Mdot
.2573 .41549 Mdot
.55988 .30258 Mdot
.27179 .71191 Mdot
.88005 .60826 Mdot
.2507 .37066 Mdot
.50729 .25658 Mdot
.81487 .30758 Mdot
.14527 .33039 Mdot
.59422 .44895 Mdot
.66484 .07063 Mdot
.69386 .02901 Mdot
.76836 .0745 Mdot
.94954 .18118 Mdot
.47807 .52854 Mdot
.85359 .37552 Mdot
.11541 .26182 Mdot
.63831 .5229 Mdot
.01206 .37374 Mdot
.30149 .28943 Mdot
.53462 .23313 Mdot
.00816 .47355 Mdot
.42458 .41642 Mdot
.33262 .90804 Mdot
.27335 .94073 Mdot
.11196 .83861 Mdot
.2299 .11794 Mdot
.24263 .01273 Mdot
.14247 .89984 Mdot
.17298 .03051 Mdot
.21734 .04436 Mdot
.17099 .95365 Mdot
.14505 .97406 Mdot
.23861 .09356 Mdot
.22094 .98233 Mdot
.10771 .88677 Mdot
.29678 .18907 Mdot
.41954 .12277 Mdot
.0028 .58325 Mdot
.56647 .56367 Mdot
.58199 .01553 Mdot
.14643 .56443 Mdot
.82447 .67804 Mdot
.49685 .67238 Mdot
.14715 .6503 Mdot
.90801 .76086 Mdot
.27755 .36954 Mdot
.54964 .2721 Mdot
.16364 .614 Mdot
.82358 .65994 Mdot
.48065 .65707 Mdot
.00261 .52196 Mdot
.50629 .50368 Mdot
.05397 .54768 Mdot
.23107 .17711 Mdot
.30196 .07089 Mdot
.31763 .01566 Mdot
.31828 .00065 Mdot
.3058 .98752 Mdot
0 .45 Mdot
.45 .45 Mdot
.55573 .10573 Mdot
.04364 .48791 Mdot
.2299 .18626 Mdot
.31095 .08105 Mdot
.35861 .04766 Mdot
.54167 .18307 Mdot
.01313 .47146 Mdot
.39277 .37964 Mdot
.07733 .68455 Mdot
.24164 .16431 Mdot
.2934 .05176 Mdot
.27225 .97885 Mdot
.14789 .87564 Mdot
.13096 .98307 Mdot
.2973 .16634 Mdot
.39839 .10109 Mdot
.83559 .43719 Mdot
.22962 .39404 Mdot
.5187 .28907 Mdot
.93834 .41965 Mdot
.77887 .84053 Mdot
.7152 .93633 Mdot
.7391 .0239 Mdot
.87447 .13537 Mdot
.80022 .92575 Mdot
.78505 .98482 Mdot
.85705 .07201 Mdot
.80048 .94342 Mdot
.80242 .00194 Mdot
.85856 .05614 Mdot
.7795 .92093 Mdot
.79544 .01594 Mdot
.88037 .08493 Mdot
.72606 .84569 Mdot
.67327 .9472 Mdot
.60756 .93429 Mdot
.23873 .63118 Mdot
.75861 .51988 Mdot
.39095 .63233 Mdot
.31827 .92732 Mdot
.23245 .91418 Mdot
.03931 .80686 Mdot
.5738 .53449 Mdot
.60658 .03278 Mdot
.33093 .72435 Mdot
.08215 .75122 Mdot
.28351 .20136 Mdot
.3954 .11189 Mdot
.82669 .43129 Mdot
.2452 .41851 Mdot
.55014 .30493 Mdot
.20025 .65011 Mdot
.79027 .59002 Mdot
.45891 .66864 Mdot
.84308 .38417 Mdot
.15619 .31311 Mdot
.54322 .38703 Mdot
.22907 .68585 Mdot
.81045 .58139 Mdot
.42652 .61607 Mdot
.5463 .11978 Mdot
.98565 .43935 Mdot
.5253 .53964 Mdot
.24128 .71598 Mdot
.84484 .60357 Mdot
.37046 .52562 Mdot
.08616 .7157 Mdot
.22775 .14159 Mdot
.26612 .03837 Mdot
.19612 .93 Mdot
.07527 .87915 Mdot
.44696 .37169 Mdot
.45419 .00723 Mdot
.14515 .69096 Mdot
.95517 .81002 Mdot
.07487 .1197 Mdot
.68961 .61475 Mdot
.33921 .6496 Mdot
.0452 .70599 Mdot
.43904 .39384 Mdot
.41648 .97744 Mdot
.83574 .41926 Mdot
.21129 .37554 Mdot
.50554 .29425 Mdot
.83858 .33303 Mdot
.11757 .27899 Mdot
.64641 .52884 Mdot
.06159 .41517 Mdot
.05632 .99474 Mdot
.66497 .60865 Mdot
.23245 .56748 Mdot
.69261 .46016 Mdot
.19522 .50261 Mdot
.64908 .45386 Mdot
.00046 .35138 Mdot
.3486 .34814 Mdot
.78972 .44112 Mdot
.31041 .52068 Mdot
.79629 .48588 Mdot
.34947 .55318 Mdot
.99915 .64968 Mdot
.65479 .65564 Mdot
.23103 .57624 Mdot
.70109 .47006 Mdot
.23304 .53195 Mdot
.65722 .42419 Mdot
.0115 .35428 Mdot
.28536 .27386 Mdot
.4725 .18715 Mdot
.46813 .99563 Mdot
.24218 .77405 Mdot
.90349 .66131 Mdot
.19974 .29626 Mdot
.437 .23726 Mdot
.24469 .80769 Mdot
.93892 .69423 Mdot
.05029 .11137 Mdot
.81546 .76516 Mdot
.60181 .78635 Mdot
.05319 .45138 Mdot
.13915 .08597 Mdot
.37049 .23134 Mdot
.79206 .42156 Mdot
.28903 .49698 Mdot
.70527 .41624 Mdot
.19188 .48661 Mdot
.63787 .44598 Mdot
.93267 .2948 Mdot
.68486 .75219 Mdot
.45911 .77425 Mdot
.95026 .49115 Mdot
.78395 .8337 Mdot
.70648 .92252 Mdot
.70168 .99521 Mdot
.76003 .05835 Mdot
.93026 .17022 Mdot
.57321 .64296 Mdot
.71076 .13755 Mdot
.92871 .21795 Mdot
.62917 .70045 Mdot
.13774 .50858 Mdot
.79806 .66032 Mdot
.52205 .72399 Mdot
.39992 .87787 Mdot
.6225 .22258 Mdot
.62036 .99786 Mdot
.38267 .76232 Mdot
.39609 .01341 Mdot
.73269 .33661 Mdot
.17681 .44411 Mdot
.62258 .44578 Mdot
.84409 .2215 Mdot
.9906 .14652 Mdot
.20286 .21225 Mdot
.34954 .14669 Mdot
.59305 .2435 Mdot
.4514 .85835 Mdot
.97481 .52341 Mdot
.67383 .69902 Mdot
.36175 .68792 Mdot
.19912 .83737 Mdot
.97885 .77973 Mdot
.90619 .92733 Mdot
.45284 .54666 Mdot
.67422 .22137 Mdot
.88574 .21152 Mdot
.83013 .9444 Mdot
.75036 .92022 Mdot
.78466 .0343 Mdot
.90673 .12207 Mdot
.64494 .7382 Mdot
.26318 .61824 Mdot
.77116 .50798 Mdot
.38339 .61223 Mdot
.25045 .86706 Mdot
.00343 .75298 Mdot
.73243 .729 Mdot
.56873 .8363 Mdot
.87132 .30259 Mdot
.97968 .10836 Mdot
.22988 .25019 Mdot
.37488 .145 Mdot
.7315 .35662 Mdot
.19469 .46319 Mdot
.61039 .4157 Mdot
.73837 .12798 Mdot
.97746 .23909 Mdot
.37382 .39636 Mdot
.97657 .60275 Mdot
.74276 .76619 Mdot
.62188 .87912 Mdot
.27315 .65128 Mdot
.82212 .54896 Mdot
.37274 .55062 Mdot
.12446 .75172 Mdot
.09108 .96662 Mdot
.45438 .3633 Mdot
.50268 .0483 Mdot
.5697 .06702 Mdot
.10917 .53947 Mdot
.94299 .83382 Mdot
.16742 .22443 Mdot
.42441 .25699 Mdot
.17191 .74751 Mdot
.93676 .76485 Mdot
.13273 .19597 Mdot
.5036 .37087 Mdot
.89969 .39609 Mdot
.95236 .05266 Mdot
.33357 .38121 Mdot
.75076 .4172 Mdot
.28203 .53127 Mdot
.72169 .43967 Mdot
.25787 .53618 Mdot
.68133 .42346 Mdot
.11677 .43544 Mdot
.8062 .68943 Mdot
.54097 .73478 Mdot
.55941 .01844 Mdot
.98415 .42474 Mdot
.51965 .5355 Mdot
.19236 .67271 Mdot
.82325 .63089 Mdot
.4523 .62904 Mdot
.75239 .30009 Mdot
.16644 .41405 Mdot
.61646 .45002 Mdot
.81086 .1944 Mdot
.03888 .22802 Mdot
.99744 .95856 Mdot
.9739 .97646 Mdot
.13223 .15832 Mdot
.46783 .3356 Mdot
.57977 .11194 Mdot
.22705 .64728 Mdot
.77181 .54475 Mdot
.4202 .6484 Mdot
.53314 .11293 Mdot
.87635 .34321 Mdot
.00064 .1243 Mdot
.12044 .1198 Mdot
.47535 .35491 Mdot
.65839 .18304 Mdot
.77599 .1176 Mdot
.99285 .21686 Mdot
.25972 .26686 Mdot
.41457 .15485 Mdot
.99974 .58517 Mdot
.58672 .58698 Mdot
.75113 .16441 Mdot
.02959 .27847 Mdot
.10209 .0725 Mdot
.50796 .40587 Mdot
.96953 .46157 Mdot
.64307 .67354 Mdot
.18857 .5455 Mdot
.70195 .51338 Mdot
.27901 .57706 Mdot
.76045 .48144 Mdot
.35357 .59312 Mdot
.06028 .70672 Mdot
.35503 .29474 Mdot
.76958 .41455 Mdot
.2898 .52022 Mdot
.73058 .44078 Mdot
.27716 .54658 Mdot
.72585 .44868 Mdot
.27581 .54996 Mdot
.7263 .45049 Mdot
.27854 .55225 Mdot
.73458 .45603 Mdot
.29946 .56489 Mdot
.80364 .50418 Mdot
.35922 .55559 Mdot
.05294 .69372 Mdot
.38286 .32991 Mdot
.96482 .58197 Mdot
.79102 .8262 Mdot
.6945 .90348 Mdot
.64502 .95052 Mdot
.47591 .83089 Mdot
.13883 .66292 Mdot
.94858 .80975 Mdot
.11206 .16349 Mdot
.55434 .44228 Mdot
.36968 .81534 Mdot
.37138 .0017 Mdot
.56761 .19623 Mdot
.22299 .65538 Mdot
.78029 .5573 Mdot
.43156 .65127 Mdot
.61838 .18682 Mdot
.55956 .94117 Mdot
.90795 .3484 Mdot
.86536 .9574 Mdot
.6568 .79144 Mdot
.37668 .71989 Mdot
.31717 .94049 Mdot
.24134 .92417 Mdot
.05307 .81173 Mdot
.50014 .44707 Mdot
.94822 .44808 Mdot
.75238 .80416 Mdot
.6705 .91812 Mdot
.56658 .89608 Mdot
.91525 .34867 Mdot
.82954 .9143 Mdot
.72166 .89211 Mdot
.71024 .98858 Mdot
.77831 .06808 Mdot
.94289 .16458 Mdot
.4987 .55581 Mdot
.04545 .54674 Mdot
.27836 .23291 Mdot
.41481 .13646 Mdot
.98302 .56821 Mdot
.66985 .68683 Mdot
.33246 .66261 Mdot
.02718 .69473 Mdot
.53254 .50536 Mdot
.26413 .73159 Mdot
.88602 .62189 Mdot
.23929 .35327 Mdot
.481 .24171 Mdot
.59006 .10905 Mdot
.29641 .70635 Mdot
.93571 .6393 Mdot
.01289 .07718 Mdot
.99992 .98703 Mdot
.9875 .98758 Mdot
.0625 .07501 Mdot
.71115 .64865 Mdot
.44086 .72971 Mdot
.76601 .32516 Mdot
.19962 .43361 Mdot
.5745 .37487 Mdot
.452 .87751 Mdot
.9986 .5466 Mdot
.555 .5564 Mdot
.48877 .93377 Mdot
.34401 .85524 Mdot
.27394 .92993 Mdot
.10235 .82842 Mdot
.26268 .16032 Mdot
.31244 .04977 Mdot
.33279 .02034 Mdot
.3864 .05361 Mdot
.71062 .32422 Mdot
.11501 .40439 Mdot
.78259 .66758 Mdot
.54098 .75839 Mdot
.58309 .0421 Mdot
.18073 .59764 Mdot
.76816 .58743 Mdot
.46243 .69427 Mdot
.89617 .43373 Mdot
.00626 .1101 Mdot
.07253 .06626 Mdot
.64849 .57597 Mdot
.11953 .47104 Mdot
.83032 .71078 Mdot
.51631 .68599 Mdot
.31628 .79997 Mdot
.09737 .78109 Mdot
.2386 .14123 Mdot
.2686 .03 Mdot
.19212 .92352 Mdot
.07442 .88229 Mdot
.45457 .38016 Mdot
.52103 .06646 Mdot
.73429 .21326 Mdot
.05621 .32192 Mdot
.9928 .93659 Mdot
.97977 .98697 Mdot
.10796 .12819 Mdot
.53707 .42911 Mdot
.22331 .68624 Mdot
.8111 .58779 Mdot
.43188 .62079 Mdot
.59028 .1584 Mdot
.34729 .75701 Mdot
.19198 .84469 Mdot
.99579 .80381 Mdot
.82905 .83325 Mdot
.64178 .81273 Mdot
.32081 .67903 Mdot
.99421 .6734 Mdot
.70814 .71393 Mdot
.49783 .78969 Mdot
.27233 .7745 Mdot
.94369 .67136 Mdot
.00106 .05737 Mdot
.05103 .04997 Mdot
.74989 .69886 Mdot
.56283 .81294 Mdot
.80427 .24144 Mdot
.09565 .29138 Mdot
.75707 .66142 Mdot
.53148 .77441 Mdot
.5 .45 Mdot
.95 .45 Mdot
.74427 .79427 Mdot
.65191 .90763 Mdot
.46863 .81672 Mdot
.06715 .59852 Mdot
.20945 .1423 Mdot
.27363 .06418 Mdot
.23599 .96235 Mdot
.08857 .85259 Mdot
.35267 .26409 Mdot
.72654 .37387 Mdot
.20242 .47588 Mdot
.61363 .41121 Mdot
.75438 .14075 Mdot
.0088 .25441 Mdot
.20166 .19286 Mdot
.33143 .12978 Mdot
.48979 .15836 Mdot
.57676 .08697 Mdot
.1805 .60373 Mdot
.7747 .5942 Mdot
.4696 .6949 Mdot
.95299 .48339 Mdot
.7607 .80772 Mdot
.67999 .91928 Mdot
.60728 .92729 Mdot
.22995 .62267 Mdot
.74736 .51741 Mdot
.37871 .63135 Mdot
.24084 .86213 Mdot
.99073 .74989 Mdot
.80545 .81471 Mdot
.66732 .86187 Mdot
.49627 .82896 Mdot
.29914 .80287 Mdot
.04059 .74146 Mdot
.50096 .46037 Mdot
.96805 .46709 Mdot
.65727 .68921 Mdot
.27674 .61948 Mdot
.79782 .52108 Mdot
.38307 .58525 Mdot
.22148 .83841 Mdot
.96365 .74216 Mdot
.95808 .99443 Mdot
.24258 .2845 Mdot
.41421 .17163 Mdot
.01395 .59974 Mdot
.51616 .50221 Mdot
.13131 .61515 Mdot
.92808 .79677 Mdot
.21134 .28326 Mdot
.41322 .20189 Mdot
.03731 .62409 Mdot
.4026 .36528 Mdot
.12783 .72523 Mdot
.05141 .92358 Mdot
.62135 .56995 Mdot
.96083 .33947 Mdot
.57175 .61093 Mdot
.66811 .09636 Mdot
.7343 .06619 Mdot
.90916 .17486 Mdot
.68593 .77677 Mdot
.48771 .80178 Mdot
.20355 .71584 Mdot
.85242 .64887 Mdot
.39255 .54013 Mdot
.23637 .84382 Mdot
.97019 .73382 Mdot
.91147 .94128 Mdot
.44101 .52954 Mdot
.56701 .126 Mdot
.14837 .58136 Mdot
.83516 .68679 Mdot
.48031 .64515 Mdot
.98798 .50767 Mdot
.57969 .59171 Mdot
.70622 .12653 Mdot
.90494 .19872 Mdot
.73021 .82527 Mdot
.66097 .93076 Mdot
.53601 .87504 Mdot
.66097 .12496 Mdot
.73023 .06926 Mdot
.90499 .17476 Mdot
.70601 .80102 Mdot
.57884 .87283 Mdot
.98128 .40243 Mdot
.51448 .5332 Mdot
.14888 .6344 Mdot
.88661 .73773 Mdot
.35262 .46602 Mdot
.92824 .57562 Mdot
.98931 .06107 Mdot
.12513 .13581 Mdot
.47253 .34741 Mdot
.62863 .1561 Mdot
.59027 .96164 Mdot
.15048 .5602 Mdot
.80741 .65693 Mdot
.50673 .69932 Mdot
.25314 .74641 Mdot
.88568 .63254 Mdot
.25139 .36571 Mdot
.50306 .25167 Mdot
.77611 .27305 Mdot
.14829 .37218 Mdot
.62626 .47797 Mdot
.89819 .27193 Mdot
.83518 .93699 Mdot
.73047 .89529 Mdot
.73147 .001 Mdot
.83901 .10754 Mdot
.8909 .05189 Mdot
.64808 .75718 Mdot
.29862 .65054 Mdot
.88664 .58802 Mdot
.20277 .31613 Mdot
.45351 .25074 Mdot
.38344 .92992 Mdot
.56842 .18499 Mdot
.21775 .64933 Mdot
.77579 .55804 Mdot
.43332 .65753 Mdot
.6376 .20428 Mdot
.68947 .05188 Mdot
.77583 .08636 Mdot
.96163 .1858 Mdot
.41341 .45178 Mdot
.28854 .87513 Mdot
.08209 .79355 Mdot
.32615 .24406 Mdot
.58125 .2551 Mdot
.3807 .79945 Mdot
.42106 .04036 Mdot
.93121 .51015 Mdot
.90806 .97685 Mdot
.49331 .58525 Mdot
.03174 .53843 Mdot
.34947 .31773 Mdot
.76368 .41422 Mdot
.28787 .52419 Mdot
.72937 .44149 Mdot
.27559 .54623 Mdot
.72211 .44652 Mdot
.26565 .54354 Mdot
.70049 .43484 Mdot
.19594 .49545 Mdot
.64096 .44501 Mdot
.94863 .30768 Mdot
.60966 .66103 Mdot
.97902 .36936 Mdot
.49481 .51579 Mdot
.97431 .4795 Mdot
.63284 .65853 Mdot
.11697 .48413 Mdot
.85405 .73708 Mdot
.47548 .62143 Mdot
.92596 .45047 Mdot
.87624 .95029 Mdot
.60813 .73189 Mdot
.04005 .43192 Mdot
.19456 .15451 Mdot
.3019 .10733 Mdot
.35385 .05195 Mdot
.52057 .16672 Mdot
.83086 .3103 Mdot
.11451 .28365 Mdot
.66396 .54945 Mdot
.16865 .50468 Mdot
.70165 .533 Mdot
.29771 .59607 Mdot
.82938 .53167 Mdot
.33941 .51002 Mdot
.90655 .56714 Mdot
.0909 .18435 Mdot
.67298 .58208 Mdot
.2412 .56822 Mdot
.69704 .45584 Mdot
.20585 .50881 Mdot
.64317 .43731 Mdot
.95285 .30969 Mdot
.58776 .63491 Mdot
.80634 .21858 Mdot
.06993 .26359 Mdot
.85963 .7897 Mdot
.5094 .64977 Mdot
.22492 .71552 Mdot
.84016 .61524 Mdot
.39545 .55529 Mdot
.27042 .87496 Mdot
.04045 .77003 Mdot
.53036 .48991 Mdot
.23153 .70117 Mdot
.82611 .59458 Mdot
.4098 .58369 Mdot
.39535 .98555 Mdot
.70003 .30468 Mdot
.06434 .36431 Mdot
.99045 .92611 Mdot
.98338 .99293 Mdot
.09245 .10907 Mdot
.59015 .4977 Mdot
.68569 .09554 Mdot
.80559 .1199 Mdot
.9723 .16671 Mdot
.33191 .35961 Mdot
.72175 .38984 Mdot
.20816 .48641 Mdot
.61877 .41061 Mdot
.78569 .16693 Mdot
.03881 .25311 Mdot
.02296 .98415 Mdot
.84696 .82401 Mdot
.58461 .73765 Mdot
.88703 .30242 Mdot
.91547 .02844 Mdot
.50817 .5927 Mdot
.15807 .64989 Mdot
.87462 .71655 Mdot
.38082 .50619 Mdot
.12855 .74774 Mdot
.07112 .94257 Mdot
.53224 .46112 Mdot
.21749 .68525 Mdot
.81182 .59433 Mdot
.43725 .62543 Mdot
.63472 .19747 Mdot
.66655 .03183 Mdot
.66279 .99624 Mdot
.61001 .94722 Mdot
.2674 .6574 Mdot
.81737 .54996 Mdot
.3831 .56573 Mdot
.20213 .81904 Mdot
.95709 .75496 Mdot
.00878 .05168 Mdot
.99905 .99027 Mdot
.99598 .99693 Mdot
.02107 .02509 Mdot
.89911 .87804 Mdot
.43701 .5379 Mdot
.54542 .10841 Mdot
.96748 .42206 Mdot
.61559 .64811 Mdot
.00353 .38794 Mdot
.36677 .36324 Mdot
.90254 .53577 Mdot
.0787 .17616 Mdot
.72616 .64746 Mdot
.47523 .74907 Mdot
.05161 .57638 Mdot
.27302 .22141 Mdot
.39198 .11896 Mdot
.8115 .41952 Mdot
.26297 .45147 Mdot
.60405 .34108 Mdot
.62267 .01863 Mdot
.41747 .7948 Mdot
.66009 .24262 Mdot
.8437 .18361 Mdot
.95383 .11013 Mdot
.38263 .4288 Mdot
.06232 .67969 Mdot
.31684 .25452 Mdot
.55409 .23725 Mdot
.16275 .60866 Mdot
.82058 .65784 Mdot
.48473 .66414 Mdot
.04212 .5574 Mdot
.30809 .26597 Mdot
.53337 .22528 Mdot
.99052 .45715 Mdot
.51401 .52349 Mdot
.13545 .62144 Mdot
.91913 .78369 Mdot
.24485 .32571 Mdot
.45706 .21221 Mdot
.37232 .91526 Mdot
.48663 .11431 Mdot
.50743 .0208 Mdot
.58023 .0728 Mdot
.19116 .61093 Mdot
.76328 .57212 Mdot
.4456 .68233 Mdot
.75453 .30893 Mdot
.17709 .42256 Mdot
.60043 .42334 Mdot
.68104 .08061 Mdot
.77277 .09173 Mdot
.96721 .19443 Mdot
.38958 .42238 Mdot
.09956 .70997 Mdot
.15721 .05765 Mdot
.28483 .12762 Mdot
.32493 .04011 Mdot
.37217 .04724 Mdot
.61777 .24559 Mdot
.61454 .99677 Mdot
.34566 .73112 Mdot
.15793 .81227 Mdot
.0374 .87948 Mdot
.65747 .62007 Mdot
.20857 .5511 Mdot
.68312 .47455 Mdot
.17483 .49171 Mdot
.67442 .49958 Mdot
.1648 .49038 Mdot
.69695 .53215 Mdot
.28187 .58492 Mdot
.77498 .49311 Mdot
.36848 .5935 Mdot
.14258 .7741 Mdot
.04688 .9043 Mdot
.62776 .58088 Mdot
.00993 .38217 Mdot
.32264 .31271 Mdot
.63529 .31265 Mdot
.78498 .14969 Mdot
.02195 .23697 Mdot
.10573 .08378 Mdot
.50264 .39691 Mdot
.91803 .41539 Mdot
.88218 .96416 Mdot
.59777 .71558 Mdot
.95548 .35772 Mdot
.62077 .66528 Mdot
.05259 .43183 Mdot
.12293 .07034 Mdot
.41579 .29286 Mdot
.14634 .73054 Mdot
.99088 .84454 Mdot
.89924 .90836 Mdot
.46675 .56751 Mdot
.80319 .33644 Mdot
.19207 .38888 Mdot
.53985 .34777 Mdot
.16365 .62381 Mdot
.83335 .6697 Mdot
.46781 .63446 Mdot
.8785 .41069 Mdot
.05945 .18095 Mdot
.83387 .77442 Mdot
.57124 .73737 Mdot
.79077 .21953 Mdot
.08803 .29727 Mdot
.80001 .71197 Mdot
.57152 .77152 Mdot
.82701 .25549 Mdot
.06869 .24168 Mdot
.84434 .77565 Mdot
.54403 .69969 Mdot
.54799 .00396 Mdot
.88281 .33482 Mdot
.96582 .08302 Mdot
.28624 .32041 Mdot
.52132 .23508 Mdot
.90517 .38385 Mdot
.91425 .00908 Mdot
.49496 .58071 Mdot
.0404 .54544 Mdot
.30608 .26568 Mdot
.52612 .22004 Mdot
.92814 .40203 Mdot
.81626 .88812 Mdot
.7233 .90704 Mdot
.72879 .00549 Mdot
.83848 .10969 Mdot
.89448 .05599 Mdot
.6362 .74172 Mdot
.21912 .58292 Mdot
.70886 .48974 Mdot
.27568 .56682 Mdot
.7429 .46721 Mdot
.32308 .58019 Mdot
.90458 .5815 Mdot
.1147 .21012 Mdot
.58963 .47492 Mdot
.65929 .06967 Mdot
.66695 .00766 Mdot
.64041 .97346 Mdot
.47413 .83372 Mdot
.12754 .65341 Mdot
.98071 .85318 Mdot
.96856 .98784 Mdot
.17506 .2065 Mdot
.38871 .21366 Mdot
.88532 .4966 Mdot
.11701 .23169 Mdot
.60146 .48445 Mdot
.74896 .14751 Mdot
.01053 .26157 Mdot
.19846 .18793 Mdot
.33022 .13176 Mdot
.48642 .15621 Mdot
.54772 .0613 Mdot
.93808 .39036 Mdot
.75104 .81297 Mdot
.67807 .92703 Mdot
0 .5 Mdot
.5 .5 Mdot
1 .5 Mdot
.5 .5 Mdot
0 .5 Mdot
.5 .5 Mdot
1 .5 Mdot
.5 .5 Mdot
0 .5 Mdot
.5 .5 Mdot
1 .5 Mdot
.5 .5 Mdot
0 .5 Mdot
.5 .5 Mdot
1 .5 Mdot
.50001 .50001 Mdot
.00011 .5001 Mdot
.49945 .49934 Mdot
.99495 .4955 Mdot
.52581 .53086 Mdot
.23656 .71075 Mdot
.83719 .60063 Mdot
.38886 .55167 Mdot
.22427 .83541 Mdot
.96012 .73585 Mdot
.97221 .01209 Mdot
.17784 .20563 Mdot
.38194 .2041 Mdot
.83337 .45143 Mdot
.24949 .41612 Mdot
.55153 .30204 Mdot
.20799 .65647 Mdot
.78895 .58096 Mdot
.4508 .66184 Mdot
.77367 .32287 Mdot
.19833 .42466 Mdot
.5671 .36877 Mdot
.39181 .82471 Mdot
.5162 .12438 Mdot
.75375 .23755 Mdot
.10508 .35133 Mdot
.77315 .66808 Mdot
.54355 .77039 Mdot
.61499 .07145 Mdot
.42317 .80817 Mdot
.71417 .291 Mdot
.09113 .37696 Mdot
.86448 .77335 Mdot
.47593 .61146 Mdot
.91955 .44361 Mdot
.90266 .98312 Mdot
.52546 .62279 Mdot
.32567 .80022 Mdot
.13539 .80971 Mdot
.10762 .97223 Mdot
.38263 .27501 Mdot
.90852 .52589 Mdot
.04007 .13154 Mdot
.89409 .85402 Mdot
.43597 .54188 Mdot
.54163 .10566 Mdot
.93543 .39379 Mdot
.76893 .8335 Mdot
.70864 .93972 Mdot
.72504 .0164 Mdot
.84185 .11681 Mdot
.89231 .05046 Mdot
.64037 .74806 Mdot
.2485 .60813 Mdot
.7426 .4941 Mdot
.34958 .60698 Mdot
.05353 .70395 Mdot
.3898 .33627 Mdot
.01486 .62506 Mdot
.53604 .52118 Mdot
.30737 .77133 Mdot
.03622 .72885 Mdot
.51373 .47752 Mdot
.08725 .57352 Mdot
.08017 .99292 Mdot
.53535 .45519 Mdot
.236 .70064 Mdot
.82686 .59087 Mdot
.4044 .57754 Mdot
.35225 .94785 Mdot
.40816 .0559 Mdot
.85624 .44808 Mdot
.17928 .32305 Mdot
.49642 .31714 Mdot
.78851 .29209 Mdot
.16223 .37372 Mdot
.58703 .4248 Mdot
.59114 .00411 Mdot
.19895 .60781 Mdot
.74949 .55054 Mdot
.41411 .66462 Mdot
.50627 .09216 Mdot
.64227 .13601 Mdot
.64676 .00448 Mdot
.53903 .89227 Mdot
.70181 .16278 Mdot
.928 .22619 Mdot
.64116 .71316 Mdot
.21792 .57676 Mdot
.70315 .48523 Mdot
.25453 .55138 Mdot
.69227 .43775 Mdot
.17162 .47934 Mdot
.66928 .49766 Mdot
.14079 .47151 Mdot
.75038 .6096 Mdot
.47406 .72368 Mdot
.01693 .54288 Mdot
.4415 .42456 Mdot
.46571 .02421 Mdot
.25174 .78603 Mdot
.92375 .67201 Mdot
.10931 .18555 Mdot
.58846 .47916 Mdot
.65547 .06701 Mdot
.64577 .9903 Mdot
.51965 .87388 Mdot
.5307 .01106 Mdot
.75535 .22465 Mdot
.09346 .3381 Mdot
.81432 .72086 Mdot
.55952 .74521 Mdot
.71175 .15223 Mdot
.94604 .23429 Mdot
.55084 .60479 Mdot
.50548 .95464 Mdot
.49845 .99298 Mdot
.4806 .98215 Mdot
.32728 .84668 Mdot
.18863 .86135 Mdot
.0177 .82907 Mdot
.72311 .70541 Mdot
.52675 .80364 Mdot
.51674 .98999 Mdot
.62369 .10695 Mdot
.51193 .88824 Mdot
.48361 .97168 Mdot
.34074 .85714 Mdot
.26003 .91928 Mdot
.06744 .80741 Mdot
.41678 .34934 Mdot
.20977 .79299 Mdot
.92408 .71431 Mdot
.14992 .22584 Mdot
.47478 .32486 Mdot
.62383 .14905 Mdot
.55487 .93103 Mdot
.86242 .30755 Mdot
.0175 .15509 Mdot
.05032 .03282 Mdot
.73673 .6864 Mdot
.53334 .79662 Mdot
.56164 .0283 Mdot
.01075 .4491 Mdot
.38468 .37394 Mdot
.02021 .63553 Mdot
.51463 .49441 Mdot
.11128 .59665 Mdot
.9909 .87962 Mdot
.93416 .94326 Mdot
.32525 .39109 Mdot
.72449 .39924 Mdot
.22354 .49905 Mdot
.62386 .40033 Mdot
.80631 .18245 Mdot
.03383 .22752 Mdot
.02629 .99246 Mdot
.83554 .80925 Mdot
.6018 .76626 Mdot
.03304 .43124 Mdot
.23468 .20165 Mdot
.3274 .09272 Mdot
.43519 .1078 Mdot
.10178 .66659 Mdot
.10349 .00171 Mdot
.43077 .32728 Mdot
.28854 .85778 Mdot
.06475 .77621 Mdot
.40011 .33536 Mdot
.08125 .68114 Mdot
.21801 .13676 Mdot
.26311 .0451 Mdot
.19791 .9348 Mdot
.07776 .87985 Mdot
.43469 .35692 Mdot
.34713 .91245 Mdot
.34662 .99949 Mdot
.43108 .08446 Mdot
.04806 .61697 Mdot
.33372 .28567 Mdot
.65594 .32221 Mdot
.90326 .24732 Mdot
.78682 .88356 Mdot
.75478 .96796 Mdot
.83633 .08154 Mdot
.87205 .03573 Mdot
.71001 .83796 Mdot
.62706 .91705 Mdot
.34204 .71498 Mdot
.12411 .78207 Mdot
.12282 .99872 Mdot
.34461 .22178 Mdot
.6434 .29879 Mdot
.81558 .17218 Mdot
.0086 .19303 Mdot
.14144 .13284 Mdot
.40946 .26802 Mdot
.07737 .6679 Mdot
.22477 .1474 Mdot
.27206 .04729 Mdot
.21594 .94388 Mdot
.07115 .85521 Mdot
.44472 .37357 Mdot
.43906 .99434 Mdot
.01716 .5781 Mdot
.47537 .45821 Mdot
.7619 .28652 Mdot
.15939 .3975 Mdot
.61852 .45912 Mdot
.83269 .21417 Mdot
.01393 .18124 Mdot
.09779 .08386 Mdot
.53939 .4416 Mdot
.25388 .71449 Mdot
.85462 .60074 Mdot
.33728 .48266 Mdot
.86922 .53194 Mdot
.21701 .34779 Mdot
.47456 .25755 Mdot
.55481 .08024 Mdot
.01116 .45635 Mdot
.38946 .37831 Mdot
.05474 .66527 Mdot
.34435 .28961 Mdot
.70999 .36564 Mdot
.1547 .44471 Mdot
.67916 .52446 Mdot
.20916 .53 Mdot
.66155 .4524 Mdot
.06039 .39883 Mdot
.04659 .9862 Mdot
.71132 .66474 Mdot
.4574 .74608 Mdot
.90886 .45145 Mdot
.96401 .05515 Mdot
.26895 .30494 Mdot
.4677 .19875 Mdot
.44191 .97421 Mdot
.01848 .57657 Mdot
.46597 .44749 Mdot
.67708 .21111 Mdot
.88739 .2103 Mdot
.82184 .93445 Mdot
.7588 .93696 Mdot
.80815 .04935 Mdot
.89805 .0899 Mdot
.65379 .75575 Mdot
.32621 .67241 Mdot
.00983 .68362 Mdot
.62469 .61486 Mdot
.02577 .40109 Mdot
.24724 .22146 Mdot
.35478 .10755 Mdot
.5811 .22631 Mdot
.35084 .76974 Mdot
.22275 .87191 Mdot
.99686 .77411 Mdot
.79294 .79608 Mdot
.6628 .86986 Mdot
.48367 .82087 Mdot
.19042 .70675 Mdot
.86024 .66982 Mdot
.3874 .52716 Mdot
.19048 .80308 Mdot
.95648 .766 Mdot
.02335 .06687 Mdot
.92737 .90403 Mdot
.32233 .39496 Mdot
.71629 .39396 Mdot
.19942 .48314 Mdot
.62426 .42484 Mdot
.83319 .20894 Mdot
.00744 .17425 Mdot
.12962 .12217 Mdot
.4415 .31188 Mdot
.35303 .91153 Mdot
.3759 .02286 Mdot
.61543 .23954 Mdot
.59399 .97856 Mdot
.19292 .59893 Mdot
.74865 .55573 Mdot
.41842 .66977 Mdot
.54183 .12341 Mdot
.95467 .41284 Mdot
.68057 .7259 Mdot
.4162 .73563 Mdot
.59197 .17577 Mdot
.37627 .7843 Mdot
.3791 .00283 Mdot
.61468 .23559 Mdot
.58536 .97067 Mdot
.12528 .53993 Mdot
.87603 .75075 Mdot
.40943 .53339 Mdot
.34247 .93304 Mdot
.34423 .00176 Mdot
.42153 .0773 Mdot
.9715 .54998 Mdot
.7199 .74839 Mdot
.5625 .84261 Mdot
.83147 .26897 Mdot
.07172 .24025 Mdot
.82676 .75504 Mdot
.56881 .74205 Mdot
.77765 .20884 Mdot
.0838 .30616 Mdot
.83006 .74626 Mdot
.55239 .72232 Mdot
.63483 .08245 Mdot
.5522 .91737 Mdot
.82845 .27625 Mdot
.08616 .2577 Mdot
.76979 .68364 Mdot
.55891 .78912 Mdot
.75104 .19213 Mdot
.05722 .30619 Mdot
.97142 .9142 Mdot
.0846 .11318 Mdot
.63307 .54847 Mdot
.00826 .37518 Mdot
.32567 .31741 Mdot
.65255 .32689 Mdot
.89115 .23859 Mdot
.83367 .94252 Mdot
.73983 .90616 Mdot
.75781 .01798 Mdot
.88853 .13072 Mdot
.7373 .84877 Mdot
.6966 .9593 Mdot
.70787 .01127 Mdot
.79441 .08654 Mdot
.95195 .15754 Mdot
.44077 .48883 Mdot
.52453 .08375 Mdot
.7793 .25477 Mdot
.12933 .35003 Mdot
.67045 .54112 Mdot
.18935 .5189 Mdot
.67409 .48474 Mdot
.14856 .47448 Mdot
.72767 .57911 Mdot
.40992 .68225 Mdot
.49471 .08479 Mdot
.54248 .04777 Mdot
.88409 .34161 Mdot
.96722 .08313 Mdot
.2782 .31098 Mdot
.49253 .21434 Mdot
.65463 .1621 Mdot
.73672 .08208 Mdot
.92901 .19229 Mdot
.60194 .67293 Mdot
.94063 .33869 Mdot
.68536 .74473 Mdot
.45355 .76819 Mdot
.90118 .44763 Mdot
.99694 .09576 Mdot
.11411 .11717 Mdot
.49921 .3851 Mdot
.87876 .37955 Mdot
.02726 .1485 Mdot
.98588 .95862 Mdot
.04323 .05735 Mdot
.8017 .75847 Mdot
.61599 .81429 Mdot
.17225 .55626 Mdot
.74474 .57249 Mdot
.4307 .68596 Mdot
.64671 .21602 Mdot
.75033 .10362 Mdot
.96804 .2177 Mdot
.40798 .43995 Mdot
.23909 .83111 Mdot
.95873 .71964 Mdot
.96402 .00529 Mdot
.21901 .25499 Mdot
.38096 .16195 Mdot
.78521 .40425 Mdot
.27639 .49118 Mdot
.66876 .39237 Mdot
.0332 .36444 Mdot
.16694 .13375 Mdot
.3349 .16796 Mdot
.54356 .20866 Mdot
.05332 .50976 Mdot
.19679 .14347 Mdot
.5 .5 Mdot
1 .5 Mdot
.5 .5 Mdot
0 .5 Mdot
.5 .5 Mdot
1 .5 Mdot
.5 .5 Mdot
0 .5 Mdot
.5 .5 Mdot
1 .5 Mdot
.5 .5 Mdot
0 .5 Mdot
.5 .5 Mdot
1 .5 Mdot
.50001 .50001 Mdot
.00011 .5001 Mdot
.49945 .49934 Mdot
.99495 .4955 Mdot
.52581 .53086 Mdot
.23656 .71075 Mdot
.83719 .60063 Mdot
.38886 .55167 Mdot
.22427 .83541 Mdot
.96012 .73585 Mdot
.97221 .01209 Mdot
.17784 .20563 Mdot
.38194 .2041 Mdot
.83337 .45143 Mdot
.24949 .41612 Mdot
.55153 .30204 Mdot
.20799 .65647 Mdot
.78895 .58096 Mdot
.4508 .66184 Mdot
.77367 .32287 Mdot
.19833 .42466 Mdot
.5671 .36877 Mdot
.39181 .82471 Mdot
.5162 .12438 Mdot
.75375 .23755 Mdot
.10508 .35133 Mdot
.77315 .66808 Mdot
.54355 .77039 Mdot
.61499 .07145 Mdot
.42317 .80817 Mdot
.71417 .291 Mdot
.09113 .37696 Mdot
.86448 .77335 Mdot
.47593 .61146 Mdot
.91955 .44361 Mdot
.90266 .98312 Mdot
.52546 .62279 Mdot
.32567 .80022 Mdot
.13539 .80971 Mdot
.10762 .97223 Mdot
.38263 .27501 Mdot
.90852 .52589 Mdot
.04007 .13154 Mdot
.89409 .85402 Mdot
.43597 .54188 Mdot
.54163 .10566 Mdot
.93543 .39379 Mdot
.76893 .8335 Mdot
.70864 .93972 Mdot
.72504 .0164 Mdot
.84185 .11681 Mdot
.89231 .05046 Mdot
.64037 .74806 Mdot
.2485 .60813 Mdot
.7426 .4941 Mdot
.34958 .60698 Mdot
.05353 .70395 Mdot
.3898 .33627 Mdot
.01486 .62506 Mdot
.53604 .52118 Mdot
.30737 .77133 Mdot
.03622 .72885 Mdot
.51373 .47752 Mdot
.08725 .57352 Mdot
.08017 .99292 Mdot
.53535 .45519 Mdot
.236 .70064 Mdot
.82686 .59087 Mdot
.4044 .57754 Mdot
.35225 .94785 Mdot
.40816 .0559 Mdot
.85624 .44808 Mdot
.17928 .32305 Mdot
.49642 .31714 Mdot
.78851 .29209 Mdot
.16223 .37372 Mdot
.58703 .4248 Mdot
.59114 .00411 Mdot
.19895 .60781 Mdot
.74949 .55054 Mdot
.41411 .66462 Mdot
.50627 .09216 Mdot
.64227 .13601 Mdot
.64676 .00448 Mdot
.53903 .89227 Mdot
.70181 .16278 Mdot
.928 .22619 Mdot
.64116 .71316 Mdot
.21792 .57676 Mdot
.70315 .48523 Mdot
.25453 .55138 Mdot
.69227 .43775 Mdot
.17162 .47934 Mdot
.66928 .49766 Mdot
.14079 .47151 Mdot
.75038 .6096 Mdot
.47406 .72368 Mdot
.01693 .54288 Mdot
.4415 .42456 Mdot
.46571 .02421 Mdot
.25174 .78603 Mdot
.92375 .67201 Mdot
.10931 .18555 Mdot
.58846 .47916 Mdot
.65547 .06701 Mdot
.64577 .9903 Mdot
.51965 .87388 Mdot
.5307 .01106 Mdot
.75535 .22465 Mdot
.09346 .3381 Mdot
.81432 .72086 Mdot
.55952 .74521 Mdot
.71175 .15223 Mdot
.94604 .23429 Mdot
.55084 .60479 Mdot
.50548 .95464 Mdot
.49845 .99298 Mdot
.4806 .98215 Mdot
.32728 .84668 Mdot
.18863 .86135 Mdot
.0177 .82907 Mdot
.72311 .70541 Mdot
.52675 .80364 Mdot
.51674 .98999 Mdot
.62369 .10695 Mdot
.51193 .88824 Mdot
.48361 .97168 Mdot
.34074 .85714 Mdot
.26003 .91928 Mdot
.06744 .80741 Mdot
.41678 .34934 Mdot
.20977 .79299 Mdot
.92408 .71431 Mdot
.14992 .22584 Mdot
.47478 .32486 Mdot
.62383 .14905 Mdot
.55487 .93103 Mdot
.86242 .30755 Mdot
.0175 .15509 Mdot
.05032 .03282 Mdot
.73673 .6864 Mdot
.53334 .79662 Mdot
.56164 .0283 Mdot
.01075 .4491 Mdot
.38468 .37394 Mdot
.02021 .63553 Mdot
.51463 .49441 Mdot
.11128 .59665 Mdot
.9909 .87962 Mdot
.93416 .94326 Mdot
.32525 .39109 Mdot
.72449 .39924 Mdot
.22354 .49905 Mdot
.62386 .40033 Mdot
.80631 .18245 Mdot
.03383 .22752 Mdot
.02629 .99246 Mdot
.83554 .80925 Mdot
.6018 .76626 Mdot
.03304 .43124 Mdot
.23468 .20165 Mdot
.3274 .09272 Mdot
.43519 .1078 Mdot
.10178 .66659 Mdot
.10349 .00171 Mdot
.43077 .32728 Mdot
.28854 .85778 Mdot
.06475 .77621 Mdot
.40011 .33536 Mdot
.08125 .68114 Mdot
.21801 .13676 Mdot
.26311 .0451 Mdot
.19791 .9348 Mdot
.07776 .87985 Mdot
.43469 .35692 Mdot
.34713 .91245 Mdot
.34662 .99949 Mdot
.43108 .08446 Mdot
.04806 .61697 Mdot
.33372 .28567 Mdot
.65594 .32221 Mdot
.90326 .24732 Mdot
.78682 .88356 Mdot
.75478 .96796 Mdot
.83633 .08154 Mdot
.87205 .03573 Mdot
.71001 .83796 Mdot
.62706 .91705 Mdot
.34204 .71498 Mdot
.12411 .78207 Mdot
.12282 .99872 Mdot
.34461 .22178 Mdot
.6434 .29879 Mdot
.81558 .17218 Mdot
.0086 .19303 Mdot
.14144 .13284 Mdot
.40946 .26802 Mdot
.07737 .6679 Mdot
.22477 .1474 Mdot
.27206 .04729 Mdot
.21594 .94388 Mdot
.07115 .85521 Mdot
.44472 .37357 Mdot
.43906 .99434 Mdot
.01716 .5781 Mdot
.47537 .45821 Mdot
.7619 .28652 Mdot
.15939 .3975 Mdot
.61852 .45912 Mdot
.83269 .21417 Mdot
.01393 .18124 Mdot
.09779 .08386 Mdot
.53939 .4416 Mdot
.25388 .71449 Mdot
.85462 .60074 Mdot
.33728 .48266 Mdot
.86922 .53194 Mdot
.21701 .34779 Mdot
.47456 .25755 Mdot
.55481 .08024 Mdot
.01116 .45635 Mdot
.38946 .37831 Mdot
.05474 .66527 Mdot
.34435 .28961 Mdot
.70999 .36564 Mdot
.1547 .44471 Mdot
.67916 .52446 Mdot
.20916 .53 Mdot
.66155 .4524 Mdot
.06039 .39883 Mdot
.04659 .9862 Mdot
.71132 .66474 Mdot
.4574 .74608 Mdot
.90886 .45145 Mdot
.96401 .05515 Mdot
.26895 .30494 Mdot
.4677 .19875 Mdot
.44191 .97421 Mdot
.01848 .57657 Mdot
.46597 .44749 Mdot
.67708 .21111 Mdot
.88739 .2103 Mdot
.82184 .93445 Mdot
.7588 .93696 Mdot
.80815 .04935 Mdot
.89805 .0899 Mdot
.65379 .75575 Mdot
.32621 .67241 Mdot
.00983 .68362 Mdot
.62469 .61486 Mdot
.02577 .40109 Mdot
.24724 .22146 Mdot
.35478 .10755 Mdot
.5811 .22631 Mdot
.35084 .76974 Mdot
.22275 .87191 Mdot
.99686 .77411 Mdot
.79294 .79608 Mdot
.6628 .86986 Mdot
.48367 .82087 Mdot
.19042 .70675 Mdot
.86024 .66982 Mdot
.3874 .52716 Mdot
.19048 .80308 Mdot
.95648 .766 Mdot
.02335 .06687 Mdot
.92737 .90403 Mdot
.32233 .39496 Mdot
.71629 .39396 Mdot
.19942 .48314 Mdot
.62426 .42484 Mdot
.83319 .20894 Mdot
.00744 .17425 Mdot
.12962 .12217 Mdot
.4415 .31188 Mdot
.35303 .91153 Mdot
.3759 .02286 Mdot
.61543 .23954 Mdot
.59399 .97856 Mdot
.19292 .59893 Mdot
.74865 .55573 Mdot
.41842 .66977 Mdot
.54183 .12341 Mdot
.95467 .41284 Mdot
.68057 .7259 Mdot
.4162 .73563 Mdot
.59197 .17577 Mdot
.37627 .7843 Mdot
.3791 .00283 Mdot
.61468 .23559 Mdot
.58536 .97067 Mdot
.12528 .53993 Mdot
.87603 .75075 Mdot
.40943 .53339 Mdot
.34247 .93304 Mdot
.34423 .00176 Mdot
.42153 .0773 Mdot
.9715 .54998 Mdot
.7199 .74839 Mdot
.5625 .84261 Mdot
.83147 .26897 Mdot
.07172 .24025 Mdot
.82676 .75504 Mdot
.56881 .74205 Mdot
.77765 .20884 Mdot
.0838 .30616 Mdot
.83006 .74626 Mdot
.55239 .72232 Mdot
.63483 .08245 Mdot
.5522 .91737 Mdot
.82845 .27625 Mdot
.08616 .2577 Mdot
.76979 .68364 Mdot
.55891 .78912 Mdot
.75104 .19213 Mdot
.05722 .30619 Mdot
.97142 .9142 Mdot
.0846 .11318 Mdot
.63307 .54847 Mdot
.00826 .37518 Mdot
.32567 .31741 Mdot
.65255 .32689 Mdot
.89115 .23859 Mdot
.83367 .94252 Mdot
.73983 .90616 Mdot
.75781 .01798 Mdot
.88853 .13072 Mdot
.7373 .84877 Mdot
.6966 .9593 Mdot
.70787 .01127 Mdot
.79441 .08654 Mdot
.95195 .15754 Mdot
.44077 .48883 Mdot
.52453 .08375 Mdot
.7793 .25477 Mdot
.12933 .35003 Mdot
.67045 .54112 Mdot
.18935 .5189 Mdot
.67409 .48474 Mdot
.14856 .47448 Mdot
.72767 .57911 Mdot
.40992 .68225 Mdot
.49471 .08479 Mdot
.54248 .04777 Mdot
.88409 .34161 Mdot
.96722 .08313 Mdot
.2782 .31098 Mdot
.49253 .21434 Mdot
.65463 .1621 Mdot
.73672 .08208 Mdot
.92901 .19229 Mdot
.60194 .67293 Mdot
.94063 .33869 Mdot
.68536 .74473 Mdot
.45355 .76819 Mdot
.90118 .44763 Mdot
.99694 .09576 Mdot
.11411 .11717 Mdot
.49921 .3851 Mdot
.87876 .37955 Mdot
.02726 .1485 Mdot
.98588 .95862 Mdot
.04323 .05735 Mdot
.8017 .75847 Mdot
.61599 .81429 Mdot
.17225 .55626 Mdot
.74474 .57249 Mdot
.4307 .68596 Mdot
.64671 .21602 Mdot
.75033 .10362 Mdot
.96804 .2177 Mdot
.40798 .43995 Mdot
.23909 .83111 Mdot
.95873 .71964 Mdot
.96402 .00529 Mdot
.21901 .25499 Mdot
.38096 .16195 Mdot
.78521 .40425 Mdot
.27639 .49118 Mdot
.66876 .39237 Mdot
.0332 .36444 Mdot
.16694 .13375 Mdot
.3349 .16796 Mdot
.54356 .20866 Mdot
.05332 .50976 Mdot
.19679 .14347 Mdot
.28786 .09107 Mdot
0 .55 Mdot
.55 .55 Mdot
.44427 .89427 Mdot
.95636 .51209 Mdot
.7701 .81374 Mdot
.68905 .91895 Mdot
.64139 .95234 Mdot
.45833 .81693 Mdot
.98687 .52854 Mdot
.60723 .62036 Mdot
.92267 .31545 Mdot
.75836 .83569 Mdot
.7066 .94824 Mdot
.72775 .02115 Mdot
.85211 .12436 Mdot
.86904 .01693 Mdot
.7027 .83366 Mdot
.60161 .89891 Mdot
.16441 .56281 Mdot
.77038 .60597 Mdot
.48131 .71093 Mdot
.0617 .58039 Mdot
.22093 .15923 Mdot
.28461 .06368 Mdot
.26044 .97583 Mdot
.12458 .86414 Mdot
.20304 .07846 Mdot
.21556 .01253 Mdot
.13998 .92442 Mdot
.20607 .06608 Mdot
.20024 .99418 Mdot
.13434 .93409 Mdot
.23581 .10148 Mdot
.22763 .99181 Mdot
.11635 .88872 Mdot
.26127 .14492 Mdot
.2949 .03363 Mdot
.25848 .96358 Mdot
.10956 .85108 Mdot
.25289 .14333 Mdot
.28231 .02943 Mdot
.22054 .93823 Mdot
.06371 .84317 Mdot
.4727 .40898 Mdot
.69151 .21881 Mdot
.95003 .25852 Mdot
.5526 .60257 Mdot
.51671 .96411 Mdot
.59758 .08087 Mdot
.3195 .72192 Mdot
.03187 .71238 Mdot
.52262 .49074 Mdot
.17115 .64853 Mdot
.83955 .6684 Mdot
.45029 .61074 Mdot
.71869 .2684 Mdot
.07967 .36099 Mdot
.90595 .82627 Mdot
.35293 .44698 Mdot
.91079 .55787 Mdot
.06092 .15013 Mdot
.79495 .73403 Mdot
.59893 .80398 Mdot
.05166 .45273 Mdot
.1491 .09744 Mdot
.34895 .19986 Mdot
.64321 .29426 Mdot
.81004 .16683 Mdot
.01262 .20258 Mdot
.12697 .11435 Mdot
.44387 .3169 Mdot
.37593 .93206 Mdot
.52484 .14891 Mdot
.84693 .32209 Mdot
.0828 .23587 Mdot
.76487 .68207 Mdot
.55616 .79129 Mdot
.73246 .1763 Mdot
.01608 .28363 Mdot
.18731 .17122 Mdot
.32977 .14246 Mdot
.49516 .16539 Mdot
.62668 .13152 Mdot
.55422 .92755 Mdot
.85404 .29982 Mdot
.03825 .1842 Mdot
.95729 .91904 Mdot
.17174 .21446 Mdot
.4041 .23236 Mdot
.00504 .60094 Mdot
.5707 .56566 Mdot
.61516 .04445 Mdot
.39719 .78203 Mdot
.50858 .11139 Mdot
.68002 .17144 Mdot
.85958 .17956 Mdot
.89943 .03985 Mdot
.59734 .69791 Mdot
.93497 .33762 Mdot
.71526 .78029 Mdot
.5832 .86794 Mdot
.00738 .42418 Mdot
.37994 .37257 Mdot
.98957 .60963 Mdot
.67214 .68257 Mdot
.33811 .66597 Mdot
.0564 .71829 Mdot
.38812 .33172 Mdot
.9996 .61148 Mdot
.61387 .61427 Mdot
.95895 .34508 Mdot
.58822 .62928 Mdot
.80392 .2157 Mdot
.07037 .26645 Mdot
.86011 .78974 Mdot
.50778 .64767 Mdot
.20987 .70209 Mdot
.8331 .62324 Mdot
.42197 .58886 Mdot
.48623 .06426 Mdot
.45422 .96799 Mdot
.10617 .65195 Mdot
.06882 .96265 Mdot
.56459 .49577 Mdot
.50018 .93559 Mdot
.43706 .93688 Mdot
.94476 .5077 Mdot
.83143 .88667 Mdot
.68952 .85808 Mdot
.5822 .89269 Mdot
.02506 .44286 Mdot
.29323 .26817 Mdot
.48815 .19492 Mdot
.60021 .11206 Mdot
.36831 .76809 Mdot
.31619 .94789 Mdot
.24498 .92878 Mdot
.06023 .81525 Mdot
.46385 .40362 Mdot
.6166 .15275 Mdot
.51449 .89789 Mdot
.51368 .99919 Mdot
.6085 .09482 Mdot
.40532 .79682 Mdot
.5778 .17248 Mdot
.27345 .69565 Mdot
.8671 .59365 Mdot
.28664 .41954 Mdot
.62148 .33484 Mdot
.72648 .105 Mdot
.93341 .20693 Mdot
.593 .65959 Mdot
.86719 .27419 Mdot
.96685 .09966 Mdot
.29689 .33004 Mdot
.56085 .26396 Mdot
.24045 .6796 Mdot
.80797 .56752 Mdot
.41648 .60851 Mdot
.46684 .05036 Mdot
.28675 .81991 Mdot
.02215 .7354 Mdot
.60302 .58087 Mdot
.85573 .2527 Mdot
.98561 .12988 Mdot
.21609 .23048 Mdot
.35768 .14159 Mdot
.63059 .27291 Mdot
.71846 .08787 Mdot
.89861 .18015 Mdot
.74146 .84285 Mdot
.6968 .95533 Mdot
.70454 .00775 Mdot
.78123 .07669 Mdot
.95063 .16939 Mdot
.46012 .5095 Mdot
.6934 .23328 Mdot
.97107 .27766 Mdot
.45015 .47909 Mdot
.58599 .13583 Mdot
.29487 .70888 Mdot
.93365 .63878 Mdot
.02356 .08991 Mdot
.94917 .92561 Mdot
.22458 .27541 Mdot
.40008 .17551 Mdot
.92122 .52113 Mdot
.97159 .05037 Mdot
.21978 .24819 Mdot
.37391 .15413 Mdot
.7349 .36098 Mdot
.20495 .47006 Mdot
.60525 .4003 Mdot
.68978 .08453 Mdot
.80958 .1198 Mdot
.96631 .15673 Mdot
.35711 .39079 Mdot
.87671 .51961 Mdot
.17557 .29886 Mdot
.47996 .30439 Mdot
.64447 .1645 Mdot
.68697 .04251 Mdot
.75733 .07036 Mdot
.9406 .18326 Mdot
.5301 .5895 Mdot
.32903 .79893 Mdot
.14842 .81939 Mdot
.07305 .92464 Mdot
.50408 .43103 Mdot
.96371 .45962 Mdot
.67518 .71147 Mdot
.37987 .7047 Mdot
.32129 .94141 Mdot
.25851 .93722 Mdot
.08324 .82473 Mdot
.35147 .26823 Mdot
.7245 .37302 Mdot
.19733 .47283 Mdot
.61653 .41921 Mdot
.78051 .16398 Mdot
.03816 .25765 Mdot
.03123 .99307 Mdot
.80709 .77587 Mdot
.62612 .81903 Mdot
.23848 .61235 Mdot
.73966 .50119 Mdot
.35259 .61292 Mdot
.07496 .72237 Mdot
.29182 .21686 Mdot
.43284 .14102 Mdot
.11753 .68469 Mdot
.05228 .93476 Mdot
.6276 .57532 Mdot
.00346 .37586 Mdot
.35512 .35166 Mdot
.82699 .47187 Mdot
.28512 .45813 Mdot
.65617 .37105 Mdot
.95322 .29705 Mdot
.57304 .61982 Mdot
.68641 .11337 Mdot
.82613 .13972 Mdot
.95489 .12876 Mdot
.39522 .44034 Mdot
.15396 .75874 Mdot
.99537 .84141 Mdot
.86919 .87382 Mdot
.55902 .68984 Mdot
.65261 .09359 Mdot
.65815 .00553 Mdot
.59733 .93918 Mdot
.17611 .57878 Mdot
.75873 .58262 Mdot
.45376 .69503 Mdot
.82967 .37591 Mdot
.18297 .3533 Mdot
.51954 .33658 Mdot
.99258 .47303 Mdot
.51756 .52499 Mdot
.16523 .64767 Mdot
.85313 .6879 Mdot
.42928 .57615 Mdot
.52652 .09724 Mdot
.80857 .28204 Mdot
.13011 .32154 Mdot
.63899 .50888 Mdot
.00176 .36277 Mdot
.35223 .35047 Mdot
.81063 .4584 Mdot
.30325 .49262 Mdot
.74357 .44032 Mdot
.29707 .5535 Mdot
.78486 .48779 Mdot
.36012 .57525 Mdot
.07747 .71735 Mdot
.27371 .19624 Mdot
.36821 .0945 Mdot
.64205 .27384 Mdot
.78335 .14131 Mdot
.01437 .23102 Mdot
.14493 .13056 Mdot
.39549 .25057 Mdot
.96597 .57048 Mdot
.77283 .80686 Mdot
.68233 .9095 Mdot
.60673 .9244 Mdot
.22348 .61675 Mdot
.74158 .5181 Mdot
.3722 .63062 Mdot
.20131 .82911 Mdot
.96806 .76675 Mdot
.95687 .98881 Mdot
.2439 .28703 Mdot
.41767 .17376 Mdot
.04046 .62279 Mdot
.38309 .34264 Mdot
.97901 .59592 Mdot
.72141 .7424 Mdot
.55996 .83855 Mdot
.80841 .24844 Mdot
.09675 .28835 Mdot
.74878 .65203 Mdot
.51486 .76608 Mdot
.38482 .86996 Mdot
.51708 .13226 Mdot
.7687 .25162 Mdot
.12672 .35802 Mdot
.68848 .56175 Mdot
.28211 .59363 Mdot
.78425 .50214 Mdot
.37478 .59053 Mdot
.17644 .80166 Mdot
.98091 .80448 Mdot
.91867 .93776 Mdot
.40127 .48259 Mdot
.23621 .83494 Mdot
.96125 .72504 Mdot
.95487 .99362 Mdot
.26018 .30531 Mdot
.45369 .1935 Mdot
.32754 .87386 Mdot
.21695 .88941 Mdot
.01621 .79926 Mdot
.7022 .68599 Mdot
.45242 .75022 Mdot
.8745 .42208 Mdot
.08682 .21232 Mdot
.72109 .63427 Mdot
.45111 .73002 Mdot
.84427 .39316 Mdot
.16173 .31746 Mdot
.5321 .37037 Mdot
.12567 .59356 Mdot
.92817 .8025 Mdot
.21661 .28844 Mdot
.4154 .19879 Mdot
.04947 .63407 Mdot
.34282 .29335 Mdot
.70623 .36341 Mdot
.14186 .43563 Mdot
.71083 .56897 Mdot
.36031 .64948 Mdot
.15276 .79245 Mdot
.03269 .87993 Mdot
.68542 .65274 Mdot
.36179 .67636 Mdot
.18776 .82598 Mdot
.98376 .79599 Mdot
.89326 .90951 Mdot
.49517 .60191 Mdot
.0633 .56812 Mdot
.19994 .13664 Mdot
.27716 .07722 Mdot
.25647 .97931 Mdot
.12262 .86615 Mdot
.21285 .09023 Mdot
.21921 .00635 Mdot
.13226 .91306 Mdot
.22242 .09016 Mdot
.21518 .99276 Mdot
.12041 .90523 Mdot
.26091 .1405 Mdot
.28994 .02903 Mdot
.23979 .94985 Mdot
.07785 .83806 Mdot
.39244 .31459 Mdot
.01014 .6177 Mdot
.5569 .54676 Mdot
.4935 .93661 Mdot
.38465 .89114 Mdot
.53718 .15253 Mdot
.94759 .41042 Mdot
.71826 .77067 Mdot
.58093 .86267 Mdot
.98604 .40511 Mdot
.48873 .50269 Mdot
.9126 .42387 Mdot
.91798 .00538 Mdot
.47243 .55445 Mdot
.83483 .3624 Mdot
.15679 .32196 Mdot
.55034 .39356 Mdot
.29043 .74009 Mdot
.95221 .66177 Mdot
.94353 .99132 Mdot
.3219 .37838 Mdot
.69797 .37607 Mdot
.12913 .43116 Mdot
.75232 .62319 Mdot
.48947 .73715 Mdot
.15297 .6635 Mdot
.90308 .75011 Mdot
.29045 .38737 Mdot
.59953 .30907 Mdot
.56075 .96122 Mdot
.93697 .37622 Mdot
.74294 .80597 Mdot
.6619 .91896 Mdot
.52856 .86666 Mdot
.59406 .0655 Mdot
.28034 .68628 Mdot
.5 .55 Mdot
.05 .55 Mdot
.25573 .20573 Mdot
.34809 .09237 Mdot
.53137 .18328 Mdot
.93285 .40148 Mdot
.79055 .8577 Mdot
.72637 .93582 Mdot
.76401 .03765 Mdot
.91143 .14741 Mdot
.64733 .73591 Mdot
.27346 .62613 Mdot
.79758 .52412 Mdot
.38637 .58879 Mdot
.24562 .85925 Mdot
.9912 .74559 Mdot
.79834 .80714 Mdot
.66857 .87022 Mdot
.51021 .84164 Mdot
.42324 .91303 Mdot
.8195 .39627 Mdot
.2253 .4058 Mdot
.5304 .3051 Mdot
.04701 .51661 Mdot
.2393 .19228 Mdot
.32001 .08072 Mdot
.39271 .0727 Mdot
.76996 .37726 Mdot
.25255 .48259 Mdot
.6212 .36865 Mdot
.75858 .13738 Mdot
.00843 .24985 Mdot
.19928 .19085 Mdot
.33214 .13285 Mdot
.49601 .16387 Mdot
.63195 .13594 Mdot
.58933 .95738 Mdot
.13971 .55038 Mdot
.83297 .69326 Mdot
.49232 .65935 Mdot
.09797 .60564 Mdot
.06033 .96236 Mdot
.61043 .55011 Mdot
.87302 .26258 Mdot
.93313 .06012 Mdot
.44767 .51454 Mdot
.60248 .1548 Mdot
.42606 .82358 Mdot
.75047 .32441 Mdot
.18895 .43849 Mdot
.59431 .40535 Mdot
.62186 .02756 Mdot
.42153 .79966 Mdot
.69385 .27233 Mdot
.01165 .3178 Mdot
.24798 .23634 Mdot
.37032 .12234 Mdot
.68208 .31175 Mdot
.00799 .32592 Mdot
.27798 .26999 Mdot
.45106 .17308 Mdot
.28696 .8359 Mdot
.03869 .75173 Mdot
.52224 .48355 Mdot
.16098 .63874 Mdot
.85541 .69442 Mdot
.42839 .57298 Mdot
.51683 .08844 Mdot
.72284 .20601 Mdot
.02676 .30392 Mdot
.14424 .11748 Mdot
.38469 .24045 Mdot
.88675 .50206 Mdot
.11634 .22959 Mdot
.60217 .48583 Mdot
.75507 .1529 Mdot
.0215 .26642 Mdot
.1379 .1164 Mdot
.40533 .26743 Mdot
.04845 .64313 Mdot
.35762 .30916 Mdot
.79782 .4402 Mdot
.3022 .50438 Mdot
.75187 .44968 Mdot
.31556 .56368 Mdot
.85834 .54278 Mdot
.26689 .40855 Mdot
.56763 .30074 Mdot
.32767 .76004 Mdot
.10366 .77599 Mdot
.20425 .10059 Mdot
.23647 .03221 Mdot
.15862 .92215 Mdot
.14533 .98671 Mdot
.25032 .10499 Mdot
.24123 .99091 Mdot
.11975 .87852 Mdot
.2369 .11715 Mdot
.24373 .00684 Mdot
.13735 .89361 Mdot
.1845 .04715 Mdot
.21059 .02609 Mdot
.15658 .94599 Mdot
.17496 .01838 Mdot
.20081 .02585 Mdot
.16536 .96455 Mdot
.16969 .00432 Mdot
.19879 .02911 Mdot
.17098 .97219 Mdot
.1636 .99261 Mdot
.20231 .03871 Mdot
.17658 .97427 Mdot
.15322 .97664 Mdot
.21548 .06225 Mdot
.18975 .97428 Mdot
.12882 .93906 Mdot
.26144 .13262 Mdot
.28285 .02141 Mdot
.21381 .93097 Mdot
.05937 .84556 Mdot
.49892 .43955 Mdot
.93088 .43196 Mdot
.83161 .90073 Mdot
.70313 .87152 Mdot
.64078 .93765 Mdot
.44034 .79956 Mdot
.83202 .39168 Mdot
.19309 .36107 Mdot
.51055 .31746 Mdot
.90177 .39123 Mdot
.93777 .036 Mdot
.39837 .46061 Mdot
.19496 .79658 Mdot
.94342 .74846 Mdot
.07964 .13622 Mdot
.68134 .60169 Mdot
.29504 .6137 Mdot
.83896 .54392 Mdot
.32742 .48846 Mdot
.83103 .50361 Mdot
.30743 .4764 Mdot
.7415 .43407 Mdot
.28807 .54657 Mdot
.75227 .4642 Mdot
.33044 .57817 Mdot
.9338 .60337 Mdot
.9873 .05349 Mdot
.12961 .14231 Mdot
.46166 .33205 Mdot
.52794 .06628 Mdot
.78879 .26085 Mdot
.1308 .34201 Mdot
.65686 .52606 Mdot
.11161 .45475 Mdot
.84755 .73594 Mdot
.49477 .64722 Mdot
.10537 .6106 Mdot
.0311 .92573 Mdot
.74051 .70941 Mdot
.56202 .82151 Mdot
.80677 .24475 Mdot
.09548 .28872 Mdot
.75521 .65972 Mdot
.52842 .77321 Mdot
.49951 .97109 Mdot
.46718 .96767 Mdot
.20673 .73955 Mdot
.87312 .66639 Mdot
.33655 .46343 Mdot
.8466 .51005 Mdot
.27174 .42514 Mdot
.59317 .32143 Mdot
.53019 .93702 Mdot
.67726 .14707 Mdot
.82407 .14681 Mdot
.96648 .14241 Mdot
.34181 .37534 Mdot
.78335 .44154 Mdot
.3146 .53125 Mdot
.8223 .5077 Mdot
.33109 .50878 Mdot
.86727 .53619 Mdot
.22855 .36127 Mdot
.48584 .2573 Mdot
.64416 .15832 Mdot
.67917 .03501 Mdot
.71974 .04057 Mdot
.85431 .13457 Mdot
.87214 .01783 Mdot
.69179 .81965 Mdot
.55183 .86004 Mdot
.76827 .21644 Mdot
.09146 .3232 Mdot
.80907 .71761 Mdot
.5649 .75583 Mdot
.76256 .19766 Mdot
.07084 .30828 Mdot
.89945 .82861 Mdot
.38601 .48656 Mdot
.14116 .75514 Mdot
.03275 .89159 Mdot
.69673 .66398 Mdot
.41297 .71624 Mdot
.54988 .13692 Mdot
.0303 .48042 Mdot
.29989 .26959 Mdot
.5097 .20981 Mdot
.78735 .27765 Mdot
.14855 .3612 Mdot
.61444 .46589 Mdot
.81413 .19969 Mdot
.03868 .22455 Mdot
.99512 .95644 Mdot
.98572 .9906 Mdot
.07616 .09044 Mdot
.6536 .57744 Mdot
.14691 .49332 Mdot
.75179 .60488 Mdot
.47068 .71889 Mdot
.98548 .5148 Mdot
.60177 .61629 Mdot
.88289 .28112 Mdot
.91177 .02888 Mdot
.52709 .61531 Mdot
.33111 .80402 Mdot
.16262 .83151 Mdot
.04377 .88115 Mdot
.62237 .5786 Mdot
.97564 .35327 Mdot
.49877 .52314 Mdot
.01333 .51456 Mdot
.43467 .42133 Mdot
.41142 .97675 Mdot
.7996 .38819 Mdot
.2482 .4486 Mdot
.58279 .33459 Mdot
.47113 .88834 Mdot
.15846 .68733 Mdot
.91096 .7525 Mdot
.25473 .34377 Mdot
.48492 .23018 Mdot
.60968 .12476 Mdot
.44286 .83318 Mdot
.88459 .44173 Mdot
.06523 .18064 Mdot
.80195 .73672 Mdot
.59393 .79198 Mdot
.00593 .412 Mdot
.37641 .37047 Mdot
.96608 .58968 Mdot
.79138 .82529 Mdot
.69332 .90194 Mdot
.63942 .94611 Mdot
.44135 .80193 Mdot
.84199 .40063 Mdot
.17575 .33377 Mdot
.51448 .33873 Mdot
.95447 .43998 Mdot
.70884 .75437 Mdot
.54025 .83141 Mdot
.65038 .11013 Mdot
.66338 .013 Mdot
.6295 .96612 Mdot
.40532 .77583 Mdot
.55681 .15148 Mdot
.09754 .54073 Mdot
.99746 .89992 Mdot
.91517 .91771 Mdot
.39897 .4838 Mdot
.22214 .82316 Mdot
.94824 .72611 Mdot
.03029 .08204 Mdot
.90159 .8713 Mdot
.41869 .5171 Mdot
.39107 .97238 Mdot
.65912 .26804 Mdot
.8645 .20538 Mdot
.90789 .0434 Mdot
.56065 .65276 Mdot
.62779 .06713 Mdot
.49638 .86859 Mdot
.33964 .84326 Mdot
.24091 .90127 Mdot
.02991 .789 Mdot
.61078 .58087 Mdot
.90601 .29523 Mdot
.82157 .91556 Mdot
.74045 .91888 Mdot
.77141 .03096 Mdot
.90639 .13498 Mdot
.65952 .75313 Mdot
.35148 .69196 Mdot
.14823 .79676 Mdot
.051 .90277 Mdot
.60283 .55182 Mdot
.82538 .22256 Mdot
.03938 .21399 Mdot
.98054 .94117 Mdot
.05758 .07703 Mdot
.74031 .68273 Mdot
.53506 .79475 Mdot
.57328 .03821 Mdot
.10649 .53322 Mdot
.94866 .84216 Mdot
.14403 .19537 Mdot
.46329 .31927 Mdot
.52787 .06458 Mdot
.78658 .25871 Mdot
.13007 .34349 Mdot
.66108 .531 Mdot
.13675 .47567 Mdot
.76869 .63194 Mdot
.50704 .73835 Mdot
.29469 .78765 Mdot
.01189 .7172 Mdot
.64593 .63404 Mdot
.16424 .51831 Mdot
.72634 .5621 Mdot
.39023 .6639 Mdot
.34524 .955 Mdot
.37973 .0345 Mdot
.65022 .27048 Mdot
.8229 .17269 Mdot
.99483 .17192 Mdot
.20296 .20814 Mdot
.34532 .14235 Mdot
.56749 .22217 Mdot
.24802 .68054 Mdot
.81456 .56654 Mdot
.40477 .59021 Mdot
.36747 .9627 Mdot
.50602 .13855 Mdot
.68673 .18071 Mdot
.89464 .20791 Mdot
.78738 .89274 Mdot
.76362 .97624 Mdot
.84987 .08625 Mdot
.83797 .9881 Mdot
.77426 .93629 Mdot
.81171 .03746 Mdot
.88054 .06883 Mdot
.70924 .8287 Mdot
.61568 .90644 Mdot
.26247 .64679 Mdot
.7986 .53612 Mdot
.39727 .59868 Mdot
.32575 .92848 Mdot
.26399 .93824 Mdot
.09244 .82845 Mdot
.30957 .21712 Mdot
.48973 .18017 Mdot
.59809 .10836 Mdot
.35043 .75234 Mdot
.20321 .85279 Mdot
.98971 .78649 Mdot
.8482 .85849 Mdot
.61536 .76716 Mdot
.12113 .50578 Mdot
.85851 .73737 Mdot
.46092 .60242 Mdot
.79255 .33163 Mdot
.19868 .40613 Mdot
.54814 .34946 Mdot
.2295 .68135 Mdot
.806 .5765 Mdot
.42833 .62234 Mdot
.56579 .13746 Mdot
.15078 .58499 Mdot
.83126 .68049 Mdot
.48374 .65247 Mdot
.02257 .53884 Mdot
.40392 .38135 Mdot
.15284 .74892 Mdot
.9889 .83606 Mdot
.90259 .91369 Mdot
.45636 .55376 Mdot
.70844 .25208 Mdot
.03684 .3284 Mdot
.10967 .07283 Mdot
.47416 .36449 Mdot
.65853 .18437 Mdot
.77798 .11945 Mdot
.99435 .21637 Mdot
.25028 .25594 Mdot
.39214 .14185 Mdot
.83542 .44329 Mdot
.23614 .40071 Mdot
.52699 .29085 Mdot
.00585 .47886 Mdot
.4438 .43795 Mdot
.49645 .05265 Mdot
.52426 .02781 Mdot
.72119 .19694 Mdot
.01401 .29282 Mdot
.20889 .19488 Mdot
.32664 .11776 Mdot
.45702 .13038 Mdot
.29022 .83319 Mdot
.04471 .75449 Mdot
.49034 .44564 Mdot
.86843 .37808 Mdot
0 .6 Mdot
.6 .6 Mdot
.85484 .25484 Mdot
.99066 .13582 Mdot
.19182 .20116 Mdot
.35251 .16069 Mdot
.62231 .2698 Mdot
.66648 .04417 Mdot
.67482 .00834 Mdot
.67524 .00042 Mdot
.66908 .99384 Mdot
.63608 .967 Mdot
.44375 .80767 Mdot
.86578 .42203 Mdot
.11989 .25411 Mdot
.61193 .49204 Mdot
.82444 .21251 Mdot
.03139 .20695 Mdot
.02005 .98866 Mdot
.86874 .8487 Mdot
.53556 .66682 Mdot
.44927 .91371 Mdot
.01387 .56459 Mdot
.48152 .46766 Mdot
.82013 .33861 Mdot
.1664 .34627 Mdot
.54877 .38237 Mdot
.26725 .71848 Mdot
.87818 .61093 Mdot
.26099 .3828 Mdot
.53236 .27137 Mdot
.02869 .49633 Mdot
.32527 .29658 Mdot
.63004 .30477 Mdot
.74711 .11707 Mdot
.97809 .23098 Mdot
.36198 .38389 Mdot
.89635 .53437 Mdot
.10604 .20969 Mdot
.62714 .5211 Mdot
.94656 .31941 Mdot
.63309 .68654 Mdot
.14641 .51332 Mdot
.77341 .627 Mdot
.50247 .72905 Mdot
.24878 .74632 Mdot
.88105 .63227 Mdot
.27058 .38953 Mdot
.55533 .28475 Mdot
.21967 .66434 Mdot
.79009 .57042 Mdot
.43944 .64934 Mdot
.67498 .23555 Mdot
.90314 .22816 Mdot
.76823 .86509 Mdot
.7401 .97187 Mdot
.8239 .0838 Mdot
.90383 .07992 Mdot
.61674 .71291 Mdot
.07549 .45875 Mdot
.02541 .94992 Mdot
.79823 .77282 Mdot
.63437 .83614 Mdot
.3033 .66892 Mdot
.92002 .61673 Mdot
.07332 .15329 Mdot
.73135 .65803 Mdot
.49582 .76447 Mdot
.23103 .73521 Mdot
.86006 .62903 Mdot
.34725 .48719 Mdot
.92193 .57469 Mdot
.02144 .09951 Mdot
.97132 .94988 Mdot
.12087 .14954 Mdot
.50336 .3825 Mdot
.90939 .40603 Mdot
.91599 .0066 Mdot
.48375 .56776 Mdot
.93794 .45419 Mdot
.81562 .87768 Mdot
.71402 .8984 Mdot
.69817 .98415 Mdot
.73785 .03968 Mdot
.88836 .15052 Mdot
.75782 .86945 Mdot
.74001 .9822 Mdot
.8341 .09409 Mdot
.89032 .05622 Mdot
.65495 .76463 Mdot
.34083 .68587 Mdot
.08916 .74833 Mdot
.24551 .15635 Mdot
.28823 .04271 Mdot
.24883 .96061 Mdot
.09538 .84655 Mdot
.3135 .21812 Mdot
.50505 .19155 Mdot
.73196 .22691 Mdot
.0658 .33384 Mdot
.95207 .88628 Mdot
.16878 .21671 Mdot
.41334 .24456 Mdot
.08083 .66748 Mdot
.20654 .12572 Mdot
.25945 .05291 Mdot
.20024 .94079 Mdot
.08096 .88072 Mdot
.41911 .33815 Mdot
.21507 .79597 Mdot
.92367 .7086 Mdot
.14631 .22264 Mdot
.48305 .33674 Mdot
.70136 .21831 Mdot
.98215 .28078 Mdot
.38763 .40548 Mdot
.07023 .68261 Mdot
.27701 .20678 Mdot
.3857 .10869 Mdot
.76134 .37563 Mdot
.24823 .48689 Mdot
.62111 .37288 Mdot
.76227 .14116 Mdot
.0142 .25194 Mdot
.16684 .15263 Mdot
.35404 .18721 Mdot
.65687 .30282 Mdot
.88842 .23155 Mdot
.8386 .95018 Mdot
.73465 .89605 Mdot
.7396 .00495 Mdot
.85626 .11666 Mdot
.84778 .99152 Mdot
.74966 .90188 Mdot
.76561 .01596 Mdot
.8903 .12469 Mdot
.72351 .83322 Mdot
.65542 .93191 Mdot
.51043 .85501 Mdot
.43838 .92795 Mdot
.9457 .50732 Mdot
.82579 .88009 Mdot
.69602 .87023 Mdot
.61686 .92084 Mdot
.2842 .66733 Mdot
.86306 .57887 Mdot
.28652 .42346 Mdot
.6251 .33858 Mdot
.75195 .12685 Mdot
.99281 .24085 Mdot
.284 .2912 Mdot
.48644 .20244 Mdot
.59406 .10762 Mdot
.32244 .72838 Mdot
.05018 .72773 Mdot
.43246 .38229 Mdot
.35606 .9236 Mdot
.40394 .04788 Mdot
.81948 .41554 Mdot
.24462 .42514 Mdot
.55631 .31169 Mdot
.25401 .6977 Mdot
.83797 .58396 Mdot
.37012 .53215 Mdot
.0907 .72058 Mdot
.21019 .11949 Mdot
.25027 .04008 Mdot
.17626 .92599 Mdot
.10563 .92937 Mdot
.3487 .24307 Mdot
.68515 .33645 Mdot
.04448 .35932 Mdot
.09651 .05203 Mdot
.51363 .41713 Mdot
.02607 .51244 Mdot
.35682 .33075 Mdot
.81512 .4583 Mdot
.29554 .48042 Mdot
.70719 .41164 Mdot
.19286 .48567 Mdot
.63548 .44263 Mdot
.91602 .28054 Mdot
.75753 .84151 Mdot
.71188 .95435 Mdot
.74852 .03664 Mdot
.89919 .15067 Mdot
.70929 .8101 Mdot
.59723 .88794 Mdot
.12423 .527 Mdot
.86727 .74304 Mdot
.4354 .56812 Mdot
.56361 .12822 Mdot
.12536 .56174 Mdot
.89756 .77221 Mdot
.33834 .44078 Mdot
.8323 .49396 Mdot
.29468 .46238 Mdot
.68659 .39191 Mdot
.1053 .41872 Mdot
.83951 .73421 Mdot
.5162 .67669 Mdot
.30608 .78988 Mdot
.05032 .74424 Mdot
.44814 .39782 Mdot
.48934 .0412 Mdot
.45601 .96666 Mdot
.11862 .66261 Mdot
.02566 .90704 Mdot
.75387 .72821 Mdot
.59583 .84196 Mdot
.06881 .47298 Mdot
.075 .0062 Mdot
.5754 .50039 Mdot
.58405 .00866 Mdot
.15412 .57006 Mdot
.80623 .65211 Mdot
.50362 .69739 Mdot
.22631 .7227 Mdot
.84724 .62093 Mdot
.3807 .53346 Mdot
.15511 .77441 Mdot
.00765 .85254 Mdot
.80667 .79902 Mdot
.6499 .84323 Mdot
.39401 .74412 Mdot
.44986 .05584 Mdot
.16049 .71063 Mdot
.92864 .76815 Mdot
.17974 .2511 Mdot
.42356 .24382 Mdot
.15263 .72907 Mdot
.96968 .81705 Mdot
.99767 .02798 Mdot
.04198 .04431 Mdot
.79584 .75387 Mdot
.6179 .82205 Mdot
.19179 .5739 Mdot
.72529 .53349 Mdot
.35946 .63417 Mdot
.13279 .77333 Mdot
.08074 .94795 Mdot
.48743 .40669 Mdot
.80621 .31878 Mdot
.17031 .36411 Mdot
.55708 .38677 Mdot
.33493 .77785 Mdot
.15361 .81868 Mdot
.05635 .90273 Mdot
.57284 .51649 Mdot
.5816 .00876 Mdot
.13687 .55527 Mdot
.84785 .71098 Mdot
.46891 .62106 Mdot
.87369 .40478 Mdot
.07271 .19902 Mdot
.78028 .70757 Mdot
.58183 .80155 Mdot
.93132 .34948 Mdot
.74679 .81547 Mdot
.67612 .92933 Mdot
.60164 .92552 Mdot
.19127 .58963 Mdot
.74181 .55054 Mdot
.40496 .66315 Mdot
.44169 .03673 Mdot
.07933 .63764 Mdot
.18435 .10502 Mdot
.26872 .08437 Mdot
.24671 .97798 Mdot
.11084 .86414 Mdot
.2603 .14946 Mdot
.29801 .03771 Mdot
.27193 .97392 Mdot
.14232 .87039 Mdot
.14404 .00172 Mdot
.2696 .12556 Mdot
.2895 .01991 Mdot
.22946 .93996 Mdot
.0646 .83514 Mdot
.45984 .39523 Mdot
.5769 .11706 Mdot
.21156 .63466 Mdot
.76447 .55291 Mdot
.42687 .66239 Mdot
.59514 .16828 Mdot
.39046 .79531 Mdot
.4781 .08764 Mdot
.41295 .93484 Mdot
.76836 .35541 Mdot
.23045 .46209 Mdot
.58685 .3564 Mdot
.52149 .93464 Mdot
.60608 .08459 Mdot
.37948 .7734 Mdot
.38759 .00811 Mdot
.67264 .28505 Mdot
.94272 .27008 Mdot
.60518 .66246 Mdot
.95144 .34627 Mdot
.63236 .68091 Mdot
.13661 .50425 Mdot
.79777 .66116 Mdot
.52321 .72544 Mdot
.41053 .88732 Mdot
.704 .29347 Mdot
.06534 .36134 Mdot
.98206 .91672 Mdot
.0241 .04204 Mdot
.8981 .874 Mdot
.43766 .53956 Mdot
.55193 .11427 Mdot
.02332 .47139 Mdot
.33205 .30873 Mdot
.67148 .33944 Mdot
.99216 .32067 Mdot
.36771 .37555 Mdot
.92022 .55251 Mdot
.0081 .08788 Mdot
.03932 .03123 Mdot
.79808 .75876 Mdot
.62047 .82239 Mdot
.2079 .58743 Mdot
.72 .5121 Mdot
.32644 .60644 Mdot
.94483 .61839 Mdot
.94174 .99692 Mdot
.33741 .39566 Mdot
.78281 .44541 Mdot
.31871 .5359 Mdot
.84274 .52403 Mdot
.297 .45426 Mdot
.6854 .3884 Mdot
.09735 .41195 Mdot
.86956 .77221 Mdot
.45601 .58645 Mdot
.73846 .28244 Mdot
.13206 .3936 Mdot
.70373 .57167 Mdot
.34274 .63901 Mdot
.05154 .70879 Mdot
.40584 .3543 Mdot
.13878 .73294 Mdot
.01878 .88 Mdot
.76763 .74885 Mdot
.62373 .85611 Mdot
.26132 .63759 Mdot
.78765 .52632 Mdot
.39703 .60939 Mdot
.33489 .93785 Mdot
.3134 .97851 Mdot
.26505 .95165 Mdot
.10758 .84254 Mdot
.25309 .14551 Mdot
.28472 .03163 Mdot
.22867 .94395 Mdot
.06853 .83986 Mdot
.44338 .37485 Mdot
.43016 .98679 Mdot
.94361 .51345 Mdot
.84358 .89997 Mdot
.67053 .82695 Mdot
.47554 .80501 Mdot
.11 .63446 Mdot
.03433 .92434 Mdot
.7202 .68587 Mdot
.50068 .78048 Mdot
.28595 .78527 Mdot
.98545 .69949 Mdot
.78667 .80123 Mdot
.67254 .88587 Mdot
.54312 .87058 Mdot
.71189 .16877 Mdot
.96296 .25107 Mdot
.47099 .50803 Mdot
.77705 .30606 Mdot
.18114 .4041 Mdot
.5738 .39266 Mdot
.46476 .89095 Mdot
.11101 .64625 Mdot
.04169 .93068 Mdot
.68388 .64219 Mdot
.34538 .6615 Mdot
.08696 .74158 Mdot
.24965 .16269 Mdot
.29827 .04861 Mdot
.28363 .98536 Mdot
.17969 .89606 Mdot
.06862 .88893 Mdot
.49194 .42332 Mdot
.85887 .36692 Mdot
.08925 .23038 Mdot
.72712 .63787 Mdot
.46759 .74047 Mdot
.98278 .51519 Mdot
.61825 .63547 Mdot
.00739 .38914 Mdot
.3448 .33741 Mdot
.76 .4152 Mdot
.28709 .52709 Mdot
.73021 .44312 Mdot
.2788 .5486 Mdot
.5 .6 Mdot
.1 .6 Mdot
.04516 .94516 Mdot
.67844 .63328 Mdot
.31506 .63663 Mdot
.9294 .61434 Mdot
.02187 .09247 Mdot
.96171 .93984 Mdot
.167 .20529 Mdot
.4063 .23929 Mdot
.02691 .62061 Mdot
.46005 .43314 Mdot
.61645 .15641 Mdot
.51722 .90077 Mdot
.5383 .02108 Mdot
.82493 .28662 Mdot
.10444 .27952 Mdot
.70422 .59978 Mdot
.37232 .6681 Mdot
.23949 .86717 Mdot
.995 .75551 Mdot
.7855 .79049 Mdot
.66248 .87699 Mdot
.48931 .82683 Mdot
.24139 .75208 Mdot
.88102 .63962 Mdot
.27808 .39707 Mdot
.57836 .30028 Mdot
.40527 .82691 Mdot
.60753 .20226 Mdot
.50651 .89898 Mdot
.45104 .94453 Mdot
.0582 .60716 Mdot
.26698 .20878 Mdot
.36801 .10103 Mdot
.64745 .27944 Mdot
.81758 .17013 Mdot
.00287 .18529 Mdot
.16809 .16523 Mdot
.36354 .19545 Mdot
.71658 .35304 Mdot
.15923 .44265 Mdot
.66412 .50489 Mdot
.1248 .46068 Mdot
.79869 .67389 Mdot
.53493 .73624 Mdot
.51376 .97882 Mdot
.58878 .07502 Mdot
.25352 .66475 Mdot
.80446 .55093 Mdot
.40489 .60043 Mdot
.37848 .97359 Mdot
.58173 .20325 Mdot
.33228 .75055 Mdot
.11436 .78208 Mdot
.16304 .04868 Mdot
.25984 .0968 Mdot
.24468 .98484 Mdot
.11606 .87138 Mdot
.24512 .12905 Mdot
.26061 .01549 Mdot
.1645 .90388 Mdot
.11124 .94675 Mdot
.34116 .22992 Mdot
.63483 .29366 Mdot
.76338 .12855 Mdot
.00208 .2387 Mdot
.2262 .22412 Mdot
.34866 .12246 Mdot
.56435 .21569 Mdot
.21834 .65399 Mdot
.78021 .56187 Mdot
.43615 .65594 Mdot
.65706 .2209 Mdot
.80741 .15035 Mdot
.00015 .19275 Mdot
.19183 .19168 Mdot
.34301 .15118 Mdot
.56499 .22198 Mdot
.2294 .6644 Mdot
.78904 .55964 Mdot
.42942 .64038 Mdot
.59177 .16235 Mdot
.36148 .76971 Mdot
.27942 .91794 Mdot
.10224 .82283 Mdot
.25759 .15535 Mdot
.30012 .04253 Mdot
.28336 .98324 Mdot
.1769 .89354 Mdot
.07181 .89491 Mdot
.48092 .40911 Mdot
.75678 .27586 Mdot
.14571 .38893 Mdot
.65131 .50559 Mdot
.06355 .41225 Mdot
.04266 .9791 Mdot
.72672 .68407 Mdot
.51298 .78626 Mdot
.39003 .87705 Mdot
.55709 .16706 Mdot
.11523 .55814 Mdot
.93542 .8202 Mdot
.19535 .25993 Mdot
.40623 .21087 Mdot
.99801 .59178 Mdot
.60372 .6057 Mdot
.88512 .28141 Mdot
.90264 .01752 Mdot
.55995 .65731 Mdot
.62704 .06709 Mdot
.49194 .8649 Mdot
.30046 .80852 Mdot
.05042 .74996 Mdot
.4533 .40288 Mdot
.53399 .08068 Mdot
.8508 .31681 Mdot
.06563 .21484 Mdot
.83396 .76833 Mdot
.56491 .73095 Mdot
.73776 .17285 Mdot
.0214 .28364 Mdot
.1557 .1343 Mdot
.36582 .21012 Mdot
.74405 .37823 Mdot
.23559 .49154 Mdot
.61761 .38202 Mdot
.74997 .13237 Mdot
.99642 .24645 Mdot
.26791 .27149 Mdot
.43236 .16445 Mdot
.13748 .70512 Mdot
.99552 .85804 Mdot
.88489 .88937 Mdot
.51158 .62669 Mdot
.21927 .70769 Mdot
.83358 .6143 Mdot
.41185 .57827 Mdot
.40413 .99228 Mdot
.7652 .36107 Mdot
.23527 .47007 Mdot
.59603 .36076 Mdot
.58893 .9929 Mdot
.17247 .58354 Mdot
.77152 .59905 Mdot
.47448 .70297 Mdot
.99959 .52511 Mdot
.52754 .52795 Mdot
.24734 .7198 Mdot
.85321 .60587 Mdot
.34701 .49381 Mdot
.92738 .58037 Mdot
.99863 .07125 Mdot
.07948 .08085 Mdot
.62681 .54733 Mdot
.97083 .34402 Mdot
.51788 .54704 Mdot
.18981 .67193 Mdot
.82638 .63658 Mdot
.45118 .6248 Mdot
.73958 .2884 Mdot
.13969 .4001 Mdot
.68277 .54309 Mdot
.24202 .55925 Mdot
.68859 .44657 Mdot
.16733 .47874 Mdot
.67893 .5116 Mdot
.19538 .51645 Mdot
.66271 .46733 Mdot
.08073 .41801 Mdot
.95758 .87686 Mdot
.12787 .17028 Mdot
.49632 .36845 Mdot
.83901 .34269 Mdot
.12606 .28705 Mdot
.62012 .49407 Mdot
.87745 .25732 Mdot
.91035 .0329 Mdot
.53814 .62779 Mdot
.43039 .89225 Mdot
.85078 .42039 Mdot
.16925 .31847 Mdot
.51398 .34473 Mdot
.9564 .44243 Mdot
.70021 .7438 Mdot
.50402 .80381 Mdot
.33593 .83191 Mdot
.21222 .87629 Mdot
.00567 .79345 Mdot
.75944 .75377 Mdot
.62533 .86589 Mdot
.28064 .65531 Mdot
.84245 .56181 Mdot
.33562 .49317 Mdot
.87205 .53643 Mdot
.21072 .33867 Mdot
.46906 .25834 Mdot
.51222 .04315 Mdot
.64079 .12858 Mdot
.63131 .99052 Mdot
.44021 .8089 Mdot
.84036 .40015 Mdot
.17982 .33946 Mdot
.51177 .33195 Mdot
.92604 .41427 Mdot
.83959 .91354 Mdot
.69533 .85575 Mdot
.60008 .90475 Mdot
.16013 .56005 Mdot
.77903 .6189 Mdot
.49353 .7145 Mdot
.16275 .66922 Mdot
.88114 .71839 Mdot
.35633 .47519 Mdot
.95697 .60063 Mdot
.85518 .89821 Mdot
.63292 .77774 Mdot
.23665 .60373 Mdot
.73021 .49356 Mdot
.32926 .59905 Mdot
.94956 .6203 Mdot
.91703 .96747 Mdot
.43931 .52228 Mdot
.54701 .1077 Mdot
.97901 .432 Mdot
.5575 .57849 Mdot
.52981 .9723 Mdot
.70954 .17973 Mdot
.96754 .258 Mdot
.45119 .48365 Mdot
.59852 .14733 Mdot
.3923 .79378 Mdot
.48842 .09612 Mdot
.50352 .01511 Mdot
.54329 .03977 Mdot
.8824 .33911 Mdot
.97181 .08941 Mdot
.25752 .28571 Mdot
.43039 .17287 Mdot
.1314 .70101 Mdot
.01358 .88218 Mdot
.80079 .78721 Mdot
.64583 .84504 Mdot
.37472 .72889 Mdot
.31447 .93975 Mdot
.2303 .91583 Mdot
.04057 .81027 Mdot
.56992 .52935 Mdot
.57308 .00317 Mdot
.07004 .49696 Mdot
.0924 .02236 Mdot
.5037 .41131 Mdot
.94093 .43722 Mdot
.78224 .84132 Mdot
.71486 .93262 Mdot
.73452 .01966 Mdot
.863 .12848 Mdot
.83637 .97337 Mdot
.76376 .92739 Mdot
.80108 .03731 Mdot
.89559 .09451 Mdot
.66966 .77406 Mdot
.41883 .74918 Mdot
.62417 .20533 Mdot
.61314 .98898 Mdot
.32908 .71594 Mdot
.06564 .73656 Mdot
.35562 .28998 Mdot
.76797 .41235 Mdot
.28731 .51934 Mdot
.72305 .43573 Mdot
.25693 .53388 Mdot
.67779 .42086 Mdot
.10001 .42222 Mdot
.86734 .76733 Mdot
.45944 .5921 Mdot
.7707 .31126 Mdot
.18664 .41593 Mdot
.57562 .38898 Mdot
.47423 .89861 Mdot
.19326 .71903 Mdot
.86826 .675 Mdot
.36369 .49544 Mdot
.01742 .65373 Mdot
.54944 .53202 Mdot
.42203 .87259 Mdot
.7704 .34837 Mdot
.22372 .45331 Mdot
.5781 .35438 Mdot
.45753 .87943 Mdot
.04321 .58567 Mdot
.33014 .28693 Mdot
.64125 .31111 Mdot
.81631 .17506 Mdot
.01015 .19384 Mdot
.13297 .12282 Mdot
.42957 .2966 Mdot
.24906 .81949 Mdot
.95449 .70543 Mdot
.97417 .01968 Mdot
.17386 .19968 Mdot
.38454 .21069 Mdot
.85608 .47154 Mdot
.20326 .34718 Mdot
.48405 .28079 Mdot
.65341 .16935 Mdot
.73789 .08448 Mdot
.93324 .19535 Mdot
.58234 .6491 Mdot
.78245 .20011 Mdot
.07357 .29112 Mdot
.86786 .79429 Mdot
.48446 .6166 Mdot
.99247 .50801 Mdot
.55316 .56069 Mdot
.47907 .92592 Mdot
.25893 .77986 Mdot
.92646 .66753 Mdot
.09065 .16419 Mdot
.65404 .56338 Mdot
.13505 .48101 Mdot
.78014 .64509 Mdot
.5194 .73926 Mdot
.39409 .87469 Mdot
.58091 .18682 Mdot
.30999 .72909 Mdot
.00322 .69322 Mdot
.67391 .67069 Mdot
.33378 .65987 Mdot
.03041 .69662 Mdot
.51547 .48506 Mdot
.10866 .59319 Mdot
.99894 .89028 Mdot
.89663 .89769 Mdot
.4681 .57147 Mdot
.81772 .34963 Mdot
.18209 .36436 Mdot
.53226 .35018 Mdot
.10674 .57448 Mdot
.9888 .88206 Mdot
.94918 .96038 Mdot
.25927 .31008 Mdot
.45716 .19789 Mdot
.35875 .9016 Mdot
.39639 .03764 Mdot
.75892 .36253 Mdot
.23378 .47486 Mdot
.60034 .36656 Mdot
.62367 .02333 Mdot
.42819 .80452 Mdot
.74692 .31873 Mdot
.17953 .43261 Mdot
.60549 .42596 Mdot
.71696 .11147 Mdot
.9186 .20164 Mdot
.66552 .74691 Mdot
.3732 .70769 Mdot
.28426 .91106 Mdot
.10694 .82268 Mdot
.2361 .12915 Mdot
.25542 .01932 Mdot
.16129 .90588 Mdot
.1217 .96041 Mdot
.31084 .18914 Mdot
.46629 .15546 Mdot
.38755 .92126 Mdot
.58557 .19801 Mdot
.35412 .76855 Mdot
.2386 .88448 Mdot
.01185 .77325 Mdot
.70222 .69037 Mdot
.45685 .75463 Mdot
.91316 .4563 Mdot
.94764 .03449 Mdot
.34206 .39442 Mdot
.80362 .46156 Mdot
.31663 .51301 Mdot
.81179 .49516 Mdot
.33812 .52633 Mdot
.91679 .57867 Mdot
.05176 .13497 Mdot
.83077 .77902 Mdot
.58345 .75267 Mdot
.89385 .31041 Mdot
.89341 .99956 Mdot
.58454 .69113 Mdot
.84005 .2555 Mdot
.03603 .19598 Mdot
.98197 .94594 Mdot
.05387 .07191 Mdot
.75582 .70195 Mdot
.57111 .81529 Mdot
.86778 .29667 Mdot
.98714 .11936 Mdot
.19643 .2093 Mdot
.35415 .15772 Mdot
.62795 .27379 Mdot
.70397 .07602 Mdot
.84779 .14382 Mdot
.90193 .05414 Mdot
.59992 .69799 Mdot
0 .65 Mdot
.65 .65 Mdot
.20131 .55131 Mdot
.69026 .48895 Mdot
.21575 .52548 Mdot
.65285 .4371 Mdot
.00283 .34998 Mdot
.33302 .3302 Mdot
.69732 .3643 Mdot
.11523 .41791 Mdot
.79519 .67997 Mdot
.54463 .74944 Mdot
.60241 .05778 Mdot
.32862 .72621 Mdot
.07396 .74533 Mdot
.32003 .24607 Mdot
.55812 .2381 Mdot
.19409 .63597 Mdot
.78401 .58992 Mdot
.46267 .67866 Mdot
.88245 .41978 Mdot
.05228 .16983 Mdot
.86271 .81043 Mdot
.51935 .65664 Mdot
.31109 .79175 Mdot
.06983 .75874 Mdot
.35527 .28544 Mdot
.76157 .4063 Mdot
.27901 .51744 Mdot
.70082 .42181 Mdot
.18394 .48312 Mdot
.64757 .46363 Mdot
.00244 .35486 Mdot
.34023 .33779 Mdot
.73823 .398 Mdot
.24727 .50904 Mdot
.64239 .39512 Mdot
.90649 .2641 Mdot
.78814 .88165 Mdot
.75204 .9639 Mdot
.82993 .07789 Mdot
.88434 .05442 Mdot
.67896 .79461 Mdot
.47849 .79953 Mdot
.1279 .64941 Mdot
.97531 .84741 Mdot
.99486 .01955 Mdot
.05038 .05552 Mdot
.75909 .7087 Mdot
.58006 .82097 Mdot
.93813 .35806 Mdot
.71848 .78036 Mdot
.59116 .87267 Mdot
.06762 .47646 Mdot
.08486 .01724 Mdot
.53584 .45098 Mdot
.23559 .69975 Mdot
.82581 .59023 Mdot
.4061 .58028 Mdot
.36654 .96045 Mdot
.49849 .13195 Mdot
.61989 .12139 Mdot
.50334 .88346 Mdot
.4102 .90686 Mdot
.72128 .31108 Mdot
.12836 .40708 Mdot
.73121 .60285 Mdot
.44039 .70918 Mdot
.74195 .30157 Mdot
.15618 .41423 Mdot
.64435 .48817 Mdot
.01001 .36566 Mdot
.30567 .29566 Mdot
.55469 .24903 Mdot
.17909 .6244 Mdot
.79816 .61907 Mdot
.48069 .68254 Mdot
.02842 .54773 Mdot
.37824 .34981 Mdot
.95645 .57822 Mdot
.8357 .87925 Mdot
.67138 .83568 Mdot
.48794 .81657 Mdot
.2202 .73226 Mdot
.85784 .63764 Mdot
.36345 .5056 Mdot
.0262 .66276 Mdot
.50637 .48016 Mdot
.03108 .52471 Mdot
.33963 .30855 Mdot
.70615 .36652 Mdot
.14472 .43857 Mdot
.7042 .55948 Mdot
.33195 .62775 Mdot
.99007 .65812 Mdot
.71768 .72761 Mdot
.53648 .8188 Mdot
.60842 .07194 Mdot
.38198 .77356 Mdot
.40306 .02108 Mdot
.78673 .38367 Mdot
.25495 .46822 Mdot
.60963 .35468 Mdot
.67242 .0628 Mdot
.71957 .04714 Mdot
.86048 .14092 Mdot
.85766 .99717 Mdot
.72361 .86595 Mdot
.68836 .96476 Mdot
.6847 .99634 Mdot
.70267 .01796 Mdot
.78581 .08314 Mdot
.95495 .16915 Mdot
.43523 .48027 Mdot
.47451 .03928 Mdot
.3361 .8616 Mdot
.24271 .90661 Mdot
.03641 .79369 Mdot
.57747 .54107 Mdot
.6397 .06222 Mdot
.55899 .91929 Mdot
.88184 .32284 Mdot
.95791 .07607 Mdot
.32521 .36731 Mdot
.70054 .37533 Mdot
.1366 .43606 Mdot
.72959 .59299 Mdot
.42752 .69793 Mdot
.63542 .2079 Mdot
.68095 .04553 Mdot
.73735 .0564 Mdot
.90432 .16697 Mdot
.70143 .79712 Mdot
.56116 .85973 Mdot
.83858 .27742 Mdot
.06193 .22334 Mdot
.86263 .8007 Mdot
.5099 .64728 Mdot
.22646 .71656 Mdot
.8411 .61464 Mdot
.39225 .55115 Mdot
.24545 .85321 Mdot
.98503 .73958 Mdot
.82925 .84422 Mdot
.65227 .82302 Mdot
.38586 .73359 Mdot
.3872 .00134 Mdot
.66342 .27622 Mdot
.8929 .22948 Mdot
.81676 .92386 Mdot
.75812 .94136 Mdot
.81212 .054 Mdot
.89642 .0843 Mdot
.65568 .75927 Mdot
.33907 .68338 Mdot
.07831 .73924 Mdot
.29123 .21292 Mdot
.42725 .13602 Mdot
.07159 .64434 Mdot
.23153 .15994 Mdot
.28488 .05335 Mdot
.25078 .96591 Mdot
.10262 .85184 Mdot
.28486 .18224 Mdot
.37963 .09477 Mdot
.70989 .33026 Mdot
.11905 .40916 Mdot
.77042 .65137 Mdot
.52672 .7563 Mdot
.46918 .94246 Mdot
.19722 .72805 Mdot
.87188 .67465 Mdot
.34961 .47773 Mdot
.92441 .5748 Mdot
.00867 .08426 Mdot
.03225 .02357 Mdot
.83162 .79937 Mdot
.60175 .77013 Mdot
.03663 .43487 Mdot
.21736 .18074 Mdot
.30736 .08999 Mdot
.35483 .04747 Mdot
.52128 .16645 Mdot
.83627 .31499 Mdot
.10564 .26937 Mdot
.68864 .58299 Mdot
.30392 .61529 Mdot
.86846 .56454 Mdot
.25247 .38401 Mdot
.52252 .27006 Mdot
.94972 .42719 Mdot
.72306 .77334 Mdot
.59457 .87151 Mdot
.08978 .49521 Mdot
.98934 .89956 Mdot
.96346 .97411 Mdot
.19113 .22768 Mdot
.38007 .18893 Mdot
.80669 .42662 Mdot
.27747 .47078 Mdot
.65072 .37325 Mdot
.92822 .2775 Mdot
.69134 .76312 Mdot
.49372 .80239 Mdot
.25219 .75847 Mdot
.89669 .64449 Mdot
.21464 .31796 Mdot
.44589 .23125 Mdot
.30566 .85976 Mdot
.11878 .81312 Mdot
.17552 .05674 Mdot
.23796 .06244 Mdot
.18951 .95154 Mdot
.10648 .91697 Mdot
.33247 .226 Mdot
.59065 .25817 Mdot
.4496 .85896 Mdot
.96165 .51205 Mdot
.73955 .77789 Mdot
.62912 .88958 Mdot
.32662 .6975 Mdot
.03666 .71004 Mdot
.49232 .45566 Mdot
.89427 .40195 Mdot
.98307 .0888 Mdot
.19013 .20706 Mdot
.361 .17086 Mdot
.67792 .31692 Mdot
.9966 .31869 Mdot
.33906 .34246 Mdot
.73735 .39829 Mdot
.24621 .50886 Mdot
.6413 .39509 Mdot
.90059 .25929 Mdot
.81138 .91079 Mdot
.75443 .94305 Mdot
.81113 .0567 Mdot
.90075 .08962 Mdot
.64097 .74022 Mdot
.24393 .60296 Mdot
.73362 .48969 Mdot
.3315 .59788 Mdot
.95819 .62669 Mdot
.87421 .91602 Mdot
.58191 .70771 Mdot
.83804 .25612 Mdot
.0421 .20406 Mdot
.95489 .91279 Mdot
.17925 .22437 Mdot
.3978 .21855 Mdot
.94912 .55132 Mdot
.85054 .90142 Mdot
.65104 .8005 Mdot
.35711 .70607 Mdot
.19204 .83492 Mdot
.98594 .79391 Mdot
.87811 .89217 Mdot
.54251 .6644 Mdot
.50095 .95844 Mdot
.46605 .9651 Mdot
.1953 .72925 Mdot
.87562 .68032 Mdot
.34064 .46502 Mdot
.86743 .52679 Mdot
.21856 .35113 Mdot
.47728 .25871 Mdot
.57746 .10018 Mdot
.1987 .62124 Mdot
.76323 .56453 Mdot
.438 .67477 Mdot
.68969 .25169 Mdot
.97642 .28673 Mdot
.4276 .45118 Mdot
.38929 .96169 Mdot
.63703 .24773 Mdot
.72975 .09273 Mdot
.92757 .19781 Mdot
.61509 .68753 Mdot
.03985 .42476 Mdot
.18855 .14869 Mdot
.30518 .11663 Mdot
.37402 .06884 Mdot
.65022 .2762 Mdot
.82863 .17841 Mdot
.98791 .15928 Mdot
.23176 .24385 Mdot
.36884 .13708 Mdot
.68824 .3194 Mdot
.03887 .35064 Mdot
.12011 .08124 Mdot
.43815 .31804 Mdot
.33405 .8959 Mdot
.26767 .93361 Mdot
.09405 .82638 Mdot
.29975 .2057 Mdot
.44535 .1456 Mdot
.21586 .77051 Mdot
.89782 .68196 Mdot
.2469 .34908 Mdot
.48211 .23521 Mdot
.59235 .11024 Mdot
.31339 .72104 Mdot
.00757 .69417 Mdot
.64878 .64121 Mdot
.18626 .53748 Mdot
.69781 .51155 Mdot
.26408 .56627 Mdot
.72061 .45653 Mdot
.27229 .55168 Mdot
.72079 .4485 Mdot
.26466 .54387 Mdot
.69917 .43451 Mdot
.19143 .49226 Mdot
.64419 .45276 Mdot
.97378 .32959 Mdot
.48608 .5123 Mdot
.90104 .41496 Mdot
.96495 .06391 Mdot
.27224 .30729 Mdot
.47631 .20407 Mdot
.51516 .03885 Mdot
.66 .14484 Mdot
.74549 .08549 Mdot
.94461 .19913 Mdot
.52366 .57904 Mdot
.2677 .74405 Mdot
.90455 .63685 Mdot
.1702 .26565 Mdot
.45889 .28869 Mdot
.46301 .00412 Mdot
.21056 .74754 Mdot
.87805 .6675 Mdot
.31807 .44002 Mdot
.74436 .42629 Mdot
.28403 .53967 Mdot
.735 .45096 Mdot
.2951 .5601 Mdot
.78556 .49046 Mdot
.36241 .57685 Mdot
.09169 .72928 Mdot
.21407 .12238 Mdot
.25064 .03657 Mdot
.17313 .92249 Mdot
.10898 .93585 Mdot
.3402 .23122 Mdot
.63151 .29131 Mdot
.74218 .11066 Mdot
.96558 .2234 Mdot
.42804 .46246 Mdot
.4038 .97576 Mdot
.74645 .34264 Mdot
.2029 .45645 Mdot
.5937 .3908 Mdot
.60317 .00947 Mdot
.28528 .68211 Mdot
.88055 .59528 Mdot
.23564 .35509 Mdot
.48118 .24553 Mdot
.59525 .11407 Mdot
.33697 .74172 Mdot
.12683 .78986 Mdot
.11991 .99307 Mdot
.35082 .23091 Mdot
.68381 .33299 Mdot
.0359 .3521 Mdot
.13881 .1029 Mdot
.38864 .24983 Mdot
.92103 .53239 Mdot
.98381 .06278 Mdot
.15973 .17592 Mdot
.39601 .23628 Mdot
.95505 .55904 Mdot
.82455 .8695 Mdot
.68812 .86357 Mdot
.58264 .89452 Mdot
.03 .44736 Mdot
.2686 .2386 Mdot
.40072 .13212 Mdot
.88204 .48133 Mdot
.11552 .23348 Mdot
.60951 .49399 Mdot
.81099 .20148 Mdot
.04575 .23477 Mdot
.96464 .91889 Mdot
.129 .16436 Mdot
.48603 .35704 Mdot
.74544 .2594 Mdot
.11846 .37303 Mdot
.73673 .61826 Mdot
.4652 .72848 Mdot
.95203 .48683 Mdot
.76958 .81755 Mdot
.69279 .92321 Mdot
.65889 .9661 Mdot
.56144 .90255 Mdot
.88347 .32203 Mdot
.95025 .06678 Mdot
.35962 .40936 Mdot
.90885 .54923 Mdot
.06184 .15299 Mdot
.79277 .73093 Mdot
.5 .65 Mdot
.15 .65 Mdot
.89869 .74869 Mdot
.30963 .41094 Mdot
.68378 .37415 Mdot
.07696 .39318 Mdot
.95219 .87523 Mdot
.15709 .2049 Mdot
.43242 .27533 Mdot
.24876 .81635 Mdot
.95106 .70229 Mdot
.99057 .03952 Mdot
.09604 .10546 Mdot
.5693 .47327 Mdot
.51251 .9432 Mdot
.54317 .03066 Mdot
.87232 .32915 Mdot
.00239 .13007 Mdot
.11572 .11333 Mdot
.48852 .3728 Mdot
.78099 .29248 Mdot
.1665 .3855 Mdot
.58777 .42127 Mdot
.59277 .005 Mdot
.21098 .61821 Mdot
.74842 .53744 Mdot
.3999 .65147 Mdot
.39596 .99606 Mdot
.7145 .31855 Mdot
.11954 .40504 Mdot
.76428 .64474 Mdot
.51862 .75434 Mdot
.40298 .88436 Mdot
.64949 .24651 Mdot
.79521 .14572 Mdot
.01037 .21516 Mdot
.15301 .14264 Mdot
.38213 .22912 Mdot
.85952 .47739 Mdot
.19748 .33796 Mdot
.48147 .28399 Mdot
.63605 .15458 Mdot
.63115 .9951 Mdot
.44385 .8127 Mdot
.8716 .42775 Mdot
.10379 .23219 Mdot
.65988 .55609 Mdot
.15617 .49629 Mdot
.72644 .57027 Mdot
.39862 .67218 Mdot
.40815 .00953 Mdot
.80984 .40169 Mdot
.24779 .43794 Mdot
.57175 .32397 Mdot
.38115 .80939 Mdot
.43376 .05262 Mdot
.03597 .60221 Mdot
.38851 .35253 Mdot
.02287 .63436 Mdot
.49769 .47482 Mdot
.95635 .45866 Mdot
.71673 .76037 Mdot
.56693 .8502 Mdot
.87193 .305 Mdot
.97977 .10784 Mdot
.22885 .24908 Mdot
.37367 .14482 Mdot
.72416 .35049 Mdot
.17407 .44992 Mdot
.6343 .46023 Mdot
.92695 .29265 Mdot
.71319 .78624 Mdot
.58386 .87066 Mdot
.01473 .43087 Mdot
.34266 .32793 Mdot
.74003 .39737 Mdot
.24929 .50927 Mdot
.64449 .39519 Mdot
.91778 .27329 Mdot
.74135 .82357 Mdot
.67736 .93601 Mdot
.61341 .93605 Mdot
.27782 .66441 Mdot
.84512 .5673 Mdot
.33339 .48827 Mdot
.85703 .52364 Mdot
.25219 .39516 Mdot
.53336 .28118 Mdot
.04639 .51302 Mdot
.23927 .19288 Mdot
.32059 .08133 Mdot
.39564 .07505 Mdot
.79141 .39577 Mdot
.26377 .47235 Mdot
.6262 .36243 Mdot
.78232 .15612 Mdot
.02963 .24731 Mdot
.07072 .04109 Mdot
.6329 .56218 Mdot
.02097 .38807 Mdot
.26266 .24169 Mdot
.3938 .13113 Mdot
.83545 .44166 Mdot
.23443 .39898 Mdot
.52466 .29022 Mdot
.98677 .46212 Mdot
.54137 .55459 Mdot
.38227 .8409 Mdot
.47219 .08992 Mdot
.36847 .89627 Mdot
.44531 .07684 Mdot
.14678 .70147 Mdot
.96037 .81359 Mdot
.04849 .08812 Mdot
.80238 .75389 Mdot
.61056 .80817 Mdot
.13187 .52131 Mdot
.83215 .70028 Mdot
.50137 .66922 Mdot
.18017 .6788 Mdot
.85041 .67024 Mdot
.42027 .56987 Mdot
.45511 .03484 Mdot
.17991 .72479 Mdot
.89692 .71702 Mdot
.28608 .38916 Mdot
.58966 .30358 Mdot
.48816 .8985 Mdot
.30384 .81569 Mdot
.0686 .76475 Mdot
.3679 .2993 Mdot
.84507 .47717 Mdot
.2434 .39833 Mdot
.5286 .2852 Mdot
.01293 .48433 Mdot
.40685 .39392 Mdot
.18534 .77849 Mdot
.94042 .75508 Mdot
.10286 .16244 Mdot
.59436 .49149 Mdot
.70832 .11397 Mdot
.89839 .19007 Mdot
.75238 .85399 Mdot
.72033 .96795 Mdot
.78305 .06272 Mdot
.93592 .15287 Mdot
.52531 .58939 Mdot
.29111 .7658 Mdot
.97979 .68868 Mdot
.80954 .82975 Mdot
.67632 .86678 Mdot
.5399 .86359 Mdot
.67989 .13999 Mdot
.82761 .14772 Mdot
.95956 .13195 Mdot
.37155 .41199 Mdot
.9789 .60735 Mdot
.73349 .75458 Mdot
.59617 .86268 Mdot
.0918 .49563 Mdot
.97989 .88809 Mdot
.00839 .0285 Mdot
.97818 .96979 Mdot
.10022 .12203 Mdot
.56619 .46597 Mdot
.48222 .91603 Mdot
.27405 .79183 Mdot
.9645 .69045 Mdot
.90137 .93687 Mdot
.48529 .58391 Mdot
.96634 .48106 Mdot
.68126 .71492 Mdot
.40794 .72669 Mdot
.52557 .11762 Mdot
.82139 .29583 Mdot
.12108 .29969 Mdot
.65262 .53154 Mdot
.09614 .44352 Mdot
.90686 .81072 Mdot
.33298 .42612 Mdot
.79304 .46006 Mdot
.3267 .53366 Mdot
.87314 .54644 Mdot
.21652 .34338 Mdot
.47037 .25386 Mdot
.51804 .04767 Mdot
.69175 .17371 Mdot
.90577 .21402 Mdot
.74152 .83574 Mdot
.68976 .94825 Mdot
.67325 .98349 Mdot
.64378 .97053 Mdot
.48935 .84557 Mdot
.26045 .7711 Mdot
.91987 .65942 Mdot
.11678 .19691 Mdot
.56763 .45085 Mdot
.47777 .91014 Mdot
.23279 .75502 Mdot
.88023 .64744 Mdot
.28913 .4089 Mdot
.61745 .32832 Mdot
.69529 .07784 Mdot
.82203 .12674 Mdot
.9507 .12867 Mdot
.41898 .46828 Mdot
.34433 .92535 Mdot
.34561 .00128 Mdot
.42787 .08226 Mdot
.02234 .59447 Mdot
.46094 .4386 Mdot
.62883 .16789 Mdot
.60323 .9744 Mdot
.25066 .64743 Mdot
.78401 .53335 Mdot
.4061 .62209 Mdot
.4084 .0023 Mdot
.80432 .39592 Mdot
.25006 .44574 Mdot
.58171 .33165 Mdot
.46055 .87884 Mdot
.06605 .6055 Mdot
.22235 .1563 Mdot
.28134 .05898 Mdot
.24777 .96643 Mdot
.10022 .85245 Mdot
.29659 .19637 Mdot
.42628 .12969 Mdot
.05818 .6319 Mdot
.29184 .23367 Mdot
.44971 .15787 Mdot
.26139 .81168 Mdot
.96184 .70045 Mdot
.92687 .96504 Mdot
.38598 .4591 Mdot
.11346 .72749 Mdot
.11229 .99883 Mdot
.38869 .2764 Mdot
.94792 .55923 Mdot
.86524 .91732 Mdot
.61713 .75189 Mdot
.1169 .49977 Mdot
.86997 .75307 Mdot
.4353 .56533 Mdot
.56014 .12483 Mdot
.09599 .53585 Mdot
.99991 .90392 Mdot
.90446 .90455 Mdot
.43834 .53388 Mdot
.55129 .11296 Mdot
.01712 .46583 Mdot
.36332 .3462 Mdot
.86611 .50279 Mdot
.19943 .33331 Mdot
.47443 .27501 Mdot
.57124 .0968 Mdot
.15022 .57898 Mdot
.82699 .67677 Mdot
.49002 .66303 Mdot
.08323 .59321 Mdot
.12003 .03681 Mdot
.39403 .27399 Mdot
.97981 .58578 Mdot
.70655 .72674 Mdot
.50611 .79956 Mdot
.34843 .84232 Mdot
.28302 .93459 Mdot
.12743 .8444 Mdot
.17214 .04471 Mdot
.23345 .06131 Mdot
.1867 .95325 Mdot
.11283 .92613 Mdot
.31367 .20085 Mdot
.48842 .17474 Mdot
.58215 .09373 Mdot
.22574 .64359 Mdot
.76817 .54242 Mdot
.41742 .64926 Mdot
.51423 .09681 Mdot
.71054 .1963 Mdot
.98685 .27632 Mdot
.3551 .36825 Mdot
.84347 .48837 Mdot
.25926 .4158 Mdot
.56286 .3036 Mdot
.29514 .73228 Mdot
.95785 .66271 Mdot
.91215 .9543 Mdot
.45062 .53847 Mdot
.64897 .19835 Mdot
.7444 .09542 Mdot
.95322 .20882 Mdot
.48483 .53161 Mdot
.9104 .42557 Mdot
.93056 .02016 Mdot
.42151 .49095 Mdot
.38507 .96355 Mdot
.61222 .22715 Mdot
.56144 .94922 Mdot
.93012 .36868 Mdot
.77238 .84226 Mdot
.71773 .94535 Mdot
.75433 .0366 Mdot
.90461 .15028 Mdot
.68337 .77876 Mdot
.48 .79663 Mdot
.13698 .65698 Mdot
.94917 .81219 Mdot
.11114 .16197 Mdot
.55684 .4457 Mdot
.392 .83516 Mdot
.52784 .13584 Mdot
.85754 .32971 Mdot
.05652 .19898 Mdot
.8681 .81158 Mdot
.50085 .63275 Mdot
.13955 .6387 Mdot
.92184 .78228 Mdot
.22954 .3077 Mdot
.43235 .20281 Mdot
.17575 .7434 Mdot
.92412 .74837 Mdot
.18376 .25964 Mdot
.42443 .24067 Mdot
.15573 .73131 Mdot
.96273 .80699 Mdot
.02826 .06553 Mdot
.89701 .86875 Mdot
.43741 .5404 Mdot
.5509 .11349 Mdot
.01468 .46378 Mdot
.37582 .36114 Mdot
.95327 .57745 Mdot
.85313 .89985 Mdot
.64126 .78813 Mdot
.29338 .65212 Mdot
.87255 .57917 Mdot
.25153 .37899 Mdot
.51649 .26495 Mdot
.89663 .38015 Mdot
.95054 .0539 Mdot
.34514 .3946 Mdot
.81883 .47369 Mdot
.30404 .48521 Mdot
.73877 .43473 Mdot
.28482 .54605 Mdot
.74334 .45852 Mdot
.31497 .57163 Mdot
.86407 .5491 Mdot
.25314 .38907 Mdot
.52834 .2752 Mdot
.00084 .47251 Mdot
.46744 .46659 Mdot
.7077 .24026 Mdot
.02292 .31522 Mdot
.17827 .15535 Mdot
.33079 .15252 Mdot
.50969 .1789 Mdot
.75639 .2467 Mdot
.11628 .35989 Mdot
.7327 .61642 Mdot
.45663 .72393 Mdot
.88068 .42406 Mdot
.06389 .18321 Mdot
.81177 .74788 Mdot
.59087 .7791 Mdot
.97207 .3812 Mdot
.54778 .57571 Mdot
.45295 .90517 Mdot
.03352 .58057 Mdot
.38117 .34765 Mdot
.97219 .59102 Mdot
.75688 .78469 Mdot
.65462 .89774 Mdot
.4723 .81768 Mdot
.09701 .62472 Mdot
.08392 .9869 Mdot
.51025 .42633 Mdot
.00825 .498 Mdot
.44854 .44029 Mdot
.53484 .0863 Mdot
.86308 .32824 Mdot
.03582 .17274 Mdot
.95992 .9241 Mdot
.16164 .20172 Mdot
.41662 .25498 Mdot
.11425 .69764 Mdot
.07906 .96481 Mdot
.51292 .43386 Mdot
.0371 .52418 Mdot
.30393 .26683 Mdot
.52003 .2161 Mdot
.87599 .35596 Mdot
.01481 .13881 Mdot
.05013 .03533 Mdot
.74031 .69017 Mdot
.5425 .80219 Mdot
.63863 .09614 Mdot
.58706 .94842 Mdot
.11493 .52788 Mdot
.9064 .79147 Mdot
0 .7 Mdot
.7 .7 Mdot
.45956 .75956 Mdot
.93905 .4795 Mdot
.83482 .89577 Mdot
.69016 .85534 Mdot
.58176 .8916 Mdot
.02084 .43908 Mdot
.31448 .29364 Mdot
.58421 .26973 Mdot
.4163 .83209 Mdot
.68915 .27285 Mdot
.99565 .30649 Mdot
.33262 .33697 Mdot
.70227 .36965 Mdot
.13629 .43402 Mdot
.72867 .59238 Mdot
.42515 .69648 Mdot
.61678 .19163 Mdot
.55443 .93766 Mdot
.86574 .31131 Mdot
.0093 .14356 Mdot
.0878 .0785 Mdot
.58239 .49459 Mdot
.62832 .04593 Mdot
.4783 .84998 Mdot
.17683 .69854 Mdot
.87695 .70011 Mdot
.35513 .47818 Mdot
.95358 .59845 Mdot
.87236 .91877 Mdot
.59187 .71951 Mdot
.91937 .3275 Mdot
.78744 .86807 Mdot
.73891 .95147 Mdot
.80176 .06285 Mdot
.92029 .11853 Mdot
.57374 .65345 Mdot
.72508 .15135 Mdot
.97689 .25181 Mdot
.38989 .41299 Mdot
.09212 .70224 Mdot
.18491 .09279 Mdot
.25549 .07058 Mdot
.21265 .95716 Mdot
.08626 .87361 Mdot
.38518 .29891 Mdot
.94826 .56309 Mdot
.86717 .9189 Mdot
.61165 .74448 Mdot
.07514 .46349 Mdot
.03195 .95681 Mdot
.76658 .73463 Mdot
.60926 .84267 Mdot
.15805 .5488 Mdot
.77357 .61551 Mdot
.49097 .71741 Mdot
.14522 .65425 Mdot
.91821 .77299 Mdot
.23884 .32062 Mdot
.44811 .20928 Mdot
.30057 .85246 Mdot
.09471 .79414 Mdot
.26432 .16961 Mdot
.32434 .06003 Mdot
.38963 .06529 Mdot
.74279 .35315 Mdot
.20888 .46609 Mdot
.59787 .38899 Mdot
.62956 .03169 Mdot
.47129 .84173 Mdot
.11313 .64184 Mdot
.02808 .91495 Mdot
.74747 .71939 Mdot
.5808 .83333 Mdot
.95575 .37495 Mdot
.63645 .6807 Mdot
.15953 .52308 Mdot
.74373 .5842 Mdot
.44114 .69742 Mdot
.73589 .29474 Mdot
.14034 .40445 Mdot
.68486 .54453 Mdot
.25147 .56661 Mdot
.70404 .45257 Mdot
.22457 .52053 Mdot
.6452 .42064 Mdot
.94701 .3018 Mdot
.61295 .66594 Mdot
.0048 .39185 Mdot
.36307 .35827 Mdot
.87679 .51372 Mdot
.16937 .29258 Mdot
.4878 .31842 Mdot
.72087 .23308 Mdot
.04943 .32856 Mdot
.0375 .98806 Mdot
.76551 .72801 Mdot
.60232 .83681 Mdot
.10703 .50471 Mdot
.91775 .81072 Mdot
.27894 .3612 Mdot
.54443 .26549 Mdot
.11691 .57248 Mdot
.94267 .82576 Mdot
.16114 .21847 Mdot
.43471 .27357 Mdot
.26397 .82926 Mdot
.98344 .71947 Mdot
.81864 .8352 Mdot
.66592 .84728 Mdot
.47538 .80947 Mdot
.1132 .63782 Mdot
.02374 .91054 Mdot
.76869 .74494 Mdot
.62004 .85136 Mdot
.23427 .61422 Mdot
.73984 .50558 Mdot
.35724 .61739 Mdot
.10402 .74678 Mdot
.17339 .06937 Mdot
.25526 .08187 Mdot
.22366 .96839 Mdot
.09319 .86953 Mdot
.34702 .25383 Mdot
.68743 .34041 Mdot
.05695 .36952 Mdot
.03625 .9793 Mdot
.76397 .72772 Mdot
.60149 .83751 Mdot
.10224 .50075 Mdot
.93554 .83331 Mdot
.20781 .27227 Mdot
.40491 .1971 Mdot
.97525 .57035 Mdot
.71813 .74287 Mdot
.55282 .83469 Mdot
.75051 .19769 Mdot
.06229 .31177 Mdot
.9491 .88682 Mdot
.18616 .23706 Mdot
.39756 .2114 Mdot
.94039 .54282 Mdot
.89082 .95043 Mdot
.54697 .65615 Mdot
.52717 .98019 Mdot
.69659 .16943 Mdot
.91796 .22137 Mdot
.68849 .77053 Mdot
.49093 .80244 Mdot
.22995 .73902 Mdot
.86371 .63376 Mdot
.33908 .47537 Mdot
.87038 .53129 Mdot
.21199 .34161 Mdot
.47114 .25915 Mdot
.52936 .05822 Mdot
.79191 .26255 Mdot
.13014 .33823 Mdot
.65555 .52541 Mdot
.10457 .44902 Mdot
.87313 .76856 Mdot
.43865 .56552 Mdot
.5853 .14664 Mdot
.30085 .71555 Mdot
.95871 .65786 Mdot
.90236 .94365 Mdot
.48741 .58505 Mdot
.98445 .49704 Mdot
.59016 .60571 Mdot
.79375 .2036 Mdot
.0696 .27585 Mdot
.87363 .80403 Mdot
.47219 .59856 Mdot
.87703 .40485 Mdot
.05952 .18249 Mdot
.83499 .77547 Mdot
.56943 .73444 Mdot
.77462 .20519 Mdot
.08059 .30597 Mdot
.84625 .76566 Mdot
.52841 .68216 Mdot
.40839 .87998 Mdot
.68194 .27355 Mdot
.96923 .2873 Mdot
.47056 .50132 Mdot
.76696 .2964 Mdot
.17112 .40417 Mdot
.59525 .42413 Mdot
.64702 .05177 Mdot
.58767 .94065 Mdot
.11141 .52374 Mdot
.91745 .80604 Mdot
.27579 .35834 Mdot
.53464 .25885 Mdot
.03409 .49944 Mdot
.29674 .26266 Mdot
.49303 .19628 Mdot
.64051 .14748 Mdot
.64869 .00818 Mdot
.55276 .90407 Mdot
.81943 .26667 Mdot
.09584 .27641 Mdot
.74117 .64532 Mdot
.49886 .75769 Mdot
.24858 .74972 Mdot
.88425 .63568 Mdot
.26059 .37634 Mdot
.52532 .26472 Mdot
.96651 .44119 Mdot
.64042 .67391 Mdot
.17462 .5342 Mdot
.71738 .54276 Mdot
.35089 .63352 Mdot
.08679 .73589 Mdot
.24483 .15804 Mdot
.28938 .04455 Mdot
.25377 .96439 Mdot
.10438 .85062 Mdot
.27558 .1712 Mdot
.34706 .07147 Mdot
.50526 .15821 Mdot
.70032 .19505 Mdot
.95561 .25529 Mdot
.51764 .56203 Mdot
.2029 .68526 Mdot
.82251 .61961 Mdot
.44258 .62007 Mdot
.66934 .22677 Mdot
.87017 .20082 Mdot
.88233 .01216 Mdot
.64518 .76286 Mdot
.28911 .64393 Mdot
.85242 .56331 Mdot
.30697 .45455 Mdot
.71805 .41108 Mdot
.22085 .50279 Mdot
.62819 .40735 Mdot
.83897 .21078 Mdot
.99424 .15526 Mdot
.18984 .19561 Mdot
.35001 .16017 Mdot
.60889 .25888 Mdot
.57191 .96302 Mdot
.02132 .44942 Mdot
.32192 .3006 Mdot
.62028 .29836 Mdot
.68272 .06244 Mdot
.76119 .07846 Mdot
.95098 .1898 Mdot
.47851 .52753 Mdot
.85604 .37753 Mdot
.10939 .25335 Mdot
.65588 .54649 Mdot
.12725 .47137 Mdot
.79977 .67252 Mdot
.53234 .73257 Mdot
.48972 .95739 Mdot
.37523 .8855 Mdot
.47408 .09886 Mdot
.39233 .91824 Mdot
.61304 .22071 Mdot
.56015 .94711 Mdot
.91838 .35823 Mdot
.82323 .90485 Mdot
.7263 .90306 Mdot
.73111 .00482 Mdot
.84218 .11107 Mdot
.88563 .04345 Mdot
.66253 .7769 Mdot
.38943 .7269 Mdot
.40313 .01369 Mdot
.7798 .37667 Mdot
.25109 .47129 Mdot
.60832 .35723 Mdot
.66657 .05825 Mdot
.6893 .02273 Mdot
.74608 .05678 Mdot
.9166 .17052 Mdot
.64456 .72796 Mdot
.25096 .60639 Mdot
.74328 .49233 Mdot
.34871 .60542 Mdot
.04751 .69881 Mdot
.41864 .37113 Mdot
.24476 .82612 Mdot
.9574 .71264 Mdot
.96469 .00729 Mdot
.21713 .25245 Mdot
.37917 .16203 Mdot
.7743 .39514 Mdot
.27056 .49626 Mdot
.66202 .39146 Mdot
.00164 .33962 Mdot
.32977 .32813 Mdot
.68086 .35108 Mdot
.04253 .36167 Mdot
.11002 .06749 Mdot
.46725 .35723 Mdot
.59683 .12958 Mdot
.36316 .76633 Mdot
.28533 .92217 Mdot
.12075 .83542 Mdot
.1897 .06895 Mdot
.22357 .03387 Mdot
.15868 .93511 Mdot
.15811 .99943 Mdot
.22403 .06592 Mdot
.19066 .96663 Mdot
.11975 .92908 Mdot
.28749 .16774 Mdot
.3719 .08441 Mdot
.65334 .28144 Mdot
.84966 .19632 Mdot
.94868 .09902 Mdot
.40075 .45207 Mdot
.20223 .80148 Mdot
.93943 .7372 Mdot
.09044 .15101 Mdot
.64188 .55144 Mdot
.06005 .41818 Mdot
.06775 .0077 Mdot
.61538 .54763 Mdot
.90175 .28637 Mdot
.83303 .93128 Mdot
.7302 .89718 Mdot
.73286 .00266 Mdot
.84315 .11029 Mdot
.88209 .03894 Mdot
.67294 .79085 Mdot
.4498 .77687 Mdot
.88109 .43129 Mdot
.06944 .18835 Mdot
.78697 .71753 Mdot
.58866 .80169 Mdot
.97937 .39071 Mdot
.51411 .53474 Mdot
.14748 .63337 Mdot
.89002 .74253 Mdot
.34261 .45259 Mdot
.86447 .52186 Mdot
.22448 .36001 Mdot
.4847 .26022 Mdot
.63796 .15327 Mdot
.64049 .00253 Mdot
.50362 .86313 Mdot
.39213 .8885 Mdot
.58201 .18989 Mdot
.32093 .73891 Mdot
.05457 .73364 Mdot
.41366 .35909 Mdot
.19759 .78393 Mdot
.92729 .7297 Mdot
.14842 .22112 Mdot
.47478 .32637 Mdot
.62537 .15059 Mdot
.56559 .94022 Mdot
.95205 .38646 Mdot
.66912 .71708 Mdot
.3595 .69038 Mdot
.18925 .82975 Mdot
.98509 .79584 Mdot
.88514 .90005 Mdot
.52121 .63608 Mdot
.30535 .78414 Mdot
.0421 .73675 Mdot
.4876 .4455 Mdot
.84637 .35878 Mdot
.12115 .27477 Mdot
.62744 .50629 Mdot
.9335 .30606 Mdot
.69164 .75814 Mdot
.4898 .79816 Mdot
.21659 .72679 Mdot
.85376 .63716 Mdot
.37653 .52278 Mdot
.11915 .74262 Mdot
.10347 .98432 Mdot
.41345 .30998 Mdot
.14698 .73353 Mdot
.99179 .84482 Mdot
.89403 .90223 Mdot
.48446 .59043 Mdot
.96627 .48181 Mdot
.68241 .71614 Mdot
.41367 .73126 Mdot
.56984 .15617 Mdot
.19936 .62952 Mdot
.77071 .57136 Mdot
.44673 .67602 Mdot
.7568 .31007 Mdot
.17994 .42314 Mdot
.5952 .41526 Mdot
.63781 .04261 Mdot
.52896 .89115 Mdot
.62169 .09273 Mdot
.48565 .86396 Mdot
.24926 .76362 Mdot
.89881 .64954 Mdot
.20992 .31112 Mdot
.44209 .23216 Mdot
.5 .7 Mdot
.2 .7 Mdot
.84044 .64044 Mdot
.41987 .57943 Mdot
.46182 .04195 Mdot
.23906 .77724 Mdot
.90485 .66579 Mdot
.1977 .29285 Mdot
.43608 .23837 Mdot
.23891 .80283 Mdot
.93036 .69145 Mdot
.09388 .16351 Mdot
.6377 .54383 Mdot
.02961 .39191 Mdot
.21544 .18583 Mdot
.31335 .09791 Mdot
.38426 .07091 Mdot
.71451 .33026 Mdot
.13128 .41676 Mdot
.72981 .59854 Mdot
.43349 .70367 Mdot
.68502 .25153 Mdot
.95905 .27403 Mdot
.51657 .55752 Mdot
.18985 .67328 Mdot
.82767 .63782 Mdot
.44952 .62185 Mdot
.72393 .27441 Mdot
.09752 .37359 Mdot
.83039 .73287 Mdot
.53822 .70783 Mdot
.51103 .97281 Mdot
.56095 .04993 Mdot
.0272 .46625 Mdot
.30395 .27675 Mdot
.53001 .22606 Mdot
.96487 .43486 Mdot
.64367 .6788 Mdot
.19701 .55335 Mdot
.69745 .50044 Mdot
.25179 .55434 Mdot
.69212 .44033 Mdot
.17368 .48155 Mdot
.66682 .49314 Mdot
.12531 .45849 Mdot
.7945 .66919 Mdot
.53451 .74001 Mdot
.51421 .9797 Mdot
.59329 .07907 Mdot
.28863 .69534 Mdot
.90254 .61391 Mdot
.15682 .25428 Mdot
.48256 .32574 Mdot
.68649 .20392 Mdot
.91695 .23047 Mdot
.70273 .78578 Mdot
.55381 .85108 Mdot
.77441 .2206 Mdot
.09602 .32161 Mdot
.78555 .68953 Mdot
.56149 .77594 Mdot
.75724 .19575 Mdot
.06593 .30868 Mdot
.92621 .86028 Mdot
.28473 .35852 Mdot
.55558 .27085 Mdot
.20765 .65207 Mdot
.78484 .57719 Mdot
.44953 .66469 Mdot
.76681 .31728 Mdot
.19196 .42516 Mdot
.57629 .38433 Mdot
.47444 .89815 Mdot
.19446 .72002 Mdot
.86754 .67308 Mdot
.36444 .49689 Mdot
.02304 .6586 Mdot
.52093 .49789 Mdot
.16493 .644 Mdot
.85023 .6853 Mdot
.43588 .58565 Mdot
.58477 .14889 Mdot
.29939 .71462 Mdot
.95315 .65376 Mdot
.93015 .977 Mdot
.38055 .45039 Mdot
.07108 .69054 Mdot
.28041 .20933 Mdot
.39593 .11552 Mdot
.83376 .43783 Mdot
.23492 .40115 Mdot
.52699 .29207 Mdot
.00705 .48006 Mdot
.4378 .43075 Mdot
.44413 .00633 Mdot
.06733 .62321 Mdot
.23315 .16581 Mdot
.29111 .05797 Mdot
.27197 .98085 Mdot
.14933 .87736 Mdot
.12814 .97881 Mdot
.30378 .17564 Mdot
.42834 .12456 Mdot
.06808 .63974 Mdot
.24565 .17757 Mdot
.30954 .0639 Mdot
.33642 .02688 Mdot
.40947 .07305 Mdot
.88242 .47295 Mdot
.10557 .22315 Mdot
.64274 .53717 Mdot
.0504 .40767 Mdot
.11112 .06071 Mdot
.45568 .34456 Mdot
.49399 .03831 Mdot
.49027 .99628 Mdot
.4185 .92823 Mdot
.80085 .38235 Mdot
.2409 .44006 Mdot
.56869 .32779 Mdot
.36255 .79386 Mdot
.30947 .94692 Mdot
.2192 .90973 Mdot
.03564 .81644 Mdot
.60469 .56905 Mdot
.85483 .25014 Mdot
.986 .13117 Mdot
.21505 .22905 Mdot
.35677 .14172 Mdot
.62584 .26907 Mdot
.68685 .06101 Mdot
.7754 .08855 Mdot
.96387 .18847 Mdot
.40306 .43918 Mdot
.20485 .80179 Mdot
.93709 .73224 Mdot
.09835 .16126 Mdot
.61417 .51582 Mdot
.86238 .24821 Mdot
.95829 .09591 Mdot
.34284 .38455 Mdot
.79752 .45468 Mdot
.317 .51948 Mdot
.81965 .50265 Mdot
.3314 .51175 Mdot
.87163 .54023 Mdot
.21614 .34451 Mdot
.47169 .25554 Mdot
.53007 .05839 Mdot
.79772 .26765 Mdot
.12975 .33203 Mdot
.65085 .52111 Mdot
.07678 .42592 Mdot
.98587 .9091 Mdot
.99373 .00786 Mdot
.04544 .05171 Mdot
.78335 .7379 Mdot
.61097 .82762 Mdot
.15395 .54298 Mdot
.77965 .6257 Mdot
.50016 .72051 Mdot
.22179 .72163 Mdot
.84679 .625 Mdot
.38612 .53933 Mdot
.19461 .80848 Mdot
.95581 .7612 Mdot
.0224 .06659 Mdot
.9327 .9103 Mdot
.30017 .36746 Mdot
.60844 .30827 Mdot
.6184 .00996 Mdot
.38279 .76439 Mdot
.39886 .01608 Mdot
.75367 .3548 Mdot
.22226 .46859 Mdot
.59365 .37139 Mdot
.5834 .98975 Mdot
.13059 .54719 Mdot
.86284 .73226 Mdot
.4407 .57786 Mdot
.61301 .17231 Mdot
.51157 .89856 Mdot
.49103 .97946 Mdot
.4077 .91668 Mdot
.71391 .30621 Mdot
.10569 .39178 Mdot
.81081 .70512 Mdot
.54967 .73886 Mdot
.63063 .08095 Mdot
.52671 .89608 Mdot
.60887 .08217 Mdot
.39509 .78622 Mdot
.49898 .10389 Mdot
.59574 .09676 Mdot
.32297 .72724 Mdot
.05119 .72822 Mdot
.42721 .37601 Mdot
.31124 .88403 Mdot
.16265 .85141 Mdot
.0636 .90096 Mdot
.53109 .46749 Mdot
.21484 .68375 Mdot
.81158 .59674 Mdot
.44005 .62847 Mdot
.65874 .21869 Mdot
.81335 .1546 Mdot
.99495 .1816 Mdot
.21192 .21697 Mdot
.34655 .13463 Mdot
.56587 .21932 Mdot
.2332 .66734 Mdot
.79265 .55945 Mdot
.42642 .63376 Mdot
.56326 .13684 Mdot
.13137 .5681 Mdot
.88082 .74945 Mdot
.38872 .5079 Mdot
.17959 .79087 Mdot
.96363 .78404 Mdot
4e-05 .0364 Mdot
.03619 .03615 Mdot
.8212 .78502 Mdot
.61066 .78945 Mdot
.1138 .50314 Mdot
.88651 .77271 Mdot
.38802 .50152 Mdot
.16879 .78076 Mdot
.97739 .8086 Mdot
.94374 .96635 Mdot
.29578 .35204 Mdot
.5795 .28372 Mdot
.39686 .81736 Mdot
.54175 .14489 Mdot
.97554 .43379 Mdot
.57989 .60435 Mdot
.72026 .14038 Mdot
.95534 .23507 Mdot
.49896 .54363 Mdot
.03535 .53638 Mdot
.32633 .29099 Mdot
.62894 .3026 Mdot
.73856 .10963 Mdot
.9594 .22084 Mdot
.46136 .50196 Mdot
.69547 .23412 Mdot
.97893 .28345 Mdot
.40946 .43054 Mdot
.23987 .83041 Mdot
.95845 .71858 Mdot
.96461 .00617 Mdot
.21645 .25184 Mdot
.37887 .16241 Mdot
.77287 .39401 Mdot
.26948 .49661 Mdot
.66033 .39085 Mdot
.99308 .33275 Mdot
.37423 .38114 Mdot
.96378 .58955 Mdot
.80471 .84093 Mdot
.69455 .88984 Mdot
.63155 .937 Mdot
.38805 .7565 Mdot
.42395 .0359 Mdot
.94751 .52356 Mdot
.83188 .88437 Mdot
.68612 .85424 Mdot
.56592 .87979 Mdot
.89406 .32814 Mdot
.91024 .01618 Mdot
.52198 .61174 Mdot
.28707 .76509 Mdot
.96816 .68109 Mdot
.87063 .90246 Mdot
.58222 .71159 Mdot
.84407 .26186 Mdot
.031 .18693 Mdot
.0023 .9713 Mdot
.9575 .9552 Mdot
.20668 .24919 Mdot
.38279 .17611 Mdot
.81062 .42783 Mdot
.27269 .46207 Mdot
.63197 .35928 Mdot
.81279 .18081 Mdot
.02211 .20933 Mdot
.07716 .05505 Mdot
.61301 .53586 Mdot
.87513 .26212 Mdot
.92437 .04924 Mdot
.48332 .55895 Mdot
.9257 .44238 Mdot
.86951 .94381 Mdot
.6278 .75829 Mdot
.18763 .55983 Mdot
.71783 .5302 Mdot
.33943 .6216 Mdot
.01826 .67883 Mdot
.56952 .55126 Mdot
.59213 .0226 Mdot
.22421 .63208 Mdot
.7568 .53259 Mdot
.40246 .64566 Mdot
.4073 .00484 Mdot
.7993 .392 Mdot
.25236 .45306 Mdot
.59147 .3391 Mdot
.53616 .9447 Mdot
.73184 .19567 Mdot
.03434 .30251 Mdot
.09831 .06397 Mdot
.51703 .41871 Mdot
.05472 .53769 Mdot
.2169 .16218 Mdot
.289 .07211 Mdot
.28032 .99131 Mdot
.1777 .89738 Mdot
.07398 .89628 Mdot
.47083 .39685 Mdot
.66463 .1938 Mdot
.81604 .15141 Mdot
.987 .17096 Mdot
.24888 .26189 Mdot
.39671 .14783 Mdot
.87121 .4745 Mdot
.15202 .28081 Mdot
.52327 .37125 Mdot
.05685 .53358 Mdot
.20089 .14404 Mdot
.28346 .08257 Mdot
.27649 .99303 Mdot
.17083 .89434 Mdot
.0861 .91527 Mdot
.42764 .34154 Mdot
.27991 .85227 Mdot
.0377 .75779 Mdot
.53405 .49635 Mdot
.26697 .73292 Mdot
.89213 .62516 Mdot
.2159 .32377 Mdot
.45106 .23516 Mdot
.34903 .89797 Mdot
.3417 .99267 Mdot
.40013 .05843 Mdot
.80446 .40433 Mdot
.25828 .45382 Mdot
.59953 .34125 Mdot
.59295 .99342 Mdot
.20068 .60773 Mdot
.74739 .5467 Mdot
.40802 .66064 Mdot
.46007 .05205 Mdot
.23556 .77549 Mdot
.90154 .66598 Mdot
.2136 .31206 Mdot
.44058 .22698 Mdot
.26124 .82066 Mdot
.97059 .70935 Mdot
.88462 .91402 Mdot
.5374 .65279 Mdot
.44962 .91222 Mdot
.01506 .56544 Mdot
.47523 .46017 Mdot
.76272 .28749 Mdot
.16074 .39802 Mdot
.61535 .45461 Mdot
.80854 .1932 Mdot
.0413 .23276 Mdot
.9882 .9469 Mdot
.01764 .02944 Mdot
.92386 .90623 Mdot
.34294 .41908 Mdot
.83257 .48962 Mdot
.28969 .45713 Mdot
.6672 .37751 Mdot
.01138 .34418 Mdot
.27599 .26461 Mdot
.44133 .16534 Mdot
.2052 .76388 Mdot
.89883 .69363 Mdot
.25389 .35506 Mdot
.4952 .24131 Mdot
.7029 .2077 Mdot
.97626 .27336 Mdot
.41519 .43894 Mdot
.28819 .873 Mdot
.07903 .79084 Mdot
.33912 .26009 Mdot
.65526 .31614 Mdot
.89385 .23859 Mdot
.82161 .92776 Mdot
.75257 .93096 Mdot
.79747 .0449 Mdot
.90726 .10979 Mdot
.63009 .72283 Mdot
.16551 .53541 Mdot
.74018 .57467 Mdot
.42681 .68663 Mdot
.61895 .19215 Mdot
.56838 .94943 Mdot
.98187 .41349 Mdot
.52199 .54012 Mdot
0 .75 Mdot
.75 .75 Mdot
.61408 .86408 Mdot
.21011 .59602 Mdot
.72686 .51675 Mdot
.34594 .61908 Mdot
.04731 .70137 Mdot
.42237 .37506 Mdot
.27527 .85291 Mdot
.02812 .75284 Mdot
.58516 .55704 Mdot
.71029 .12513 Mdot
.915 .20471 Mdot
.68684 .77184 Mdot
.48619 .79935 Mdot
.18895 .70277 Mdot
.85859 .66964 Mdot
.3929 .5343 Mdot
.2328 .8399 Mdot
.96512 .73232 Mdot
.93965 .97453 Mdot
.32658 .38693 Mdot
.72593 .39935 Mdot
.22666 .50073 Mdot
.62526 .3986 Mdot
.81292 .18766 Mdot
.02873 .21581 Mdot
.04451 .01578 Mdot
.75276 .70825 Mdot
.57493 .82217 Mdot
.90244 .32751 Mdot
.87091 .96847 Mdot
.64715 .77624 Mdot
.31283 .66568 Mdot
.95011 .63728 Mdot
.93094 .98083 Mdot
.38016 .44922 Mdot
.06758 .68742 Mdot
.29601 .22842 Mdot
.45657 .16056 Mdot
.31686 .86029 Mdot
.15991 .84306 Mdot
.06264 .90273 Mdot
.5381 .47546 Mdot
.27772 .73962 Mdot
.92012 .64239 Mdot
.09851 .1784 Mdot
.63052 .53201 Mdot
.97715 .34663 Mdot
.48318 .50603 Mdot
.87172 .38853 Mdot
.06411 .1924 Mdot
.81976 .75565 Mdot
.58417 .76441 Mdot
.91072 .32655 Mdot
.82995 .91922 Mdot
.72563 .89568 Mdot
.72236 .99673 Mdot
.8164 .09405 Mdot
.92897 .11256 Mdot
.52242 .59345 Mdot
.2723 .74988 Mdot
.91901 .64671 Mdot
.10849 .18948 Mdot
.596 .4875 Mdot
.71546 .11947 Mdot
.92289 .20742 Mdot
.64923 .72634 Mdot
.27371 .62448 Mdot
.79645 .52274 Mdot
.38616 .58971 Mdot
.24522 .85906 Mdot
.9907 .74548 Mdot
.80123 .81053 Mdot
.66862 .86739 Mdot
.50761 .83899 Mdot
.39989 .89227 Mdot
.63669 .2368 Mdot
.71695 .08026 Mdot
.88737 .17042 Mdot
.78202 .89464 Mdot
.76828 .98626 Mdot
.86129 .09301 Mdot
.80694 .94565 Mdot
.79614 .9892 Mdot
.85294 .0568 Mdot
.79881 .94588 Mdot
.80678 .00797 Mdot
.85868 .05189 Mdot
.77486 .91618 Mdot
.79156 .0167 Mdot
.88458 .09302 Mdot
.71656 .83198 Mdot
.63813 .92157 Mdot
.40969 .77157 Mdot
.5825 .17281 Mdot
.30731 .72481 Mdot
.98949 .68218 Mdot
.74516 .75567 Mdot
.6144 .86924 Mdot
.21723 .60283 Mdot
.72951 .51228 Mdot
.34665 .61714 Mdot
.04891 .70226 Mdot
.41416 .36525 Mdot
.20724 .79308 Mdot
.9262 .71896 Mdot
.14343 .21722 Mdot
.48714 .34372 Mdot
.74096 .25381 Mdot
.10706 .3661 Mdot
.779 .67195 Mdot
.54659 .76758 Mdot
.63564 .08905 Mdot
.56333 .92769 Mdot
.92275 .35942 Mdot
.80192 .87917 Mdot
.73641 .93449 Mdot
.78093 .04452 Mdot
.91856 .13763 Mdot
.60171 .68315 Mdot
.94937 .34766 Mdot
.64548 .6961 Mdot
.22392 .57844 Mdot
.7032 .47928 Mdot
.24875 .54555 Mdot
.68026 .4315 Mdot
.12058 .44032 Mdot
.79531 .67474 Mdot
.53928 .74397 Mdot
.55546 .01617 Mdot
.95204 .39658 Mdot
.67929 .72725 Mdot
.41245 .73317 Mdot
.56324 .15079 Mdot
.14518 .58194 Mdot
.84604 .70086 Mdot
.46423 .61819 Mdot
.8341 .36987 Mdot
.16611 .33201 Mdot
.53525 .36914 Mdot
.14914 .61389 Mdot
.86527 .71614 Mdot
.41583 .55055 Mdot
.40427 .98844 Mdot
.76228 .35801 Mdot
.23106 .46878 Mdot
.59364 .36257 Mdot
.5745 .98086 Mdot
.05801 .48351 Mdot
.1444 .08639 Mdot
.35308 .20868 Mdot
.67327 .32019 Mdot
.98057 .30729 Mdot
.42357 .443 Mdot
.35185 .92829 Mdot
.38651 .03466 Mdot
.69235 .30585 Mdot
.04 .34764 Mdot
.11061 .07061 Mdot
.46781 .3572 Mdot
.60117 .13337 Mdot
.39602 .79485 Mdot
.51371 .11769 Mdot
.72724 .21353 Mdot
.04348 .31624 Mdot
.05915 .01567 Mdot
.67023 .61108 Mdot
.25838 .58815 Mdot
.73399 .47561 Mdot
.31805 .58406 Mdot
.88833 .57028 Mdot
.17771 .28938 Mdot
.46596 .28825 Mdot
.51775 .05179 Mdot
.69355 .17579 Mdot
.91407 .22052 Mdot
.7073 .79323 Mdot
.57476 .86746 Mdot
.94653 .37177 Mdot
.68556 .73903 Mdot
.44861 .76304 Mdot
.85813 .40952 Mdot
.13435 .27622 Mdot
.57789 .44354 Mdot
.54516 .96727 Mdot
.82434 .27918 Mdot
.09826 .27392 Mdot
.72722 .62896 Mdot
.45887 .73165 Mdot
.90582 .44695 Mdot
.97422 .0684 Mdot
.22229 .24807 Mdot
.37312 .15083 Mdot
.72694 .35381 Mdot
.18316 .45622 Mdot
.62211 .43896 Mdot
.83443 .21231 Mdot
.00771 .17329 Mdot
.12702 .1193 Mdot
.44862 .3216 Mdot
.41674 .96812 Mdot
.82826 .41152 Mdot
.22188 .39362 Mdot
.51876 .29688 Mdot
.94667 .42791 Mdot
.74094 .79427 Mdot
.64749 .90655 Mdot
.44493 .79744 Mdot
.86455 .41961 Mdot
.12194 .25739 Mdot
.60684 .4849 Mdot
.78472 .17788 Mdot
.05028 .26556 Mdot
.96972 .91944 Mdot
.09985 .13013 Mdot
.57599 .47614 Mdot
.56405 .98807 Mdot
.98849 .42443 Mdot
.49344 .50495 Mdot
.95246 .45902 Mdot
.73934 .78688 Mdot
.63782 .89847 Mdot
.38488 .74706 Mdot
.39456 .00968 Mdot
.71901 .32444 Mdot
.13647 .41747 Mdot
.71147 .575 Mdot
.36806 .65659 Mdot
.2033 .83524 Mdot
.97207 .76877 Mdot
.93535 .96328 Mdot
.33885 .4035 Mdot
.79738 .45854 Mdot
.321 .52361 Mdot
.83954 .51855 Mdot
.30045 .46091 Mdot
.70279 .40233 Mdot
.17054 .46776 Mdot
.6602 .48965 Mdot
.09124 .43104 Mdot
.91802 .82678 Mdot
.29363 .37562 Mdot
.59677 .30313 Mdot
.5363 .93953 Mdot
.72775 .19145 Mdot
.02241 .29466 Mdot
.16074 .13834 Mdot
.35565 .19491 Mdot
.67306 .31741 Mdot
.97688 .30382 Mdot
.44196 .46508 Mdot
.50973 .06777 Mdot
.64555 .13582 Mdot
.66404 .01849 Mdot
.63804 .974 Mdot
.46168 .82363 Mdot
.01962 .55794 Mdot
.44059 .42097 Mdot
.45525 .01466 Mdot
.16074 .70549 Mdot
.92281 .76207 Mdot
.20425 .28144 Mdot
.41731 .21306 Mdot
.07726 .65994 Mdot
.21739 .14013 Mdot
.26674 .04935 Mdot
.20817 .94143 Mdot
.07377 .8656 Mdot
.44127 .3675 Mdot
.40695 .96567 Mdot
.75772 .35077 Mdot
.22127 .46355 Mdot
.58884 .36757 Mdot
.54647 .95764 Mdot
.82481 .27834 Mdot
.09641 .2716 Mdot
.73367 .63726 Mdot
.47916 .74549 Mdot
.07918 .60002 Mdot
.14751 .06833 Mdot
.32487 .17736 Mdot
.50916 .18429 Mdot
.75756 .24839 Mdot
.11878 .36122 Mdot
.7236 .60482 Mdot
.42723 .70362 Mdot
.639 .21178 Mdot
.70473 .06573 Mdot
.83979 .13506 Mdot
.91628 .07649 Mdot
.55215 .63586 Mdot
.54653 .99438 Mdot
.862 .31547 Mdot
.0269 .1649 Mdot
.00441 .97751 Mdot
.95107 .94666 Mdot
.23487 .2838 Mdot
.40962 .17475 Mdot
.98515 .57553 Mdot
.66449 .67935 Mdot
.30097 .63648 Mdot
.88003 .57905 Mdot
.22159 .34156 Mdot
.46677 .24518 Mdot
.48102 .01425 Mdot
.36268 .88167 Mdot
.39803 .03535 Mdot
.76742 .36939 Mdot
.24423 .47681 Mdot
.60769 .36346 Mdot
.66873 .06104 Mdot
.70173 .033 Mdot
.79798 .09624 Mdot
.95807 .1601 Mdot
.40829 .45022 Mdot
.25148 .84319 Mdot
.98064 .72916 Mdot
.84499 .86435 Mdot
.63083 .78584 Mdot
.23274 .60191 Mdot
.72711 .49438 Mdot
.32408 .59696 Mdot
.92546 .60139 Mdot
.02974 .10428 Mdot
.92703 .89729 Mdot
.31738 .39035 Mdot
.692 .37462 Mdot
.10753 .41554 Mdot
.82631 .71878 Mdot
.53354 .70723 Mdot
.47383 .94029 Mdot
.23172 .7579 Mdot
.88287 .65115 Mdot
.28188 .39901 Mdot
.58908 .3072 Mdot
.48779 .89871 Mdot
.30108 .81329 Mdot
.05717 .75609 Mdot
.42161 .36444 Mdot
.25927 .83765 Mdot
.98472 .72546 Mdot
.81695 .83222 Mdot
.66614 .84919 Mdot
.47829 .81216 Mdot
.13897 .66068 Mdot
.94584 .80687 Mdot
.12454 .1787 Mdot
.51773 .39319 Mdot
.03477 .51704 Mdot
.31034 .27557 Mdot
.55094 .2406 Mdot
.1421 .59116 Mdot
.86554 .72343 Mdot
.42217 .55663 Mdot
.45543 .03326 Mdot
.18075 .72532 Mdot
.8958 .71505 Mdot
.28926 .39347 Mdot
.60237 .31311 Mdot
.58369 .98132 Mdot
.1242 .54051 Mdot
.8809 .75669 Mdot
.39565 .51475 Mdot
.23115 .83551 Mdot
.96038 .72922 Mdot
.9641 .00372 Mdot
.217 .2529 Mdot
.37968 .16268 Mdot
.77806 .39839 Mdot
.27326 .4952 Mdot
.66625 .39299 Mdot
.0226 .35635 Mdot
.22128 .19868 Mdot
.32396 .10269 Mdot
.43072 .10676 Mdot
.06768 .63696 Mdot
.24504 .17736 Mdot
.30885 .06382 Mdot
.3339 .02504 Mdot
.3961 .0622 Mdot
.78157 .38547 Mdot
.25928 .47771 Mdot
.6248 .36552 Mdot
.77708 .15228 Mdot
.02736 .25028 Mdot
.08707 .05971 Mdot
.56725 .48018 Mdot
.50429 .93704 Mdot
.47133 .96705 Mdot
.23879 .76746 Mdot
.89492 .65613 Mdot
.23432 .3394 Mdot
.46503 .23072 Mdot
.45296 .98792 Mdot
.11638 .66342 Mdot
.03584 .91946 Mdot
.70654 .67071 Mdot
.45006 .74352 Mdot
.84974 .39968 Mdot
.15179 .30204 Mdot
.5 .75 Mdot
.25 .75 Mdot
.88592 .63592 Mdot
.25377 .36785 Mdot
.50785 .25408 Mdot
.81687 .30902 Mdot
.14308 .32621 Mdot
.5973 .45423 Mdot
.691 .0937 Mdot
.8231 .1321 Mdot
.95382 .13072 Mdot
.40326 .44944 Mdot
.21646 .8132 Mdot
.94022 .72376 Mdot
.07265 .13243 Mdot
.714 .64135 Mdot
.44105 .72705 Mdot
.76484 .32379 Mdot
.19787 .43303 Mdot
.57604 .37817 Mdot
.46649 .89045 Mdot
.12411 .65762 Mdot
.99837 .87425 Mdot
.88406 .8857 Mdot
.51143 .62736 Mdot
.21871 .70728 Mdot
.83337 .61466 Mdot
.41274 .57937 Mdot
.4114 .99867 Mdot
.82143 .41003 Mdot
.2352 .41377 Mdot
.5397 .3045 Mdot
.11922 .57952 Mdot
.94008 .82086 Mdot
.17053 .23044 Mdot
.42292 .2524 Mdot
.15661 .73369 Mdot
.96257 .80595 Mdot
.02815 .06558 Mdot
.89772 .86957 Mdot
.43499 .53727 Mdot
.52974 .09475 Mdot
.83148 .30174 Mdot
.10447 .27299 Mdot
.69758 .59311 Mdot
.34489 .64731 Mdot
.07034 .72545 Mdot
.31927 .24892 Mdot
.55796 .2387 Mdot
.1935 .63553 Mdot
.78442 .59093 Mdot
.46348 .67906 Mdot
.88911 .42563 Mdot
.02967 .14056 Mdot
.96373 .93405 Mdot
.14951 .18578 Mdot
.43601 .2865 Mdot
.28653 .85052 Mdot
.05218 .76565 Mdot
.45906 .40687 Mdot
.58249 .12343 Mdot
.25782 .67533 Mdot
.82042 .56259 Mdot
.38982 .5694 Mdot
.24811 .85829 Mdot
.9924 .74429 Mdot
.78988 .79748 Mdot
.66665 .87677 Mdot
.50821 .84156 Mdot
.40723 .89902 Mdot
.69299 .28577 Mdot
.02214 .32915 Mdot
.1968 .17466 Mdot
.31904 .12223 Mdot
.43036 .11133 Mdot
.06965 .63928 Mdot
.23681 .16716 Mdot
.29371 .0569 Mdot
.27828 .98457 Mdot
.16632 .88803 Mdot
.09075 .92443 Mdot
.4138 .32305 Mdot
.16249 .7487 Mdot
.9613 .79881 Mdot
.02833 .06703 Mdot
.89809 .86976 Mdot
.43345 .53536 Mdot
.51642 .08297 Mdot
.71413 .19771 Mdot
.99775 .28362 Mdot
.29714 .29939 Mdot
.53095 .23381 Mdot
.98001 .44907 Mdot
.56862 .58861 Mdot
.62285 .05423 Mdot
.45416 .8313 Mdot
.96898 .51483 Mdot
.69955 .73057 Mdot
.48871 .78916 Mdot
.19893 .71022 Mdot
.85193 .653 Mdot
.39824 .54631 Mdot
.27979 .88155 Mdot
.0667 .78692 Mdot
.40025 .33355 Mdot
.0804 .68014 Mdot
.2214 .141 Mdot
.26626 .04486 Mdot
.20284 .93658 Mdot
.07389 .87105 Mdot
.44609 .3722 Mdot
.44812 .00203 Mdot
.09336 .64525 Mdot
.12191 .02854 Mdot
.37813 .25622 Mdot
.86223 .4841 Mdot
.19472 .33249 Mdot
.47966 .28494 Mdot
.62259 .14293 Mdot
.54127 .91868 Mdot
.74561 .20434 Mdot
.06361 .318 Mdot
.94812 .88451 Mdot
.1894 .24128 Mdot
.39639 .20699 Mdot
.92823 .53185 Mdot
.9456 .01736 Mdot
.33641 .39081 Mdot
.77335 .43694 Mdot
.3124 .53906 Mdot
.82192 .50952 Mdot
.33369 .51177 Mdot
.8819 .54821 Mdot
.18299 .30109 Mdot
.46729 .28429 Mdot
.5242 .05691 Mdot
.74985 .22565 Mdot
.08959 .33974 Mdot
.83479 .7452 Mdot
.53967 .70488 Mdot
.51941 .97974 Mdot
.63469 .11528 Mdot
.58425 .94955 Mdot
.09639 .51214 Mdot
.97431 .87793 Mdot
.03127 .05696 Mdot
.87073 .83946 Mdot
.51881 .64808 Mdot
.29825 .77944 Mdot
.01442 .71617 Mdot
.62978 .61536 Mdot
.0562 .42642 Mdot
.09737 .04117 Mdot
.49869 .40133 Mdot
.89087 .39218 Mdot
.98849 .09762 Mdot
.16662 .17814 Mdot
.38009 .21346 Mdot
.83135 .45126 Mdot
.25431 .42296 Mdot
.56358 .30928 Mdot
.3062 .74262 Mdot
.00348 .69727 Mdot
.67642 .67295 Mdot
.34652 .67009 Mdot
.10118 .75466 Mdot
.19434 .09317 Mdot
.24085 .04651 Mdot
.17512 .93426 Mdot
.11635 .94123 Mdot
.31376 .19741 Mdot
.4853 .17154 Mdot
.55406 .06876 Mdot
.99401 .43995 Mdot
.47587 .48185 Mdot
.78943 .31356 Mdot
.18306 .39363 Mdot
.5597 .37664 Mdot
.34452 .78482 Mdot
.20602 .8615 Mdot
.9957 .78968 Mdot
.81547 .81977 Mdot
.65638 .84091 Mdot
.42413 .76775 Mdot
.68071 .25658 Mdot
.94746 .26675 Mdot
.57534 .62788 Mdot
.7111 .13576 Mdot
.92784 .21674 Mdot
.63256 .70472 Mdot
.16157 .52901 Mdot
.74409 .58252 Mdot
.43993 .69584 Mdot
.72519 .28526 Mdot
.11104 .38585 Mdot
.78114 .6701 Mdot
.54407 .76293 Mdot
.61156 .06749 Mdot
.39758 .78601 Mdot
.51509 .11752 Mdot
.73809 .223 Mdot
.07205 .33396 Mdot
.91872 .84667 Mdot
.30994 .39122 Mdot
.66516 .35522 Mdot
.97989 .31473 Mdot
.435 .4551 Mdot
.44763 .01264 Mdot
.10029 .65266 Mdot
.09646 .99617 Mdot
.45799 .36152 Mdot
.52881 .07083 Mdot
.80023 .27142 Mdot
.13071 .33048 Mdot
.64567 .51497 Mdot
.04383 .39815 Mdot
.13905 .09522 Mdot
.38012 .24108 Mdot
.85917 .47905 Mdot
.20034 .34117 Mdot
.48122 .28089 Mdot
.63098 .14976 Mdot
.59754 .96656 Mdot
.20493 .60739 Mdot
.74261 .53768 Mdot
.39317 .65056 Mdot
.35083 .95766 Mdot
.41062 .05979 Mdot
.87713 .46651 Mdot
.1208 .24368 Mdot
.59774 .47694 Mdot
.71666 .11892 Mdot
.92532 .20866 Mdot
.63775 .71243 Mdot
.1985 .56074 Mdot
.70298 .50449 Mdot
.27329 .57031 Mdot
.74141 .46813 Mdot
.322 .58059 Mdot
.90059 .57858 Mdot
.13069 .2301 Mdot
.54537 .41468 Mdot
.27336 .72799 Mdot
.89924 .62588 Mdot
.18426 .28502 Mdot
.44889 .26463 Mdot
.36189 .913 Mdot
.42496 .06307 Mdot
.98201 .55705 Mdot
.66472 .68272 Mdot
.3054 .64067 Mdot
.89879 .59339 Mdot
.15386 .25507 Mdot
.492 .33814 Mdot
.7742 .28219 Mdot
.15762 .38343 Mdot
.60942 .45179 Mdot
.7682 .15878 Mdot
.03379 .26559 Mdot
.06464 .03085 Mdot
.65537 .59073 Mdot
.16897 .5136 Mdot
.70979 .54083 Mdot
.32935 .61955 Mdot
.97042 .64107 Mdot
.81738 .84696 Mdot
.68007 .8627 Mdot
.55103 .87096 Mdot
.77314 .22211 Mdot
.09758 .32444 Mdot
.78096 .68338 Mdot
.55741 .77645 Mdot
.7271 .16968 Mdot
.99935 .27225 Mdot
.27614 .27679 Mdot
.45384 .1777 Mdot
.31289 .85905 Mdot
.14371 .83082 Mdot
.09979 .95608 Mdot
.4022 .30241 Mdot
.06229 .66009 Mdot
.29741 .23512 Mdot
.46751 .1701 Mdot
.41175 .94424 Mdot
.76943 .35768 Mdot
.23291 .46347 Mdot
.58871 .35581 Mdot
.53384 .94513 Mdot
.71407 .18023 Mdot
.98012 .26605 Mdot
.38495 .40483 Mdot
.05276 .66781 Mdot
.35796 .30519 Mdot
.7957 .43774 Mdot
.30191 .50622 Mdot
.75279 .45087 Mdot
.31757 .56479 Mdot
.86719 .54962 Mdot
.24228 .37509 Mdot
.5046 .26232 Mdot
.79911 .29451 Mdot
.15509 .35597 Mdot
.58928 .4342 Mdot
.6162 .02692 Mdot
.38616 .76996 Mdot
.42549 .03932 Mdot
.96205 .53657 Mdot
.76174 .79968 Mdot
.67248 .91074 Mdot
.56773 .89526 Mdot
.92295 .35522 Mdot
.79669 .87374 Mdot
.73692 .94023 Mdot
.78747 .05055 Mdot
.92137 .13391 Mdot
.58355 .66218 Mdot
.80409 .22054 Mdot
.07499 .2709 Mdot
.84017 .76518 Mdot
.54537 .7052 Mdot
.56388 .01851 Mdot
.01765 .45377 Mdot
.34812 .33047 Mdot
.7696 .42148 Mdot
.29673 .52713 Mdot
.75744 .46072 Mdot
.33103 .57358 Mdot
.93181 .60079 Mdot
.99543 .06362 Mdot
.09102 .09558 Mdot
.58365 .49263 Mdot
.6352 .05156 Mdot
.52339 .88819 Mdot
.57473 .05134 Mdot
.13019 .55546 Mdot
.8726 .74241 Mdot
.41458 .54198 Mdot
.38691 .97233 Mdot
.63256 .24565 Mdot
.70249 .06993 Mdot
.83725 .13475 Mdot
.92284 .0856 Mdot
.52764 .6048 Mdot
.32492 .79728 Mdot
.12929 .80437 Mdot
.12494 .99565 Mdot
.33311 .20817 Mdot
.57567 .24256 Mdot
.32821 .75254 Mdot
.09848 .77027 Mdot
.22254 .12406 Mdot
.24906 .02652 Mdot
.16151 .91245 Mdot
.12769 .96618 Mdot
.2929 .16522 Mdot
.38427 .09136 Mdot
.73502 .35076 Mdot
.19493 .45991 Mdot
.60678 .41185 Mdot
.71128 .1045 Mdot
.89707 .18578 Mdot
.75419 .85713 Mdot
.72502 .97082 Mdot
.79623 .07121 Mdot
.93486 .13863 Mdot
.51686 .582 Mdot
.21663 .69977 Mdot
.82672 .61009 Mdot
.42394 .59723 Mdot
.50881 .08486 Mdot
.6553 .14649 Mdot
.72441 .06911 Mdot
.89324 .16883 Mdot
.7546 .86137 Mdot
.72959 .97498 Mdot
.80951 .07992 Mdot
.92654 .11704 Mdot
.53972 .61318 Mdot
.42807 .88835 Mdot
.82989 .40182 Mdot
.20836 .37847 Mdot
.51066 .3023 Mdot
.8875 .37684 Mdot
.98789 .10039 Mdot
.17298 .1851 Mdot
.37191 .19893 Mdot
.76792 .39601 Mdot
.27096 .50304 Mdot
.66957 .3986 Mdot
.04299 .37342 Mdot
.11912 .07613 Mdot
.43711 .31799 Mdot
.32624 .88913 Mdot
.22667 .90043 Mdot
.02497 .7983 Mdot
.64921 .62425 Mdot
.17152 .52231 Mdot
.71247 .54095 Mdot
.33667 .6242 Mdot
.00796 .67128 Mdot
.62355 .6156 Mdot
0 .8 Mdot
.8 .8 Mdot
.65956 .85956 Mdot
.4581 .79855 Mdot
.96675 .50865 Mdot
.70644 .73969 Mdot
.51875 .81231 Mdot
.46198 .94323 Mdot
.14159 .67961 Mdot
.95574 .81415 Mdot
.07573 .11999 Mdot
.68538 .60965 Mdot
.31855 .63317 Mdot
.93938 .62083 Mdot
.97435 .03496 Mdot
.18811 .21376 Mdot
.37097 .18286 Mdot
.74636 .37539 Mdot
.23555 .48919 Mdot
.61524 .37969 Mdot
.73294 .1177 Mdot
.95834 .2254 Mdot
.47204 .5137 Mdot
.79105 .31901 Mdot
.18729 .39624 Mdot
.55481 .36752 Mdot
.29846 .74365 Mdot
.97929 .68083 Mdot
.80468 .82539 Mdot
.67905 .87437 Mdot
.55862 .87957 Mdot
.83934 .28072 Mdot
.06317 .22383 Mdot
.85631 .79314 Mdot
.5241 .66779 Mdot
.35991 .83581 Mdot
.33691 .977 Mdot
.36183 .02493 Mdot
.53658 .17474 Mdot
.96511 .42853 Mdot
.63594 .67084 Mdot
.14681 .51087 Mdot
.76968 .62287 Mdot
.49813 .72845 Mdot
.21348 .71535 Mdot
.84395 .63047 Mdot
.39998 .55603 Mdot
.30102 .90104 Mdot
.14473 .84371 Mdot
.10929 .96456 Mdot
.36754 .25825 Mdot
.80194 .4344 Mdot
.29163 .48969 Mdot
.70512 .4135 Mdot
.1887 .48358 Mdot
.63981 .4511 Mdot
.94848 .30867 Mdot
.61152 .66304 Mdot
.99289 .38137 Mdot
.42399 .43109 Mdot
.34297 .91899 Mdot
.33262 .98965 Mdot
.35498 .02236 Mdot
.49695 .14197 Mdot
.61756 .12061 Mdot
.48825 .87069 Mdot
.27674 .7885 Mdot
.96685 .69011 Mdot
.88733 .92048 Mdot
.53227 .64494 Mdot
.40152 .86925 Mdot
.62456 .22305 Mdot
.63323 .00866 Mdot
.46933 .8361 Mdot
.09207 .62274 Mdot
.10567 .0136 Mdot
.43274 .32707 Mdot
.30291 .87017 Mdot
.12 .81708 Mdot
.17446 .05446 Mdot
.23799 .06353 Mdot
.19061 .95262 Mdot
.10581 .9152 Mdot
.3337 .22788 Mdot
.59803 .26433 Mdot
.50598 .90795 Mdot
.45578 .9498 Mdot
.09998 .6442 Mdot
.08945 .98947 Mdot
.4852 .39575 Mdot
.7775 .2923 Mdot
.16729 .3898 Mdot
.59008 .42278 Mdot
.61028 .0202 Mdot
.34211 .73184 Mdot
.14131 .7992 Mdot
.07626 .93495 Mdot
.49757 .42131 Mdot
.90191 .40434 Mdot
.95021 .04829 Mdot
.34139 .39118 Mdot
.79716 .45577 Mdot
.31846 .5213 Mdot
.82718 .50872 Mdot
.32154 .49436 Mdot
.81246 .49093 Mdot
.33277 .52031 Mdot
.8863 .55353 Mdot
.16974 .28345 Mdot
.47778 .30803 Mdot
.63075 .15297 Mdot
.59944 .96869 Mdot
.21983 .62039 Mdot
.74609 .52626 Mdot
.3861 .64001 Mdot
.29511 .90901 Mdot
.13449 .83938 Mdot
.14054 .00605 Mdot
.28576 .14521 Mdot
.34489 .05913 Mdot
.48214 .13725 Mdot
.49461 .01247 Mdot
.46932 .97472 Mdot
.23063 .76131 Mdot
.8861 .65546 Mdot
.27254 .38644 Mdot
.55605 .28351 Mdot
.22383 .66779 Mdot
.79256 .56872 Mdot
.43577 .64321 Mdot
.6415 .20573 Mdot
.7123 .0708 Mdot
.86607 .15377 Mdot
.85055 .98448 Mdot
.73407 .88352 Mdot
.7261 .99203 Mdot
.81967 .09357 Mdot
.92227 .1026 Mdot
.54759 .62532 Mdot
.50113 .95353 Mdot
.46256 .96143 Mdot
.16432 .70176 Mdot
.90957 .74525 Mdot
.25431 .34474 Mdot
.48537 .23106 Mdot
.61414 .12878 Mdot
.47516 .86102 Mdot
.16303 .68787 Mdot
.89905 .73602 Mdot
.29528 .39623 Mdot
.62221 .32693 Mdot
.72302 .1008 Mdot
.92193 .19891 Mdot
.64569 .72376 Mdot
.2527 .60701 Mdot
.74578 .49309 Mdot
.35256 .60678 Mdot
.06869 .71613 Mdot
.31878 .25009 Mdot
.55719 .23842 Mdot
.18741 .63021 Mdot
.78859 .60119 Mdot
.47127 .68268 Mdot
.95394 .48267 Mdot
.75455 .80061 Mdot
.6688 .91424 Mdot
.55523 .88643 Mdot
.82056 .26533 Mdot
.09226 .2717 Mdot
.75369 .66142 Mdot
.5289 .77521 Mdot
.50527 .97637 Mdot
.51849 .01323 Mdot
.6609 .1424 Mdot
.7473 .0864 Mdot
.94762 .20032 Mdot
.50801 .56039 Mdot
.12445 .61644 Mdot
.95583 .83137 Mdot
.09246 .13663 Mdot
.61769 .52523 Mdot
.89368 .276 Mdot
.85977 .96609 Mdot
.6853 .82553 Mdot
.53411 .84882 Mdot
.61991 .08579 Mdot
.46787 .84797 Mdot
.09248 .62461 Mdot
.10554 .01306 Mdot
.43278 .32724 Mdot
.30335 .87057 Mdot
.12186 .81851 Mdot
.16828 .04642 Mdot
.24427 .07599 Mdot
.2069 .96263 Mdot
.09604 .88914 Mdot
.35295 .2569 Mdot
.72082 .36787 Mdot
.18411 .46329 Mdot
.62743 .44332 Mdot
.87047 .24304 Mdot
.92339 .05292 Mdot
.49211 .56872 Mdot
.00561 .5135 Mdot
.47984 .47423 Mdot
.81335 .33351 Mdot
.17384 .36049 Mdot
.54538 .37154 Mdot
.23028 .6849 Mdot
.80964 .57936 Mdot
.42577 .61613 Mdot
.54093 .11516 Mdot
.93943 .39851 Mdot
.75174 .81231 Mdot
.67807 .92632 Mdot
.6066 .92854 Mdot
.22681 .6202 Mdot
.74474 .51793 Mdot
.37614 .6314 Mdot
.22541 .84928 Mdot
.97387 .74846 Mdot
.90441 .93054 Mdot
.46457 .56016 Mdot
.77873 .31417 Mdot
.18888 .41014 Mdot
.56609 .37721 Mdot
.39276 .82667 Mdot
.52425 .1315 Mdot
.82486 .30061 Mdot
.11857 .2937 Mdot
.65698 .53841 Mdot
.12453 .46755 Mdot
.80664 .68211 Mdot
.53303 .72639 Mdot
.48896 .95593 Mdot
.36766 .8787 Mdot
.42308 .05542 Mdot
.96076 .53769 Mdot
.77033 .80957 Mdot
.68491 .91458 Mdot
.62168 .93678 Mdot
.32966 .70797 Mdot
.0602 .73054 Mdot
.37933 .31914 Mdot
.93244 .55311 Mdot
.94438 .01194 Mdot
.33778 .39339 Mdot
.78226 .44449 Mdot
.31802 .53576 Mdot
.83992 .52189 Mdot
.30277 .46286 Mdot
.71223 .40946 Mdot
.20455 .49232 Mdot
.6279 .42336 Mdot
.85329 .22538 Mdot
.96627 .11299 Mdot
.3136 .34733 Mdot
.63461 .32101 Mdot
.7895 .15489 Mdot
.02434 .23484 Mdot
.08948 .06514 Mdot
.56076 .47128 Mdot
.4471 .88634 Mdot
.96996 .52286 Mdot
.70185 .73189 Mdot
.49721 .79537 Mdot
.27308 .77587 Mdot
.94656 .67348 Mdot
.98715 .0406 Mdot
.11759 .13044 Mdot
.49778 .38019 Mdot
.86242 .36464 Mdot
.07459 .21218 Mdot
.78353 .70894 Mdot
.58192 .79839 Mdot
.92877 .34685 Mdot
.75776 .82899 Mdot
.69952 .94175 Mdot
.69977 .00026 Mdot
.7591 .05932 Mdot
.93069 .17159 Mdot
.57228 .64159 Mdot
.70261 .13033 Mdot
.89799 .19539 Mdot
.75953 .86153 Mdot
.73315 .97362 Mdot
.81461 .08147 Mdot
.91961 .10499 Mdot
.56373 .64412 Mdot
.64211 .07838 Mdot
.58826 .94615 Mdot
.12105 .53279 Mdot
.88586 .76481 Mdot
.3829 .49703 Mdot
.1322 .7493 Mdot
.05892 .92672 Mdot
.58257 .52365 Mdot
.65863 .07606 Mdot
.67015 .01152 Mdot
.65845 .9883 Mdot
.58155 .9231 Mdot
.05087 .46932 Mdot
.17013 .11926 Mdot
.31268 .14255 Mdot
.42642 .11374 Mdot
.04322 .61681 Mdot
.36117 .31795 Mdot
.82595 .46478 Mdot
.28035 .4544 Mdot
.64085 .3605 Mdot
.86355 .2227 Mdot
.92863 .06508 Mdot
.47674 .54811 Mdot
.86257 .38583 Mdot
.09525 .23268 Mdot
.70029 .60505 Mdot
.36553 .66524 Mdot
.19753 .832 Mdot
.97544 .77791 Mdot
.92457 .94913 Mdot
.38216 .45759 Mdot
.08821 .70605 Mdot
.20791 .11969 Mdot
.25225 .04435 Mdot
.18263 .93037 Mdot
.09725 .91462 Mdot
.37269 .27544 Mdot
.849 .47631 Mdot
.23071 .38171 Mdot
.50651 .2758 Mdot
.82785 .32134 Mdot
.13264 .30479 Mdot
.61277 .48014 Mdot
.8179 .20513 Mdot
.03725 .21936 Mdot
.9982 .96095 Mdot
.97173 .97352 Mdot
.14212 .17039 Mdot
.44472 .3026 Mdot
.36809 .92337 Mdot
.47025 .10216 Mdot
.36535 .8951 Mdot
.4264 .06105 Mdot
.9904 .56401 Mdot
.62154 .63114 Mdot
.02316 .40161 Mdot
.26325 .24009 Mdot
.39312 .12987 Mdot
.82978 .43666 Mdot
.24347 .4137 Mdot
.54402 .30055 Mdot
.1488 .60478 Mdot
.85724 .70844 Mdot
.43629 .57905 Mdot
.58118 .14489 Mdot
.27004 .68886 Mdot
.85363 .58359 Mdot
.32335 .46972 Mdot
.79524 .47189 Mdot
.3365 .54126 Mdot
.92423 .58773 Mdot
.02253 .0983 Mdot
.96365 .94112 Mdot
.15703 .19339 Mdot
.42106 .26403 Mdot
.15488 .73382 Mdot
.96774 .81286 Mdot
.00489 .03715 Mdot
.00781 .00292 Mdot
.95607 .94826 Mdot
.20793 .25186 Mdot
.3844 .17647 Mdot
.82095 .43655 Mdot
.26271 .44176 Mdot
.59394 .33123 Mdot
.54522 .95128 Mdot
.80877 .26355 Mdot
.11131 .30254 Mdot
.69666 .58534 Mdot
.33409 .63744 Mdot
.00937 .67527 Mdot
.61911 .60975 Mdot
.98698 .36786 Mdot
.44589 .45891 Mdot
.5333 .08741 Mdot
.85211 .31881 Mdot
.06348 .21138 Mdot
.84217 .77868 Mdot
.55329 .71112 Mdot
.63052 .07723 Mdot
.52235 .89183 Mdot
.5701 .04775 Mdot
.09284 .52274 Mdot
.00194 .9091 Mdot
.89748 .89554 Mdot
.46206 .56458 Mdot
.76358 .30152 Mdot
.17513 .41155 Mdot
.59361 .41847 Mdot
.63019 .03658 Mdot
.4798 .84961 Mdot
.5 .8 Mdot
.3 .8 Mdot
.04044 .74044 Mdot
.50082 .46038 Mdot
.96697 .46615 Mdot
.66266 .69568 Mdot
.30882 .64617 Mdot
.91614 .60732 Mdot
.08367 .16753 Mdot
.6921 .60843 Mdot
.34171 .64961 Mdot
.05714 .71543 Mdot
.38114 .324 Mdot
.94832 .56718 Mdot
.87092 .9226 Mdot
.60122 .73029 Mdot
.99323 .39201 Mdot
.43261 .43938 Mdot
.41422 .98161 Mdot
.82402 .4098 Mdot
.22957 .40555 Mdot
.5302 .30063 Mdot
.04096 .51076 Mdot
.26813 .22717 Mdot
.38844 .12031 Mdot
.79024 .4018 Mdot
.2707 .48046 Mdot
.64649 .37579 Mdot
.90895 .26246 Mdot
.77455 .8656 Mdot
.74101 .96646 Mdot
.81977 .07876 Mdot
.90728 .08751 Mdot
.60776 .70048 Mdot
.00621 .39845 Mdot
.36123 .35503 Mdot
.86335 .50212 Mdot
.20874 .34539 Mdot
.47727 .26853 Mdot
.58723 .10996 Mdot
.27765 .69042 Mdot
.87076 .59311 Mdot
.27235 .4016 Mdot
.57084 .29848 Mdot
.34898 .77814 Mdot
.22162 .87264 Mdot
.99784 .77622 Mdot
.78917 .79133 Mdot
.66101 .87184 Mdot
.47728 .81627 Mdot
.13506 .65778 Mdot
.95687 .82181 Mdot
.07692 .12005 Mdot
.67926 .60234 Mdot
.28745 .60818 Mdot
.81224 .52479 Mdot
.36701 .55477 Mdot
.09546 .72845 Mdot
.19503 .09957 Mdot
.2463 .05127 Mdot
.18379 .93749 Mdot
.10221 .91842 Mdot
.35333 .25112 Mdot
.71704 .36371 Mdot
.17104 .454 Mdot
.64527 .47423 Mdot
.00097 .3557 Mdot
.34987 .3489 Mdot
.79693 .44706 Mdot
.30999 .51306 Mdot
.78717 .47718 Mdot
.34819 .56102 Mdot
.00051 .65232 Mdot
.64927 .64876 Mdot
.19631 .54705 Mdot
.69206 .49575 Mdot
.22888 .53682 Mdot
.66141 .43253 Mdot
.03984 .37843 Mdot
.14227 .10242 Mdot
.37624 .23397 Mdot
.82859 .45235 Mdot
.26194 .43336 Mdot
.58435 .32241 Mdot
.46993 .88559 Mdot
.14631 .67638 Mdot
.93678 .79047 Mdot
.15822 .22144 Mdot
.44574 .28752 Mdot
.36074 .91501 Mdot
.42067 .05992 Mdot
.94798 .52731 Mdot
.833 .88503 Mdot
.68401 .85101 Mdot
.55471 .8707 Mdot
.80088 .24617 Mdot
.10469 .30381 Mdot
.72739 .62271 Mdot
.45296 .72557 Mdot
.85405 .40109 Mdot
.1395 .28545 Mdot
.56877 .42927 Mdot
.4646 .89582 Mdot
.11463 .65003 Mdot
.02986 .91524 Mdot
.73728 .70742 Mdot
.55523 .81795 Mdot
.7521 .19687 Mdot
.06296 .31086 Mdot
.94451 .88155 Mdot
.20668 .26218 Mdot
.39578 .1891 Mdot
.9064 .51061 Mdot
.0351 .1287 Mdot
.9201 .885 Mdot
.34122 .42112 Mdot
.82629 .48507 Mdot
.29988 .47359 Mdot
.71365 .41377 Mdot
.21256 .49892 Mdot
.62807 .41551 Mdot
.84643 .21835 Mdot
.98056 .13413 Mdot
.25042 .26985 Mdot
.40619 .15577 Mdot
.94267 .53648 Mdot
.87182 .92915 Mdot
.60432 .73249 Mdot
.01585 .41153 Mdot
.31662 .30077 Mdot
.5995 .28288 Mdot
.53442 .93491 Mdot
.70838 .17396 Mdot
.95855 .25017 Mdot
.4956 .53706 Mdot
.0019 .50629 Mdot
.49491 .49301 Mdot
.95231 .4574 Mdot
.73855 .78623 Mdot
.63599 .89744 Mdot
.37365 .73767 Mdot
.31691 .94325 Mdot
.24308 .92617 Mdot
.05621 .81314 Mdot
.48398 .42777 Mdot
.79982 .31583 Mdot
.1756 .37579 Mdot
.55682 .38122 Mdot
.3274 .77058 Mdot
.11305 .78565 Mdot
.17225 .0592 Mdot
.24768 .07543 Mdot
.20915 .96146 Mdot
.09303 .88388 Mdot
.36216 .26914 Mdot
.78261 .42045 Mdot
.29384 .51123 Mdot
.73298 .43914 Mdot
.27984 .54686 Mdot
.73213 .45229 Mdot
.2915 .55936 Mdot
.77443 .48293 Mdot
.35835 .58392 Mdot
.07653 .71818 Mdot
.27939 .20286 Mdot
.38711 .10772 Mdot
.76924 .38213 Mdot
.25732 .48808 Mdot
.63249 .37517 Mdot
.83166 .19916 Mdot
.00146 .1698 Mdot
.16105 .15959 Mdot
.37608 .21503 Mdot
.80868 .43261 Mdot
.2805 .47181 Mdot
.65862 .37812 Mdot
.97217 .31355 Mdot
.47956 .50739 Mdot
.84426 .3647 Mdot
.13329 .28903 Mdot
.59459 .46129 Mdot
.67969 .0851 Mdot
.77192 .09223 Mdot
.96769 .19576 Mdot
.38809 .4204 Mdot
.08808 .7 Mdot
.20249 .11441 Mdot
.25208 .04959 Mdot
.18768 .9356 Mdot
.09351 .90583 Mdot
.38177 .28826 Mdot
.91645 .53468 Mdot
.00947 .09302 Mdot
.03622 .02675 Mdot
.81161 .77539 Mdot
.61865 .80704 Mdot
.18142 .56277 Mdot
.73195 .55053 Mdot
.38941 .65746 Mdot
.33353 .94412 Mdot
.31351 .97998 Mdot
.26695 .95344 Mdot
.11263 .84567 Mdot
.23408 .12146 Mdot
.24702 .01294 Mdot
.14607 .89905 Mdot
.16025 .01418 Mdot
.23284 .0726 Mdot
.19782 .96498 Mdot
.10805 .91023 Mdot
.3187 .21064 Mdot
.51743 .19874 Mdot
.83794 .32051 Mdot
.10675 .26881 Mdot
.6831 .57635 Mdot
.27654 .59344 Mdot
.77134 .4948 Mdot
.37023 .59889 Mdot
.15808 .78785 Mdot
.01255 .85447 Mdot
.77926 .76671 Mdot
.64128 .86202 Mdot
.36738 .7261 Mdot
.2689 .90152 Mdot
.06418 .79528 Mdot
.42228 .3581 Mdot
.25774 .83545 Mdot
.98043 .72269 Mdot
.83979 .85936 Mdot
.6406 .80081 Mdot
.3025 .6619 Mdot
.91039 .60788 Mdot
.11294 .20256 Mdot
.5896 .47666 Mdot
.66086 .07126 Mdot
.67599 .01513 Mdot
.6869 .01091 Mdot
.72547 .03857 Mdot
.86491 .13944 Mdot
.84046 .97555 Mdot
.75494 .91448 Mdot
.78297 .02803 Mdot
.90127 .11829 Mdot
.66721 .76595 Mdot
.39988 .73267 Mdot
.47705 .07717 Mdot
.39414 .91709 Mdot
.62367 .22952 Mdot
.63433 .01066 Mdot
.47757 .84324 Mdot
.16434 .68677 Mdot
.89453 .73019 Mdot
.31015 .41562 Mdot
.69029 .38014 Mdot
.10704 .41674 Mdot
.82975 .72271 Mdot
.52959 .69984 Mdot
.43537 .90578 Mdot
.90103 .46567 Mdot
.01568 .11465 Mdot
.02074 .00506 Mdot
.88101 .86027 Mdot
.49874 .61772 Mdot
.10763 .60889 Mdot
.01925 .91163 Mdot
.79643 .77718 Mdot
.64062 .84419 Mdot
.34597 .70536 Mdot
.13374 .78777 Mdot
.09167 .95793 Mdot
.4428 .35113 Mdot
.4021 .9593 Mdot
.71854 .31644 Mdot
.12738 .40883 Mdot
.73676 .60938 Mdot
.45636 .71961 Mdot
.87433 .41797 Mdot
.08338 .20905 Mdot
.73509 .65171 Mdot
.496 .76091 Mdot
.22893 .73293 Mdot
.85752 .62859 Mdot
.35548 .49796 Mdot
.97523 .61974 Mdot
.76767 .79245 Mdot
.66734 .89967 Mdot
.5342 .86685 Mdot
.63858 .10438 Mdot
.59499 .95641 Mdot
.17756 .58257 Mdot
.75946 .5819 Mdot
.45348 .69402 Mdot
.82648 .373 Mdot
.18739 .36091 Mdot
.51932 .33193 Mdot
.98612 .4668 Mdot
.54998 .56387 Mdot
.45802 .90804 Mdot
.0756 .61758 Mdot
.18366 .10806 Mdot
.27303 .08937 Mdot
.25996 .98693 Mdot
.13498 .87503 Mdot
.1744 .03942 Mdot
.22308 .04868 Mdot
.17357 .9505 Mdot
.13599 .96242 Mdot
.25815 .12216 Mdot
.2677 .00954 Mdot
.17003 .90234 Mdot
.09598 .92595 Mdot
.39005 .29407 Mdot
.97423 .58418 Mdot
.73801 .76378 Mdot
.61272 .87471 Mdot
.21212 .59941 Mdot
.72885 .51672 Mdot
.34982 .62098 Mdot
.06876 .71894 Mdot
.32119 .25243 Mdot
.56915 .24796 Mdot
.28609 .71694 Mdot
.91746 .63137 Mdot
.10105 .18359 Mdot
.62386 .52281 Mdot
.92877 .30491 Mdot
.71582 .78705 Mdot
.59136 .87554 Mdot
.07184 .48048 Mdot
.06637 .99453 Mdot
.60968 .54331 Mdot
.86142 .25174 Mdot
.96522 .1038 Mdot
.31057 .34535 Mdot
.62155 .31098 Mdot
.70307 .08151 Mdot
.85058 .14751 Mdot
.89702 .04644 Mdot
.61507 .71805 Mdot
.07025 .45518 Mdot
.04949 .97924 Mdot
.68786 .63837 Mdot
.35647 .66861 Mdot
.15113 .79466 Mdot
.03984 .88871 Mdot
.65255 .61271 Mdot
.17696 .5244 Mdot
.70256 .52561 Mdot
.29314 .59057 Mdot
.8103 .51716 Mdot
.36254 .55224 Mdot
.06779 .70525 Mdot
.31274 .24495 Mdot
.52906 .21632 Mdot
.94763 .41857 Mdot
.72622 .77859 Mdot
.60648 .88026 Mdot
.1777 .57122 Mdot
.74783 .57013 Mdot
.43195 .68411 Mdot
.65407 .22213 Mdot
.79397 .1399 Mdot
.00571 .21173 Mdot
.17751 .17181 Mdot
.3488 .17129 Mdot
.61388 .26508 Mdot
.60984 .99596 Mdot
.31507 .70523 Mdot
.99802 .68295 Mdot
.69483 .69681 Mdot
.43945 .74462 Mdot
.77039 .33094 Mdot
.20628 .43589 Mdot
.56986 .36358 Mdot
.4069 .83704 Mdot
.62879 .22189 Mdot
.65697 .02818 Mdot
.61428 .95731 Mdot
.30457 .69029 Mdot
.94561 .64104 Mdot
.96003 .01442 Mdot
.25131 .29128 Mdot
.42853 .17723 Mdot
.12215 .69361 Mdot
.04222 .92007 Mdot
.67019 .62797 Mdot
.27509 .6049 Mdot
.77973 .50464 Mdot
.37907 .59934 Mdot
.21103 .83196 Mdot
.96214 .7511 Mdot
.97579 .01365 Mdot
.15827 .18248 Mdot
.40664 .24837 Mdot
.03834 .6317 Mdot
.40424 .3659 Mdot
.13957 .73533 Mdot
.0184 .87883 Mdot
.76872 .75032 Mdot
.62543 .85671 Mdot
.27205 .64662 Mdot
0 .85 Mdot
.85 .85 Mdot
.60131 .75131 Mdot
.01488 .41357 Mdot
.32442 .30953 Mdot
.63944 .31502 Mdot
.81036 .17092 Mdot
.0162 .20585 Mdot
.10882 .09261 Mdot
.49769 .38887 Mdot
.87039 .3727 Mdot
.05336 .18298 Mdot
.86975 .81639 Mdot
.49946 .62971 Mdot
.12542 .62596 Mdot
.96153 .83611 Mdot
.06433 .1028 Mdot
.72899 .66466 Mdot
.49804 .76905 Mdot
.25335 .75531 Mdot
.89483 .64148 Mdot
.22008 .32525 Mdot
.45088 .23079 Mdot
.34323 .89236 Mdot
.30727 .96403 Mdot
.22856 .92129 Mdot
.04586 .8173 Mdot
.54656 .5007 Mdot
.36853 .82197 Mdot
.37138 .00284 Mdot
.56871 .19733 Mdot
.23218 .66348 Mdot
.78855 .55637 Mdot
.42648 .63793 Mdot
.56788 .1414 Mdot
.17015 .60227 Mdot
.79563 .62548 Mdot
.48972 .69408 Mdot
.11187 .62215 Mdot
.01385 .90198 Mdot
.81901 .80516 Mdot
.63516 .81614 Mdot
.2877 .65255 Mdot
.85729 .56958 Mdot
.29727 .43998 Mdot
.67194 .37467 Mdot
.02937 .35742 Mdot
.18239 .15303 Mdot
.32035 .13795 Mdot
.45128 .13094 Mdot
.24651 .79523 Mdot
.92792 .68141 Mdot
.09682 .1689 Mdot
.62903 .53221 Mdot
.96868 .33966 Mdot
.52615 .55747 Mdot
.26589 .73973 Mdot
.89708 .63119 Mdot
.19955 .30247 Mdot
.44344 .2439 Mdot
.29971 .85627 Mdot
.09581 .7961 Mdot
.26101 .16519 Mdot
.31478 .05377 Mdot
.34548 .0307 Mdot
.45664 .11116 Mdot
.26805 .81141 Mdot
.97253 .70448 Mdot
.86836 .89583 Mdot
.58415 .71579 Mdot
.86191 .27776 Mdot
.98951 .12761 Mdot
.19047 .20096 Mdot
.35437 .1639 Mdot
.63527 .2809 Mdot
.75313 .11786 Mdot
.98486 .23173 Mdot
.3224 .33753 Mdot
.65913 .33673 Mdot
.93323 .2741 Mdot
.66114 .72791 Mdot
.33396 .67282 Mdot
.04416 .7102 Mdot
.44921 .40505 Mdot
.50474 .05553 Mdot
.59345 .08871 Mdot
.29936 .70591 Mdot
.94432 .64496 Mdot
.97114 .02682 Mdot
.19888 .22774 Mdot
.36951 .17063 Mdot
.72568 .35617 Mdot
.18295 .45727 Mdot
.62355 .4406 Mdot
.84473 .22118 Mdot
.98841 .14368 Mdot
.21315 .22474 Mdot
.35353 .14038 Mdot
.60737 .25383 Mdot
.55705 .94968 Mdot
.89758 .34053 Mdot
.90657 .00898 Mdot
.53266 .6261 Mdot
.3858 .85314 Mdot
.50639 .12059 Mdot
.67173 .16533 Mdot
.81911 .14738 Mdot
.97718 .15807 Mdot
.29443 .31725 Mdot
.54072 .24629 Mdot
.06892 .5282 Mdot
.12963 .06071 Mdot
.37999 .25037 Mdot
.86769 .48769 Mdot
.17851 .31083 Mdot
.48576 .30725 Mdot
.69348 .20772 Mdot
.94579 .2523 Mdot
.57029 .62451 Mdot
.67101 .10072 Mdot
.75141 .08039 Mdot
.94584 .19443 Mdot
.51212 .56628 Mdot
.16315 .65103 Mdot
.8619 .69874 Mdot
.41054 .54864 Mdot
.3654 .95486 Mdot
.48643 .12103 Mdot
.51254 .02612 Mdot
.62635 .11381 Mdot
.53462 .90826 Mdot
.68331 .14869 Mdot
.84968 .16637 Mdot
.91868 .069 Mdot
.53247 .61378 Mdot
.37194 .83947 Mdot
.40862 .03668 Mdot
.84022 .4316 Mdot
.21164 .37142 Mdot
.50118 .28954 Mdot
.79894 .29776 Mdot
.15853 .35959 Mdot
.58302 .42449 Mdot
.56264 .97962 Mdot
.96949 .40686 Mdot
.58859 .61909 Mdot
.79625 .20767 Mdot
.07129 .27504 Mdot
.86383 .79254 Mdot
.49746 .63364 Mdot
.11334 .61588 Mdot
.00121 .88787 Mdot
.8806 .87939 Mdot
.51956 .63896 Mdot
.29508 .77552 Mdot
.00092 .70583 Mdot
.70034 .69942 Mdot
.46004 .7597 Mdot
.94291 .48288 Mdot
.81688 .87397 Mdot
.708 .89112 Mdot
.67465 .96665 Mdot
.63284 .95819 Mdot
.41664 .7838 Mdot
.64324 .2266 Mdot
.74252 .09929 Mdot
.95467 .21214 Mdot
.47987 .5252 Mdot
.86454 .38467 Mdot
.08703 .22249 Mdot
.73023 .64321 Mdot
.47894 .74871 Mdot
.08066 .60172 Mdot
.14164 .06098 Mdot
.33694 .19531 Mdot
.58031 .24336 Mdot
.36228 .78197 Mdot
.29609 .93381 Mdot
.16221 .86612 Mdot
.07948 .91727 Mdot
.46324 .38376 Mdot
.59197 .12873 Mdot
.32925 .73728 Mdot
.08774 .75849 Mdot
.26271 .17497 Mdot
.32714 .06444 Mdot
.40582 .07867 Mdot
.86301 .4572 Mdot
.16503 .30201 Mdot
.508 .34298 Mdot
.90699 .39899 Mdot
.92061 .01361 Mdot
.46721 .54661 Mdot
.78593 .31872 Mdot
.19046 .40453 Mdot
.55796 .3675 Mdot
.32227 .76431 Mdot
.08541 .76314 Mdot
.27895 .19354 Mdot
.37679 .09784 Mdot
.69578 .31898 Mdot
.06481 .36903 Mdot
.99262 .92781 Mdot
.97207 .97945 Mdot
.14601 .17394 Mdot
.43532 .28931 Mdot
.28424 .84892 Mdot
.04477 .76052 Mdot
.49604 .45128 Mdot
.91962 .42357 Mdot
.88226 .96264 Mdot
.59594 .71368 Mdot
.94124 .3453 Mdot
.68857 .74733 Mdot
.46801 .77944 Mdot
.02504 .55703 Mdot
.40751 .38248 Mdot
.17842 .7709 Mdot
.94603 .76762 Mdot
.08422 .13819 Mdot
.66 .57578 Mdot
.17643 .51643 Mdot
.6957 .51927 Mdot
.26484 .56914 Mdot
.72475 .4599 Mdot
.28474 .55999 Mdot
.75708 .47234 Mdot
.3424 .58532 Mdot
.99619 .65379 Mdot
.67663 .68044 Mdot
.35486 .67822 Mdot
.15216 .7973 Mdot
.03935 .88719 Mdot
.65388 .61453 Mdot
.18543 .53155 Mdot
.69333 .50789 Mdot
.24542 .55209 Mdot
.68389 .43847 Mdot
.14169 .4578 Mdot
.73358 .59189 Mdot
.43364 .70006 Mdot
.68255 .24891 Mdot
.94698 .26443 Mdot
.57571 .62873 Mdot
.71464 .13893 Mdot
.94029 .22564 Mdot
.57419 .6339 Mdot
.70879 .1346 Mdot
.92032 .21154 Mdot
.6666 .74627 Mdot
.37744 .71085 Mdot
.31271 .93526 Mdot
.21924 .90653 Mdot
.03243 .81319 Mdot
.62016 .58773 Mdot
.97137 .3512 Mdot
.52193 .55056 Mdot
.22551 .70358 Mdot
.82817 .60266 Mdot
.41323 .58506 Mdot
.42051 .00729 Mdot
.89423 .47372 Mdot
.05503 .1608 Mdot
.83826 .78324 Mdot
.56861 .73035 Mdot
.76449 .19588 Mdot
.06985 .30535 Mdot
.90182 .83197 Mdot
.37829 .47647 Mdot
.08346 .70516 Mdot
.23083 .14737 Mdot
.27219 .04136 Mdot
.21027 .93808 Mdot
.0688 .85854 Mdot
.46059 .39179 Mdot
.5793 .11871 Mdot
.2304 .6511 Mdot
.77586 .54546 Mdot
.42073 .64487 Mdot
.53335 .11262 Mdot
.87772 .34437 Mdot
.99628 .11856 Mdot
.14087 .14459 Mdot
.42317 .2823 Mdot
.18833 .76515 Mdot
.922 .73368 Mdot
.18007 .25807 Mdot
.42987 .2498 Mdot
.20452 .77465 Mdot
.91026 .70574 Mdot
.21142 .30116 Mdot
.43107 .21965 Mdot
.18313 .75206 Mdot
.91801 .73488 Mdot
.20178 .28377 Mdot
.42221 .22043 Mdot
.11954 .69733 Mdot
.05659 .93705 Mdot
.60581 .54922 Mdot
.8423 .2365 Mdot
.01072 .16842 Mdot
.10416 .09344 Mdot
.51944 .41528 Mdot
.07044 .55101 Mdot
.14428 .07384 Mdot
.34091 .19662 Mdot
.60028 .25938 Mdot
.51611 .91582 Mdot
.54447 .02837 Mdot
.8801 .33563 Mdot
.97785 .09774 Mdot
.23016 .25231 Mdot
.37704 .14687 Mdot
.74627 .36923 Mdot
.22928 .48301 Mdot
.60764 .37835 Mdot
.68331 .07567 Mdot
.77668 .09337 Mdot
.96852 .19184 Mdot
.3793 .41078 Mdot
.02387 .64457 Mdot
.50198 .47811 Mdot
.99394 .49196 Mdot
.5283 .53436 Mdot
.2597 .7314 Mdot
.87908 .61939 Mdot
.26577 .38669 Mdot
.54384 .27807 Mdot
.12492 .58108 Mdot
.91863 .79372 Mdot
.25743 .3388 Mdot
.48337 .22593 Mdot
.59308 .10972 Mdot
.31788 .72479 Mdot
.02838 .7105 Mdot
.54127 .51289 Mdot
.33982 .79855 Mdot
.19703 .85722 Mdot
.00129 .80426 Mdot
.79651 .79522 Mdot
.65858 .86207 Mdot
.45594 .79736 Mdot
.94881 .49287 Mdot
.79388 .84507 Mdot
.71096 .91709 Mdot
.70878 .99782 Mdot
.78354 .07476 Mdot
.94774 .16419 Mdot
.47124 .5235 Mdot
.79451 .32327 Mdot
.18858 .39407 Mdot
.5505 .36192 Mdot
.26004 .70954 Mdot
.85771 .59767 Mdot
.32391 .4662 Mdot
.79402 .4701 Mdot
.33587 .54185 Mdot
.9219 .58603 Mdot
.03295 .11105 Mdot
.915 .88205 Mdot
.36418 .44919 Mdot
.97391 .60973 Mdot
.76543 .79151 Mdot
.6658 .90037 Mdot
.52792 .86213 Mdot
.58451 .05659 Mdot
.20527 .62075 Mdot
.75565 .55039 Mdot
.41943 .66377 Mdot
.54296 .12354 Mdot
.96359 .42063 Mdot
.63688 .67329 Mdot
.15447 .5176 Mdot
.75271 .59824 Mdot
.46487 .71216 Mdot
.9331 .46823 Mdot
.85598 .92288 Mdot
.65494 .79896 Mdot
.37512 .72018 Mdot
.3081 .93299 Mdot
.20043 .89232 Mdot
.03227 .83184 Mdot
.63975 .60748 Mdot
.10455 .4648 Mdot
.88899 .78444 Mdot
.389 .50001 Mdot
.17347 .78448 Mdot
.97019 .79671 Mdot
.97437 .00418 Mdot
.15718 .18281 Mdot
.41006 .25288 Mdot
.06633 .65627 Mdot
.27162 .20529 Mdot
.37308 .10146 Mdot
.67731 .30423 Mdot
.98141 .30411 Mdot
.41532 .43391 Mdot
.28408 .86875 Mdot
.06419 .78011 Mdot
.40706 .34287 Mdot
.13567 .72861 Mdot
.5 .85 Mdot
.35 .85 Mdot
.29869 .94869 Mdot
.18501 .88632 Mdot
.04885 .86384 Mdot
.57609 .52724 Mdot
.6159 .03981 Mdot
.39718 .78128 Mdot
.50773 .11055 Mdot
.67239 .16466 Mdot
.82129 .1489 Mdot
.97436 .15306 Mdot
.30614 .33178 Mdot
.59242 .28628 Mdot
.4899 .89748 Mdot
.31675 .82684 Mdot
.12605 .8093 Mdot
.1424 .01635 Mdot
.28973 .14733 Mdot
.35751 .06778 Mdot
.55585 .19835 Mdot
.13721 .58136 Mdot
.87273 .73552 Mdot
.40719 .53446 Mdot
.32817 .92098 Mdot
.26676 .93859 Mdot
.09743 .83068 Mdot
.28788 .19045 Mdot
.39565 .10777 Mdot
.82419 .42854 Mdot
.24795 .42376 Mdot
.55771 .30976 Mdot
.26265 .70494 Mdot
.85701 .59437 Mdot
.32297 .46595 Mdot
.78989 .46692 Mdot
.33609 .54619 Mdot
.92724 .59115 Mdot
.01017 .08294 Mdot
.02194 .01177 Mdot
.88061 .85866 Mdot
.49882 .61821 Mdot
.10876 .60994 Mdot
.01528 .90653 Mdot
.81499 .79971 Mdot
.63718 .82219 Mdot
.30506 .66789 Mdot
.92488 .61982 Mdot
.05121 .12633 Mdot
.82521 .774 Mdot
.59119 .76598 Mdot
.96117 .36997 Mdot
.60029 .63912 Mdot
.89588 .29559 Mdot
.86943 .97355 Mdot
.65784 .78841 Mdot
.3787 .72086 Mdot
.33031 .95161 Mdot
.30668 .97637 Mdot
.23888 .9322 Mdot
.05971 .82083 Mdot
.47228 .41257 Mdot
.69182 .21954 Mdot
.95184 .26001 Mdot
.54387 .59203 Mdot
.43913 .89526 Mdot
.91859 .47947 Mdot
.94338 .02478 Mdot
.35621 .41283 Mdot
.89394 .53773 Mdot
.12035 .22641 Mdot
.58232 .46197 Mdot
.59518 .01286 Mdot
.23529 .64011 Mdot
.76607 .53078 Mdot
.40526 .63919 Mdot
.41976 .0145 Mdot
.89607 .47631 Mdot
.04929 .15322 Mdot
.86298 .81369 Mdot
.52165 .65868 Mdot
.33144 .80979 Mdot
.16985 .83841 Mdot
.03248 .86263 Mdot
.66931 .63683 Mdot
.2801 .61078 Mdot
.79665 .51656 Mdot
.37977 .58312 Mdot
.19909 .81932 Mdot
.96084 .76174 Mdot
.99397 .03314 Mdot
.06928 .07531 Mdot
.67478 .6055 Mdot
.27224 .59746 Mdot
.76646 .49423 Mdot
.36882 .60236 Mdot
.15342 .7846 Mdot
.02285 .86943 Mdot
.73288 .71003 Mdot
.55055 .81767 Mdot
.71614 .16559 Mdot
.97069 .25455 Mdot
.42925 .45856 Mdot
.4087 .97946 Mdot
.78357 .37486 Mdot
.24783 .46426 Mdot
.59811 .35028 Mdot
.59246 .99436 Mdot
.19827 .60581 Mdot
.74832 .55005 Mdot
.4124 .66408 Mdot
.49376 .08136 Mdot
.53145 .03769 Mdot
.78788 .25643 Mdot
.12699 .3391 Mdot
.66854 .54155 Mdot
.18141 .51287 Mdot
.68206 .50065 Mdot
.19683 .51477 Mdot
.65911 .46228 Mdot
.05867 .39957 Mdot
.05676 .99809 Mdot
.66589 .60913 Mdot
.23711 .57122 Mdot
.6979 .46079 Mdot
.2136 .5157 Mdot
.64423 .43063 Mdot
.95184 .30761 Mdot
.59144 .6396 Mdot
.83651 .24507 Mdot
.03508 .19857 Mdot
.99005 .95496 Mdot
.01463 .02458 Mdot
.93694 .92231 Mdot
.2892 .35226 Mdot
.561 .2718 Mdot
.24941 .68841 Mdot
.82374 .57433 Mdot
.39471 .57097 Mdot
.28122 .88651 Mdot
.07501 .79379 Mdot
.36295 .28793 Mdot
.80575 .4428 Mdot
.29499 .48923 Mdot
.71434 .41936 Mdot
.21994 .5056 Mdot
.63127 .41132 Mdot
.86076 .2295 Mdot
.94526 .0845 Mdot
.40542 .46016 Mdot
.24181 .83639 Mdot
.96559 .72378 Mdot
.92838 .96279 Mdot
.37576 .44737 Mdot
.03911 .66335 Mdot
.43145 .39234 Mdot
.35866 .92721 Mdot
.42151 .06285 Mdot
.9569 .53539 Mdot
.79033 .83344 Mdot
.70227 .91194 Mdot
.67857 .9763 Mdot
.65862 .98005 Mdot
.57408 .91547 Mdot
.98962 .41554 Mdot
.47776 .48813 Mdot
.81069 .33294 Mdot
.17768 .36699 Mdot
.54363 .36595 Mdot
.21118 .66755 Mdot
.79762 .58644 Mdot
.44864 .65102 Mdot
.74638 .29773 Mdot
.1579 .41153 Mdot
.63672 .47882 Mdot
.95915 .32243 Mdot
.5644 .60525 Mdot
.60828 .04387 Mdot
.35296 .74469 Mdot
.20868 .85572 Mdot
.98765 .77897 Mdot
.85299 .86534 Mdot
.60719 .75421 Mdot
.05629 .4491 Mdot
.11951 .06322 Mdot
.42259 .30308 Mdot
.20489 .7823 Mdot
.91756 .71267 Mdot
.18185 .26429 Mdot
.43264 .25079 Mdot
.22585 .79322 Mdot
.91778 .69193 Mdot
.15998 .2422 Mdot
.4616 .30163 Mdot
.49706 .03546 Mdot
.51193 .01487 Mdot
.61023 .0983 Mdot
.41995 .80971 Mdot
.69263 .27268 Mdot
.00779 .31516 Mdot
.26845 .26066 Mdot
.42249 .15405 Mdot
.05519 .6327 Mdot
.30923 .25404 Mdot
.52546 .21623 Mdot
.91919 .39373 Mdot
.85459 .9354 Mdot
.67205 .81746 Mdot
.47262 .80057 Mdot
.08251 .60988 Mdot
.14037 .05786 Mdot
.33817 .19781 Mdot
.58855 .25037 Mdot
.42726 .83871 Mdot
.77434 .34708 Mdot
.2225 .44816 Mdot
.57317 .35067 Mdot
.41815 .84499 Mdot
.71513 .29697 Mdot
.09955 .38442 Mdot
.83168 .73213 Mdot
.53437 .70269 Mdot
.47577 .9414 Mdot
.24824 .77246 Mdot
.90668 .65845 Mdot
.18155 .27487 Mdot
.44379 .26224 Mdot
.32067 .87688 Mdot
.19148 .87082 Mdot
.02268 .83119 Mdot
.69568 .673 Mdot
.4185 .72283 Mdot
.59547 .17696 Mdot
.40133 .80586 Mdot
.5599 .15857 Mdot
.12797 .56806 Mdot
.8937 .76574 Mdot
.34941 .45571 Mdot
.90141 .55199 Mdot
.10024 .19884 Mdot
.64286 .54261 Mdot
.05649 .41364 Mdot
.08294 .02644 Mdot
.55475 .47182 Mdot
.4023 .84755 Mdot
.60814 .20583 Mdot
.51402 .90588 Mdot
.51788 .00386 Mdot
.64662 .12874 Mdot
.66254 .01593 Mdot
.62853 .96599 Mdot
.3996 .77107 Mdot
.51359 .11398 Mdot
.72257 .20898 Mdot
.02913 .30656 Mdot
.13292 .1038 Mdot
.41071 .27779 Mdot
.09577 .68506 Mdot
.15017 .05441 Mdot
.30255 .15238 Mdot
.40103 .09848 Mdot
.85049 .44946 Mdot
.19925 .34877 Mdot
.49009 .29084 Mdot
.7116 .22151 Mdot
.01491 .30332 Mdot
.214 .19908 Mdot
.32738 .11338 Mdot
.45579 .12841 Mdot
.27866 .82287 Mdot
.00546 .7268 Mdot
.69407 .68862 Mdot
.4287 .73463 Mdot
.68078 .25208 Mdot
.94324 .26246 Mdot
.59465 .65141 Mdot
.87021 .27557 Mdot
.95689 .08667 Mdot
.34167 .38479 Mdot
.79214 .45046 Mdot
.31787 .52573 Mdot
.82927 .51141 Mdot
.3194 .49012 Mdot
.79969 .48029 Mdot
.34021 .54052 Mdot
.94086 .60065 Mdot
.94604 .00518 Mdot
.32175 .37571 Mdot
.6947 .37295 Mdot
.11516 .42046 Mdot
.79802 .68286 Mdot
.54464 .74662 Mdot
.59964 .055 Mdot
.30746 .70782 Mdot
.97301 .66555 Mdot
.82658 .85357 Mdot
.66773 .84115 Mdot
.47743 .8097 Mdot
.12967 .65224 Mdot
.97135 .84168 Mdot
.01249 .04114 Mdot
.96627 .95377 Mdot
.15442 .18815 Mdot
.42343 .26902 Mdot
.17693 .75349 Mdot
.93171 .75478 Mdot
.14999 .21828 Mdot
.467 .31701 Mdot
.55468 .08768 Mdot
.01763 .46295 Mdot
.35744 .33981 Mdot
.82751 .47007 Mdot
.28215 .45464 Mdot
.64535 .3632 Mdot
.89035 .245 Mdot
.84359 .95324 Mdot
.72377 .88017 Mdot
.70293 .97916 Mdot
.74781 .04488 Mdot
.90666 .15886 Mdot
.68206 .7754 Mdot
.47156 .7895 Mdot
.06306 .5915 Mdot
.2246 .16154 Mdot
.28622 .06161 Mdot
.26246 .97625 Mdot
.12804 .86558 Mdot
.19094 .0629 Mdot
.21559 .02465 Mdot
.15209 .93651 Mdot
.17875 .02666 Mdot
.20111 .02236 Mdot
.16154 .96043 Mdot
.17559 .01405 Mdot
.19512 .01953 Mdot
.16615 .97103 Mdot
.17418 .00803 Mdot
.19218 .01801 Mdot
.16881 .97663 Mdot
.17319 .00438 Mdot
.19072 .01753 Mdot
.17055 .97983 Mdot
.17225 .0017 Mdot
.19018 .01794 Mdot
.1718 .98162 Mdot
.17113 .99933 Mdot
.19039 .01926 Mdot
.1728 .9824 Mdot
.16964 .99685 Mdot
.19142 .02178 Mdot
.17373 .98231 Mdot
.16745 .99372 Mdot
.19361 .02616 Mdot
.17488 .98127 Mdot
.16387 .98899 Mdot
.19797 .0341 Mdot
.17699 .97902 Mdot
.15711 .98012 Mdot
.20757 .05047 Mdot
.1833 .97573 Mdot
.14135 .95805 Mdot
.23499 .09364 Mdot
.21949 .9845 Mdot
.11032 .89083 Mdot
.28929 .17897 Mdot
.38795 .09866 Mdot
.76544 .37749 Mdot
.25178 .48634 Mdot
.6241 .37232 Mdot
.77976 .15565 Mdot
.03008 .25032 Mdot
.07111 .04103 Mdot
.63079 .55968 Mdot
.00635 .37557 Mdot
.33747 .33111 Mdot
.71855 .38108 Mdot
.19203 .47348 Mdot
.62452 .43249 Mdot
.8424 .21788 Mdot
.99183 .14944 Mdot
.19842 .20658 Mdot
.34892 .15051 Mdot
.59369 .24477 Mdot
.4571 .8634 Mdot
.02379 .56669 Mdot
.42459 .4008 Mdot
.31705 .89246 Mdot
.19283 .87578 Mdot
.02563 .8328 Mdot
.67978 .65415 Mdot
.34134 .66156 Mdot
.06729 .72595 Mdot
.33611 .26882 Mdot
.64996 .31385 Mdot
.86494 .21498 Mdot
.9159 .05096 Mdot
.52856 .61267 Mdot
.3401 .81153 Mdot
.21133 .87124 Mdot
.0012 .78987 Mdot
.78264 .78144 Mdot
0 .9 Mdot
.9 .9 Mdot
.45484 .55484 Mdot
.69781 .24296 Mdot
.99548 .29768 Mdot
.32477 .32929 Mdot
.66068 .3359 Mdot
.93976 .27908 Mdot
.63053 .69078 Mdot
.136 .50546 Mdot
.80117 .66518 Mdot
.52334 .72217 Mdot
.4083 .88496 Mdot
.68631 .27801 Mdot
.99039 .30408 Mdot
.3617 .37131 Mdot
.88225 .52055 Mdot
.15388 .27162 Mdot
.50851 .35463 Mdot
.92266 .41415 Mdot
.85715 .93449 Mdot
.66265 .8055 Mdot
.4186 .75596 Mdot
.62931 .21071 Mdot
.64884 .01953 Mdot
.56489 .91605 Mdot
.92271 .35781 Mdot
.80056 .87785 Mdot
.73675 .9362 Mdot
.78318 .04642 Mdot
.91957 .13639 Mdot
.59532 .67576 Mdot
.89916 .30384 Mdot
.86259 .96343 Mdot
.67276 .81017 Mdot
.46839 .79562 Mdot
.04417 .57579 Mdot
.3147 .27052 Mdot
.56192 .24722 Mdot
.23172 .6698 Mdot
.79478 .56306 Mdot
.42812 .63334 Mdot
.5752 .14708 Mdot
.22928 .65408 Mdot
.7787 .54943 Mdot
.42415 .64544 Mdot
.55849 .13434 Mdot
.09312 .53463 Mdot
.01247 .91935 Mdot
.84462 .83215 Mdot
.5997 .75508 Mdot
.0079 .4082 Mdot
.36083 .35293 Mdot
.85906 .49823 Mdot
.21988 .36082 Mdot
.48651 .26662 Mdot
.65879 .17228 Mdot
.76716 .10837 Mdot
.98314 .21599 Mdot
.31692 .33378 Mdot
.63367 .31675 Mdot
.77991 .14625 Mdot
.02062 .24071 Mdot
.11738 .09675 Mdot
.46498 .34761 Mdot
.56943 .10445 Mdot
.1446 .57517 Mdot
.84119 .69659 Mdot
.47394 .63275 Mdot
.92507 .45113 Mdot
.88155 .95648 Mdot
.59274 .71119 Mdot
.91695 .32422 Mdot
.79647 .87951 Mdot
.74292 .94645 Mdot
.80235 .05943 Mdot
.91614 .1138 Mdot
.59016 .67401 Mdot
.86204 .27189 Mdot
.98317 .12113 Mdot
.2219 .23873 Mdot
.36387 .14197 Mdot
.66493 .30106 Mdot
.92467 .25974 Mdot
.69225 .76759 Mdot
.5014 .80914 Mdot
.32031 .81891 Mdot
.1321 .81179 Mdot
.12177 .98967 Mdot
.33982 .21806 Mdot
.61657 .27674 Mdot
.63826 .02169 Mdot
.51054 .87228 Mdot
.45654 .946 Mdot
.10212 .64558 Mdot
.0809 .97877 Mdot
.51746 .43657 Mdot
.07603 .55857 Mdot
.12238 .04635 Mdot
.39402 .27163 Mdot
.9774 .58338 Mdot
.71847 .74107 Mdot
.55182 .83336 Mdot
.74156 .18974 Mdot
.04381 .30225 Mdot
.04325 .99943 Mdot
.74367 .70043 Mdot
.5573 .81363 Mdot
.76346 .20615 Mdot
.07971 .31626 Mdot
.86101 .7813 Mdot
.49619 .63518 Mdot
.10473 .60854 Mdot
.03193 .9272 Mdot
.73713 .7052 Mdot
.55276 .81564 Mdot
.73102 .17826 Mdot
.01545 .28443 Mdot
.19191 .17647 Mdot
.32767 .13576 Mdot
.47942 .15174 Mdot
.48748 .00807 Mdot
.40803 .92054 Mdot
.71999 .31196 Mdot
.12628 .4063 Mdot
.73847 .61219 Mdot
.46182 .72335 Mdot
.9205 .45867 Mdot
.91284 .99234 Mdot
.48527 .57243 Mdot
.95472 .46946 Mdot
.73686 .78213 Mdot
.62928 .89242 Mdot
.33035 .70107 Mdot
.05632 .72597 Mdot
.39623 .33992 Mdot
.06017 .66394 Mdot
.31287 .2527 Mdot
.53729 .22442 Mdot
.02035 .48307 Mdot
.36132 .34097 Mdot
.84981 .48849 Mdot
.24038 .39057 Mdot
.5189 .27852 Mdot
.92945 .41054 Mdot
.81784 .88839 Mdot
.72063 .90279 Mdot
.71859 .99796 Mdot
.80899 .09041 Mdot
.93782 .12883 Mdot
.4909 .55307 Mdot
.98028 .48939 Mdot
.60733 .62705 Mdot
.93004 .32271 Mdot
.72683 .79679 Mdot
.62591 .89908 Mdot
.31728 .69137 Mdot
.99264 .67536 Mdot
.71951 .72687 Mdot
.54008 .82057 Mdot
.63827 .09819 Mdot
.5871 .94883 Mdot
.11565 .52855 Mdot
.90405 .7884 Mdot
.32416 .42011 Mdot
.74893 .42478 Mdot
.28777 .53884 Mdot
.74376 .45598 Mdot
.31297 .56921 Mdot
.85415 .54118 Mdot
.27927 .42511 Mdot
.60908 .32981 Mdot
.64404 .03497 Mdot
.55518 .91114 Mdot
.84489 .28971 Mdot
.05647 .21158 Mdot
.88101 .82455 Mdot
.46302 .58201 Mdot
.78848 .32546 Mdot
.19562 .40714 Mdot
.55308 .35745 Mdot
.27521 .72214 Mdot
.89722 .622 Mdot
.18972 .2925 Mdot
.4471 .25738 Mdot
.34094 .89385 Mdot
.29769 .95675 Mdot
.19001 .89231 Mdot
.04645 .85645 Mdot
.58232 .53587 Mdot
.66909 .08677 Mdot
.72908 .05998 Mdot
.89353 .16445 Mdot
.74893 .8554 Mdot
.71839 .96946 Mdot
.78003 .06164 Mdot
.93598 .15595 Mdot
.52807 .59208 Mdot
.31561 .78754 Mdot
.0824 .76679 Mdot
.29781 .21541 Mdot
.44903 .15122 Mdot
.24955 .80052 Mdot
.93599 .68644 Mdot
.05854 .12255 Mdot
.7805 .72196 Mdot
.59615 .81565 Mdot
.04467 .44852 Mdot
.18458 .1399 Mdot
.30321 .11863 Mdot
.36943 .06622 Mdot
.62079 .25136 Mdot
.63883 .01803 Mdot
.51001 .87119 Mdot
.45124 .94123 Mdot
.05647 .60523 Mdot
.27463 .21816 Mdot
.39203 .11739 Mdot
.81028 .41825 Mdot
.26366 .45338 Mdot
.60706 .3434 Mdot
.64463 .03757 Mdot
.56092 .91629 Mdot
.89332 .3324 Mdot
.91779 .02446 Mdot
.49249 .5747 Mdot
.01461 .52213 Mdot
.43459 .41997 Mdot
.40944 .97485 Mdot
.78403 .37459 Mdot
.24733 .46331 Mdot
.59671 .34938 Mdot
.58217 .98546 Mdot
.11762 .53545 Mdot
.90265 .78503 Mdot
.32743 .42478 Mdot
.76738 .43995 Mdot
.31478 .5474 Mdot
.83913 .52434 Mdot
.30738 .46826 Mdot
.73319 .42581 Mdot
.26687 .53368 Mdot
.69272 .42585 Mdot
.16127 .46855 Mdot
.68444 .52317 Mdot
.22851 .54407 Mdot
.66864 .44012 Mdot
.08041 .41177 Mdot
.95296 .87255 Mdot
.15003 .19707 Mdot
.44567 .29565 Mdot
.36837 .9227 Mdot
.47118 .10281 Mdot
.37335 .90217 Mdot
.4796 .10625 Mdot
.44344 .96384 Mdot
.01966 .57622 Mdot
.45858 .43892 Mdot
.61084 .15226 Mdot
.4778 .86695 Mdot
.18984 .71204 Mdot
.86645 .67661 Mdot
.37201 .50556 Mdot
.07513 .70312 Mdot
.27165 .19652 Mdot
.36438 .09273 Mdot
.61858 .2542 Mdot
.62817 .00958 Mdot
.44106 .81289 Mdot
.8507 .40965 Mdot
.15876 .30806 Mdot
.53084 .37207 Mdot
.11742 .58659 Mdot
.95462 .83719 Mdot
.10521 .15059 Mdot
.57182 .46662 Mdot
.52433 .9525 Mdot
.64644 .12212 Mdot
.65501 .00856 Mdot
.58503 .93002 Mdot
.08235 .49732 Mdot
.02862 .94627 Mdot
.77563 .74701 Mdot
.62231 .84668 Mdot
.24336 .62105 Mdot
.7513 .50793 Mdot
.37328 .62198 Mdot
.19899 .82572 Mdot
.96735 .76836 Mdot
.96265 .99529 Mdot
.21702 .25437 Mdot
.38114 .16412 Mdot
.78847 .40733 Mdot
.27749 .48902 Mdot
.66902 .39152 Mdot
.03349 .36447 Mdot
.16526 .13177 Mdot
.33717 .17191 Mdot
.55797 .2208 Mdot
.17563 .61766 Mdot
.79864 .62301 Mdot
.48411 .68547 Mdot
.05854 .57443 Mdot
.23237 .17383 Mdot
.29894 .06657 Mdot
.3037 .00475 Mdot
.25718 .95348 Mdot
.0977 .84053 Mdot
.29647 .19877 Mdot
.42831 .13184 Mdot
.0751 .64679 Mdot
.21549 .14039 Mdot
.26788 .05239 Mdot
.21322 .94534 Mdot
.07409 .86087 Mdot
.43487 .36078 Mdot
.35235 .91748 Mdot
.37826 .02591 Mdot
.63267 .25441 Mdot
.71188 .07921 Mdot
.87336 .16149 Mdot
.83069 .95733 Mdot
.76196 .93127 Mdot
.80417 .04221 Mdot
.89655 .09238 Mdot
.66314 .76659 Mdot
.38199 .71885 Mdot
.34841 .96642 Mdot
.40701 .0586 Mdot
.85111 .4441 Mdot
.19194 .34083 Mdot
.492 .30007 Mdot
.73611 .2441 Mdot
.09005 .35395 Mdot
.84673 .75667 Mdot
.51799 .67126 Mdot
.3149 .79691 Mdot
.08908 .77418 Mdot
.27176 .18268 Mdot
.35074 .07899 Mdot
.53149 .18074 Mdot
.93122 .39973 Mdot
.79758 .86636 Mdot
.72861 .93103 Mdot
.76369 .03507 Mdot
.90873 .14504 Mdot
.65822 .7495 Mdot
.34165 .68343 Mdot
.09069 .74903 Mdot
.2387 .14801 Mdot
.27543 .03673 Mdot
.21228 .93684 Mdot
.06618 .85391 Mdot
.47004 .40386 Mdot
.66544 .1954 Mdot
.82133 .15589 Mdot
.98127 .15994 Mdot
.27199 .29072 Mdot
.45925 .18725 Mdot
.36433 .90508 Mdot
.4306 .06628 Mdot
.02635 .59575 Mdot
.43849 .41214 Mdot
.43072 .99223 Mdot
.9532 .52247 Mdot
.79859 .84539 Mdot
.70655 .90796 Mdot
.68733 .98078 Mdot
.69694 .00961 Mdot
.7593 .06236 Mdot
.93384 .17454 Mdot
.55828 .62445 Mdot
.58166 .02338 Mdot
.1519 .57024 Mdot
.81308 .66118 Mdot
.50198 .6889 Mdot
.20476 .70278 Mdot
.83816 .6334 Mdot
.41905 .58089 Mdot
.45742 .03837 Mdot
.20128 .74386 Mdot
.88285 .68157 Mdot
.31241 .42956 Mdot
.71244 .40004 Mdot
.19569 .48325 Mdot
.62909 .4334 Mdot
.87024 .24115 Mdot
.92238 .05214 Mdot
.49659 .57421 Mdot
.04694 .55035 Mdot
.27343 .22649 Mdot
.39788 .12445 Mdot
.85554 .45766 Mdot
.19117 .33562 Mdot
.48796 .29679 Mdot
.70056 .2126 Mdot
.97391 .27335 Mdot
.4291 .45519 Mdot
.40421 .97511 Mdot
.74852 .34431 Mdot
.20686 .45835 Mdot
.5 .9 Mdot
.4 .9 Mdot
.64516 .24516 Mdot
.77129 .12613 Mdot
.00155 .23026 Mdot
.22094 .21939 Mdot
.34476 .12382 Mdot
.54621 .20145 Mdot
.06657 .52037 Mdot
.1344 .06783 Mdot
.36932 .23492 Mdot
.78886 .41954 Mdot
.28944 .50058 Mdot
.70997 .42053 Mdot
.20952 .49956 Mdot
.63083 .42131 Mdot
.86824 .23741 Mdot
.92618 .05794 Mdot
.48254 .55636 Mdot
.91691 .43437 Mdot
.90684 .98993 Mdot
.51227 .60542 Mdot
.20346 .6912 Mdot
.82786 .6244 Mdot
.43566 .6078 Mdot
.60525 .16959 Mdot
.45906 .85381 Mdot
.02946 .5704 Mdot
.39482 .36537 Mdot
.07638 .68156 Mdot
.24355 .16717 Mdot
.29755 .054 Mdot
.28682 .98927 Mdot
.1917 .90488 Mdot
.05641 .86471 Mdot
.53449 .47808 Mdot
.25211 .71762 Mdot
.85574 .60363 Mdot
.33648 .48074 Mdot
.86358 .52711 Mdot
.2329 .36931 Mdot
.49455 .26165 Mdot
.71807 .22352 Mdot
.03333 .31526 Mdot
.11697 .08364 Mdot
.45356 .33659 Mdot
.46964 .01608 Mdot
.27448 .80484 Mdot
.9784 .70391 Mdot
.83308 .85468 Mdot
.65348 .8204 Mdot
.38929 .73581 Mdot
.41112 .02183 Mdot
.84262 .4315 Mdot
.20483 .36221 Mdot
.49753 .2927 Mdot
.77292 .2754 Mdot
.15087 .37794 Mdot
.62394 .47307 Mdot
.87953 .25559 Mdot
.90015 .02062 Mdot
.57474 .67459 Mdot
.75352 .17878 Mdot
.04611 .29259 Mdot
.02042 .97431 Mdot
.8522 .83178 Mdot
.57617 .72397 Mdot
.8132 .23703 Mdot
.07763 .26443 Mdot
.81995 .74232 Mdot
.57048 .75053 Mdot
.79836 .22789 Mdot
.08929 .29093 Mdot
.78745 .69816 Mdot
.56899 .78154 Mdot
.81849 .24949 Mdot
.0805 .26202 Mdot
.80273 .72222 Mdot
.57846 .77573 Mdot
.8814 .30294 Mdot
.93982 .05842 Mdot
.40953 .4697 Mdot
.27948 .86995 Mdot
.0544 .77492 Mdot
.45588 .40148 Mdot
.55248 .0966 Mdot
.00984 .45735 Mdot
.39838 .38854 Mdot
.12293 .72455 Mdot
.07001 .94707 Mdot
.54268 .47268 Mdot
.31057 .76789 Mdot
.0441 .73353 Mdot
.47286 .42876 Mdot
.71256 .2397 Mdot
.03565 .32309 Mdot
.11127 .07562 Mdot
.4699 .35863 Mdot
.6191 .1492 Mdot
.52637 .90727 Mdot
.61739 .09102 Mdot
.45765 .84025 Mdot
.0049 .54726 Mdot
.51785 .51294 Mdot
.15545 .6376 Mdot
.86985 .7144 Mdot
.3971 .52725 Mdot
.25322 .85611 Mdot
.99547 .74226 Mdot
.76941 .77393 Mdot
.64915 .87974 Mdot
.4267 .77755 Mdot
.70907 .28237 Mdot
.06889 .35982 Mdot
.9614 .89251 Mdot
.12146 .16006 Mdot
.51146 .39 Mdot
.98157 .47012 Mdot
.5804 .59883 Mdot
.71839 .13799 Mdot
.94855 .23017 Mdot
.53261 .58405 Mdot
.34331 .81071 Mdot
.22599 .88268 Mdot
.00724 .78125 Mdot
.73784 .7306 Mdot
.57928 .84144 Mdot
.95298 .37371 Mdot
.65103 .69805 Mdot
.25464 .6036 Mdot
.74463 .48999 Mdot
.34806 .60344 Mdot
.04229 .69423 Mdot
.44393 .40164 Mdot
.46118 .01725 Mdot
.20938 .7482 Mdot
.87958 .6702 Mdot
.31455 .43497 Mdot
.72581 .41126 Mdot
.23831 .5125 Mdot
.63973 .40142 Mdot
.89839 .25865 Mdot
.82098 .92259 Mdot
.74869 .92771 Mdot
.79044 .04176 Mdot
.91051 .12006 Mdot
.62453 .71402 Mdot
.12399 .49946 Mdot
.8407 .71671 Mdot
.49543 .65473 Mdot
.11817 .62274 Mdot
.98766 .86948 Mdot
.94347 .95581 Mdot
.28674 .34327 Mdot
.54546 .25873 Mdot
.11812 .57266 Mdot
.93777 .81965 Mdot
.18201 .24424 Mdot
.41229 .23028 Mdot
.05918 .6469 Mdot
.30128 .2421 Mdot
.48662 .18534 Mdot
.57837 .09176 Mdot
.19684 .61847 Mdot
.76279 .56595 Mdot
.43923 .67644 Mdot
.70052 .26129 Mdot
.02249 .32197 Mdot
.18753 .16504 Mdot
.32321 .13568 Mdot
.46058 .13738 Mdot
.32486 .86427 Mdot
.19601 .87116 Mdot
.01657 .82056 Mdot
.72135 .70478 Mdot
.52222 .80087 Mdot
.47813 .95591 Mdot
.28139 .80326 Mdot
.99217 .71078 Mdot
.75775 .76558 Mdot
.63609 .87834 Mdot
.35514 .71905 Mdot
.19446 .83933 Mdot
.98685 .79239 Mdot
.87118 .88433 Mdot
.56195 .69077 Mdot
.67554 .11358 Mdot
.78347 .10794 Mdot
.98095 .19747 Mdot
.31148 .33053 Mdot
.61002 .29854 Mdot
.61878 .00876 Mdot
.38393 .76516 Mdot
.40676 .02282 Mdot
.81358 .40682 Mdot
.24677 .43318 Mdot
.56609 .31933 Mdot
.3349 .76881 Mdot
.14442 .80951 Mdot
.07614 .93173 Mdot
.49497 .41882 Mdot
.87856 .3836 Mdot
.0321 .15354 Mdot
.96244 .93034 Mdot
.15326 .19082 Mdot
.42954 .27628 Mdot
.22859 .79904 Mdot
.92361 .69503 Mdot
.13305 .20944 Mdot
.51588 .38283 Mdot
.00972 .49383 Mdot
.43557 .42586 Mdot
.42266 .98709 Mdot
.88942 .46676 Mdot
.06944 .18002 Mdot
.77865 .70922 Mdot
.58395 .80529 Mdot
.94999 .36605 Mdot
.66035 .71036 Mdot
.31269 .65234 Mdot
.93626 .62357 Mdot
.9942 .05794 Mdot
.09276 .09856 Mdot
.57816 .4854 Mdot
.58895 .01079 Mdot
.19044 .6015 Mdot
.75495 .56451 Mdot
.43301 .67806 Mdot
.65585 .22284 Mdot
.80346 .14761 Mdot
.00289 .19943 Mdot
.18208 .17918 Mdot
.3471 .16503 Mdot
.59905 .25194 Mdot
.50042 .90137 Mdot
.40471 .90429 Mdot
.68108 .27637 Mdot
.9687 .28762 Mdot
.47401 .50531 Mdot
.79817 .32416 Mdot
.18578 .38761 Mdot
.54878 .363 Mdot
.24791 .69913 Mdot
.83305 .58514 Mdot
.38401 .55097 Mdot
.19306 .80905 Mdot
.95856 .7655 Mdot
.01086 .0523 Mdot
.98718 .97632 Mdot
.05314 .06596 Mdot
.75399 .70085 Mdot
.56858 .81459 Mdot
.84853 .27994 Mdot
.03581 .18728 Mdot
.97455 .93874 Mdot
.09068 .11613 Mdot
.60583 .51515 Mdot
.80841 .20257 Mdot
.05089 .24248 Mdot
.94321 .89232 Mdot
.2247 .2815 Mdot
.40616 .18146 Mdot
.96812 .56197 Mdot
.75174 .78362 Mdot
.64937 .89763 Mdot
.44573 .79636 Mdot
.86951 .42379 Mdot
.10775 .23824 Mdot
.64803 .54028 Mdot
.08147 .43344 Mdot
.9692 .88773 Mdot
.0712 .10201 Mdot
.69125 .62005 Mdot
.35034 .65909 Mdot
.10953 .75918 Mdot
.16113 .0516 Mdot
.26787 .10674 Mdot
.26755 .99968 Mdot
.15991 .89236 Mdot
.11196 .95205 Mdot
.34335 .23139 Mdot
.64686 .30351 Mdot
.83856 .19171 Mdot
.97627 .13771 Mdot
.27945 .30318 Mdot
.48757 .20812 Mdot
.60874 .12117 Mdot
.43325 .82451 Mdot
.80411 .37086 Mdot
.22528 .42117 Mdot
.54578 .32049 Mdot
.1823 .63652 Mdot
.80402 .62173 Mdot
.47627 .67224 Mdot
.98299 .50672 Mdot
.60855 .62556 Mdot
.93642 .32787 Mdot
.69762 .7612 Mdot
.5131 .81548 Mdot
.42016 .90706 Mdot
.79151 .37134 Mdot
.23926 .44776 Mdot
.57547 .33621 Mdot
.42039 .84492 Mdot
.73096 .31057 Mdot
.14765 .41669 Mdot
.67279 .52513 Mdot
.18344 .51066 Mdot
.67602 .49258 Mdot
.16448 .48846 Mdot
.69585 .53137 Mdot
.27744 .58159 Mdot
.76146 .48402 Mdot
.35668 .59522 Mdot
.07886 .72218 Mdot
.27135 .19249 Mdot
.35976 .08842 Mdot
.58871 .22895 Mdot
.40697 .81826 Mdot
.61048 .20351 Mdot
.52673 .91624 Mdot
.62917 .10245 Mdot
.53977 .9106 Mdot
.72588 .18611 Mdot
.01331 .28743 Mdot
.2077 .19439 Mdot
.32713 .11943 Mdot
.46075 .13362 Mdot
.32237 .86162 Mdot
.1831 .86073 Mdot
.02674 .84364 Mdot
.6841 .65736 Mdot
.36141 .6773 Mdot
.1866 .82519 Mdot
.98494 .79834 Mdot
.88853 .90359 Mdot
.51015 .62161 Mdot
.20274 .69259 Mdot
.83001 .62727 Mdot
.43353 .60353 Mdot
.58521 .15167 Mdot
.30524 .72004 Mdot
.97764 .67239 Mdot
.80606 .82842 Mdot
.68017 .87411 Mdot
.56283 .88267 Mdot
.874 .31116 Mdot
.97788 .10388 Mdot
.23609 .25821 Mdot
.38447 .14838 Mdot
.79329 .40883 Mdot
.27524 .48195 Mdot
.65708 .38184 Mdot
.96847 .31139 Mdot
.49914 .53067 Mdot
.0238 .52466 Mdot
.38247 .35867 Mdot
.99122 .60875 Mdot
.66139 .67017 Mdot
.27741 .61602 Mdot
.79583 .51841 Mdot
.38246 .58664 Mdot
.21911 .83665 Mdot
.96259 .74348 Mdot
.96553 .00294 Mdot
.20788 .24235 Mdot
.37493 .16705 Mdot
.75388 .37895 Mdot
.24658 .4927 Mdot
.62545 .37887 Mdot
.79434 .16888 Mdot
.03436 .24002 Mdot
.03575 .00139 Mdot
.789 .75325 Mdot
.62306 .83405 Mdot
.2352 .61215 Mdot
.73808 .50287 Mdot
.35191 .61383 Mdot
.07236 .72045 Mdot
.30357 .23121 Mdot
.48322 .17965 Mdot
.5456 .06239 Mdot
.92287 .37727 Mdot
.81915 .89628 Mdot
.726 .90685 Mdot
.7343 .0083 Mdot
.85127 .11697 Mdot
.8643 .01304 Mdot
.71624 .85194 Mdot
.65729 .94105 Mdot
.52871 .87142 Mdot
.59999 .07128 Mdot
.32608 .72608 Mdot
.06295 .73687 Mdot
.37059 .30765 Mdot
.86896 .49837 Mdot
.18442 .31545 Mdot
.47904 .29463 Mdot
.62739 .14835 Mdot
.57525 .94786 Mdot
.03047 .45522 Mdot
0 .95 Mdot
.95 .95 Mdot
.24427 .29427 Mdot
.42518 .18091 Mdot
.10142 .67624 Mdot
.1148 .01337 Mdot
.39248 .27769 Mdot
.97351 .58102 Mdot
.73913 .76562 Mdot
.61624 .87711 Mdot
.23662 .62037 Mdot
.74684 .51023 Mdot
.37093 .62409 Mdot
.18738 .81645 Mdot
.97487 .78749 Mdot
.93755 .96268 Mdot
.32627 .38872 Mdot
.72638 .40011 Mdot
.22833 .50195 Mdot
.62651 .39818 Mdot
.81989 .19339 Mdot
.02165 .20175 Mdot
.07233 .05068 Mdot
.63394 .56161 Mdot
.02633 .39239 Mdot
.23524 .20891 Mdot
.33485 .09961 Mdot
.475 .14015 Mdot
.44089 .96589 Mdot
.00247 .56158 Mdot
.54675 .54428 Mdot
.41362 .86686 Mdot
.70505 .29144 Mdot
.06644 .36139 Mdot
.97612 .90967 Mdot
.05234 .07622 Mdot
.76877 .71644 Mdot
.59155 .82278 Mdot
.02043 .42888 Mdot
.30668 .28624 Mdot
.54874 .24206 Mdot
.12665 .57792 Mdot
.90865 .782 Mdot
.29555 .38689 Mdot
.61367 .31812 Mdot
.66155 .04788 Mdot
.65584 .99429 Mdot
.57488 .91904 Mdot
.99896 .42408 Mdot
.43031 .43135 Mdot
.38931 .959 Mdot
.63445 .24514 Mdot
.71273 .07828 Mdot
.8747 .16196 Mdot
.82593 .95123 Mdot
.76684 .94091 Mdot
.81561 .04876 Mdot
.88513 .06953 Mdot
.69072 .80558 Mdot
.53399 .84327 Mdot
.61337 .07938 Mdot
.4209 .80753 Mdot
.69725 .27635 Mdot
.02705 .3298 Mdot
.1684 .14135 Mdot
.33891 .17051 Mdot
.56471 .2258 Mdot
.2311 .66639 Mdot
.79126 .56015 Mdot
.42827 .63701 Mdot
.58001 .15174 Mdot
.26853 .68852 Mdot
.8505 .58198 Mdot
.33171 .48121 Mdot
.84247 .51076 Mdot
.2845 .44204 Mdot
.63854 .35403 Mdot
.84442 .20588 Mdot
.97403 .12961 Mdot
.28465 .31063 Mdot
.5075 .22285 Mdot
.78281 .27531 Mdot
.14862 .36581 Mdot
.61884 .47022 Mdot
.84574 .22691 Mdot
.99115 .14541 Mdot
.19846 .2073 Mdot
.34959 .15113 Mdot
.59773 .24814 Mdot
.48779 .89006 Mdot
.29243 .80464 Mdot
.02235 .72992 Mdot
.59633 .57398 Mdot
.80419 .20786 Mdot
.06218 .25799 Mdot
.89591 .83373 Mdot
.40744 .51153 Mdot
.30695 .89952 Mdot
.16296 .85601 Mdot
.06737 .90441 Mdot
.51414 .44676 Mdot
.05972 .54559 Mdot
.197 .13728 Mdot
.2814 .0844 Mdot
.27332 .99193 Mdot
.16311 .88978 Mdot
.10076 .93766 Mdot
.37926 .2785 Mdot
.89135 .51209 Mdot
.10628 .21493 Mdot
.63132 .52504 Mdot
.9748 .34348 Mdot
.49393 .51913 Mdot
.97062 .47669 Mdot
.6518 .68118 Mdot
.24162 .58983 Mdot
.71891 .47728 Mdot
.28908 .57018 Mdot
.77859 .48951 Mdot
.36426 .58567 Mdot
.11081 .74655 Mdot
.14286 .03205 Mdot
.30388 .16102 Mdot
.41404 .11016 Mdot
.95129 .53726 Mdot
.8242 .8729 Mdot
.6923 .8681 Mdot
.60206 .90976 Mdot
.17826 .5762 Mdot
.75165 .5734 Mdot
.43907 .68742 Mdot
.71036 .27128 Mdot
.06134 .35098 Mdot
.9935 .93216 Mdot
.97115 .97766 Mdot
.14963 .17847 Mdot
.42832 .2787 Mdot
.22207 .79375 Mdot
.91884 .69677 Mdot
.15942 .24058 Mdot
.46153 .30211 Mdot
.49695 .03543 Mdot
.51106 .0141 Mdot
.6025 .09144 Mdot
.36283 .76033 Mdot
.2775 .91467 Mdot
.09467 .81717 Mdot
.28754 .19287 Mdot
.39718 .10963 Mdot
.83607 .4389 Mdot
.23007 .39399 Mdot
.5187 .28864 Mdot
.93795 .41925 Mdot
.78062 .84267 Mdot
.71682 .9362 Mdot
.74298 .02616 Mdot
.88214 .13916 Mdot
.77295 .89081 Mdot
.76628 .99333 Mdot
.86787 .10159 Mdot
.79172 .92385 Mdot
.7916 .99987 Mdot
.86772 .07613 Mdot
.76682 .89909 Mdot
.77378 .00697 Mdot
.88242 .10864 Mdot
.74127 .85885 Mdot
.71253 .97126 Mdot
.76714 .05461 Mdot
.92938 .16224 Mdot
.5699 .64052 Mdot
.68417 .11426 Mdot
.81856 .13439 Mdot
.96526 .1467 Mdot
.35323 .38797 Mdot
.85335 .50012 Mdot
.24081 .38746 Mdot
.51604 .27523 Mdot
.90336 .38732 Mdot
.92635 .02299 Mdot
.44669 .52035 Mdot
.60084 .15414 Mdot
.41456 .81372 Mdot
.65853 .24397 Mdot
.8376 .17907 Mdot
.96622 .12862 Mdot
.32952 .3633 Mdot
.71495 .38543 Mdot
.18756 .47261 Mdot
.63073 .44317 Mdot
.88953 .2588 Mdot
.86102 .97149 Mdot
.68637 .82535 Mdot
.53795 .85158 Mdot
.65265 .1147 Mdot
.67943 .02678 Mdot
.71257 .03314 Mdot
.82911 .11655 Mdot
.92492 .09581 Mdot
.52702 .6021 Mdot
.31736 .79034 Mdot
.09191 .77455 Mdot
.25825 .16634 Mdot
.31201 .05375 Mdot
.33516 .02316 Mdot
.39995 .06479 Mdot
.80964 .40969 Mdot
.2561 .44646 Mdot
.58929 .33319 Mdot
.51522 .92593 Mdot
.54755 .03232 Mdot
.90776 .36021 Mdot
.87811 .97035 Mdot
.6207 .74259 Mdot
.1295 .5088 Mdot
.82858 .69908 Mdot
.5087 .68012 Mdot
.24968 .74098 Mdot
.87658 .6269 Mdot
.28341 .40684 Mdot
.60062 .31721 Mdot
.5762 .97558 Mdot
.06505 .48885 Mdot
.11113 .04608 Mdot
.441 .32988 Mdot
.36729 .92629 Mdot
.46859 .1013 Mdot
.35143 .88284 Mdot
.33885 .98742 Mdot
.38133 .04248 Mdot
.66796 .28664 Mdot
.92393 .25597 Mdot
.69234 .76841 Mdot
.50251 .81017 Mdot
.33028 .82776 Mdot
.1827 .85242 Mdot
.01917 .83647 Mdot
.72178 .7026 Mdot
.52099 .79922 Mdot
.46672 .94573 Mdot
.1812 .71448 Mdot
.88408 .70288 Mdot
.32854 .44446 Mdot
.79185 .46331 Mdot
.33095 .5391 Mdot
.89698 .56603 Mdot
.13483 .23785 Mdot
.53777 .40293 Mdot
.2026 .66483 Mdot
.80239 .59979 Mdot
.45645 .65406 Mdot
.80943 .35298 Mdot
.19972 .39029 Mdot
.53106 .33134 Mdot
.07844 .54738 Mdot
.09872 .02028 Mdot
.47143 .37271 Mdot
.64525 .17381 Mdot
.70041 .05517 Mdot
.81602 .11561 Mdot
.95123 .13521 Mdot
.42252 .47129 Mdot
.3726 .95008 Mdot
.52313 .15053 Mdot
.83499 .31186 Mdot
.10583 .27085 Mdot
.68926 .58342 Mdot
.3066 .61734 Mdot
.87956 .57296 Mdot
.21741 .33785 Mdot
.46445 .24704 Mdot
.46471 .00026 Mdot
.21993 .75522 Mdot
.88089 .66096 Mdot
.29993 .41904 Mdot
.65926 .35933 Mdot
.95647 .29721 Mdot
.55459 .59812 Mdot
.52739 .9728 Mdot
.691 .1636 Mdot
.893 .202 Mdot
.78885 .89585 Mdot
.76576 .97691 Mdot
.8513 .08554 Mdot
.83278 .98149 Mdot
.78102 .94823 Mdot
.82225 .04123 Mdot
.86473 .04249 Mdot
.74414 .8794 Mdot
.73687 .99273 Mdot
.8399 .10303 Mdot
.88397 .04407 Mdot
.6702 .78624 Mdot
.43341 .76321 Mdot
.74397 .31056 Mdot
.16781 .42384 Mdot
.62284 .45503 Mdot
.8549 .23206 Mdot
.96769 .11279 Mdot
.30512 .33744 Mdot
.59462 .2895 Mdot
.50815 .91353 Mdot
.47871 .97056 Mdot
.30066 .82195 Mdot
.06449 .76383 Mdot
.38912 .32463 Mdot
.99887 .60975 Mdot
.61654 .61767 Mdot
.97903 .36249 Mdot
.48788 .50885 Mdot
.91196 .42408 Mdot
.92137 .00942 Mdot
.45906 .53768 Mdot
.71329 .25423 Mdot
.05209 .3388 Mdot
.03275 .98067 Mdot
.78576 .75301 Mdot
.62485 .83909 Mdot
.25097 .62612 Mdot
.76303 .51206 Mdot
.38544 .62241 Mdot
.27339 .88795 Mdot
.05928 .78588 Mdot
.43976 .38048 Mdot
.40853 .96877 Mdot
.77169 .36316 Mdot
.23861 .46691 Mdot
.59429 .35568 Mdot
.57206 .97777 Mdot
.03721 .46515 Mdot
.24426 .20705 Mdot
.33794 .09369 Mdot
.48335 .1454 Mdot
.51239 .02905 Mdot
.6281 .1157 Mdot
.54675 .91865 Mdot
.78794 .24119 Mdot
.11171 .32378 Mdot
.71615 .60444 Mdot
.40958 .69343 Mdot
.50355 .09397 Mdot
.62237 .11882 Mdot
.51585 .89348 Mdot
.5201 .00425 Mdot
.66469 .14459 Mdot
.76713 .10244 Mdot
.97721 .21007 Mdot
.34628 .36907 Mdot
.79895 .45268 Mdot
.31343 .51448 Mdot
.80114 .48771 Mdot
.34591 .54478 Mdot
.97287 .62695 Mdot
.78884 .81597 Mdot
.68589 .89705 Mdot
.60784 .92196 Mdot
.22825 .62041 Mdot
.74496 .51671 Mdot
.3752 .63023 Mdot
.21863 .84343 Mdot
.96955 .75092 Mdot
.93232 .96277 Mdot
.35469 .42237 Mdot
.89546 .54076 Mdot
.11652 .22106 Mdot
.59289 .47637 Mdot
.68321 .09031 Mdot
.79092 .10772 Mdot
.9761 .18518 Mdot
.32795 .35185 Mdot
.69671 .36875 Mdot
.11767 .42096 Mdot
.78798 .67031 Mdot
.54081 .75283 Mdot
.57616 .03536 Mdot
.12455 .54839 Mdot
.88739 .76284 Mdot
.37436 .48697 Mdot
.07039 .69603 Mdot
.28959 .2192 Mdot
.42899 .1394 Mdot
.08763 .65864 Mdot
.16338 .07575 Mdot
.286 .12262 Mdot
.32292 .03692 Mdot
.36067 .03774 Mdot
.54298 .18231 Mdot
.02252 .47954 Mdot
.34494 .32242 Mdot
.74569 .40075 Mdot
.26011 .51442 Mdot
.66269 .40258 Mdot
.01588 .35319 Mdot
.25807 .24219 Mdot
.38761 .12954 Mdot
.79422 .40661 Mdot
.27218 .47796 Mdot
.64687 .37468 Mdot
.9098 .26294 Mdot
.77086 .86105 Mdot
.73644 .96559 Mdot
.5 .95 Mdot
.45 .95 Mdot
.05573 .60573 Mdot
.27928 .22355 Mdot
.40754 .12826 Mdot
.92439 .51685 Mdot
.95083 .02645 Mdot
.31599 .36516 Mdot
.66147 .34548 Mdot
.95308 .29161 Mdot
.56841 .61533 Mdot
.64801 .0796 Mdot
.62065 .97264 Mdot
.35927 .73861 Mdot
.2362 .87694 Mdot
.00324 .76703 Mdot
.74762 .74438 Mdot
.60596 .85834 Mdot
.15241 .54645 Mdot
.78774 .63533 Mdot
.50598 .71824 Mdot
.26609 .7601 Mdot
.91779 .6517 Mdot
.11972 .20193 Mdot
.56045 .44073 Mdot
.41419 .85375 Mdot
.69596 .28177 Mdot
.02819 .33223 Mdot
.16412 .13593 Mdot
.34426 .18015 Mdot
.60009 .25582 Mdot
.51125 .91116 Mdot
.50107 .98982 Mdot
.49838 .99731 Mdot
.48437 .98599 Mdot
.36111 .87675 Mdot
.38443 .02332 Mdot
.66803 .2836 Mdot
.92121 .25317 Mdot
.70368 .78247 Mdot
.55338 .8497 Mdot
.76979 .21641 Mdot
.09168 .32189 Mdot
.80672 .71504 Mdot
.56584 .75912 Mdot
.77282 .20697 Mdot
.08245 .30963 Mdot
.84042 .75797 Mdot
.53747 .69704 Mdot
.49436 .95689 Mdot
.41175 .9174 Mdot
.74259 .33083 Mdot
.1863 .44371 Mdot
.60398 .41768 Mdot
.69883 .09485 Mdot
.85067 .15184 Mdot
.90106 .05039 Mdot
.60028 .69922 Mdot
.95595 .35567 Mdot
.61605 .6601 Mdot
.01843 .40238 Mdot
.29209 .27366 Mdot
.49038 .1983 Mdot
.62139 .13101 Mdot
.52213 .90074 Mdot
.57732 .05518 Mdot
.15267 .57535 Mdot
.81586 .66319 Mdot
.4991 .68324 Mdot
.17607 .67697 Mdot
.857 .68093 Mdot
.40958 .55258 Mdot
.36272 .95314 Mdot
.46973 .10701 Mdot
.36614 .89641 Mdot
.43216 .06602 Mdot
.03759 .60543 Mdot
.38232 .34473 Mdot
.97634 .59402 Mdot
.73535 .75901 Mdot
.60374 .86838 Mdot
.14793 .5442 Mdot
.7994 .65146 Mdot
.51172 .71232 Mdot
.30597 .79425 Mdot
.0543 .74834 Mdot
.42986 .37556 Mdot
.33016 .9003 Mdot
.25471 .92456 Mdot
.06567 .81096 Mdot
.42986 .36419 Mdot
.31879 .88894 Mdot
.19611 .87732 Mdot
.0226 .82649 Mdot
.69143 .66883 Mdot
.39975 .70832 Mdot
.45183 .05208 Mdot
.17187 .72004 Mdot
.90939 .73752 Mdot
.24747 .33808 Mdot
.4716 .22413 Mdot
.49801 .02641 Mdot
.5105 .01249 Mdot
.5964 .0859 Mdot
.3166 .7202 Mdot
.01882 .70223 Mdot
.5896 .57078 Mdot
.75498 .16538 Mdot
.0339 .27892 Mdot
.07731 .04341 Mdot
.60059 .52329 Mdot
.78207 .18148 Mdot
.05509 .27302 Mdot
.95012 .89502 Mdot
.18864 .23852 Mdot
.39486 .20622 Mdot
.91745 .5226 Mdot
.99232 .07486 Mdot
.12094 .12862 Mdot
.48214 .3612 Mdot
.71857 .23643 Mdot
.04744 .32887 Mdot
.04914 .00171 Mdot
.71229 .66314 Mdot
.45839 .7461 Mdot
.91651 .45812 Mdot
.93263 .01613 Mdot
.40637 .47374 Mdot
.26185 .85548 Mdot
.00633 .74448 Mdot
.70649 .70015 Mdot
.47935 .77286 Mdot
.10804 .62869 Mdot
.03721 .92917 Mdot
.70827 .67106 Mdot
.45535 .74708 Mdot
.89396 .43861 Mdot
.02114 .12718 Mdot
.00078 .97964 Mdot
.97496 .97418 Mdot
.12368 .14872 Mdot
.49118 .3675 Mdot
.79696 .30578 Mdot
.16868 .37172 Mdot
.5686 .39992 Mdot
.43401 .86541 Mdot
.8506 .41659 Mdot
.16604 .31544 Mdot
.51886 .35282 Mdot
.00339 .48453 Mdot
.46418 .46079 Mdot
.67634 .21216 Mdot
.88538 .20904 Mdot
.82918 .9438 Mdot
.75201 .92283 Mdot
.78884 .03683 Mdot
.90674 .1179 Mdot
.64073 .73399 Mdot
.23637 .59565 Mdot
.72202 .48564 Mdot
.30456 .58255 Mdot
.83786 .53329 Mdot
.31976 .4819 Mdot
.79287 .47312 Mdot
.3399 .54703 Mdot
.94589 .60599 Mdot
.92342 .97754 Mdot
.41657 .49315 Mdot
.35207 .9355 Mdot
.39485 .04278 Mdot
.75395 .3591 Mdot
.22679 .47284 Mdot
.59737 .37058 Mdot
.60784 .01047 Mdot
.31673 .70889 Mdot
.00803 .6913 Mdot
.64315 .63512 Mdot
.15054 .5074 Mdot
.7544 .60385 Mdot
.47191 .71751 Mdot
.99382 .52191 Mdot
.55897 .56514 Mdot
.52749 .96853 Mdot
.68752 .16002 Mdot
.87687 .18935 Mdot
.8447 .96783 Mdot
.73516 .89046 Mdot
.73486 .99971 Mdot
.84362 .10876 Mdot
.87921 .03559 Mdot
.68147 .80226 Mdot
.49611 .81464 Mdot
.2835 .78739 Mdot
.98139 .69789 Mdot
.80924 .82785 Mdot
.67488 .86564 Mdot
.53282 .85793 Mdot
.61883 .08602 Mdot
.4615 .84267 Mdot
.03732 .57581 Mdot
.3543 .31699 Mdot
.78801 .43371 Mdot
.30418 .51617 Mdot
.7702 .46602 Mdot
.34134 .57114 Mdot
.97689 .63555 Mdot
.77363 .79673 Mdot
.67219 .89856 Mdot
.55433 .88214 Mdot
.80947 .25513 Mdot
.10182 .29235 Mdot
.72907 .62725 Mdot
.46079 .73172 Mdot
.92084 .46005 Mdot
.91242 .99158 Mdot
.48656 .57414 Mdot
.96675 .48019 Mdot
.67801 .71126 Mdot
.3913 .71329 Mdot
.40147 .01017 Mdot
.76512 .36365 Mdot
.23783 .47271 Mdot
.59972 .36188 Mdot
.61484 .01512 Mdot
.36586 .75103 Mdot
.28522 .91935 Mdot
.11765 .83243 Mdot
.19951 .08186 Mdot
.22288 .02336 Mdot
.1483 .92542 Mdot
.17947 .03117 Mdot
.20418 .02471 Mdot
.16066 .95648 Mdot
.17402 .01336 Mdot
.19786 .02384 Mdot
.16687 .96901 Mdot
.17035 .00348 Mdot
.19638 .02603 Mdot
.17096 .97458 Mdot
.16604 .99508 Mdot
.19849 .03245 Mdot
.17469 .9762 Mdot
.15922 .98452 Mdot
.20604 .04682 Mdot
.18101 .97497 Mdot
.14494 .96394 Mdot
.22883 .08388 Mdot
.20847 .97964 Mdot
.11174 .90328 Mdot
.29551 .18377 Mdot
.41043 .11492 Mdot
.93095 .52052 Mdot
.9198 .98885 Mdot
.44658 .52678 Mdot
.60639 .15981 Mdot
.4567 .85031 Mdot
.0076 .5509 Mdot
.50533 .49773 Mdot
.04039 .53506 Mdot
.29572 .25533 Mdot
.48263 .18691 Mdot
.54818 .06555 Mdot
.94588 .3977 Mdot
.71514 .76925 Mdot
.57185 .85672 Mdot
.91463 .34278 Mdot
.82675 .91212 Mdot
.72591 .89916 Mdot
.72641 .0005 Mdot
.82878 .10237 Mdot
.91151 .08272 Mdot
.58225 .67074 Mdot
.80344 .22119 Mdot
.0765 .27307 Mdot
.83444 .75793 Mdot
.55331 .71888 Mdot
.63844 .08512 Mdot
.57495 .93652 Mdot
.01698 .44202 Mdot
.34039 .32341 Mdot
.72461 .38422 Mdot
.20877 .48416 Mdot
.61602 .40725 Mdot
.76536 .14934 Mdot
.0236 .25824 Mdot
.11725 .09365 Mdot
.46242 .34517 Mdot
.54694 .08452 Mdot
.95529 .40835 Mdot
.67252 .71723 Mdot
.37438 .70187 Mdot
.28541 .91103 Mdot
.10982 .82441 Mdot
.22506 .11525 Mdot
.23987 .01481 Mdot
.14285 .90298 Mdot
.17483 .03198 Mdot
.21469 .03986 Mdot
.16777 .95308 Mdot
.15218 .98441 Mdot
.22639 .07421 Mdot
.19875 .97236 Mdot
.11429 .91553 Mdot
.29681 .18253 Mdot
.4131 .11629 Mdot
.9509 .5378 Mdot
.82697 .87607 Mdot
.68936 .86239 Mdot
.58593 .89657 Mdot
.05524 .4693 Mdot
.1456 .09037 Mdot
.35309 .20749 Mdot
.67217 .31907 Mdot
.97473 .30256 Mdot
.45344 .47871 Mdot
.61085 .15741 Mdot
.48301 .87216 Mdot
.23646 .75345 Mdot
.87986 .6434 Mdot
.28661 .40675 Mdot
.60862 .32201 Mdot
.63334 .02472 Mdot
.48601 .85267 Mdot
.24091 .75489 Mdot
.88353 .64263 Mdot
.27058 .38705 Mdot
.55285 .28227 Mdot
.19828 .64544 Mdot
.78794 .58965 Mdot
.46017 .67224 Mdot
.85653 .39636 Mdot
.12658 .27005 Mdot
.60107 .47449 Mdot
.73643 .13536 Mdot
.98182 .24539 Mdot
.3542 .37238 Mdot
.84286 .48866 Mdot
.26129 .41842 Mdot
.56843 .30714 Mdot
.33994 .77151 Mdot
.17057 .83063 Mdot
.023 .85243 Mdot
.71499 .69199 Mdot
.49421 .77922 Mdot
.23287 .73866 Mdot
.8639 .63103 Mdot
.3357 .4718 Mdot
.85106 .51536 Mdot
.26336 .41231 Mdot
.56551 .30215 Mdot
.31342 .74791 Mdot
.03454 .72112 Mdot
.51576 .48121 Mdot
.1071 .59134 Mdot
.00407 .89698 Mdot
.87255 .86847 Mdot
.54085 .66831 Mdot
.49198 .95113 Mdot
.387 .89502 Mdot
.5558 .1688 Mdot
.10722 .55143 Mdot
.96359 .85637 Mdot
.07259 .109 Mdot
.69088 .61829 Mdot
.34726 .65638 Mdot
.09121 .74394 Mdot
.23108 .13988 Mdot
.26474 .03365 Mdot
.18907 .92434 Mdot
.07997 .89089 Mdot
.43435 .35438 Mdot
.34211 .90776 Mdot
.3172 .97509 Mdot
.27606 .95886 Mdot
.13573 .85967 Mdot
.15636 .02063 Mdot
.25025 .09389 Mdot
.23005 .97981 Mdot
.10451 .87446 Mdot
.29883 .19432 Mdot
.4311 .13227 Mdot
.096 .6649 Mdot
.12893 .03293 Mdot
.35488 .22595 Mdot
.70002 .34514 Mdot
.10475 .40473 Mdot
.82804 .7233 Mdot
.53414 .7061 Mdot
.47741 .94327 Mdot
.26308 .78567 Mdot
.93843 .67535 Mdot
.03409 .09566 Mdot
.89293 .85883 Mdot
.446 .55307 Mdot
.62828 .18228 Mdot
.6144 .98612 Mdot
.3341 .71971 Mdot
.09168 .75758 Mdot
.24239 .1507 Mdot
.28028 .03789 Mdot
.22419 .94391 Mdot
0 1 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.5 1 Mdot
.49999 .99999 Mdot
.49995 .99995 Mdot
.49951 .99957 Mdot
.49569 .99617 Mdot
.46166 .96597 Mdot
.16181 .70015 Mdot
.91459 .75278 Mdot
.23697 .32238 Mdot
.449 .21203 Mdot
.31008 .86108 Mdot
.1355 .82543 Mdot
.12292 .98742 Mdot
.33291 .20999 Mdot
.57661 .24369 Mdot
.33608 .75947 Mdot
.14049 .80441 Mdot
.08429 .94379 Mdot
.46526 .38097 Mdot
.60497 .13971 Mdot
.42736 .82238 Mdot
.7587 .33135 Mdot
.20247 .44377 Mdot
.58146 .379 Mdot
.50614 .92467 Mdot
.47376 .96762 Mdot
.25854 .78478 Mdot
.93084 .6723 Mdot
.07215 .14131 Mdot
.72551 .65336 Mdot
.4798 .75428 Mdot
.09304 .61325 Mdot
.09146 .99841 Mdot
.48433 .39287 Mdot
.76767 .28334 Mdot
.15823 .39057 Mdot
.61483 .4566 Mdot
.80732 .19248 Mdot
.04242 .2351 Mdot
.9841 .94168 Mdot
.03689 .05279 Mdot
.83375 .79685 Mdot
.59398 .76023 Mdot
.9745 .38052 Mdot
.53276 .55826 Mdot
.3187 .78594 Mdot
.09273 .77404 Mdot
.25374 .16101 Mdot
.30097 .04723 Mdot
.29076 .98979 Mdot
.20282 .91205 Mdot
.04939 .84657 Mdot
.55578 .50639 Mdot
.44468 .8889 Mdot
.95406 .50938 Mdot
.78059 .82653 Mdot
.70069 .9201 Mdot
.68183 .98114 Mdot
.67642 .99459 Mdot
.66815 .99173 Mdot
.62987 .96172 Mdot
.40309 .77322 Mdot
.53908 .13599 Mdot
.94587 .40679 Mdot
.72431 .77844 Mdot
.60234 .87804 Mdot
.14843 .54609 Mdot
.7997 .65127 Mdot
.51117 .71147 Mdot
.30078 .78961 Mdot
.03254 .73176 Mdot
.53809 .50555 Mdot
.30775 .76966 Mdot
.03587 .72812 Mdot
.51503 .47917 Mdot
.09927 .58424 Mdot
.03281 .93354 Mdot
.73832 .70552 Mdot
.55493 .81661 Mdot
.74846 .19353 Mdot
.05601 .30756 Mdot
.97952 .92351 Mdot
.04599 .06647 Mdot
.79501 .74902 Mdot
.61386 .81886 Mdot
.16348 .54962 Mdot
.75962 .59613 Mdot
.4678 .70819 Mdot
.95212 .48432 Mdot
.76655 .81443 Mdot
.68904 .92249 Mdot
.6449 .95585 Mdot
.4806 .8357 Mdot
.18082 .70023 Mdot
.87055 .68973 Mdot
.36976 .4992 Mdot
.05566 .6859 Mdot
.35984 .30418 Mdot
.80489 .44505 Mdot
.29842 .49353 Mdot
.72903 .43061 Mdot
.26406 .53503 Mdot
.68935 .42529 Mdot
.1488 .45945 Mdot
.71191 .56311 Mdot
.35734 .64543 Mdot
.13261 .77527 Mdot
.08334 .95073 Mdot
.47698 .39364 Mdot
.71006 .23308 Mdot
.02234 .31228 Mdot
.17875 .15642 Mdot
.33086 .1521 Mdot
.5096 .17874 Mdot
.75546 .24586 Mdot
.11475 .35929 Mdot
.73861 .62386 Mdot
.4737 .73509 Mdot
.02551 .55181 Mdot
.39954 .37403 Mdot
.11612 .71658 Mdot
.09009 .97397 Mdot
.46658 .3765 Mdot
.61088 .14429 Mdot
.47002 .85915 Mdot
.12058 .65055 Mdot
.00555 .88497 Mdot
.8517 .84615 Mdot
.59212 .74043 Mdot
.94201 .34988 Mdot
.68891 .7469 Mdot
.46881 .77991 Mdot
.03182 .563 Mdot
.37358 .34176 Mdot
.92056 .54698 Mdot
.0008 .08024 Mdot
.07542 .07462 Mdot
.64163 .56621 Mdot
.07352 .43188 Mdot
.0089 .93538 Mdot
.88204 .87315 Mdot
.50735 .62531 Mdot
.18411 .67676 Mdot
.8409 .65678 Mdot
.43495 .59405 Mdot
.58624 .15129 Mdot
.3121 .72586 Mdot
.00762 .69552 Mdot
.64981 .64219 Mdot
.19256 .54275 Mdot
.69299 .50043 Mdot
.2368 .54381 Mdot
.67036 .43355 Mdot
.08139 .41103 Mdot
.9472 .86581 Mdot
.17585 .22865 Mdot
.40915 .2333 Mdot
.0405 .63134 Mdot
.39142 .35093 Mdot
.03989 .64847 Mdot
.41203 .37213 Mdot
.19923 .7872 Mdot
.92855 .72933 Mdot
.14137 .21282 Mdot
.48968 .34831 Mdot
.76584 .27616 Mdot
.15057 .38473 Mdot
.63164 .48107 Mdot
.93268 .30104 Mdot
.69103 .75835 Mdot
.48787 .79684 Mdot
.19986 .71199 Mdot
.8526 .65274 Mdot
.39584 .54324 Mdot
.26091 .86507 Mdot
.01451 .7536 Mdot
.66669 .65218 Mdot
.28378 .61709 Mdot
.81177 .52799 Mdot
.37099 .55922 Mdot
.12283 .75184 Mdot
.0977 .97487 Mdot
.4308 .3331 Mdot
.29465 .86384 Mdot
.08796 .79331 Mdot
.29642 .20846 Mdot
.43785 .14143 Mdot
.15524 .71738 Mdot
.95025 .79502 Mdot
.08785 .1376 Mdot
.64124 .55339 Mdot
.05856 .41732 Mdot
.07515 .01659 Mdot
.58501 .50986 Mdot
.66207 .07706 Mdot
.68747 .02539 Mdot
.74205 .05458 Mdot
.90932 .16728 Mdot
.67755 .76823 Mdot
.44643 .76888 Mdot
.84735 .40092 Mdot
.16035 .313 Mdot
.53137 .37102 Mdot
.1206 .58922 Mdot
.94413 .82353 Mdot
.15077 .20664 Mdot
.45293 .30216 Mdot
.43041 .97748 Mdot
.93616 .50575 Mdot
.8769 .94074 Mdot
.59595 .71905 Mdot
.94672 .35077 Mdot
.6635 .71678 Mdot
.33383 .67033 Mdot
.04109 .70726 Mdot
.4639 .4228 Mdot
.63613 .17224 Mdot
.64928 .01315 Mdot
.56077 .91149 Mdot
.88742 .32664 Mdot
.93804 .05062 Mdot
.41152 .47348 Mdot
.29704 .88552 Mdot
.11679 .81975 Mdot
.19044 .07365 Mdot
.22711 .03668 Mdot
.1612 .93409 Mdot
.15015 .98895 Mdot
.23716 .08701 Mdot
.21371 .97655 Mdot
.10501 .8913 Mdot
.31343 .20842 Mdot
.49507 .18164 Mdot
.64217 .14711 Mdot
.65732 .01515 Mdot
.60294 .94562 Mdot
.21993 .61699 Mdot
.74266 .52273 Mdot
.3783 .63563 Mdot
.24263 .86434 Mdot
.99408 .75144 Mdot
.78698 .7929 Mdot
.66403 .87705 Mdot
.49655 .83252 Mdot
.30492 .80837 Mdot
.06486 .75995 Mdot
.38325 .31838 Mdot
.95571 .57246 Mdot
.83424 .87854 Mdot
.67441 .84017 Mdot
.50535 .83094 Mdot
.37374 .86839 Mdot
.44811 .07438 Mdot
.16568 .71756 Mdot
.9219 .75623 Mdot
.20314 .28124 Mdot
.41824 .21509 Mdot
.08583 .66759 Mdot
.18133 .0955 Mdot
.26485 .08352 Mdot
.23914 .97429 Mdot
.10194 .8628 Mdot
.29897 .19704 Mdot
.43426 .13528 Mdot
.12232 .68806 Mdot
.03599 .91367 Mdot
.69987 .66387 Mdot
.42301 .72314 Mdot
.62797 .20496 Mdot
.63528 .00731 Mdot
.47959 .84431 Mdot
.18142 .70183 Mdot
.871 .68959 Mdot
.36789 .49689 Mdot
.04262 .67473 Mdot
.42255 .37993 Mdot
.28151 .85895 Mdot
.04813 .76662 Mdot
.48296 .43484 Mdot
.79878 .31582 Mdot
.17676 .37798 Mdot
.55655 .37979 Mdot
.32392 .76737 Mdot
.0952 .77129 Mdot
.23911 .1439 Mdot
.27153 .03243 Mdot
.20006 .92852 Mdot
.0689 .86884 Mdot
.47037 .40147 Mdot
.66561 .19524 Mdot
.82197 .15636 Mdot
.98043 .15846 Mdot
.27554 .29511 Mdot
.47087 .19533 Mdot
.46339 .99253 Mdot
.20194 .73854 Mdot
.87681 .67487 Mdot
.33045 .45364 Mdot
.80932 .47887 Mdot
.32579 .51647 Mdot
.85212 .52633 Mdot
.27097 .41886 Mdot
.58541 .31443 Mdot
.4694 .88399 Mdot
.1405 .6711 Mdot
.95095 .81045 Mdot
.09932 .14837 Mdot
.59668 .49736 Mdot
.72997 .13328 Mdot
.96852 .23855 Mdot
.42602 .45751 Mdot
.38414 .95812 Mdot
.60101 .21687 Mdot
.47843 .87742 Mdot
.20531 .72688 Mdot
.86174 .65643 Mdot
.36878 .50704 Mdot
.05784 .68906 Mdot
.35089 .29305 Mdot
.7463 .39541 Mdot
.25549 .50919 Mdot
.65125 .39577 Mdot
.95345 .3022 Mdot
.57685 .6234 Mdot
.71756 .14071 Mdot
.94929 .23173 Mdot
.53004 .58075 Mdot
.3198 .78976 Mdot
.10091 .78111 Mdot
.22202 .12111 Mdot
.24622 .02419 Mdot
.15664 .91042 Mdot
.13922 .98258 Mdot
.26687 .12765 Mdot
.2867 .01983 Mdot
.22193 .93523 Mdot
.06036 .83843 Mdot
.48634 .42599 Mdot
.81685 .33051 Mdot
.1646 .34775 Mdot
.55484 .39024 Mdot
.32139 .76655 Mdot
.08406 .76267 Mdot
.28529 .20123 Mdot
.39972 .11443 Mdot
.85772 .458 Mdot
.18422 .3265 Mdot
.49044 .30622 Mdot
.7298 .23935 Mdot
.07427 .34447 Mdot
.91752 .84324 Mdot
.31265 .39513 Mdot
.6789 .36625 Mdot
.04992 .37102 Mdot
.07718 .02725 Mdot
.58511 .50794 Mdot
.66085 .07574 Mdot
.68041 .01956 Mdot
.70925 .02884 Mdot
.81585 .1066 Mdot
.94253 .12668 Mdot
.46282 .52029 Mdot
.72521 .26239 Mdot
.08819 .36298 Mdot
.86496 .77677 Mdot
.47761 .61265 Mdot
.93401 .4564 Mdot
.83922 .90521 Mdot
.68799 .84877 Mdot
.56735 .87936 Mdot
.90424 .33689 Mdot
.87172 .96748 Mdot
.64304 .77132 Mdot
.28617 .64313 Mdot
.84387 .5577 Mdot
.32742 .48355 Mdot
.82611 .49869 Mdot
.3139 .48779 Mdot
.77621 .46231 Mdot
.33753 .56132 Mdot
.94904 .61151 Mdot
.91121 .96217 Mdot
.46318 .55197 Mdot
.7597 .29652 Mdot
.16824 .40854 Mdot
.6065 .43826 Mdot
.73583 .12933 Mdot
.97482 .239 Mdot
.38932 .41449 Mdot
.09 .70068 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo002:ooooo`?o0000
00?o410@ooooooooool0Foooool008cooooo00?o0000ooooooooool0G?ooool008cooooo00?o0000
ooooooooool0G?ooool008Oooooo00KoMgMgoa0@4?l0003o410@oiRHV?l0001Nooooo`00Q_ooool0
1omgMgOo8B4Qolc<c?ooooooc<c<ob4Q8Ol00000G_ooool008Kooooo00?o410@olc<c?ooool00_oo
ool00oo<c<co0000ooooo`1Mooooo`00Q_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo05cooooo0026ooooo`03oa0@4?o<c<cooooo00;ooooo00?oc<c<o`000?ooool0GOooool008Ko
oooo00OoZJVYob4Q8Oo<c<coooooolc<c?lQ8B7o000005kooooo0027ooooo`07ojVYZOl@413o0000
oa0@4?n7QhOo0000oa0@401Mooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo0019ooooo`04oiRHV?l0003o0000
oiRHV0Kooooo00?oEEEEo`000?mEEED01Oooool6o`0000cooooo00CoV9RHo`000?l0003oV9RH1_oo
ool00omEEEGo0000oeEEE@09ooooo`;o000000?o410@ooooooooool02?ooool01?nHV9So0000o`00
0?nHV9P6ooooo`03oeEEEOl0003oEEEE00Kooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h;oooo
o`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01_ooool01_o^k^koEEEEo`000?l0
003oEEEEonk^kQ?ooooo1?l000000ol@413oooooooooo`04ooooo`00B?ooool01_nj^[[o8B4QomgM
gOoMgMgo8B4QokZj^PGooooo0ol00005ooooo`03oiRHV?l0003ogMgM00;ooooo00?o410@oooooooo
ool02Oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol0000:ooooo`03o`000?oooooo
oooo00Sooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001_ooool2ogMgM`;ooooo
00?oMgMgoeEEEOooool02Oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol00006oooo
o`06oeEEEOmgMgOooooooooooomgMgOoEEEE5Oooool00ol0003oooooooooo`06ooooo`00B?ooool0
1_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool00on7QhOo8B4Q
onk^kP0=ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06oooo
o`Ko00002Oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_oo
ool00olQ8B7oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00KoA4A4oiRHV?oooooooooo
oiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo0018ooooo`06o`000?o^k^koooooooooooo^
k^ko00003oooool00onYZJWo8B4Qonk^kP0<ooooo`06o`000?o^k^koooooooooooo^k^ko00003_oo
ool01Om4A4Co^[Zjoooooooooooo000000[ooooo00Ko0000onk^k_ooooooooooonk^k_l0000>oooo
o`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool02?ooool01_l0003ok^k^oooooooooooo
k^k^o`0000kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Kooooo0018ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool0
0onHV9So<S8booooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool0
1OoMgMgo8B4Qoooooooooooo000000[ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0<ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE2_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00cooooo00KoEEEEogMgMoooooooooooogMgMomEEEDEooooo`03o`000?oooooo
oooo00Kooooo0018ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool00om4
A4CoMgMgooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01?mg
MgOoV9RHooooool0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool0
1_l0003oMgMgo`000?l0003oEEEEonk^kP[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0<ooooo`03omgMgOl0003o000000;o000000?ogMgMooooooooool04oooool00ol0003ooooo
ooooo`06ooooo`00B?ooool01_l0003ok^k^ooooooooooook^k^o`00017ooooo00?ogMgMoa0@4?oo
ool02_ooool01_l0003ok^k^ooooooooooook^k^o`0000oooooo00Cok^k^ob4Q8Ooooooo00002_oo
ool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00?oA4A4oiRHV?ooool03Oooool01_l0003o
k^k^ooooooooooook^k^o`0000kooooo00Ko<S8bofIVI_o^k^kok^k^ofIVI_lb<S8Eooooo`03o`00
0?oooooooooo00Kooooo0018ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A44_ooool00ol0003o
ooooooooo`09ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A44?ooool00omgMgOoV9RHo`00000:
ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A43_ooool00onj^[[o8B4Qooooo`0=ooooo`06odA4
A?nHV9SooooooooooonHV9SoA4A43_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool01_ooool004Sooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X=
ooooo`06o`000?n7QhOok^k^oooooonHV9SoEEEE2oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj
^Q3ooooo00?ok^k^oc8b<_l000002_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Poooooo00?o
EEEEoc8b<_oMgMd03?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00Ko<S8bofIVI_o^
k^kok^k^ofIVI_lb<S8Cooooo`03o`000?m4A4Co000000Sooooo0019ooooo`04oiRHV?l0003o0000
oiRHV0kooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h<ooooo`04oiRHV?l0003o0000oiRHV1;o
oooo00?oV9RHoa0@4?ooool02_ooool01?nHV9So0000o`000?nHV9PAooooo`04oiRHV?lQ8B7o0000
ob4Q8@_ooooo00CoV9RHo`000?l0003oV9RH3oooool01_o^k^koA4A4o`000?l0003oA4A4onk^kQ?o
oooo00?oc<c<oeEEEOl000002?ooool00>_ooooo003[ooooo`00joooool00>_ooooo000aoooook?o
00001oooool0037ooooo00Co0000ooooool0003ooooo0ol00002ooooo`?o000000Coooooo`000?oo
oooooooo1?l00002ooooo`03o`000?oooooooooo00?o00000_ooool2o`0000?ooooo0_l00002oooo
o`04o`000?ooooooooooooooo`;o00000_ooool2o`0000;ooooo00Co0000ooooool0003o00001?oo
ool01?l0003oooooo`000?l00003ooooo`?o00000_ooool3o`0000Gooooo0_l000000ooooooo0000
ooooo`02ooooo`04o`000?oooooo0000o`0000;ooooo0ol00002ooooo`;o00000oooool2o`000004
ooooool0003oooooo`0000Kooooo1?l000000ooooooo0000ooooo`03ooooo`;o00000_ooool01?l0
003oooooo`000?ooool3o`0000;ooooo0_l00003ooooo`;o00001?ooool01?l0003oooooo`000?l0
0002ooooo`03o`000?oooooooooo00?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`;o
000000Coooooo`000?l0003o00001?ooool00ol0003oooooooooo`05ooooo`00<Oooool01?l0003o
ooooooooooooool2o`0000?ooooo00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooooooo
ool2o`0000Cooooo00?o0000ooooool000001?ooool00ol0003oooooo`000007ooooo`04o`000?oo
oooo0000ooooo`?o000000Coooooo`000?oooooo00000_ooool01?l0003oooooo`000?l00004oooo
o`?o00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00?o000000Kooooo
o`000?l0003oooooo`000?ooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?oo
ool00ol000001Ooooooo0000oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01_l0003ooooooooooooo
oooo0000ooooo`;o00000oooool01?l0003oooooo`000?ooool7o`0000Oooooo000aooooo`03o`00
0?oooooooooo00Gooooo00Go0000oooooooooooo0000ooooo`04o`000003ooooool0003o000000;o
00000oooool00ol0003oooooooooo`02o`000005ooooool0003oooooooooool000000_ooool00ol0
003oooooooooo`02ooooo`?o000000?oooooo`000?l000000_ooool00ol0003oooooo`000002oooo
o`03o`000?oooooo000000_ooooo1?l00002ooooo`03o`000?oooooo000000?ooooo0_l000001?oo
oooo0000ooooool00003ooooo`?o00000_ooool01?l0003oooooooooooooool2o`000006ooooool0
003oooooo`000?oooooo00000_ooool00ol0003oooooooooo`02ooooo`Go000000?oooooo`000?oo
ool00oooool00ol0003oooooooooo`02o`0000?ooooo00Co0000ooooool0003o00001?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`;o000000Soooooo`00
0?oooooo0000ooooool0003oooooo`0000;ooooo00Co0000ooooool0003o00000_ooool2o`0000Oo
oooo000aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000002ooooo`;o00002Oooool00ol0003oooooo`000003ooooo`?o00000_ooool2o`0000Gooooo
00Co0000oooooooooooooooo0ol00006ooooo`?o000000?oooooo`000?ooool00_ooool2o`0000?o
oooo0_l00004ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l00002oooo
o`03o`000?oooooo000000?ooooo1?l000000ooooooo0000ooooo`02ooooo`05o`000?oooooo0000
o`000?ooool00_l00002ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool00ol0003ooooo
o`00000>ooooo`?o00000oooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooooooool2o`0000Oooooo000aoooo
o`03o`000?oooooo000000;o00000_ooool01_l0003ooooooooooooooooo0000ooooo`?o000000?o
ooooo`000?ooool00oooool00ol0003oooooooooo`02ooooo`06o`000?oooooo0000o`000?oooooo
00000_ooool2o`000003ooooool0003ooooo00?ooooo0_l00005ooooo`03o`000?oooooo000000Co
oooo00?o0000ooooool000000_l00002ooooo`03o`000?oooooooooo00;o00002?ooool00ol0003o
ooooooooo`03ooooo`?o00000oooool01Ol0003oooooo`000?oooooo000000?ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`04o`000003ooooool0003ooooo00;ooooo0ol00000
1?oooooo0000o`000?l00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooo`000003ooooo`;o00000oooool2o`000003ooooool0003o000000?o00000oooool2o`00
00;ooooo0_l00007ooooo`00<Oooool00ol0003oooooo`000004ooooo`06o`000?oooooo0000o`00
0?oooooo00002_ooool01_l0003oooooooooool0003oooooo`0000;ooooo0_l00002ooooo`08o`00
0?ooooooooooo`000?oooooo0000ooooool00004ooooo`;o00000_ooool00ol0003oooooo`000007
ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000Gooooo0_l00004ooooo`03o`000?oooooo
000000Wooooo00Go0000ooooooooooooooooo`00000:ooooo`06o`000?ooooooooooooooool0003o
oooo0_l00003ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000Cooooo00?o
0000ooooooooool00ol000000ooooooo0000o`000002ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00Co
0000oooooooooooooooo0_l00007ooooo`00<Oooool3o`0000Cooooo00Go0000ooooool0003ooooo
o`000009ooooo`04o`000?ooooooooooooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`06
o`000?oooooo0000ooooool0003ooooo0_l000001Ooooooo0000ooooool0003ooooo00?o000000?o
ooooo`000?ooool00_ooool2o`0000Cooooo0_l00006ooooo`04o`000?oooooo0000ooooo`;o0000
0_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;o000000?oooooo`000?ooool0
1?l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00Gooooo0ol00002ooooo`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooooooo0ol000000ooooooo0000ooooo`02o`000003
ooooool0003ooooo00;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000Kooooo00?o0000
ooooool000000_l00002ooooo`05o`000?ooooooooooooooool000000_ooool3o`0000;ooooo00?o
0000ooooooooool00_l000000ooooooo0000ooooo`06ooooo`00<Oooool01Ol0003oooooo`000?oo
oooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;o000000Coooooo`000?oooooooooo
0ol00007ooooo`;o00000_ooool2o`0000?ooooo00?o0000ooooooooool01?l000000ooooooo0000
o`000002ooooo`?o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000_ooooo
00?o0000ooooooooool00_ooool01?l0003oooooo`000?ooool2o`0000Cooooo00?o0000oooooooo
ool00_l00002ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Cooooo1Ol00002oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool000000oooool00ol0003oooooo`000003
o`000003ooooool0003ooooo00Kooooo00So0000oooooooooooo0000ooooool0003oooooo`0000go
oooo00Co0000oooooooooooo00001oooool0037ooooo0ol000000ooooooo0000ooooo`02ooooo`;o
00000oooool2o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000
o`000003o`000003ooooool0003o000000Go000000?oooooo`000?ooool01Oooool4o`0000Gooooo
00?o0000ooooooooool00oooool3o`000003ooooool0003o000000;ooooo00Go0000oooooooooooo
0000ooooo`02o`0000Cooooo0_l000001?oooooo0000o`000?l0000:ooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00Sooooo0_l00003ooooo`;o00001oooool00ol0003oooooooooo`02ooooo`?o00000_ooool3o`00
0007ooooool0003oooooo`000?oooooo0000ooooo`03o`000003ooooool0003o000000Oooooo000a
ooooo`03o`000?oooooo000000?ooooo1?l00002ooooo`08o`000?oooooo0000ooooool0003ooooo
o`000?ooool2o`0000?ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooo000000;ooooo0ol000000ooooooo0000o`000002ooooo`Co000000?oooooo`00
0?ooool00oooool02_l0003ooooooooooooooooo0000ooooool0003oooooo`000?ooool2o`0000Ko
oooo1?l00002ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool2o`0000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_oo
ool01_l0003ooooooooooooooooo0000ooooo`?o00000_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000003ooooo`Go00000_ooool01Ol0003o
ooooo`000?l0003ooooo00Ko000000Coooooo`000?oooooo00001oooool0037ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo0000ooooool000000oooool2
o`000004ooooool0003oooooo`0000;ooooo00Go0000oooooooooooo0000ooooo`02o`0000;ooooo
0_l000001?oooooo0000ooooool00004ooooo`03o`000?oooooooooo00?o00001Oooool01?l0003o
ooooooooool00009ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;ooooo00?o0000oooo
ooooool01?ooool01_l0003ooooooooooooooooo0000ooooo`?o00003Oooool00ol0003oooooo`00
0004ooooo`Co00001?ooool01?l0003oooooooooool00004ooooo`05o`000?oooooo0000ooooool0
00000oooool01_l0003oooooo`000?l0003oooooo`0000Kooooo00?o0000ooooooooool01oooool3
o`0000Oooooo1?l00007ooooo`00<Oooool00ol0003oooooooooo`03o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?ooool01?l000002?oooooo0000ooooool0003oooooo`000?oooooo
00001oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000Cooooo00Wo0000oooo
ool0003oooooo`000?oooooo0000ooooool000000_ooool3o`000005ooooool0003oooooo`000?oo
ool00_l000001?oooooo0000ooooool00005ooooo`;o00000_ooool00ol0003oooooooooo`02o`00
0007ooooool0003oooooo`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00;o000000?o
ooooo`000?ooool00_l000001Ooooooo0000oooooooooooo000000;ooooo00?o0000ooooool00000
0_ooool00ol0003oooooooooo`05ooooo`07o`000?ooooooooooooooool0003oooooo`000006oooo
o`;o00000oooool2o`0000cooooo00?o0000ooooooooool00oooool01ol0003oooooo`000?oooooo
0000ooooool000000_ooool2o`000003ooooool0003ooooo00;o00001oooool0037ooooo00?o0000
ooooooooool01?ooool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_l00000
1?oooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_l0
0004ooooo`03o`000?oooooo000000?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`05
o`000?ooooooooooooooool000000oooool3o`0000;ooooo0_l000001Ooooooo0000oooooooooooo
000000Kooooo00?o0000ooooooooool02_ooool3o`0000;ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooooooool3o`0000Oooooo0_l00006ooooo`04o`000?oooooo0000ooooo`;o0000
1?ooool4o`0000?ooooo0_l00008ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`05oooo
o`00<Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Co00000oooool01?l0003o
ooooooooooooool2o`000003ooooool0003ooooo00Cooooo0ol00004ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool2o`000004ooooool0003oooooooooo`;o00001?ooool2
o`0000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Co0000oooooooooooo
oooo0_l00002ooooo`06o`000?oooooo0000o`000?oooooo00001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo0ol000001?oooooo0000o`000?ooool4o`000003ooooool0
003o000000;ooooo1Ol000000ooooooo0000o`000005ooooo`;o00000oooool2o`0000;ooooo0_l0
00001_oooooo0000ooooool0003oooooo`0000?ooooo00Oo0000oooooooooooo0000ooooool0003o
oooo00?o00001_ooool00ol0003oooooo`000003ooooo`03o`000?oooooo000000Oooooo000aoooo
o`04o`000?oooooo0000ooooo`?o000000Coooooo`000?oooooo00000oooool01?l0003oooooo`00
0?ooool2o`000004ooooool0003oooooooooo`;o00000oooool00ol0003oooooo`000004ooooo`;o
00000_ooool4o`000003ooooool0003o000000;o000000Coooooo`000?oooooo00000_ooool00ol0
003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000ooooooooooooooooo`00
0?ooool3o`000003ooooool0003o000000;ooooo00Co0000oooooooooooo00000oooool2o`0000;o
oooo0ol000001Ooooooo0000ooooool0003ooooo00;o000000?oooooo`000?ooool00_ooool3o`00
0003ooooool0003o000000Go00000_ooool3o`000003ooooool0003ooooo00;o00001?ooool02_l0
003oooooo`000?l0003oooooo`000?oooooo0000ooooool00002ooooo`09o`000?oooooo0000oooo
ool0003oooooo`000?oooooo000000Gooooo00?o0000ooooool000000_ooool01?l0003oooooo`00
0?l00002ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000Oooooo000aooooo`08o`00
0?oooooo0000ooooool0003oooooo`000?ooool2o`0000Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool02?l0003ooooo
ooooool0003oooooo`000?oooooo00001_ooool01ol0003oooooo`000?oooooo0000ooooool00000
0_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo0000ooooool000001Oooool00ol0003o
ooooo`000007ooooo`;o00001_ooool4o`000004ooooool0003o0000o`0000?ooooo0_l000000ooo
oooo0000o`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooo000000Cooooo0ol00002ooooo`;o000000Goooooo`000?oooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooo`000?l00005
ooooo`04o`000?ooooooooooo`0000;ooooo0ol00002ooooo`03o`000?oooooooooo00Gooooo000a
ooooo`04o`000?oooooo0000ooooo`Co000000Goooooo`000?ooooooooooo`000002ooooo`;o0000
00Coooooo`000?l0003ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooool0
003o0000ooooool00006ooooo`;o000000Goooooo`000?l0003oooooo`000003ooooo`03o`000?oo
oooooooo00?ooooo0ol000001?oooooo0000ooooooooool2o`000003ooooool0003ooooo00Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooo`000002o`0000;ooooo0_l00002ooooo`04o`00
0?ooooooooooooooo`?o000000Coooooo`000?l0003o00000_ooool01_l0003oooooooooool0003o
ooooo`0000;ooooo00?o0000ooooooooool00ol00005ooooo`?o00001?ooool2o`0000?ooooo00?o
0000ooooooooool01?l000000ooooooo0000ooooo`02o`0000?ooooo00?o0000ooooool000001?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`00<Oooool2
o`0000;ooooo00?o0000ooooooooool01Oooool4o`000003ooooool0003o000000Kooooo0ol00007
ooooo`;o00000oooool3o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000;o00000_ooool00ol0003oooooooooo`04o`000005ooooool0003o
ooooooooool000000oooool00ol0003oooooooooo`02ooooo`;o000000Ooooooo`000?l0003ooooo
o`000?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool2o`000007ooooool0003ooooo
o`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00?ooooo00Co0000oooooooooooooooo
0_l000001?oooooo0000ooooooooool2o`000003ooooool0003ooooo00;ooooo00?o0000oooooooo
ool01oooool2o`000005ooooool0003oooooo`000?ooool00_l00007ooooo`03o`000?oooooo0000
00?ooooo0_l00002ooooo`04o`000?oooooo0000ooooo`?o00001oooool0037ooooo0_l00003oooo
o`;o00000_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000?ooooo0_l00003
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00?o00000oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00;ooooo0ol0
0003ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool00_ooool2o`000004ooooool0
003oooooo`0000;ooooo00?o0000ooooooooool00ol000001?oooooo0000ooooool00003ooooo`;o
00001?ooool01Ol0003oooooooooool0003ooooo00;o00002?ooool01?l0003oooooo`000?l00003
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool01Ol0003oooooo`00
0?oooooo000000;ooooo00?o0000ooooool000001Oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooool000000_l000000ooooooo0000ooooo`06ooooo`00<Oooool2o`0000?ooooo
0_l00002ooooo`08o`000?ooooooooooooooool0003oooooo`000?ooool2o`0000;ooooo00?o0000
ooooool000001_ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?l000000oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001?l00000
0ooooooo0000ooooo`02o`0000;ooooo0_l00008ooooo`?o00000_ooool01?l0003oooooooooool0
0004ooooo`Go00000oooool3o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooool000000_ooool2o`0000Wooooo00Co0000oooooooooooo00000_ooool3o`0000Gooooo
0_l00003ooooo`06o`000?oooooo0000ooooool0003ooooo1?l000000ooooooo0000ooooo`04oooo
o`03o`000?oooooooooo00Gooooo000aooooo`;o000000?oooooo`000?ooool00_ooool01ol0003o
oooooooooooooooo0000ooooool000000_ooool2o`000007ooooool0003o0000o`000?oooooo0000
ooooo`03o`0000;ooooo00Co0000oooooooooooo00000_ooool7o`0000?ooooo00?o0000ooooool0
00001Oooool01?l0003oooooo`000?ooool2o`0000Kooooo00Co0000ooooool0003ooooo1ol0000:
ooooo`03o`000?oooooooooo00Go000000Coooooo`000?oooooo00001?ooool00ol0003oooooo`00
0004ooooo`Co00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o00000_oo
ool2o`000003ooooool0003o000000;ooooo0_l00005ooooo`;o000000Coooooo`000?l0003ooooo
0ol00002ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00001Oooool01_l0003ooooo
o`000?oooooo0000ooooo`;o00001oooool0037ooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool4o`0000?ooooo0_l00004
ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00003ooooo`03o`000?oooooooooo00;o
oooo0_l000001?oooooo0000ooooooooool2o`000004ooooool0003o0000o`0000?ooooo00Ko0000
ooooool0003o0000ooooool00003ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`;o0000
00Coooooo`000?oooooo00000oooool2o`0000;ooooo00Co0000oooooooooooooooo0_l00002oooo
o`03o`000?oooooo000000Cooooo00?o0000ooooool000000_l00004ooooo`03o`000?oooooo0000
00?ooooo00Co0000oooooooooooooooo1?l00005ooooo`;o00001oooool00ol0003oooooo`000002
ooooo`;o00000_ooool2o`000004ooooool0003o0000o`0000Sooooo0_l000000ooooooo0000oooo
o`06ooooo`00<Oooool2o`0000;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`06
ooooo`Go00000_ooool2o`000006ooooool0003oooooo`000?oooooo00000oooool4o`0000;ooooo
00?o0000ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;o0000
1Oooool01?l0003oooooooooooooool2o`0000;ooooo00Co0000oooooooooooo00000oooool3o`00
00Cooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooooooool0003ooooo
0ol00002ooooo`?o000000Coooooo`000?l0003o00000_ooool3o`0000Sooooo0_l000001Ooooooo
0000oooooooooooo000000;ooooo00Co0000ooooool0003o00001?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooool000000oooool2o`0000;ooooo00?o0000ooooooooool00_oo
ool5o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?ooool01_ooool0037ooooo00Go
0000ooooool0003oooooo`000002ooooo`03o`000?oooooo000000?ooooo0_l00002ooooo`;o0000
0oooool01?l0003oooooooooool00002ooooo`Co00001?ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00004ooooo`?o000000?o
ooooo`000?l000000oooool00ol0003oooooo`000003o`0000;ooooo00Go0000ooooool0003o0000
ooooo`04o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00?o000000Coooooo`000?l0003o
oooo0_l00003ooooo`03o`000?oooooooooo00;o00000_ooool2o`000003ooooool0003o000000Ko
oooo0_l00002ooooo`04o`000?ooooooooooooooo`Co000000Coooooo`000?oooooo00000oooool0
0ol0003oooooooooo`02ooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`03o`000?oo
oooooooo00?ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`000003o`000006oooo
ool0003o0000o`000?oooooo00001oooool0037ooooo00?o0000ooooooooool00ol00007ooooo`04
o`000?oooooo0000o`0000;ooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00002
ooooo`05o`000?oooooo0000o`000?ooool00_l000001?oooooo0000ooooool00002ooooo`03o`00
0?oooooooooo00Sooooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo0_l00005ooooo`?o
00000oooool00ol0003oooooooooo`02o`000004ooooool0003oooooo`0000?ooooo00Ko0000oooo
ooooooooooooo`000?ooool2o`0000Kooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool3o`0000?ooooo1Ol00002ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool00oooool2o`0000;ooooo00?o0000ooooooooool00_l000001Ooooooo0000oooo
oooooooo000000Oooooo00?o0000ooooooooool00_l00007ooooo`00<Oooool00ol0003oooooo`00
0006ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooool0003oooooo`000002ooooo`?o0000
00?oooooo`000?ooool00_ooool01?l0003oooooooooooooool3o`0000;ooooo0_l000001_oooooo
0000ooooool0003oooooo`0000?ooooo0_l00002ooooo`?o000000?oooooo`000?ooool00_l00002
ooooo`?o00000oooool00ol0003oooooooooo`05ooooo`06o`000?ooooooooooooooool0003ooooo
0ol00003ooooo`04o`000?ooooooooooooooo`;o00001Oooool3o`000006ooooool0003ooooooooo
ool0003ooooo0_l000001?oooooo0000ooooooooool2o`000003ooooool0003ooooo00Cooooo00Co
0000oooooooooooo00000oooool01?l0003oooooo`000?ooool3o`000004ooooool0003o0000o`00
00;ooooo0ol00002ooooo`03o`000?oooooo000000Cooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000Oooooo000aooooo`;o0000
0oooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`04o`000?oooooo
0000o`0000;ooooo0ol00002ooooo`05o`000?ooooooooooo`000?ooool01?l00004ooooo`03o`00
0?oooooooooo00Co00000oooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo0_l00000
0ooooooo0000o`000003ooooo`04o`000?oooooo0000o`0000Oooooo00Co0000ooooool0003o0000
1?ooool00ol0003oooooo`000002o`0000;ooooo1Ol00002ooooo`?o000000?oooooo`000?l00000
0_l000000ooooooo0000o`000004o`0000;ooooo0_l00004ooooo`0:o`000?ooooooooooo`000?oo
oooo0000ooooool0003oooooo`0000;ooooo00?o0000ooooool000000_l000000ooooooo0000oooo
o`02ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`04o`000?oooooo0000o`0000Cooooo
00?o0000ooooooooool01?ooool6o`0000Oooooo000aooooo`03o`000?oooooo000000;o000000?o
ooooo`000?ooool00_l0000>ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooo`000002o`000004ooooool0003oooooo`0000?ooooo0_l0000:ooooo`?o
00000_ooool3o`0000;ooooo00Co0000ooooool0003o00000oooool2o`0000;ooooo00?o0000oooo
ooooool00_l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`00
00?ooooo00Co0000ooooool0003ooooo1Ol000000ooooooo0000ooooo`06ooooo`03o`000?oooooo
oooo00[ooooo1Ol00004ooooo`;o00000oooool00ol0003oooooooooo`02o`0000Kooooo0ol00002
ooooo`Co000000Goooooo`000?l0003oooooo`000002ooooo`;o00001oooool0037ooooo00Co0000
oooooooooooo00000oooool2o`000003ooooool0003ooooo00Cooooo2?l00005ooooo`?o00001Ooo
ool5o`000006ooooool0003o0000o`000?oooooo00001_ooool2o`0000;ooooo00Co0000oooooooo
oooooooo0_l00003ooooo`?o00001_ooool2o`0000;ooooo0_l00006ooooo`04o`000?oooooooooo
o`0000Cooooo0ol00003ooooo`05o`000?ooooooooooo`000?ooool00_l00005ooooo`?o00000_oo
ool5o`000004ooooool0003oooooooooo`;o000000Coooooo`000?oooooooooo0ol00002ooooo`;o
00002oooool00ol0003oooooooooo`02o`000003ooooool0003o000000Gooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooo000000;o00001oooool0037ooooo00?o0000oooo
ool000000_ooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0003oooooo`00
0003ooooo`?o000000Ooooooo`000?l0003oooooo`000?oooooo000000;ooooo0_l00007ooooo`Ko
00000oooool3o`0000Kooooo00Co0000ooooool0003ooooo0_l000000ooooooo0000ooooo`02oooo
o`;o00000_ooool2o`000003ooooool0003o000000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooo`000002ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooooooo0_l00000
1?oooooo0000ooooool00003ooooo`?o000000Goooooo`000?ooooooooooo`000004ooooo`06o`00
0?ooooooooooo`000?oooooo00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool2o`00
0006ooooool0003o0000o`000?oooooo00001?ooool01Ol0003oooooo`000?l0003ooooo00;o0000
0_ooool01?l0003oooooo`000?ooool2o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`00<Oooool3o`0000Cooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00004ooooo`05o`000?oooooo0000ooooool000000_ooool2o`000005ooooool0003o0000
ooooool000001Oooool00ol0003oooooooooo`03ooooo`?o000000?oooooo`000?ooool00_l00005
ooooo`?o000000Coooooo`000?oooooo00000_ooool01?l0003oooooo`000?ooool2o`0000;ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`;o000000?oooooo`000?ooool01?ooool01?l0
003oooooooooool00004ooooo`?o00000oooool02Ol0003oooooo`000?oooooo0000ooooool0003o
ooooo`000003ooooo`?o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooooooo0ol00007ooooo`;o00000_ooool00ol0003oooooooooo`03o`00
0004ooooool0003o0000ooooo`;o00001Oooool01?l0003oooooo`000?l00007ooooo`00<Oooool0
1_l0003oooooooooool0003oooooo`0000Gooooo0_l000001Ooooooo0000ooooool0003ooooo00;o
000000?oooooo`000?l000000_l00002ooooo`07o`000?ooooooooooo`000?oooooo0000ooooo`02
o`0000?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00004ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool2o`0000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`?o000000Coooooo`000?oooooo00000oooool4o`0000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00005ooooo`04o`000?oooooo0000ooooo`;o00000_ooool5o`0000;o
oooo00Co0000ooooool0003o00000_ooool01?l0003oooooo`000?ooool3o`0000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooool0003ooooo
o`000003ooooo`;o00001oooool001?ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000
oeEEE@05ooooo`Ko00001_ooool2o`0000Cooooo1_l000002Ooooooo0000o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`04o`000?ooooooooooooooo`Go00000oooool2o`000005ooooool0
003oooooooooool000001?ooool3o`0000;ooooo00?o0000ooooool000001Oooool01_l0003ooooo
oooooooooooo0000ooooo`;o00002Oooool2o`0000Cooooo00Co0000ooooool0003ooooo0_l00000
1ooooooo0000ooooool0003oooooo`000?ooool00ol000001Ooooooo0000ooooool0003ooooo00;o
00001Oooool00ol0003oooooo`000004ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooooooool3o`0000Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo000B
ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Gooooo00?oV9RHo`000?oMgMd0
0_ooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000
o`000003ooooo`03o`000?oooooo000000Co00000oooool2o`0000?ooooo0_l00002ooooo`?o0000
00Goooooo`000?ooooooooooo`000005ooooo`06o`000?ooooooooooooooool0003ooooo0_l00008
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooo000000Cooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool2o`0000?o
oooo0ol00002ooooo`03o`000?oooooo000000?ooooo0_l00003ooooo`03o`000?oooooooooo00;o
oooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Gooooo00?o0000ooooooooool01Oooool0
01;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?o
QhN7ob4Q8Oo^k^h02?ooool00ol0003oooooo`000004ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05o`000003ooooool0003o000000Co000000?o
ooooo`000?ooool00oooool00ol0003oooooooooo`03ooooo`?o00000_ooool01?l0003ooooooooo
ool00003ooooo`;o000000Coooooo`000?oooooo00001_ooool01Ol0003ooooooooooooooooo0000
00?ooooo1Ol00002ooooo`;o00001_ooool00ol0003oooooo`000002o`000005ooooool0003ooooo
ooooool000002?ooool00ol0003oooooo`000003o`0000Kooooo1_l00002ooooo`Co00001Oooool0
1Ol0003oooooo`000?oooooo000000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooo`00
0?ooool2o`0000?ooooo0_l000001?oooooo0000ooooooooool2o`000004ooooool0003ooooooooo
o`;o00001oooool001;ooooo00Ko0000onk^k_ooooooooooonk^k_l0000?ooooo`03ojVYZOlQ8B7o
k^k^00Oooooo0ol000002?oooooo0000ooooool0003oooooo`000?oooooo00000_ooool00ol0003o
ooooooooo`02ooooo`04o`000?oooooo0000o`0000Cooooo00Ko0000oooooooooooo0000ooooool0
0002ooooo`04o`000?oooooo0000ooooo`;o00000_ooool00ol0003oooooo`000005ooooo`;o0000
00Goooooo`000?ooooooooooo`000004ooooo`?o00000_ooool00ol0003oooooo`000005ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool01_l0003oooooo`000?oooooo0000ooooo`Co0000
0_ooool3o`000003ooooool0003ooooo00;ooooo00Co0000oooooooooooooooo1?l00008ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool2o`0000Gooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool02?l0003ooooooooo
oooooooo0000ooooool0003ooooo0_l00003ooooo`;o000000?oooooo`000?ooool01?ooool2o`00
00Oooooo000Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00onHV9So
<S8booooo`06ooooo`;o000000Goooooo`000?l0003oooooo`000004ooooo`03o`000?oooooooooo
00;o000000?oooooo`000?ooool00_l000001?oooooo0000ooooool00002ooooo`;o000000Gooooo
o`000?l0003o0000ooooo`05o`0000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00Co0000
00Coooooo`000?oooooooooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00;o
oooo1?l00002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000ooooool0003o00000_ooool3o`0000Cooooo0_l00002
ooooo`Co00002?ooool00ol0003oooooo`000002ooooo`Co000000Coooooo`000?oooooooooo0ol0
0003ooooo`;o000000Koooooo`000?ooooooooooo`000?ooool2o`0000;ooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`Oo00002?ooool00ol0003oooooooooo`05ooooo`004_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?oA4A4ogMgMoooool01Oooool3o`00
00;ooooo00?o0000ooooool000000_ooool4o`0000;ooooo00?o0000ooooooooool00ol00003oooo
o`04o`000?oooooo0000o`0000;ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooool000001Ol000001Ooooooo0000oooooooooooo000000;ooooo0_l00003
ooooo`03o`000?oooooooooo00;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02ooooo`07o`000?oooooo
ooooooooool0003oooooo`000008ooooo`03o`000?oooooo000000Cooooo0ol00004ooooo`03o`00
0?oooooo000000;o00000_ooool01?l0003oooooooooool00005ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`05ooooo`004_ooool01_l0003ok^k^ooooooooooook^k^
o`00017ooooo00?ogMgMoa0@4?ooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
000000;ooooo00?o0000ooooooooool00oooool02?l0003oooooooooool0003oooooo`000?oooooo
00000_ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000009ooooo`04
o`000?ooooooooooo`0000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00Co0000oooo
oooooooo00001Oooool2o`0000Cooooo0ol00003ooooo`05o`000?oooooo0000ooooool000001Ooo
ool01?l0003oooooo`000?l00004ooooo`05o`000?oooooo0000ooooool000000oooool00ol0003o
ooooooooo`02ooooo`Ko000000?oooooo`000?ooool01?ooool3o`0000_ooooo00?o0000ooooool0
00001Oooool2o`0000;ooooo1?l00007ooooo`004_ooool01_m4A4CoV9RHooooooooooooV9RHodA4
A1;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002ooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`?o000000?o
ooooo`000?ooool00_l00004ooooo`03o`000?oooooo000000?ooooo0_l00003ooooo`;o00002?oo
ool00ol0003oooooo`000002o`000003ooooool0003ooooo00?ooooo00Go0000oooooooooooo0000
ooooo`02o`0000?ooooo00Co0000oooooooooooooooo0ol00002ooooo`;o000000?oooooo`000?oo
ool01?l00002ooooo`Co00000_ooool00ol0003oooooo`000002ooooo`;o000000?oooooo`000?oo
ool00_l00002ooooo`03o`000?oooooooooo00Cooooo0_l00002ooooo`03o`000?oooooo000000;o
000000?oooooo`000?ooool01?ooool01_l0003ooooooooooooooooo0000ooooo`;o000000Cooooo
o`000?oooooo00000_ooool02_l0003ooooooooooooooooo0000ooooool0003oooooo`000?ooool2
o`000004ooooool0003o0000o`0000Gooooo00?o0000ooooooooool01Oooool001;ooooo00Ko^[Zj
ob4Q8OoMgMgogMgMob4Q8Onj^[X=ooooo`06o`000?n7QhOok^k^oooooonHV9SoEEEE1_ooool01?l0
003oooooooooool00002ooooo`;o00001oooool2o`000006ooooool0003o0000ooooool0003ooooo
0ol00004ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Gooooo00Co0000ooooool0003o
00001?ooool2o`000004ooooool0003o0000ooooo`Co000000Koooooo`000?oooooo0000ooooool0
0002ooooo`03o`000?oooooo000000;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Ko0000ooooooooooooooooo`000?ooool4o`0000Kooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000Cooooo00Co0000oooooooooooo00002_ooool01Ol0003oooooo`000?oooooo000000?o
oooo00Co0000oooooooooooooooo0_l00002ooooo`06o`000?ooooooooooooooool0003ooooo0_l0
0003ooooo`?o000000?oooooo`000?ooool00_l000001_oooooo0000oooooooooooo0000ooooo`;o
000000?oooooo`000?l000000ol00007ooooo`004oooool01?nHV9So0000o`000?nHV9P>ooooo`06
ojVYZOlb<S;o0000o`000?mEEEGok^k^1_ooool2o`000003ooooool0003o000000;ooooo0_l00000
0ooooooo0000ooooo`03ooooo`04o`000?oooooo0000o`0000;ooooo00Co0000oooooooooooo0000
1?ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooool000000oooool01?l0003o
ooooo`000?l00004ooooo`;o00001_ooool2o`0000;ooooo1Ol00003ooooo`03o`000?oooooo0000
00Gooooo00Go0000oooooooooooo0000ooooo`05o`0000;ooooo0_l00009ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`02o`00000<ooooool0003o0000o`000?oooooo
0000ooooool0003oooooo`000?oooooo00001_ooool01?l0003oooooo`000?l00003ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo000000Ko
oooo0_l00007ooooo`00<Oooool2o`0000;ooooo00?o0000ooooool000000_ooool00ol0003ooooo
o`000002o`0000Cooooo0ol00007ooooo`;o000000Goooooo`000?l0003oooooo`000002ooooo`04
o`000?oooooo0000o`0000;ooooo00?o0000ooooooooool00ol00002ooooo`;o000000?oooooo`00
0?l000001_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool2
o`000005ooooool0003oooooooooool000001?ooool00ol0003oooooo`000007ooooo`03o`000?oo
oooo000000;o000000Goooooo`000?l0003oooooo`000003ooooo`05o`000?ooooooooooo`000?oo
ool00_l000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooo`000?ooool00_l00002oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ol000001Ooooooo0000o`000?oooooo
000000Wooooo0_l000000ooooooo0000o`000005ooooo`03o`000?oooooooooo00Cooooo0ol00000
1?oooooo0000o`000?l00007ooooo`00<Oooool2o`0000?ooooo0_l00006ooooo`;o00001oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000ooooool0003o00000oooool00ol0003ooooo
o`000003o`000003ooooool0003ooooo00Cooooo00Co0000oooooooooooo00000_ooool3o`0000[o
oooo00Go0000ooooool0003o0000ooooo`02o`0000?ooooo0_l00002ooooo`Oo00000oooool01?l0
003oooooooooool00002ooooo`Go00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooool000000_l00003ooooo`03o`000?oooooooooo00Gooooo0ol000001_oooooo0000o`00
0?l0003oooooo`0000Cooooo0ol00004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`02o`0000[ooooo00?o0000ooooool000000ol00007ooooo`00<Oooool6o`000003
ooooool0003ooooo00Cooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l00006oooo
o`?o000000?oooooo`000?ooool00_ooool4o`000003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03o`0000Cooooo0ol00003ooooo`?o000000Coooooo`00
0?l0003ooooo0ol00003ooooo`03o`000?oooooooooo00;o00000oooool2o`000003ooooool0003o
oooo00Oooooo00Co0000oooooooooooooooo1?l000001Ooooooo0000oooooooooooo000000;ooooo
00?o0000ooooooooool00_ooool3o`0000;ooooo1?l000001?oooooo0000o`000?l00003ooooo`?o
000000?oooooo`000?ooool00oooool00ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003o
ooooooooo`03ooooo`Go000000?oooooo`000?ooool00_l000001?oooooo0000o`000?ooool3o`00
00Oooooo000aooooo`03o`000?oooooooooo00?o000000Coooooo`000?l0003ooooo0_l00003oooo
o`05o`000?ooooooooooooooool000000_ooool2o`0000?ooooo00?o0000ooooooooool00_ooool2
o`000003ooooool0003ooooo00;ooooo0_l000001Ooooooo0000oooooooooooo000000Kooooo0_l0
00000ooooooo0000ooooo`03ooooo`05o`000?oooooo0000o`000?ooool00ol000000ooooooo0000
ooooo`03ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01?l00003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool000000oooool01_l0003oooooo`000?oooooo0000oooo
o`;o00001Oooool00ol0003oooooooooo`04ooooo`;o00002?ooool00ol0003oooooo`000002o`00
00Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo0000ooooo`?o00000_oo
ool01Ol0003oooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool6o`0000?ooooo
00?o0000ooooooooool01Oooool0037ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00Co
0000oooooooooooooooo0_l00005ooooo`;o00002?ooool00ol0003oooooo`000004ooooo`08o`00
0?oooooo0000o`000?oooooo0000ooooool00003ooooo`;o00000oooool01?l0003oooooo`000?l0
0002ooooo`05o`000?ooooooooooooooool000002oooool3o`000005ooooool0003o0000ooooool0
00001Oooool01?l0003oooooo`000?ooool2o`0000?ooooo00Co0000oooooooooooo00001Oooool2
o`000003ooooool0003ooooo00?ooooo0ol000000ooooooo0000ooooo`05ooooo`05o`000?oooooo
ooooooooool000002Oooool3o`0000;ooooo00?o0000ooooool000000_ooool2o`0000?ooooo0ol0
0004ooooo`;o00000oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00;o00001ooo
ool0037ooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooooooo`Co00001oooool00ol0
003oooooooooo`04ooooo`Co000000?oooooo`000?ooool00ol000001_oooooo0000ooooool0003o
ooooo`0000;ooooo1?l00003ooooo`Co000000?oooooo`000?ooool01?ooool01?l0003ooooooooo
ooooool3o`000004ooooool0003oooooooooo`;o000000Coooooo`000?oooooooooo0_l00004oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo0000ooooo`02o`0000Sooooo00Go
0000ooooool0003oooooo`00000;ooooo`Go000000Goooooo`000?ooooooooooo`000003ooooo`03
o`000?oooooo000000Wooooo0_l00008ooooo`;o00001oooool0037ooooo00?o0000ooooool00000
0_ooool2o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o00000_ooool00ol0003ooooo
o`000007ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool2o`0000Kooooo0_l000001?oo
oooo0000o`000?ooool2o`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003oooooooooool0
003ooooo00?o00000_ooool00ol0003oooooooooo`04o`0000?ooooo0_l00005ooooo`03o`000?oo
oooo000000;o00000oooool3o`0000Wooooo00So0000ooooool0003oooooo`000?oooooo0000oooo
o`;o000000?oooooo`000?ooool01?l00002ooooo`04o`000?ooooooooooo`0000;ooooo1Ol00007
ooooo`;o00001?ooool4o`0000;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooool000000_l00002ooooo`03o`000?oooooooooo00Gooooo000aooooo`03o`000?oooooo
oooo00;ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`?o00000_ooool2
o`000005ooooool0003oooooooooool000001?ooool3o`0000;ooooo00Go0000oooooooooooo0000
ooooo`02o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000003ooooo`03o`00
0?oooooo000000Gooooo00Oo0000ooooool0003o0000ooooool0003ooooo00;o000000?oooooo`00
0?l000001Oooool2o`000004ooooool0003oooooooooo`;o00000_ooool01?l0003oooooo`000?l0
0006ooooo`03o`000?oooooo000000?o00000_ooool01?l0003oooooo`000?l00004ooooo`Co0000
00?oooooo`000?l000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000?ooooo
00Oo0000oooooooooooo0000ooooool0003ooooo00?o00000oooool00ol0003oooooooooo`03oooo
o`?o000000?oooooo`000?ooool01?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00Gooooo000aooooo`03o`000?oooooooooo00?o00001?ooool2o`0000Cooooo0_l000000ooooooo
0000o`000002ooooo`Co00000oooool2o`000006ooooool0003oooooooooool0003ooooo0_l00002
ooooo`;o00000_ooool2o`000003ooooool0003ooooo00Cooooo00?o0000ooooool000000_l00002
ooooo`;o000000Goooooo`000?ooooooooooo`000003ooooo`;o00001?ooool2o`0000?ooooo00Go
0000ooooool0003o0000ooooo`02o`0000Cooooo00?o0000ooooooooool00_ooool2o`0000;ooooo
0ol000000ooooooo0000o`000005ooooo`05o`000?ooooooooooo`000?ooool00_l00002ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooool0003o0000ooooo`04o`000003ooooool0003ooooo
00?ooooo0_l000000ooooooo0000ooooo`09ooooo`?o00000_ooool00ol0003oooooo`000002oooo
o`04o`000?oooooo0000ooooo`Co000000?oooooo`000?l000001oooool0037ooooo00Oo0000oooo
oooooooo0000ooooool0003ooooo00;o00001?ooool00ol0003oooooo`000003o`0000;ooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooo`000005o`0000Kooooo0ol000001?oooooo0000
ooooooooool4o`000003ooooool0003o000000;o000000Coooooo`000?l0003o00000_ooool00ol0
003oooooooooo`02o`0000?ooooo00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`02
ooooo`05o`000?oooooo0000o`000?ooool00ol00004ooooo`03o`000?oooooo000000Cooooo00?o
0000ooooooooool00oooool3o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;o000000?o
ooooo`000?ooool02Oooool3o`0000Kooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oo
oooo000000Oooooo0ol00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
1Oooool0037ooooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02o`000005ooooool0003oooooooooool00000
0_ooool3o`000003ooooool0003ooooo00?ooooo0_l00004ooooo`04o`000?ooooooooooooooo`;o
00000_ooool2o`000004ooooool0003oooooooooo`?o00000oooool01?l0003oooooo`000?ooool2
o`000003ooooool0003ooooo00;o00001?ooool2o`000003ooooool0003ooooo00?ooooo00?o0000
ooooooooool01_ooool3o`0000Gooooo0ol00002ooooo`04o`000?oooooo0000ooooo`;o00001?oo
ool2o`000009ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o00001Oooool01Ol0
003oooooo`000?oooooo000000Gooooo00?o0000ooooool000001?ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000000;ooooo0_l00003ooooo`03o`000?oooooooooo00;o00001oooool0
037ooooo0_l000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00?ooooo00?o0000oooo
ooooool00_ooool3o`0000?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`;o00000_oo
ool3o`0000;ooooo00_o0000oooooooooooo0000ooooool0003oooooo`000?oooooo0000ooooo`02
o`0000;ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0000?ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`02o`000003oooo
ool0003ooooo00;o000000Goooooo`000?l0003o0000ooooo`04o`000003ooooool0003o000000?o
oooo0ol00002ooooo`06o`000?oooooo0000o`000?oooooo00000oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooo`000?ooool00ol00004ooooo`;o00001?ooool2o`0000?ooooo00Go
0000oooooooooooo0000ooooo`02o`000004ooooool0003oooooooooo`Ko000000Coooooo`000?oo
oooooooo0_l000001?oooooo0000o`000?l00007ooooo`00<Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`03o`0000Kooooo0ol000001_oooooo0000ooooool0003oooooo`0000Gooooo00?o0000ooooool0
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo1?l00009ooooo`Ko000000Coooooo`00
0?l0003ooooo0_l00002ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01Ol0
00000ooooooo0000ooooo`02o`0000;ooooo00?o0000ooooool000000_l00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooool000000_ooool4o`000005ooooool0003oooooooooool0
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00001oooool0037ooooo
0ol000001Ooooooo0000ooooool0003ooooo00Co000000?oooooo`000?l000000_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooooooo`Go00000_ooool4o`000003ooooool0003ooooo
00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`05o`000?oooooo0000
ooooool000001?ooool00ol0003oooooooooo`0<ooooo`06o`000?oooooo0000o`000?oooooo0000
0oooool3o`000004ooooool0003o0000o`0000?ooooo0_l000001ooooooo0000o`000?oooooo0000
ooooool000001_ooool2o`0000?ooooo00Co0000oooooooooooooooo1?l000000ooooooo0000oooo
o`04ooooo`;o00000oooool3o`0000Oooooo0_l00002ooooo`04o`000?ooooooooooooooo`Co0000
0oooool00ol0003oooooooooo`05ooooo`00<Oooool01Ol0003oooooo`000?oooooo000000Gooooo
0_l00004ooooo`;o00000oooool3o`0000Cooooo0ol00006ooooo`;o00000oooool2o`0000?ooooo
0_l000001?oooooo0000o`000?l00002ooooo`04o`000?oooooo0000o`0000?ooooo0ol00002oooo
o`;o00000_ooool01?l0003oooooooooooooool2o`000003ooooool0003o000000Co00000oooool2
o`0000;ooooo00Co0000oooooooooooooooo0ol00003ooooo`05o`000?ooooooooooo`000?ooool0
1?l00003ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000000_l000001Ooooooo0000
oooooooooooo000000Gooooo00Co0000ooooool0003o00000oooool4o`0000?ooooo00Co0000oooo
ool0003ooooo0ol00003ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`04o`000?oooooo
ooooooooo`?o00001oooool0037ooooo00?o0000ooooool000000oooool2o`0000?ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo00So0000ooooooooooooooooo`000?oooooo0000ooooo`Ko
00001?ooool7o`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04
o`000?oooooo0000o`0000Cooooo0_l000001?oooooo0000ooooool00004ooooo`03o`000?oooooo
000000;ooooo00?o0000ooooooooool02Oooool2o`0000Oooooo1?l00002ooooo`;o00000_ooool0
0ol0003oooooo`000003ooooo`03o`000?oooooo000000Cooooo0_l000000ooooooo0000ooooo`05
o`000003ooooool0003ooooo00Oooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`00
0002o`000005ooooool0003o0000ooooool000000_ooool2o`0000;ooooo00Co0000oooooooooooo
00001oooool0037ooooo00Co0000oooooooooooooooo0_l000001_oooooo0000ooooool0003ooooo
o`0000Oooooo00Ko0000ooooooooooooooooo`000?ooool3o`000003ooooool0003o000000Cooooo
0_l000000ooooooo0000o`00000:ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool3o`00
0004ooooool0003o0000o`0000?ooooo0_l000001?oooooo0000ooooool00003ooooo`?o00000_oo
ool3o`0000;ooooo00Co0000oooooooooooooooo0_l000000ooooooo0000ooooo`07ooooo`0:o`00
0?oooooo0000o`000?oooooo0000ooooool0003oooooo`0000Wooooo00?o0000ooooooooool00ol0
0004ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02o`0000?o
oooo00?o0000ooooool000001?l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01_ooool01?l0003oooooooooooooool2o`0000Oooooo000aooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`03o`000?oooooo0000
00;o000000?oooooo`000?l000001?ooool01ol0003oooooo`000?l0003oooooo`000?ooool00_l0
0005ooooo`;o000000?oooooo`000?ooool00ol00005ooooo`08o`000?oooooo0000o`000?oooooo
0000ooooool00003ooooo`03o`000?oooooo000000Oooooo00Co0000ooooool0003o00001Oooool0
1?l0003oooooooooool00002ooooo`;o000000Coooooo`000?oooooo00000_ooool2o`00000:oooo
ool0003oooooo`000?oooooo0000ooooool0003oooooo`0000?ooooo0_l000001?oooooo0000oooo
ooooool2o`0000?ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00?o0000ooooool00000
0_ooool3o`000003ooooool0003ooooo00Gooooo0_l00007ooooo`00<Oooool01?l0003oooooo`00
0?ooool2o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000Gooooo
00?o0000ooooooooool01_ooool01_l0003oooooo`000?oooooo0000ooooo`?o000000Goooooo`00
0?ooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooool0003ooooo
o`000002ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Cooooo0_l00003ooooo`;o0000
0_ooool3o`0000Gooooo0_l000001Ooooooo0000o`000?oooooo000000;ooooo0_l00002ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0000:ooooo`05o`000?oooooo
ooooooooool000002oooool00ol0003oooooo`000004ooooo`;o00000_ooool01?l0003oooooo`00
0?l00006ooooo`Co00001?ooool00ol0003oooooooooo`05ooooo`00<Oooool2o`0000?ooooo00Ko
0000ooooool0003oooooo`000?ooool3o`0000;ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00?ooooo0_l00005ooooo`;o000000?oooooo`000?l000000oooool00ol0
003oooooooooo`02ooooo`06o`000?ooooooooooooooool0003ooooo0_l000001?oooooo0000oooo
ooooool8o`0000;ooooo00Wo0000ooooool0003o0000ooooool0003oooooo`000?ooool01Ol00000
1Ooooooo0000o`000?oooooo000000;ooooo00?o0000ooooooooool00_l000000ooooooo0000oooo
o`06ooooo`05o`000?ooooooooooooooool000001_ooool2o`0000Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00001_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00Co0000ooooool0003ooooo0ol000000ooooooo
0000o`000003ooooo`;o000000?oooooo`000?l000001oooool0037ooooo1?l00003ooooo`03o`00
0?oooooooooo00;o000000?oooooo`000?ooool00_l00002ooooo`03o`000?oooooooooo00;o0000
1?ooool01_l0003oooooooooool0003oooooo`0000Cooooo0_l000001_oooooo0000o`000?l0003o
ooooo`0000Gooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`05o`000?oo
oooo0000o`000?ooool00_l00002ooooo`;o000000?oooooo`000?ooool00oooool2o`0000Cooooo
00?o0000ooooool000002Oooool2o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool000000_ooool4o`000004
ooooool0003o0000ooooo`;o000000?oooooo`000?ooool01Oooool3o`000005ooooool0003ooooo
ooooool000000_ooool01?l0003oooooo`000?l00006ooooo`04o`000?oooooo0000ooooo`?o0000
0_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Gooooo000aooooo`04o`000?oo
ooooooooooooo`;o00000_ooool00ol0003oooooooooo`02o`000006ooooool0003oooooooooool0
003ooooo0ol000001Ooooooo0000ooooool0003ooooo00;o00000_ooool01?l0003oooooo`000?l0
0004ooooo`?o000000Coooooo`000?oooooo00000oooool3o`0000;ooooo0_l00003ooooo`03o`00
0?oooooooooo00;ooooo0_l000000ooooooo0000o`000005ooooo`;o000000?oooooo`000?ooool0
0oooool3o`000006ooooool0003oooooo`000?oooooo00001?ooool00ol0003oooooooooo`02o`00
00;ooooo00go0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000
00;ooooo00Go0000ooooooooooooooooo`000008ooooo`;o00000_ooool01Ol0003oooooo`000?l0
003ooooo00;o00001oooool3o`0000Gooooo00?o0000ooooooooool00_ooool01?l0003oooooo`00
0?l00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`00<Oooool00ol0003oooooo`000002ooooo`;o00001Oooool01Ol0003ooooo
o`000?oooooo000000;ooooo0_l00006ooooo`03o`000?oooooooooo00?o00001?ooool2o`0000Ko
oooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`Co00001Oooool00ol0003o
ooooooooo`02ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?ooool00_ooool2o`00
0004ooooool0003oooooo`0000Cooooo0_l00004ooooo`;o00000_ooool00ol0003oooooooooo`02
ooooo`?o00000_ooool01Ol0003ooooooooooooooooo000000Gooooo0_l000002?oooooo0000o`00
0?l0003oooooo`000?oooooo00000oooool4o`0000;ooooo00?o0000ooooooooool00ol00002oooo
o`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo
00Gooooo0_l00004ooooo`05o`000?ooooooooooooooool000001oooool0037ooooo0_l00002oooo
o`03o`000?oooooooooo00Co000000?oooooo`000?ooool01Oooool00ol0003oooooo`000002o`00
00;ooooo00Go0000ooooool0003oooooo`000007ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000001?ooool00ol0003ooooo
o`000006o`0000;ooooo00Co0000ooooool0003ooooo0ol000000ooooooo0000o`000003ooooo`03
o`000?oooooooooo00Co00000_ooool3o`000009ooooool0003oooooo`000?oooooo0000ooooool0
003ooooo00;o00000oooool2o`000003ooooool0003ooooo00;ooooo00Co0000ooooool0003o0000
0_ooool3o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo0_l000000ooooooo
0000ooooo`02ooooo`Go000000?oooooo`000?l000000_l000000ooooooo0000ooooo`03ooooo`06
o`000?oooooo0000o`000?oooooo00000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000
ooooooooool01Oooool0037ooooo0ol00004ooooo`;o000000?oooooo`000?ooool01?ooool2o`00
0003ooooool0003ooooo00Gooooo0_l000000ooooooo0000o`000002o`000004ooooool0003ooooo
ooooo`;o00000oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool3o`0000;ooooo0_l0
0002ooooo`05o`000?ooooooooooooooool000000_ooool4o`0000?ooooo0ol000000ooooooo0000
ooooo`02ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000ooooo`?o
000000?oooooo`000?l000000_ooool00ol0003oooooo`000002o`0000;ooooo0ol000001?oooooo
0000o`000?ooool4o`0000;ooooo0ol000000ooooooo0000o`000004o`000003ooooool0003ooooo
00Oooooo0ol000001ooooooo0000o`000?l0003oooooo`000?ooool00_l000001Ooooooo0000oooo
oooooooo000000;ooooo00Go0000ooooool0003o0000ooooo`02o`0000Cooooo00?o0000oooooooo
ool01Oooool001?ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@09ooooo`;o
000000?o410@ooooooooool00oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00ko
oooo00Co0000oooooooooooo00002Oooool02Ol0003ooooooooooooooooo0000ooooool0003ooooo
o`000004ooooo`03o`000?oooooooooo00?o00001?ooool00ol0003oooooooooo`02o`000003oooo
ool0003ooooo00Co000000Goooooo`000?l0003o0000ooooo`04o`0000?ooooo1Ol00002ooooo`03
o`000?oooooo000000;o00000oooool00ol0003oooooooooo`03ooooo`Co00000oooool2o`0000Go
oooo00Go0000oooooooooooo0000ooooo`02o`0000?ooooo0_l000001?oooooo0000o`000?ooool2
o`000003ooooool0003ooooo00;o00001?ooool00ol0003oooooooooo`03ooooo`;o000000Cooooo
o`000?oooooo00002oooool01?l0003oooooooooooooool2o`0000Oooooo000Booooo`06okZj^_lQ
8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000[ooooo00?o0000ooooooooool01?ooool3o`000003
ooooool0003ooooo00;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000?ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`000002o`00
00Oooooo1?l000000ooooooo0000o`000006o`0000?ooooo00?o0000ooooooooool00ol00007oooo
o`03o`000?oooooooooo00;o000000Goooooo`000?ooooooooooo`000004ooooo`;o00000_ooool0
0ol0003oooooooooo`05ooooo`Co000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000002
ooooo`;o000000Coooooo`000?oooooo00001_ooool01?l0003oooooooooool00005ooooo`05o`00
0?ooooooooooo`000?ooool00ol00005ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000Oooooo000Booooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool0
0omEEEGo0000oeEEE@06ooooo`Ko00001Oooool2o`0000?ooooo00?o0000ooooool000001_ooool2
o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`;o00000oooool2o`000004ooooool0
003oooooooooo`?o000000?oooooo`000?ooool00_l00002ooooo`04o`000?oooooo0000o`0000;o
oooo1?l000000ooooooo0000o`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooo
oooooooo0000ooooo`06o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?ooool00_ooool5
o`000004ooooool0003oooooo`0000?ooooo00Co0000oooooooooooooooo0_l000001?oooooo0000
o`000?l00002ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?ooool00_ooool01?l0
003oooooooooooooool3o`0000;ooooo00?o0000ooooooooool00_l000001?oooooo0000ooooool0
0007ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000ol00005ooooo`03o`000?oo
oooooooo00;o00001oooool001;ooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`05odA4
A?nj^[[oooooooooool000001_ooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool2o`00
00Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000;o00000oooool2
o`0000Oooooo0_l00006ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool3o`0000Kooooo
0_l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_l00002ooooo`;o0000
00Goooooo`000?l0003oooooo`000008ooooo`04o`000?ooooooooooo`0000Kooooo0_l000001?oo
oooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo0ol000001?oooooo0000o`00
0?l00002ooooo`?o00000_ooool01?l0003oooooo`000?ooool2o`0000;ooooo1?l00006ooooo`?o
00001?ooool4o`0000Oooooo0_l00007ooooo`004_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00cooooo00GogMgMob4Q8Oooooooooooo`000006ooooo`03o`000?oooooooooo00?o
00000_ooool01Ol0003ooooooooooooooooo000000Kooooo00Oo0000ooooool0003oooooo`000?oo
oooo000000Gooooo0_l000000ooooooo0000o`000002ooooo`Co00001Oooool5o`0000Gooooo00Co
0000ooooool0003o00001Oooool01?l0003oooooooooool00004ooooo`04o`000?oooooooooooooo
o`Co000000Coooooo`000?l0003ooooo1ol00003ooooo`03o`000?oooooooooo00?ooooo00So0000
ooooooooooooooooo`000?oooooo0000ooooo`;o00000_ooool00ol0003oooooooooo`03o`0000?o
oooo0ol00007ooooo`03o`000?oooooo000000Cooooo0_l000001?oooooo0000o`000?l00002oooo
o`05o`000?ooooooooooooooool000000_ooool2o`000003ooooool0003o000000?o000000Sooooo
o`000?l0003o0000ooooool0003oooooo`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00Go
oooo000Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01?mgMgOoV9RH
ooooool00006ooooo`Co00000oooool3o`000003ooooool0003ooooo00Go00000oooool01Ol0003o
ooooo`000?oooooo000000;ooooo00Co0000ooooool0003o00000_ooool2o`0000?ooooo00?o0000
ooooooooool01Oooool6o`0000;ooooo00Co0000oooooooooooooooo0_l000001ooooooo0000oooo
ool0003oooooo`000?ooool00_l00006ooooo`?o00000oooool3o`000004ooooool0003ooooooooo
o`;o00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Cooooo1?l000001?oo
oooo0000o`000?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool4o`000003ooooool0003o
oooo00;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00Co0000ooooool0003o00000ooo
ool00ol0003oooooo`000002ooooo`;o00000oooool01_l0003ooooooooooooooooo0000ooooo`;o
000000Coooooo`000?oooooo00001Oooool00ol0003oooooooooo`05ooooo`004_ooool01_l0003o
k^k^ooooooooooook^k^o`0000oooooo00Cok^k^ob4Q8Ooooooo00001_ooool01_l0003ooooooooo
ool0003oooooo`0000Cooooo0ol000000ooooooo0000o`000003ooooo`?o000000[oooooo`000?l0
003oooooo`000?oooooo0000ooooool0003ooooo0_l00002ooooo`;o00000_ooool00ol0003ooooo
o`000002o`000003ooooool0003ooooo00?ooooo00Co0000oooooooooooooooo1?l00004ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo0_l00003ooooo`;o000000Coooooo`000?oooooo00000_ooool01_l0
003oooooo`000?l0003oooooo`0000;ooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00Go
0000ooooool0003oooooo`000004ooooo`Co00002?ooool00ol0003oooooooooo`02ooooo`;o0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o00001?ooool4o`000005oooo
ool0003o0000ooooool000001oooool001;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@@oooo
o`03ogMgMonHV9So000000Kooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?l0003o
oooo00;o00001_ooool2o`000003ooooool0003ooooo00Oooooo00?o0000ooooool000001oooool6
o`000003ooooool0003o000000;ooooo00?o0000ooooool000001?ooool01_l0003oooooooooool0
003oooooo`0000Gooooo00?o0000ooooooooool01Oooool2o`0000Cooooo00?o0000ooooooooool0
0_ooool2o`0000;ooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool0
0ol0003oooooo`000002o`0000;ooooo00Co0000ooooool0003ooooo0_l00002ooooo`07o`000?oo
ooooooooo`000?oooooo0000ooooo`03o`000004ooooool0003o0000o`0000;ooooo00Go0000oooo
ool0003o0000ooooo`03o`000003ooooool0003o000000Cooooo00?o0000ooooool000001?l00000
0ooooooo0000o`000003ooooo`03o`000?oooooo000000;ooooo0_l000001_oooooo0000o`000?l0
003oooooo`0000?ooooo00?o0000ooooooooool01Oooool001;ooooo00Ko^[Zjob4Q8OoMgMgogMgM
ob4Q8Onj^[X@ooooo`03onk^k_lb<S;o000000Kooooo0_l00002ooooo`;o000000Goooooo`000?oo
ooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00005
ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool00oooool2o`0000;ooooo00?o0000
ooooool000000_ooool00ol0003oooooooooo`02ooooo`;o00001_ooool00ol0003oooooo`000003
ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`Co00000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo0_l000001_oooooo0000ooooool0003oooooo`0000;ooooo
00?o0000ooooooooool00_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000000_l000000ooooooo0000o`000002ooooo`03o`000?oooooo000000;o0000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000ooooool0003o00000_ooool2o`00
00Gooooo0_l00002ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool01_ooool001?o
oooo00CoV9RHo`000?l0003oV9RH4_ooool00onHV9So410@ooooo`05ooooo`04o`000?oooooo0000
o`0000;ooooo0_l000001ooooooo0000o`000?l0003oooooo`000?ooool00_l00006ooooo`;o0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;o00001oooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?ooooo0ol00002ooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooool000000_l000001?oooooo0000o`000?l00002ooooo`04o`000?oooooo
ooooooooo`;o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000000?ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooool0
00000_l000001?oooooo0000ooooooooool2o`000004ooooool0003oooooooooo`?o00000_ooool0
0ol0003oooooooooo`02ooooo`;o000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o0000
1_ooool00ol0003oooooo`000003ooooo`;o000000?oooooo`000?ooool00oooool5o`0000;ooooo
00?o0000ooooooooool01Oooool0037ooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oo
oooooooo00Ko00001oooool01?l0003oooooooooool00005ooooo`;o00002?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooo0000
00?o000000?oooooo`000?ooool00_l000000ooooooo0000o`000002ooooo`05o`000?oooooo0000
o`000?ooool00_l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool2
o`000007ooooool0003oooooooooool0003oooooo`000002ooooo`03o`000?oooooo000000;o0000
1?ooool3o`000003ooooool0003ooooo00;ooooo0ol000000ooooooo0000o`000002o`000003oooo
ool0003o000000?o00001?ooool2o`0000?ooooo00?o0000ooooooooool01Oooool2o`000003oooo
ool0003ooooo00?ooooo00Co0000ooooool0003o00001oooool0037ooooo00Go0000oooooooooooo
0000ooooo`02o`0000Oooooo00Co0000oooooooooooo00001?ooool01ol0003oooooo`000?oooooo
0000ooooool000000_ooool3o`0000;ooooo0_l00003ooooo`07o`000?ooooooooooooooool0003o
ooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_l00002ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`07oooo
o`;o00001?ooool01?l0003oooooooooooooool2o`000003ooooool0003o000000;ooooo00Co0000
oooooooooooooooo0_l00002ooooo`Co00001?ooool00ol0003oooooooooo`02ooooo`;o00001?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000ooooool0003o00000_ooool2o`0000Co
oooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool4o`0000Co
oooo0_l00007ooooo`00<Oooool3o`000003ooooool0003o000000;ooooo00?o0000ooooool00000
0oooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooool0003o0000ooooo`03o`000003ooooool0003o0000
00oooooo0ol000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?ooool00_ooool01?l0
003oooooooooool00002ooooo`06o`000?oooooo0000o`000?oooooo00000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`000003ooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool2o`00000:ooooool0003ooooo
ooooool0003oooooo`000?oooooo0000ooooo`?o000000?oooooo`000?ooool00_ooool00ol0003o
ooooo`000002o`0000Cooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000oooool01?l0
003oooooo`000?ooool2o`0000;ooooo0_l00007ooooo`00<Oooool01Ol0003oooooo`000?l0003o
oooo00;o00000_ooool00ol0003oooooooooo`02o`0000Kooooo00?o0000ooooooooool00_ooool2
o`0000Cooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooool000000ol000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;ooooo00Co
0000ooooool0003o00000_ooool2o`0000Cooooo0_l00003ooooo`;o00000oooool2o`0000Gooooo
00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000?ooooo00Co0000oooooooo
oooooooo0_l00002ooooo`04o`000?oooooo0000o`0000;ooooo0_l000000ooooooo0000ooooo`02
o`0000;ooooo1Ol000001Ooooooo0000o`000?l0003ooooo00;o00001_ooool00ol0003ooooooooo
o`02ooooo`07o`000?ooooooooooooooool0003oooooo`000008ooooo`04o`000?oooooooooooooo
o`;o000000?oooooo`000?ooool00oooool01Ol0003oooooo`000?oooooo000000Oooooo000aoooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0003o00001_ooool01?l0003ooooo
o`000?l00002ooooo`03o`000?oooooooooo00Cooooo0_l000001Ooooooo0000o`000?oooooo0000
00gooooo1Ol00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000oooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00Oo0000oooooooooooooooo
o`000?oooooo000000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool3o`0000Co
oooo00Go0000oooooooooooo0000ooooo`02o`0000;ooooo00?o0000ooooooooool01Ol00006oooo
o`;o00001Oooool2o`000004ooooool0003o0000o`0000Cooooo1?l00002ooooo`04o`000?oooooo
ooooo`0000Oooooo0003ooooo`04oa0@4?l0003o0000o`0002[ooooo00So0000oooooooooooo0000
ooooool0003oooooo`0000Gooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooo000000;o000000Ooooooo`000?oooooo0000ooooool0003ooooo00Oo0000
2Oooool01Ol0003oooooo`000?l0003ooooo00;o000000?oooooo`000?ooool00_ooool00ol0003o
ooooo`000004ooooo`?o00000_ooool01?l0003oooooooooooooool2o`000003ooooool0003ooooo
00;ooooo0_l00002ooooo`;o00001Oooool2o`0000Gooooo0_l00005ooooo`04o`000?oooooo0000
o`0000Gooooo00?o0000ooooooooool01?ooool2o`000006ooooool0003oooooooooool0003ooooo
0ol00005ooooo`03o`000?oooooooooo00;ooooo00co0000ooooooooooooooooo`000?oooooo0000
ooooool0003oooooo`000?ooool3o`0000Gooooo00Co0000ooooool0003o00000_ooool00ol0003o
ooooooooo`05ooooo`001?ooool00ol0003oooooooooo`0Zooooo`04o`000?oooooo0000ooooo`?o
00000_ooool2o`000003ooooool0003ooooo00Kooooo0_l000001Ooooooo0000ooooool0003ooooo
00;o00000oooool4o`000007ooooool0003oooooooooool0003oooooo`000002ooooo`?o000000?o
ooooo`000?l000000_ooool2o`000006ooooool0003oooooo`000?oooooo00002oooool2o`000004
ooooool0003oooooo`0000Gooooo00Co0000ooooool0003o00000oooool01Ol0003oooooo`000?oo
oooo000000;ooooo00?o0000ooooool000000ol00004ooooo`03o`000?oooooooooo00;o00000ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo
1?l00003ooooo`04o`000?ooooooooooooooo`?o00000oooool2o`0000Cooooo00?o0000ooooool0
00002?ooool00ol0003oooooo`000004ooooo`;o000000?oooooo`000?ooool01_ooool000Cooooo
00?o0000ooooooooool0:_ooool2o`0000;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000002ooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo0_l00004ooooo`;o00001?ooool01?l0003oooooo`000?ooool3o`0000Kooooo1?l00000
0ooooooo0000o`000002o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`?o00001oooool01?l0003oooooo`000?l00002ooooo`;o00000oooool00ol0003oooooo`00
0005o`0000?ooooo00?o0000ooooool000001oooool2o`0000;ooooo00Go0000oooooooooooo0000
ooooo`03o`000003ooooool0003ooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo
0_l000001?oooooo0000ooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool2o`00
00Gooooo00Co0000oooooooooooooooo0_l00007ooooo`001?ooool01_l0003oQhN7oa0@4?l0003o
410@ogMgMbOooooo1Ol000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_oo
ool01?l0003oooooooooooooool2o`000003ooooool0003ooooo00Gooooo00?o0000ooooool00000
1Ol00002ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo0ol00002ooooo`Co
000000Coooooo`000?oooooo00001_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
000000?o000000?oooooo`000?l000001?ooool01?l0003oooooo`000?l00006ooooo`;o000000?o
ooooo`000?ooool00_ooool3o`0000;ooooo0_l00006ooooo`03o`000?oooooo000000;ooooo00Go
0000ooooool0003o0000ooooo`02o`0000?ooooo00[o0000oooooooooooo0000ooooool0003ooooo
o`000?oooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`03ooooo`?o000000?oooooo`000?ooool01?ooool00ol0003o
ooooooooo`05ooooo`001?ooool01ol0003o8B4Qolc<c?ooooooc<c<ob4Q8OmgMgL09_ooool2o`00
0003ooooool0003o000000?ooooo0_l00002ooooo`;o00000oooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooool000000_l00002ooooo`03o`000?oooooo000000;o00000_ooool4
o`0000;ooooo00?o0000ooooool000000_ooool01Ol0003oooooo`000?l0003ooooo00;o000000Co
ooooo`000?oooooooooo0_l00005ooooo`;o00000oooool00ol0003oooooooooo`02o`000003oooo
ool0003o000000Sooooo0_l00006ooooo`;o000000?oooooo`000?l000000oooool2o`000003oooo
ool0003o000000;ooooo1Ol00004ooooo`07o`000?oooooo0000ooooool0003oooooo`000003oooo
o`04o`000?oooooo0000o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool01Ooo
ool000Cooooo00?o0000olc<c?ooool00_ooool00oo<c<co410@ooooo`0Uooooo`03o`000?oooooo
000000;ooooo0_l00005ooooo`05o`000?ooooooooooooooool000001_ooool01_l0003ooooooooo
ool0003oooooo`0000;ooooo00?o0000ooooooooool00ol000001Ooooooo0000ooooool0003ooooo
00?o00000oooool2o`0000?ooooo0_l00002ooooo`Co000000?oooooo`000?ooool00_l00008oooo
o`08o`000?ooooooooooo`000?oooooo0000ooooool00006ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooo`000?ooool2o`0000?ooooo00Co0000ooooool0003ooooo0ol00008
ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`?o000000?oooooo`000?l000000_ooool3
o`000003ooooool0003ooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00Ko0000
oooooooooooo0000ooooool00009ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0
003o00001oooool000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Tooooo`?o
00000oooool01?l0003oooooo`000?l00003ooooo`?o00000_ooool2o`000003ooooool0003o0000
00;o000000?oooooo`000?l000002?ooool6o`000003ooooool0003ooooo00Kooooo0_l00005oooo
o`;o00000oooool01Ol0003oooooooooool0003ooooo00;o00003?ooool00ol0003oooooo`000004
ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;o00001Oooool00ol0003oooooooooo`04ooooo`?o000000Goooooo`000?l0003oooooo`00
0005ooooo`03o`000?oooooooooo00;ooooo0ol000000ooooooo0000o`000004ooooo`05o`000?oo
ooooooooo`000?ooool01?l00002ooooo`05o`000?ooooooooooooooool000002_ooool01?l0003o
ooooo`000?ooool2o`0000Oooooo0004ooooo`03o`000?o<c<cooooo00;ooooo00?oc<c<oa0@4?oo
ool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooooooo0ol000001Ooooooo0000ooooool0003ooooo00?o000000?oooooo`000?l000000_ooool2
o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Sooooo0_l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo00Kooooo1_l00000
1_oooooo0000o`000?oooooo0000ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o0000
0oooool01?l0003oooooooooool00002ooooo`;o000000?oooooo`000?ooool00oooool00ol0003o
ooooo`000005ooooo`;o000000Ooooooo`000?l0003oooooo`000?oooooo000000?ooooo0_l00000
1?oooooo0000o`000?l00005ooooo`03o`000?oooooooooo00Kooooo00So0000ooooool0003o0000
ooooool0003oooooo`0000Cooooo0_l000000ooooooo0000ooooo`06ooooo`001?ooool01ol0003o
8B4Qolc<c?oooooo^[Zjob4Q8OnYZJT09_ooool2o`0000?ooooo00Ko0000ooooool0003o0000oooo
ool00004ooooo`?o00001Oooool01?l0003oooooo`000?l00003ooooo`Co000000?oooooo`000?oo
ool00_l00002ooooo`;o000000Coooooo`000?oooooo00001Oooool00ol0003oooooo`000003o`00
0007ooooool0003o0000o`000?oooooo0000ooooo`02o`0000Cooooo00?o0000ooooool000002?oo
ool01?l0003oooooo`000?ooool2o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo
00Co0000ooooool0003o00001Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo
00;o00000_ooool01_l0003oooooo`000?l0003oooooo`0000;ooooo0_l00008ooooo`;o00000_oo
ool3o`0000;ooooo0_l000000ooooooo0000ooooo`02o`0000;ooooo00Ko0000ooooool0003ooooo
o`000?ooool3o`0000Gooooo00?o0000ooooooooool01Oooool000?ooooo00Oo410@o`000?n7QhOo
410@o`000?l@413oZJVY02Oooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`02o`00
00Oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo1?l00002ooooo`;o00000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`Co000000?ooooo
o`000?l000002_ooool00ol0003oooooooooo`02ooooo`;o000000Koooooo`000?l0003o0000oooo
ool00002ooooo`05o`000?oooooo0000o`000?ooool00_l00006ooooo`;o000000Goooooo`000?l0
003oooooo`000003ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`;o00001?ooool2o`00
0004ooooool0003o0000o`0000Kooooo1?l000000ooooooo0000ooooo`02o`000004ooooool0003o
ooooo`0000Kooooo00Go0000ooooooooooooooooo`000006ooooo`;o00000_ooool01?l0003ooooo
ooooool00007ooooo`00<Oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?oo
ool00_l00004ooooo`04o`000?oooooo0000o`0000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`;o00000oooool00ol0003oooooooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`?o00000_ooool3o`000006ooooool0003oooooooooool0003ooooo0_l000000ooooooo
0000ooooo`03ooooo`05o`000?ooooooooooo`000?ooool00ol00002ooooo`04o`000?oooooo0000
o`0000?ooooo00Co0000ooooool0003o00000_ooool01?l0003oooooo`000?l00005ooooo`04o`00
0?ooooooooooo`0000?ooooo0_l000001?oooooo0000o`000?l00004ooooo`Go00001?ooool01?l0
003oooooo`000?ooool2o`0000Kooooo00?o0000ooooool000000oooool5o`000003ooooool0003o
oooo00;o000000?oooooo`000?ooool00_ooool2o`000003ooooool0003ooooo00;o00000_ooool2
o`0000?ooooo0_l00007ooooo`00<Oooool01?l0003oooooooooool00002ooooo`;o00001?ooool0
0ol0003oooooo`000006ooooo`?o00001Oooool01?l0003oooooo`000?l00003ooooo`?o00001ooo
ool00ol0003oooooo`000002ooooo`?o00000oooool01_l0003oooooooooool0003oooooo`0000?o
oooo00Ko0000ooooool0003o0000ooooool00005ooooo`?o00001Oooool01Ol0003ooooooooooooo
oooo000000Cooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`000002ooooo`?o0000
00?oooooo`000?l000000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ool000000oooool2o`0000?ooooo00?o0000ooooooooool00ol00005ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00007ooooo`00<Oooool00ol0
003oooooooooo`02ooooo`?o00000_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooo0000
ooooo`;o00001oooool5o`0000Gooooo00Co0000ooooool0003o00000_ooool3o`000005ooooool0
003o0000ooooool000000_ooool3o`0000Oooooo00Ko0000ooooool0003oooooo`000?ooool2o`00
0003ooooool0003ooooo00;o00001oooool01?l0003oooooooooooooool3o`000003ooooool0003o
oooo00;ooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`03ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002o`0000?ooooo00?o
0000ooooooooool00oooool2o`0000;ooooo0_l000002Ooooooo0000oooooooooooo0000ooooool0
003oooooo`000004ooooo`;o00000oooool3o`000003ooooool0003o000000;o00000oooool01_l0
003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool01Oooool0037ooooo00?o0000
ooooooooool00_l000001?oooooo0000ooooooooool2o`0000Kooooo00Ko0000ooooool0003o0000
ooooool0000:ooooo`03o`000?oooooo000000Gooooo00Go0000ooooooooooooooooo`000005oooo
o`;o00000oooool00ol0003oooooo`000003o`0000Oooooo0_l00006ooooo`;o000000Coooooo`00
0?oooooo00000oooool02?l0003oooooo`000?l0003oooooo`000?oooooo00000_ooool00ol0003o
ooooo`000004ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool000000_l000001?oo
oooo0000ooooool00004ooooo`04o`000?oooooo0000o`0000?ooooo0ol00003ooooo`03o`000?oo
oooooooo00Sooooo00Co0000ooooool0003ooooo0_l000000ooooooo0000o`000002ooooo`03o`00
0?oooooo000000Cooooo00?o0000ooooool000000ol00006ooooo`03o`000?oooooooooo00Gooooo
000aooooo`;o000000?oooooo`000?ooool00_ooool3o`000003ooooool0003ooooo00;o00000_oo
ool00ol0003oooooooooo`03ooooo`Go00001_ooool2o`0000Cooooo0ol000001_oooooo0000oooo
oooooooo0000ooooo`?o00000_ooool01_l0003oooooo`000?oooooo0000ooooo`?o00001Oooool0
0ol0003oooooo`000002o`000003ooooool0003ooooo00;ooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`?o00000_ooool00ol0003oooooooooo`02ooooo`Co00001oooool01Ol0003ooooo
ooooool0003ooooo00;o00000_ooool2o`0000;ooooo0_l00005ooooo`;o00000oooool2o`0000;o
oooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`000?oooooo
000000Sooooo00[o0000oooooooooooo0000ooooool0003oooooo`000?oooooo00001?ooool00ol0
003oooooooooo`05ooooo`00<Oooool3o`0000;ooooo00?o0000ooooooooool00ol00002ooooo`04
o`000?ooooooooooooooo`Co000000Koooooo`000?ooooooooooo`000?ooool3o`0000Kooooo0_l0
00000ooooooo0000ooooo`03ooooo`;o00000oooool2o`0000Kooooo00Go0000oooooooooooo0000
ooooo`05o`000004ooooool0003o0000o`0000;ooooo0_l00003ooooo`;o00000_ooool4o`000004
ooooool0003oooooo`0000;ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo00?o0000
ooooooooool00_ooool4o`0000?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Kooooo00Co
0000ooooool0003ooooo0ol000000ooooooo0000ooooo`02o`000005ooooool0003oooooo`000?oo
ool00_l00002ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`Go000000Goooooo`00
0?ooooooooooo`000003ooooo`04o`000?ooooooooooooooo`;o00001oooool0037ooooo00Co0000
oooooooooooooooo0_l000000ooooooo0000o`000002ooooo`04o`000?ooooooooooo`0000Kooooo
00Co0000ooooool0003o00001_ooool01ol0003ooooooooooooooooo0000ooooool000000oooool2
o`0000;ooooo0_l00006ooooo`03o`000?oooooo000000;ooooo00Co0000ooooool0003o00000_oo
ool2o`0000;ooooo00Co0000ooooool0003o00000oooool01?l0003oooooooooool00002ooooo`06
o`000?oooooo0000o`000?oooooo00000_ooool00ol0003oooooooooo`05o`0000;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o00000oooool0
1ol0003ooooooooooooooooo0000ooooool000001?ooool00ol0003oooooooooo`02ooooo`?o0000
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`03o`00
0?oooooooooo00Cooooo00So0000ooooooooooooooooo`000?oooooo0000ooooo`;o00001oooool0
037ooooo0_l00003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_l000000ooooooo0000ooooo`02o`000004ooooool0003oooooooooo`;o000000?o
ooooo`000?l000000oooool01_l0003oooooo`000?l0003oooooo`0000Gooooo1?l000003?oooooo
0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`0000Wooooo00Go0000oooooooo
ooooooooo`000002ooooo`;o000000?oooooo`000?ooool01Ol00005ooooo`03o`000?oooooo0000
00;o00000oooool01?l0003oooooooooool00002ooooo`;o00000_ooool01ol0003ooooooooooooo
oooo0000ooooool000000_ooool3o`000004ooooool0003oooooo`0000Cooooo00?o0000ooooool0
00000ol00002ooooo`03o`000?oooooo000000?ooooo00Co0000ooooool0003ooooo0ol000000ooo
oooo0000ooooo`09ooooo`;o000000Soooooo`000?oooooo0000ooooool0003oooooo`0000Oooooo
000aooooo`03o`000?oooooooooo00?o00001Oooool3o`000003ooooool0003ooooo00Cooooo00?o
0000ooooool000001?ooool00ol0003oooooooooo`0:ooooo`04o`000?oooooo0000ooooo`Ko0000
00?oooooo`000?l000000_ooool3o`0000?ooooo00?o0000ooooooooool00oooool2o`0000Gooooo
00Co0000ooooool0003o00000oooool2o`0000;ooooo00?o0000ooooool000000_ooool00ol0003o
ooooooooo`02ooooo`;o000000Goooooo`000?ooooooooooo`000005ooooo`Co00000_ooool00ol0
003oooooooooo`07ooooo`04o`000?oooooo0000o`0000Kooooo00?o0000ooooool000001?ooool0
0ol0003oooooo`000002o`000003ooooool0003ooooo00Co000000?oooooo`000?ooool00_ooool4
o`0000Oooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00007ooooo`00<Oooool0
0ol0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000004ooooo`03o`00
0?oooooooooo00?o00000_ooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooo000000;o
oooo00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooo000000;ooooo1?l000001Ooo
oooo0000ooooool0003ooooo00Co00000oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooo000000Cooooo0_l000000ooooooo0000o`000002o`0000Oooooo00?o0000ooooool000001Ooo
ool2o`0000Gooooo00?o0000ooooooooool01?ooool01Ol0003oooooo`000?l0003ooooo00;o0000
00?oooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000ooooool0003o00001?ooool3
o`0000?ooooo1?l000001Ooooooo0000oooooooooooo000000Oooooo000aooooo`03o`000?oooooo
oooo00;o000000?oooooo`000?l000000_l000002?oooooo0000ooooool0003oooooo`000?oooooo
00000oooool5o`000003ooooool0003ooooo00;ooooo0_l00005ooooo`Co00001Oooool01Ol0003o
ooooo`000?l0003ooooo00?o00000_ooool3o`000003ooooool0003ooooo00;ooooo0_l00003oooo
o`05o`000?oooooo0000o`000?ooool00_l000000ooooooo0000ooooo`04ooooo`05o`000?oooooo
0000ooooool000001?ooool3o`0000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooo`00
0?ooool2o`0000;ooooo0ol000000ooooooo0000ooooo`02o`0000;ooooo00Go0000oooooooooooo
ooooo`00000:ooooo`03o`000?oooooooooo00?o00001oooool4o`0000?ooooo00?o0000oooooooo
ool00ol00003ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo000Cooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01_ooool01_o^k^ko
EEEEo`000?l0003oEEEEonk^kPGooooo0_l00006ooooo`06o`000?ooooooooooooooool0003ooooo
0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo1?l000001?oooooo0000o`000?l00006oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooool000000_l00003ooooo`04o`000?oooooo0000
o`0000?ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00Co00000oooool0
0ol0003oooooooooo`02o`0000?ooooo0ol00003ooooo`06o`000?ooooooooooo`000?oooooo0000
1_ooool2o`0000;ooooo00?o0000ooooooooool01?ooool2o`0000?ooooo00?o0000ooooool00000
0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`04
o`000?oooooo0000ooooo`?o000000Coooooo`000?l0003ooooo0_l000001Ooooooo0000oooooooo
oooo000000?ooooo0_l000001?oooooo0000ooooool00004ooooo`Go00000_ooool00ol0003ooooo
ooooo`05ooooo`004_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`;o
MgMg0_ooool00omgMgOoEEEEooooo`04ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooo
oooo00001oooool2o`000005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool0
0003ooooo`06o`000?oooooo0000o`000?oooooo00001Oooool01_l0003ooooooooooooooooo0000
ooooo`;o000000?oooooo`000?l000001?ooool00ol0003oooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000Cooooo
0_l00002ooooo`07o`000?ooooooooooooooool0003oooooo`000004ooooo`05o`000?oooooo0000
ooooool000000oooool2o`0000?ooooo00?o0000ooooool000000oooool01_l0003oooooooooool0
003oooooo`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`06o`000?ooooooooooo`00
0?oooooo00002?ooool00ol0003oooooo`000003ooooo`;o00001?ooool4o`0000?ooooo0_l00007
ooooo`004_ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_oo
ool00olQ8B7oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?l0
0002ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`Co00002Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?ooool00_ooool2o`00
0004ooooool0003o0000o`0000?ooooo0_l00003ooooo`;o000000Goooooo`000?ooooooooooo`00
0003ooooo`?o000000?oooooo`000?ooool01oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000ooooool0003o00000_ooool2o`000003ooooool0003ooooo00;o000000Goooooo`000?oo
ooooooooo`000002ooooo`03o`000?oooooooooo00;o00001_ooool01ol0003ooooooooooooooooo
0000ooooool000000oooool2o`0000;ooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool000000ol000000ooooooo0000ooooo`03o`0000;ooooo0_l00005ooooo`08o`00
0?ooooooooooo`000?oooooo0000ooooool00007ooooo`004_ooool01_l0003ok^k^oooooooooooo
k^k^o`0000kooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`03ooooo`;o000000?o
ooooo`000?ooool00_ooool2o`00000;ooooool0003oooooo`000?oooooo0000ooooool0003ooooo
o`000?ooool01Ol00002ooooo`0;o`000?oooooo0000o`000?oooooo0000ooooool0003oooooo`00
0?ooool00_l000000ooooooo0000o`000003o`0000?ooooo00?o0000ooooool000001_ooool3o`00
0004ooooool0003oooooooooo`Co00000_ooool3o`0000?ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooo`000?l00002ooooo`?o00000_ooool2o`0000?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooo00001Oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`04
o`0000;ooooo00Ko0000ooooool0003oooooo`000?ooool2o`000004ooooool0003oooooooooo`;o
000000Goooooo`000?l0003oooooo`000003ooooo`?o00000_ooool2o`0000;ooooo00?o0000oooo
ooooool00_l00007ooooo`004_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00co
oooo00Ko0000oeEEEOo^k^koooooogMgMomEEED5ooooo`?o00001?ooool01_l0003oooooo`000?l0
003oooooo`0000;ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooool000000_ooool00ol0003oooooooooo`03o`000003ooooool0003o000000?ooooo
0ol000001?oooooo0000o`000?ooool2o`0000Gooooo00Co0000oooooooooooooooo0_l00003oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`0000cooooo00Co0000
oooooooooooo00000oooool00ol0003oooooo`000002ooooo`05o`000?oooooo0000ooooool00000
0oooool01?l0003oooooooooool00002ooooo`Co00000_ooool3o`000007ooooool0003o0000o`00
0?oooooo0000ooooo`02o`0000;ooooo0_l000000ooooooo0000o`00000:ooooo`04o`000?oooooo
ooooooooo`?o00000oooool3o`0000?ooooo00?o0000ooooooooool00_ooool2o`000004ooooool0
003oooooo`0000Oooooo000Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?oo
ool01_l0003oMgMgo`000?l0003oEEEEonk^kPGooooo00?o0000ooooool000003?ooool01Ol0003o
ooooo`000?oooooo000000Kooooo0_l000000ooooooo0000ooooo`02ooooo`;o00001_ooool4o`00
00Gooooo00Co0000ooooool0003o00002?ooool2o`0000Cooooo0_l000000ooooooo0000o`000002
ooooo`;o00000oooool01ol0003oooooooooool0003oooooo`000?ooool01?l00002ooooo`Co0000
1Oooool01?l0003oooooooooool00003ooooo`?o00000oooool3o`000003ooooool0003o000000?o
000000?oooooo`000?ooool01?ooool01Ol0003oooooo`000?oooooo000000Gooooo00Co0000oooo
oooooooo00000_ooool2o`000003ooooool0003ooooo00Cooooo00?o0000ooooooooool00ol00003
ooooo`05o`000?ooooooooooooooool000000oooool01_l0003oooooo`000?l0003oooooo`0000Oo
oooo000Booooo`06o`000?o^k^koooooooooooo^k^ko00003_ooool00om4A4CoV9RHooooo`08oooo
o`03o`000?oooooo000000;ooooo00?o0000ooooooooool00ol00003ooooo`;o000000Koooooo`00
0?ooooooooooo`000?ooool2o`0000;ooooo00?o0000ooooool000000_ooool01_l0003ooooooooo
oooooooo0000ooooo`So000000Ooooooo`000?l0003oooooo`000?oooooo000000;ooooo0_l00002
ooooo`;o00000_ooool3o`000003ooooool0003o000000;o00001_ooool01Ol0003oooooooooool0
003ooooo00?o00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo000000;ooooo
00Co0000ooooool0003o00000_ooool01Ol0003oooooo`000?l0003ooooo00?o000000Goooooo`00
0?ooooooooooo`000003ooooo`03o`000?oooooo000000Kooooo0_l000000ooooooo0000ooooo`03
ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000ooooo`04ooooo`;o00001oooool0
1?l0003oooooo`000?ooool2o`000004ooooool0003oooooo`0000Cooooo00?o0000ooooooooool0
1Oooool001;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@>ooooo`03okZj^_lQ8B7ooooo00So
oooo00?o0000ooooooooool00_l00002ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool2
o`000005ooooool0003o0000o`000?ooool00_l00003ooooo`03o`000?oooooooooo00;o000000?o
ooooo`000?ooool01?ooool01?l0003oooooo`000?ooool3o`000005ooooool0003oooooooooool0
00000oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00Co000000Coooooo`000?oooooooooo0ol00004ooooo`;o000000Oo
ooooo`000?oooooo0000ooooool0003ooooo00?o000000?oooooo`000?ooool00oooool01_l0003o
oooooooooooooooo0000ooooo`?o000000Goooooo`000?ooooooooooo`000004ooooo`06o`000?oo
ooooooooo`000?oooooo00000_ooool01ol0003oooooooooool0003oooooo`000?ooool00ol00003
ooooo`;o00000_ooool2o`000005ooooool0003oooooo`000?ooool00ol000000ooooooo0000oooo
o`02ooooo`;o00001Oooool01_l0003oooooooooool0003oooooo`0000Oooooo000Booooo`06okZj
^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3oooool00omEEEGo<S8bomgMg@07ooooo`;o000000Coooooo`00
0?oooooooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo0ol00003ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooooooool00_l00003ooooo`?o00002Oooool00ol0003oooooo`000002
ooooo`;o00000oooool2o`000003ooooool0003o000000;o00001Oooool01Ol0003oooooooooool0
003ooooo00;o000000Coooooo`000?oooooo00000oooool00ol0003oooooo`000004ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_l000001Ooooooo0000o`000?oooooo000000;o
oooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;o
oooo0_l00002ooooo`04o`000?oooooo0000ooooo`;o00001Oooool02?l0003oooooo`000?oooooo
0000ooooool0003ooooo0ol000001Ooooooo0000oooooooooooo000000;ooooo0_l00006ooooo`;o
000000?oooooo`000?ooool00oooool00ol0003oooooooooo`05ooooo`004oooool01?nHV9So0000
o`000?nHV9PAooooo`04oiRHV?lQ8B7o0000ob4Q8@Gooooo0_l00002ooooo`03o`000?oooooooooo
00;ooooo0_l000000ooooooo0000ooooo`02o`00000:ooooool0003oooooooooool0003oooooo`00
0?oooooo0000ooooo`?o00001?ooool3o`0000;ooooo00?o0000ooooool000001_ooool00ol0003o
ooooooooo`04ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool00ol0003oooooo`000002
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01?ooool2o`0000?ooooo0_l0
0002ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooo`000?ooool3o`0000;ooooo00?o0000ooooool000000_l00004ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000004ooooo`05o`00
0?oooooo0000ooooool000000_ooool3o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00?o
oooo0ol00004ooooo`03o`000?oooooooooo00;o00001oooool0037ooooo0_l00002ooooo`03o`00
0?oooooooooo00;ooooo0_l000001?oooooo0000o`000?l00005ooooo`03o`000?oooooooooo00;o
oooo0_l00002ooooo`;o000000?oooooo`000?ooool01?ooool01Ol0003ooooooooooooooooo0000
00;ooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo0_l00002ooooo`;o00001_ooool0
1?l0003oooooooooool00003ooooo`?o00000oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo0_l00002ooooo`06o`000?oooooo0000o`000?oooooo00001?ooool3o`0000Co
oooo00Co0000oooooooooooooooo1Ol00002ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ool000000_ooool01?l0003oooooo`000?ooool2o`000003ooooool0003ooooo00?ooooo00Co0000
ooooool0003ooooo1?l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00Gooooo000a
ooooo`03o`000?oooooooooo00;o00000_ooool3o`000004ooooool0003oooooo`0000?ooooo0_l0
00001Ooooooo0000oooooooooooo000000Gooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`02ooooo`;o00000oooool4o`0000?ooooo1?l000000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00;o000000Coooooo`000?oooooo00000_ooool00ol0003oooooo`000002o`0000So
oooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000?ooooo0_l00005ooooo`03
o`000?oooooo000000Gooooo0_l000001?oooooo0000ooooool00005ooooo`03o`000?oooooooooo
00;o000000?oooooo`000?ooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`000002ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Gooooo
000aooooo`;o000000?oooooo`000?ooool02?ooool00ol0003oooooooooo`02ooooo`;o000000Co
ooooo`000?l0003o00000_ooool5o`0000;ooooo00?o0000ooooooooool00_l000001?oooooo0000
ooooool00007ooooo`03o`000?oooooo000000;o00000_ooool01?l0003oooooooooooooool2o`00
00;ooooo00?o0000ooooool000000oooool2o`0000;ooooo00?o0000ooooooooool00_l000000ooo
oooo0000o`000002o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`;o000000ko
ooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo
00Go0000oooooooooooo0000ooooo`02o`000003ooooool0003o000000Kooooo0ol000001?oooooo
0000ooooooooool2o`000004ooooool0003oooooooooo`Co00000_ooool00ol0003oooooooooo`02
o`000005ooooool0003o0000ooooool000000_ooool01?l0003oooooo`000?l00002ooooo`09o`00
0?ooooooooooo`000?oooooo0000ooooool0003ooooo00Co00001oooool0037ooooo1Ol00004oooo
o`Co000000?oooooo`000?ooool00_l00004ooooo`?o00001Oooool00ol0003oooooo`000004oooo
o`03o`000?oooooooooo00;o00001Oooool2o`000004ooooool0003oooooo`0000?ooooo00Co0000
oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00So0000oooooooooooo
ooooo`000?oooooo0000ooooo`;o00001oooool00ol0003oooooo`000003ooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`;o00000_ooool01_l0003oooooo`000?l0003oooooo`0000;o
oooo00?o0000ooooooooool00_ooool2o`0000Gooooo1Ol000000ooooooo0000ooooo`03ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooool000000oooool01?l0003oooooo`000?l00004oooo
o`Co00000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooool000001oooool0037ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002oooo
o`;o000000?oooooo`000?ooool00_ooool01?l0003oooooooooooooool2o`0000;ooooo0ol00000
0ooooooo0000ooooo`02ooooo`04o`000?oooooo0000o`0000;ooooo00Co0000ooooool0003o0000
0_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l000000ooooooo0000o`000004o`0000;o
oooo0_l00002ooooo`;o00000_ooool5o`000003ooooool0003ooooo00;o00000_ooool00ol0003o
ooooo`000002o`0000Sooooo00?o0000ooooooooool01?ooool01?l0003oooooooooooooool3o`00
00Kooooo0ol00004ooooo`;o000000Soooooo`000?ooooooooooo`000?oooooo0000ooooo`;o0000
1_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ool000000oooool01Ol0003oooooo`000?l0003ooooo00;o000000?oooooo`000?l000000_l00007
ooooo`00<Oooool00ol0003oooooo`000007ooooo`04o`000?ooooooooooooooo`;o00000_ooool0
1?l0003oooooooooooooool2o`000006ooooool0003o0000o`000?oooooo00000oooool2o`0000?o
oooo00?o0000ooooool000000_l00003ooooo`03o`000?oooooooooo00?o00000_ooool00ol0003o
ooooooooo`02ooooo`;o000000?oooooo`000?l000000_ooool00ol0003oooooo`000004ooooo`;o
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_l000001?oooooo0000o`000?l00002ooooo`05o`000?oooooo0000ooooool000001?ooool2
o`0000;ooooo00?o0000ooooooooool00_ooool3o`0000;ooooo00Co0000oooooooooooo00002_oo
ool00ol0003oooooo`000002o`0000Kooooo0_l000000ooooooo0000ooooo`04o`000004ooooool0
003oooooo`0000Cooooo00Co0000oooooooooooo00000_ooool2o`0000Gooooo00?o0000oooooooo
ool01Oooool0037ooooo0ol000001_oooooo0000ooooool0003oooooo`0000Kooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooooooool2o`0000;ooooo00Co0000ooooool0003ooooo
0_l00007ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooooooool4o`00
00Cooooo00?o0000ooooool000000oooool2o`0000Kooooo00Go0000ooooool0003oooooo`000002
ooooo`04o`000?oooooo0000o`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooo`00
0003o`0000;ooooo00?o0000ooooooooool00_l00005ooooo`03o`000?oooooooooo00;o000000Co
ooooo`000?oooooo00002_ooool01?l0003oooooo`000?l00002ooooo`06o`000?oooooo0000oooo
ool0003ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00000oooool2o`000003ooooool0
003o000000Gooooo00?o0000ooooool000000_l00007ooooo`00<Oooool01?l0003oooooooooool0
0005ooooo`04o`000?oooooo0000ooooo`Co00000_ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo00Kooooo1?l000000ooooooo0000ooooo`03ooooo`;o000000?oooooo`000?l00000
0_l00005ooooo`;o00000_ooool2o`0000Cooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00;ooooo00Go0000ooooool0003oooooo`000003ooooo`?o000000?oooooo`000?ooool03Oooool0
0ol0003oooooooooo`03o`000006ooooool0003oooooo`000?oooooo00003_ooool2o`000007oooo
ool0003oooooooooool0003oooooo`000003ooooo`;o00000oooool2o`0000;ooooo1_l00003oooo
o`03o`000?oooooooooo00?ooooo1?l000001?oooooo0000ooooool00007ooooo`00<Oooool3o`00
00Kooooo1?l000000ooooooo0000o`000002o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo
00;o00001_ooool00ol0003oooooo`000003o`0000Gooooo00Ko0000oooooooooooo0000ooooool0
0004ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`09ooooo`?o00001Ooo
ool01?l0003oooooo`000?ooool2o`0000;ooooo00Go0000ooooool0003oooooo`00000:ooooo`07
o`000?oooooo0000ooooool0003oooooo`000004ooooo`;o00001?ooool2o`0000;ooooo0_l00000
1?oooooo0000o`000?l00003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00ooo
ool2o`000003ooooool0003o000000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0000Cooooo1Ol00007ooooo`00<Oooool3o`000003ooooool0
003ooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooo`000002o`000004oooo
ool0003o0000o`0000?ooooo00Co0000ooooool0003o00000_ooool2o`0000?ooooo1?l00003oooo
o`;o00001?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000;o00002?ooool2
o`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`Co00000_ooool2
o`00000:ooooool0003o0000ooooool0003oooooo`000?oooooo0000ooooo`;o00000_ooool00ol0
003oooooo`000005o`0000?ooooo0_l00007ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000
ooooool0003oooooo`000004ooooo`04o`000?ooooooooooooooo`;o000000Goooooo`000?l0003o
ooooo`000003ooooo`06o`000?oooooo0000o`000?oooooo00000oooool00ol0003oooooooooo`05
ooooo`00<Oooool3o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`03o`000?oooooo
oooo00Cooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01ooo
ool01?l0003oooooo`000?l00003ooooo`?o00001_ooool00ol0003oooooo`00000;ooooo`;o0000
0_ooool01Ol0003oooooo`000?l0003ooooo00;o000000Goooooo`000?l0003oooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01oooool2o`0000Gooooo00_o0000
ooooool0003o0000ooooool0003oooooo`000?oooooo0000ooooo`02o`0000;ooooo00Ko0000oooo
oooooooo0000ooooool00006ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
0000ooooo`02o`0000Wooooo0_l00002ooooo`;o000000?oooooo`000?ooool00_ooool2o`000003
ooooool0003o000000Oooooo000aooooo`;o000000?oooooo`000?ooool01?ooool3o`000003oooo
ool0003ooooo00?o00001Oooool00ol0003oooooo`000002o`000008ooooool0003oooooooooool0
003oooooo`000?ooool2o`000003ooooool0003o000000;o000000Ooooooo`000?ooooooooooo`00
0?oooooo000000Sooooo0_l000000ooooooo0000o`000003ooooo`?o00001_ooool4o`000003oooo
ool0003ooooo00;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`06o`000005oooo
ool0003oooooooooool000000oooool01_l0003oooooo`000?oooooo0000ooooo`;o00002_ooool0
1_l0003oooooo`000?oooooo0000ooooo`?o000000?oooooo`000?l000000_ooool01?l0003ooooo
o`000?l00002ooooo`;o00000_ooool00ol0003oooooo`000005ooooo`;o00001oooool00ol0003o
ooooo`000002o`000003ooooool0003ooooo00;o000000Coooooo`000?l0003o00001oooool0037o
oooo00?o0000ooooool000000_ooool00ol0003oooooo`000002o`000004ooooool0003o0000oooo
o`?o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
ooooo`?o00000oooool01?l0003oooooooooool00003ooooo`04o`000?oooooo0000ooooo`;o0000
00?oooooo`000?ooool00_l00002ooooo`03o`000?oooooooooo00?o000000?oooooo`000?ooool0
0oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool01?l0003oooooooooooooool3o`0000Kooooo00?o0000ooooool000001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool4o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`;o00000oooool2o`0000?ooooo00?o0000oooo
ooooool01?ooool2o`000004ooooool0003o0000o`0000Gooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooo`000007ooooo`00<Oooool2o`000003ooooool0003ooooo00?o00000_ooool0
0ol0003oooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool2
o`000008ooooool0003oooooo`000?oooooo0000ooooool00002ooooo`?o00000_ooool2o`0000?o
oooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool0
0ol0003oooooo`000002o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`04o`0000;ooooo0_l000001?oooooo0000o`000?l00002ooooo`03o`000?oooooo000000;o0000
0oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo0_l00007ooooo`03o`00
0?oooooooooo00;o00000oooool2o`0000;ooooo0ol00002ooooo`03o`000?oooooo000000Oooooo
00?o0000ooooooooool01Oooool0037ooooo00?o0000ooooool000000_ooool2o`0000?ooooo1Ol0
00000ooooooo0000ooooo`03ooooo`;o00001?ooool2o`000004ooooool0003o0000ooooo`Go0000
0_ooool01?l0003oooooooooooooool2o`0000;ooooo00Go0000oooooooooooo0000ooooo`05o`00
0009ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o00001?ooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0003o00001oooool00ol0
003oooooooooo`04ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`Oo00000oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000ooooo`02o`00
0006ooooool0003oooooo`000?oooooo00001?ooool2o`000005ooooool0003oooooooooool00000
0_ooool01_l0003oooooooooool0003oooooo`0000Cooooo00Co0000oooooooooooo00001oooool0
037ooooo0ol00004ooooo`05o`000?oooooo0000o`000?ooool00ol000000ooooooo0000o`000002
ooooo`03o`000?oooooo000000;o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`02
ooooo`Co00002?ooool2o`0000Cooooo1Ol00005ooooo`;o00000_ooool01?l0003oooooo`000?oo
ool4o`000004ooooool0003oooooooooo`;o000000?oooooo`000?ooool00_l00005ooooo`06o`00
0?oooooo0000o`000?oooooo00000_ooool2o`0000Gooooo00Go0000ooooooooooooooooo`000002
ooooo`06o`000?ooooooooooooooool0003ooooo1?l000001?oooooo0000ooooool00003ooooo`05
o`000?oooooo0000ooooool000001_ooool01?l0003oooooo`000?ooool3o`0000;ooooo1?l00003
ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000ooooool0003ooooo0_l000000ooooooo0000
o`000002ooooo`03o`000?oooooooooo00Gooooo000aooooo`03o`000?oooooooooo00Go000000Co
ooooo`000?oooooo00000oooool4o`0000Gooooo1Ol00006ooooo`;o00000_ooool00ol0003ooooo
o`000003ooooo`Go00000oooool00ol0003oooooo`000002o`0000?ooooo0_l000001?oooooo0000
ooooooooool2o`000004ooooool0003o0000ooooo`;o00000oooool01?l0003oooooo`000?ooool2
o`000003ooooool0003ooooo00;ooooo0_l00002ooooo`03o`000?oooooo000000Cooooo1Ol00002
ooooo`;o00001Oooool5o`0000?ooooo00Co0000ooooool0003o00000_ooool01?l0003oooooo`00
0?l00002ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
o`000002ooooo`;o000000?oooooo`000?ooool00_l00002ooooo`Co000000?oooooo`000?ooool0
0_ooool2o`000003ooooool0003o000000;ooooo00?o0000ooooooooool01Oooool0037ooooo00?o
0000ooooool000000_l00003ooooo`03o`000?oooooo000000?o00000_ooool00ol0003ooooooooo
o`06ooooo`;o000000?oooooo`000?l000000_ooool3o`000004ooooool0003oooooo`0000;ooooo
0_l000001?oooooo0000ooooool00007ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool0
1_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooool000000ol00004ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool00_l00003ooooo`;o000000Coooooo`000?oooooo
oooo0_l000000ooooooo0000ooooo`08ooooo`;o00001?ooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool01?l0003oooooooooool00003ooooo`07o`000?ooooooooooo`000?oooooo
0000ooooo`02o`000003ooooool0003ooooo00;o000000Koooooo`000?l0003o0000ooooool00002
ooooo`04o`000?oooooo0000ooooo`?o00000_ooool01?l0003oooooooooooooool3o`0000Cooooo
00?o0000ooooooooool01Oooool0037ooooo0_l000000ooooooo0000o`000002ooooo`03o`000?oo
oooo000000?ooooo0_l000001?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00;ooooo
0ol00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00?o0000
00Koooooo`000?l0003o0000ooooool00003ooooo`?o00002?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00?o
0000ooooooooool00_l00002ooooo`?o00000oooool2o`0000;ooooo0_l00002ooooo`;o00000ooo
ool00ol0003oooooooooo`02o`0000;ooooo0_l000000ooooooo0000ooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
0_l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool2o`0000;ooooo
1?l00007ooooo`00<Oooool01?l0003oooooooooool00004ooooo`?o00000_ooool01Ol0003ooooo
o`000?l0003ooooo00?o00000_ooool2o`000008ooooool0003o0000ooooool0003oooooo`000?oo
ool2o`0000;ooooo0_l000000ooooooo0000ooooo`02ooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo0ol00002ooooo`04o`000?oooooo0000o`0000;ooooo00?o0000oooooooo
ool00_l00004ooooo`04o`000?ooooooooooo`0000;ooooo0ol00005ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooooooo1Ol00002ooooo`04o`000?oooooo0000ooooo`?o00001Ooo
ool2o`000003ooooool0003o000000;o000000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`02ooooo`06o`000?ooooooooooo`000?oooooo00001oooool0037ooooo0_l000001Ooooooo0000
o`000?l0003ooooo00;o00001_ooool01?l0003oooooooooool00003ooooo`04o`000?oooooo0000
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`05o`000?ooooooooooo`000?ooool00ol0
00000ooooooo0000ooooo`07ooooo`04o`000?ooooooooooooooo`;o000000Koooooo`000?l0003o
0000ooooool00009ooooo`04o`000?oooooo0000o`0000;ooooo0_l000001?oooooo0000o`000?l0
0002ooooo`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`04o`000004ooooool0
003oooooooooo`Co00000oooool01?l0003oooooo`000?l00003ooooo`;o000000Ooooooo`000?oo
oooo0000ooooool0003ooooo00Co000000Coooooo`000?oooooo00000_ooool01?l0003oooooo`00
0?l00002ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o00001Oooool2o`0000;ooooo
0_l00002ooooo`?o000000Coooooo`000?l0003ooooo0_l00007ooooo`00<Oooool01?l0003ooooo
ooooool00003ooooo`;o000000?oooooo`000?ooool00_l00002ooooo`04o`000?oooooo0000oooo
o`;o00001Oooool2o`0000Gooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool3
o`000003ooooool0003ooooo00?ooooo0ol000001ooooooo0000ooooool0003oooooo`000?ooool0
0_l00002ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Gooooo
0_l00004ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_ooool2o`0000Cooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooo0000o`0000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo0ol000001?oooooo0000oooo
ooooool2o`000003ooooool0003ooooo00?ooooo0_l00002ooooo`;o00000_ooool2o`000004oooo
ool0003o0000ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000Oooooo000aooooo`;o
00001oooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooool000001?oo
ool00ol0003oooooo`000002o`0000;ooooo0_l000001Ooooooo0000oooooooooooo000000Oooooo
00Co0000oooooooooooo00001?ooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`00
00?ooooo00?o0000ooooool000000_ooool2o`000003ooooool0003ooooo00;ooooo0_l000000ooo
oooo0000ooooo`03ooooo`03o`000?oooooo000000;o000000?oooooo`000?l000000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Ko00000_ooool00ol0003oooooo`000002oooo
o`;o00000oooool2o`0000Cooooo00?o0000ooooooooool00ol00002ooooo`;o00000_ooool00ol0
003oooooooooo`03o`0000?ooooo00?o0000ooooool000001oooool0037ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Cooooo1?l00004ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool2o`0000?ooooo0_l000000ooooooo0000ooooo`07oooo
o`05o`000?ooooooooooo`000?ooool01Ol000001_oooooo0000oooooooooooo0000ooooo`?o0000
00?oooooo`000?ooool00_ooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`02ooooo`;o00000oooool2o`0000;ooooo1?l00004ooooo`04
o`000?oooooo0000ooooo`Ko00000oooool2o`0000Kooooo00?o0000ooooooooool00oooool2o`00
00;ooooo00Co0000oooooooooooo00001Oooool2o`0000;ooooo00?o0000ooooool000001?ooool0
1?l0003oooooooooool00003ooooo`;o00001?ooool00ol0003oooooooooo`05ooooo`00<Oooool0
0ol0003oooooo`000002o`0000?ooooo1Ol00003ooooo`Co00001?ooool2o`000003ooooool0003o
000000;ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ooo
ool2o`0000;ooooo00Co0000ooooool0003ooooo0_l000001?oooooo0000ooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
000000;ooooo00?o0000ooooooooool01?ooool01?l0003oooooo`000?l00003ooooo`Go000000?o
ooooo`000?ooool00oooool01_l0003oooooo`000?l0003oooooo`0000;ooooo0_l000000ooooooo
0000o`000005ooooo`;o000000?oooooo`000?l000000_ooool01_l0003oooooo`000?oooooo0000
ooooo`;o000000?oooooo`000?ooool00ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooooooool2o`0000Oooooo
000Cooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01_ooool01_o^k^koEEEE
o`000?l0003oEEEEonk^kPGooooo0_l000000ooooooo0000ooooo`03ooooo`05o`000?oooooo0000
ooooool000001?ooool4o`000003ooooool0003o000000Kooooo00Wo0000ooooool0003o0000oooo
ool0003oooooo`000?ooool00_l00004ooooo`?o00000oooool01Ol0003oooooo`000?oooooo0000
00?ooooo00?o0000ooooooooool00oooool01ol0003ooooooooooooooooo0000ooooool000000_oo
ool00ol0003oooooooooo`03ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool2o`0000Wo
oooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo0_l000001_oooooo0000oooooooooooo0000ooooo`?o000000Goooooo`000?oooooooooo
o`000004ooooo`;o00001_ooool4o`0000;ooooo00?o0000ooooooooool01_ooool4o`0000Cooooo
1Ol000001?oooooo0000ooooool00007ooooo`004_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj
^PGooooo0ol00006ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE1Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oooooooooo00;o000000Go
ooooo`000?l0003o0000ooooo`02o`0000Cooooo0ol00006ooooo`?o000000?oooooo`000?ooool0
0_l000000ooooooo0000ooooo`02o`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000002o`0000Sooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo0ol000001Ooooooo0000o`000?oooooo
000000;ooooo0ol00005ooooo`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?oooooo0000ooooool000000oooool00ol0003oooooooooo`05ooooo`04o`00
0?oooooo0000o`0000Cooooo00Wo0000oooooooooooo0000ooooool0003oooooo`000?ooool00_l0
00000ooooooo0000ooooo`06ooooo`004_ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo
00?oEEEEo`000?mEEED01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo1ol00002ooooo`03o`000?oooooooooo00?o
000000?oooooo`000?ooool00_ooool2o`0000Cooooo00Co0000oooooooooooo00000oooool02Ol0
003oooooooooool0003oooooo`000?oooooo0000ooooo`03o`000004ooooool0003oooooo`0000Go
oooo0_l00002ooooo`;o00000oooool00ol0003oooooo`000009ooooo`;o000000Coooooo`000?oo
oooo00000oooool00ol0003oooooooooo`03o`0000Gooooo00?o0000ooooool000002?ooool00ol0
003oooooooooo`02o`0000Cooooo0_l00003ooooo`?o00000_ooool2o`0000;ooooo00?o0000oooo
ool000001Oooool00ol0003oooooo`000004o`0000Kooooo00?o0000ooooool000000_ooool2o`00
0004ooooool0003o0000ooooo`;o000000?oooooo`000?ooool00_l00007ooooo`004_ooool01_l0
003ok^k^ooooooooooook^k^o`0000kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`;o000000?oooooo`000?l000000_l0000:ooooo`;o00001Oooool4o`000003ooooool0
003ooooo00?o000000Goooooo`000?ooooooooooo`000002ooooo`04o`000?ooooooooooo`0000So
oooo00Go0000oooooooooooo0000ooooo`02o`000003ooooool0003ooooo00Gooooo00Go0000oooo
ool0003oooooo`000002ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000002?l00002
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooool0003oooooo`000006ooooo`03o`000?oooooo000000?ooooo
00Go0000oooooooooooo0000ooooo`03o`000003ooooool0003ooooo00Ko00000_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003oooooooooool0003o
oooo00?o000000Coooooo`000?l0003ooooo0_l00007ooooo`004_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00cooooo00KoEEEEogMgMoooooooooooogMgMomEEED5ooooo`06o`00
0?ooooooooooo`000?oooooo00001?ooool2o`0000;ooooo00?o0000ooooooooool00_l00003oooo
o`Co00001Oooool00ol0003oooooooooo`04o`000003ooooool0003o000000;ooooo00Co0000oooo
oooooooo00000_ooool2o`000003ooooool0003o000000Gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00Ko0000ooooool0003o0000
ooooool00003ooooo`04o`000?oooooo0000o`0000Gooooo0ol000000ooooooo0000ooooo`05oooo
o`;o00000_ooool01ol0003oooooo`000?l0003oooooo`000?ooool00_l00005ooooo`03o`000?oo
oooo000000Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool01?ooool4o`0000Gooooo0_l000000ooooooo0000ooooo`03o`0000Oooooo
000Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ooMgMgo0000o`00
0002o`000003omgMgOoooooooooo00?ooooo00?o0000ooooooooool01?ooool01_l0003ooooooooo
ool0003oooooo`0000Cooooo00?o0000ooooooooool00oooool2o`000003ooooool0003ooooo00?o
oooo0_l000000ooooooo0000o`000006ooooo`?o000000Coooooo`000?l0003o00000_ooool01?l0
003oooooo`000?l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`04o`00
0?oooooo0000o`0000Gooooo0_l000000ooooooo0000o`000005ooooo`05o`000?oooooo0000oooo
ool000001oooool00ol0003oooooooooo`09ooooo`;o000000Coooooo`000?oooooooooo0_l00000
1?oooooo0000ooooool00005ooooo`03o`000?oooooooooo00?ooooo00Ko0000oooooooooooo0000
ooooool00004ooooo`03o`000?oooooooooo00?ooooo1?l000001?oooooo0000o`000?ooool2o`00
00?ooooo00?o0000ooooool000001?ooool4o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo
00Gooooo000Booooo`06o`000?o^k^koooooooooooo^k^ko00003_ooool01_lb<S;oIVIVonk^k_o^
k^koIVIVoc8b<PGooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`04o`0000?ooooo
00?o0000ooooool000000_l000000ooooooo0000o`000005ooooo`;o00000oooool2o`0000Cooooo
00Co0000oooooooooooooooo0_l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00ol00002ooooo`?o000000?oooooo`000?l000000_ooool4o`000003
ooooool0003o000000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00Go00000oooool01_l0
003oooooo`000?oooooo0000ooooo`?o00001Oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000oooooooooooo0000ooooo`02o`000006ooooool0003o0000o`000?oooooo00000_ooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooooooooooo
o`000005ooooo`Oo00000oooool00ol0003oooooooooo`05ooooo`004_ooool01_m4A4CoV9RHoooo
ooooooooV9RHodA4A0kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000Kooooo0_l000001?oooooo0000ooooool00002ooooo`Go000000Gooooo
o`000?ooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Wo0000oooooooooooooooo
o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l000000ooo
oooo0000ooooo`05ooooo`04o`000?oooooo0000ooooo`;o00000_ooool01?l0003oooooo`000?oo
ool3o`0000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000006ooooo`;o00000_oo
ool2o`000005ooooool0003o0000ooooool000000oooool3o`000005ooooool0003oooooooooool0
00001?ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00000oooool2o`0000Gooooo00?o0000ooooool000002oooool4o`000003ooooool0003o000000?o
oooo00Co0000oooooooooooo00001oooool001;ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X>
ooooo`06oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b1Oooool2o`000003ooooool0003o000000Sooooo
00Co0000ooooool0003ooooo0_l000000ooooooo0000ooooo`02ooooo`;o00000oooool02Ol0003o
oooooooooooooooo0000ooooool0003oooooo`000006ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool01Ol0003oooooooooool0003ooooo00;o000000?oooooo`000?ooool0
1?ooool00ol0003oooooo`000003ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000;o
oooo00Go0000ooooool0003oooooo`000003ooooo`?o00000_ooool01_l0003ooooooooooooooooo
0000ooooo`Co00000oooool00ol0003oooooooooo`02o`0000Cooooo00?o0000ooooooooool00_l0
00000ooooooo0000ooooo`02ooooo`?o00000_ooool01?l0003oooooo`000?ooool3o`0000Oooooo
000Cooooo`04oiRHV?l0003o0000oiRHV0oooooo00Kok^k^odA4A?l0003o0000odA4A?o^k^h5oooo
o`03o`000?oooooooooo00Co00001Oooool2o`0000?ooooo00?o0000ooooooooool00_l00002oooo
o`03o`000?oooooo000000;ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003ooooo
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo0000o`0000Gooooo0_l0
0009ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003oooooo`000?l0003ooooo00;o
000000Goooooo`000?l0003oooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00001?oo
ool00ol0003oooooooooo`05ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`05o`000?oo
oooo0000ooooool000001Oooool01_l0003oooooo`000?oooooo0000ooooo`Go000000?oooooo`00
0?ooool01?l00006ooooo`?o000000Coooooo`000?oooooooooo0ol000000ooooooo0000ooooo`04
ooooo`03o`000?oooooo000000Oooooo000aooooo`?o000000?oooooo`000?ooool01Oooool2o`00
0004ooooool0003oooooo`0000?ooooo00Go0000ooooool0003oooooo`000005ooooo`04o`000?oo
ooooooooooooo`?o000000?oooooo`000?l000001?l00002ooooo`03o`000?oooooooooo00?o0000
1_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo0ol00003ooooo`05
o`000?oooooo0000o`000?ooool00_l000001Ooooooo0000ooooool0003ooooo00Co00001oooool3
o`000006ooooool0003oooooo`000?oooooo00000oooool01Ol0003oooooo`000?oooooo000000?o
oooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000ooooool0
003o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool2o`000005ooooool0003ooooo
ooooool000001_ooool5o`0000?ooooo00?o0000ooooool000001oooool0037ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool01?l0003oooooooooooooool3
o`000004ooooool0003o0000ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo0_l000001?oooooo0000o`000?ooool2o`0000Wooooo00Co0000oooooooooooo
oooo0ol00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool2o`0000Kooooo00Ko0000
ooooool0003o0000ooooool00002ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooool000000_ooool7o`000003ooooool0003ooooo00So
oooo00?o0000ooooooooool01_l000000ooooooo0000ooooo`03o`0000?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooo`000002o`0000;ooooo2?l00002ooooo`03o`000?oooooo000000?o
00001oooool0037ooooo0_l00003ooooo`;o00000_ooool3o`000003ooooool0003ooooo00;ooooo
00Co0000ooooool0003o00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000003ooooo`;o000000Coooooo`000?oooooooooo0_l0
0002ooooo`05o`000?oooooo0000ooooool000002Oooool01?l0003oooooo`000?ooool3o`0000;o
oooo00?o0000ooooool000000_l00003ooooo`03o`000?oooooooooo00?ooooo0_l000001Ooooooo
0000o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00Co0000oooo
oooooooooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool2o`0000_ooooo00Co
0000ooooool0003ooooo0_l000001_oooooo0000o`000?l0003oooooo`0000Cooooo00Go0000oooo
ooooooooooooo`000009ooooo`04o`000?oooooo0000ooooo`;o00001oooool0037ooooo0ol00000
0ooooooo0000ooooo`02ooooo`04o`000?oooooo0000ooooo`;o00000_ooool00ol0003oooooo`00
0005ooooo`0:o`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo0_l00002
ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?ooool00_l000001_oooooo0000o`00
0?l0003oooooo`0000Cooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02ooooo`08
o`000?ooooooooooooooool0003oooooo`000?ooool2o`0000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000001Ooo
ool00ol0003oooooooooo`03o`000003ooooool0003o000000Gooooo0_l00005ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooool000000_l00004ooooo`03o`000?oooooooooo00;ooooo0_l0
0002ooooo`03o`000?oooooo000000?ooooo00Co0000ooooool0003ooooo0_l00003ooooo`03o`00
0?oooooooooo00Gooooo000aooooo`;o00001?ooool01_l0003ooooooooooooooooo0000ooooo`;o
000000Goooooo`000?ooooooooooo`000003ooooo`04o`000?oooooo0000o`0000Oooooo0ol00000
0ooooooo0000ooooo`03ooooo`?o00000oooool01?l0003oooooo`000?l00002ooooo`Co00000_oo
ool00ol0003oooooooooo`08ooooo`;o00001_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oo
oooo000000?ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00ol0
0005ooooo`09o`000?oooooo0000o`000?oooooo0000ooooool0003ooooo00;o00000_ooool01ol0
003oooooo`000?l0003oooooo`000?ooool00_l000001?oooooo0000o`000?ooool2o`0000Oooooo
00?o0000ooooool000001Oooool00ol0003oooooo`000002ooooo`;o000000?oooooo`000?ooool0
0oooool00ol0003oooooooooo`03o`000003ooooool0003o000000Oooooo000aooooo`03o`000?oo
oooo000000Cooooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo00Go0000oooooooooooo
0000ooooo`02o`0000Gooooo00Co0000ooooool0003o00001oooool01Ol0003oooooooooool0003o
oooo00;o00001?ooool3o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool02Ol0003oooooooooool0003oooooo`000?oooooo0000ooooo`04o`000004
ooooool0003oooooo`0000;ooooo1Ol00002ooooo`?o000000Coooooo`000?oooooooooo0ol00000
0ooooooo0000ooooo`02ooooo`04o`000?ooooooooooooooo`Go00000oooool01Ol0003oooooo`00
0?oooooo000000Gooooo1?l000001?oooooo0000ooooool00003ooooo`05o`000?oooooo0000oooo
ool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000ooooool0003o00000_oo
ool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?oooooo00001oooool0037ooooo00Ko
0000ooooooooooooooooo`000?ooool3o`0000?ooooo0_l000001?oooooo0000ooooool00003oooo
o`04o`000?ooooooooooooooo`;o00001?ooool00ol0003oooooo`000002o`0000;ooooo00Co0000
ooooool0003o00001?ooool01?l0003oooooooooooooool2o`0000;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooool0003o0000ooooool00003
ooooo`?o00002?ooool4o`000005ooooool0003o0000ooooool000000_ooool3o`000003ooooool0
003ooooo00Co00000_ooool00ol0003oooooooooo`02o`0000Cooooo0_l00004ooooo`;o00002?oo
ool3o`0000Gooooo00?o0000ooooool000000ol00003ooooo`04o`000?ooooooooooooooo`Oo0000
1Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?o00001oooool0037ooooo1?l0
00000ooooooo0000ooooo`02o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`000002ooooo`Go00001Oooool3o`000004ooooool0003o0000ooooo`?o0000
1?ooool00ol0003oooooooooo`03o`0000?ooooo00?o0000ooooooooool01?ooool2o`0000?ooooo
0ol00004ooooo`04o`000?ooooooooooooooo`?o00000_ooool01?l0003oooooooooool00003oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000oooool01?l0003oooooo`000?oo
ool5o`0000?ooooo0ol000001?oooooo0000o`000?l00003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_l00004ooooo`?o000000?oooooo`000?ooool01?l00006ooooo`04o`00
0?ooooooooooo`0000Sooooo0_l000000ooooooo0000o`000002ooooo`?o00001oooool0037ooooo
0_l000002_oooooo0000oooooooooooo0000ooooool0003oooooo`000?ooool4o`000003ooooool0
003ooooo00?ooooo00Co0000oooooooooooo00003_ooool01?l0003oooooooooool00004ooooo`?o
00001?ooool5o`0000?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02o`000003
ooooool0003ooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oooooo0000
00Cooooo0_l000000ooooooo0000o`000002o`0000Cooooo00Go0000ooooool0003o0000ooooo`02
o`000003ooooool0003o000000Sooooo0_l00003ooooo`Co00001?ooool01?l0003oooooooooool0
0006ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`05ooooo`;o00000ooo
ool2o`0000Kooooo00?o0000ooooool000001oooool0037ooooo00?o0000ooooool000000oooool3
o`0000?ooooo00Go0000ooooool0003o0000ooooo`05o`000003ooooool0003ooooo00Cooooo0ol0
00001?oooooo0000ooooooooool2o`000005ooooool0003oooooo`000?ooool00_l00002ooooo`Go
000000?oooooo`000?ooool00_ooool4o`0000?ooooo00Co0000ooooool0003o00000_ooool00ol0
003oooooooooo`02o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000;ooooo0_l00000
1Ooooooo0000o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l00005ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool3o`000003ooooool0003o000000Oo
oooo0_l000001?oooooo0000ooooooooool2o`0000Cooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo00Gooooo000aooooo`03o`000?oooooooooo00;ooooo0_l00004
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000000oooool00ol0003oooooooooo`03
o`000006ooooool0003oooooo`000?oooooo00000_ooool00ol0003oooooo`00000;ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool2o`000005ooooool0003o0000oooo
ool000001Oooool3o`0000;ooooo0_l00008ooooo`?o000000?oooooo`000?ooool00_ooool2o`00
0004ooooool0003o0000o`0000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
o`0000;ooooo00?o0000ooooool000000_ooool2o`0000Cooooo0_l000000ooooooo0000ooooo`02
ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo00Co0000ooooool0003ooooo
0_l000000ooooooo0000ooooo`05ooooo`03o`000?oooooooooo00Gooooo000aooooo`;o000000Co
ooooo`000?oooooo00001Oooool3o`0000Sooooo00?o0000ooooooooool00_l00003ooooo`03o`00
0?oooooo000000Kooooo0ol000000ooooooo0000ooooo`03ooooo`04o`000?ooooooooooo`0000;o
oooo0_l000001?oooooo0000ooooool00002ooooo`?o000000Coooooo`000?oooooo00000_ooool3
o`0000?ooooo00Co0000oooooooooooooooo0_l000001_oooooo0000oooooooooooo0000ooooo`Go
00002Oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000ooooool0003ooooo1_l00000
0ooooooo0000o`000004o`000003ooooool0003o000000;ooooo00Co0000oooooooooooo00002ooo
ool00ol0003oooooo`000003o`0000?ooooo00?o0000ooooool000000_l00003ooooo`;o00001Ooo
ool2o`0000;ooooo0ol00007ooooo`00<Oooool2o`000005ooooool0003oooooo`000?ooool01_l0
0004ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool2o`0000;ooooo0ol00002ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00006ooooo`07o`000?oooooo0000
ooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool3o`000004oooo
ool0003oooooo`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00000_ooool2o`000003ooooool0003ooooo00Gooooo00Co0000oooooooooooo00000oooool4
o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`?o00000_ooool00ol0003ooooooooo
o`06ooooo`;o00000oooool01?l0003oooooooooool00005ooooo`Go000000Coooooo`000?l0003o
oooo0_l00005ooooo`;o000000Coooooo`000?oooooooooo0_l00007ooooo`00<Oooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`04o`000?oooooo0000ooooo`?o00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00?ooooo00So0000oooooooooooo0000ooooool0003oooooo`0000?ooooo00?o0000oooo
ooooool00ol0000:ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooool0003o0000ooooool0
0004ooooo`;o000000?oooooo`000?ooool00_l00002ooooo`;o00001Oooool2o`000005ooooool0
003oooooooooool000001?ooool00ol0003oooooooooo`02o`0000?ooooo0_l00004ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooool000000oooool01?l0003oooooooooool0000;ooooo`;o
00001Oooool01Ol0003ooooooooooooooooo000000;ooooo0ol00002ooooo`03o`000?oooooooooo
00Gooooo000aooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000Cooooo0_l000000ooo
oooo0000o`000002o`0000Oooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o000000?oooooo`000?ooool01oooool01Ol0003oooooo`000?l0
003ooooo00;o000000Koooooo`000?l0003o0000ooooool00006ooooo`03o`000?oooooooooo00;o
oooo0_l00002ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003ooooo
00;o00001Oooool01?l0003oooooooooool00005ooooo`;o00000_ooool2o`0000;ooooo00So0000
ooooooooooooooooo`000?oooooo0000ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000000Co00000oooool2o`000003ooooool0003ooooo00;o00000_ooool00ol0003o
ooooooooo`04ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool00ol0003oooooooooo`05
ooooo`00<Oooool01?l0003oooooo`000?l00002ooooo`Co00000oooool00ol0003oooooooooo`03
o`0000Cooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02o`000004ooooool0003o
ooooooooo`;o00000_ooool3o`000003ooooool0003o000000Cooooo00Go0000ooooool0003ooooo
o`000002ooooo`07o`000?ooooooooooo`000?oooooo0000ooooo`02o`0000;ooooo00?o0000oooo
ooooool00_l00002ooooo`03o`000?oooooo000000?ooooo00Ko0000oooooooooooo0000ooooool0
0002ooooo`03o`000?oooooo000000Kooooo00Go0000ooooool0003oooooo`000002ooooo`05o`00
0?oooooo0000ooooool000000_ooool2o`0000Cooooo00Co0000ooooool0003ooooo1Ol00005oooo
o`;o00001?ooool00ol0003oooooo`000003ooooo`;o000000?oooooo`000?ooool00_ooool01?l0
003oooooooooool00002ooooo`;o00001oooool01?l0003oooooooooooooool2o`000003ooooool0
003ooooo00;ooooo00?o0000ooooooooool01Oooool0037ooooo0ol00003ooooo`;o00000oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooo000000;o00001?ooool00ol0003oooooooooo`03
o`000003ooooool0003ooooo00?o00001Oooool2o`0000;ooooo1?l000001?oooooo0000ooooool0
0002ooooo`;o00000_ooool00ol0003oooooo`000005o`0000Gooooo00?o0000ooooooooool00_l0
0002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0ol00004ooooo`;o0000
0oooool00ol0003oooooooooo`05o`0000Kooooo00Co0000ooooool0003o00002?ooool01?l0003o
ooooooooool00002ooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`03ooooo`Go000000Koooooo`000?oooooo0000ooooool00002ooooo`03o`000?oo
oooo000000;o00001oooool0037ooooo00So0000ooooool0003oooooo`000?oooooo0000ooooo`;o
00000oooool2o`0000?ooooo0ol00003ooooo`04o`000?ooooooooooooooo`Ko000000Soooooo`00
0?ooooooooooo`000?oooooo0000ooooo`?o000000Koooooo`000?oooooo0000ooooool00002oooo
o`06o`000?oooooo0000o`000?oooooo00000_ooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooo`000003ooooo`03o`000?oo
oooo000000?ooooo0_l00004ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003ooooooooo
o`02o`000003ooooool0003ooooo00Gooooo00?o0000ooooool000000ol000000ooooooo0000o`00
0002o`0000Oooooo1?l000001_oooooo0000o`000?l0003oooooo`0000Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`00
<Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool0
00000ol00003ooooo`08o`000?oooooo0000ooooool0003oooooo`000?ooool5o`000006ooooool0
003oooooooooool0003ooooo1Ol00005ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooo`000003ooooo`;o00000_ooool00ol0
003oooooo`000002ooooo`Go000000?oooooo`000?l000000ol000000ooooooo0000o`000003o`00
0005ooooool0003o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo0ol0
00001?oooooo0000ooooool00003ooooo`;o000000Coooooo`000?l0003o00002?ooool00ol0003o
ooooooooo`04ooooo`06o`000?ooooooooooooooool0003ooooo0_l000000ooooooo0000o`000003
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo000aooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooo`000003ooooo`;o000000Cooooo
o`000?oooooo00000_ooool2o`0000Wooooo1?l000000ooooooo0000ooooo`06ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool00ol0003oooooooooo`05ooooo`07o`000?ooooooooooooooool0
003oooooo`000004ooooo`03o`000?oooooo000000Go00001Oooool01ol0003ooooooooooooooooo
0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`08o`000?oooooo0000ooooool0003o
ooooo`000?ooool3o`000005ooooool0003oooooooooool000000oooool02_l0003oooooo`000?oo
oooo0000ooooool0003oooooo`000?ooool2o`0000Kooooo0_l00003ooooo`;o00001_ooool00ol0
003oooooooooo`02ooooo`;o00000oooool2o`0000;ooooo00?o0000ooooooooool00oooool4o`00
00Oooooo000aooooo`?o00000_ooool00ol0003oooooooooo`04ooooo`Co00000_ooool00ol0003o
ooooo`000004ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`08o`000?oooooo
ooooooooool0003oooooo`000?ooool2o`000004ooooool0003oooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;o00002_oo
ool01?l0003oooooo`000?l00003ooooo`03o`000?oooooooooo00;o00000oooool01_l0003ooooo
oooooooooooo0000ooooo`Ko00001_ooool00ol0003oooooooooo`03o`0000;ooooo00Ko0000oooo
ool0003oooooo`000?ooool4o`0000;ooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000000oooool01Ol0003o
ooooo`000?l0003ooooo00Co00000_ooool01?l0003oooooooooooooool2o`0000Oooooo000aoooo
o`?o00000oooool01?l0003oooooooooool00006ooooo`?o00001Oooool2o`000003ooooool0003o
oooo00Go00001?ooool2o`0000Kooooo00?o0000ooooool000001?ooool01?l0003oooooooooool0
0002ooooo`04o`000?oooooo0000o`0000;ooooo0_l000000ooooooo0000ooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000Gooooo0_l00005oooo
o`Co00000_ooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00Oooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo1?l00000
0ooooooo0000ooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool000000_oo
ool2o`000004ooooool0003o0000o`0000?ooooo0ol00007ooooo`00<Oooool00ol0003oooooo`00
0002ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`;o00000oooool3o`000005ooooool0
003oooooooooool000000oooool01Ol0003oooooo`000?oooooo000000Cooooo00Go0000ooooool0
003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`03o`000?oooooooooo
00;o00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00001_oo
ool01?l0003oooooooooool00002ooooo`;o00000oooool01_l0003oooooo`000?l0003oooooo`00
00;ooooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?oooooo0000ooooo`;o00000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001oooool2o`000003
ooooool0003ooooo00;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03o`000003
ooooool0003ooooo00?ooooo0_l000000ooooooo0000o`000007ooooo`00<Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool02Ol0003oooooo`000?oooooo0000
ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo
0_l000001Ooooooo0000oooooooooooo000000?ooooo0_l00003ooooo`03o`000?oooooooooo00Oo
oooo00Co0000oooooooooooo00000oooool2o`0000?ooooo1?l00003ooooo`03o`000?oooooooooo
00Co00001_ooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00Kooooo0_l00002
ooooo`03o`000?oooooo000000;o00000_ooool00ol0003oooooo`000005o`0000?ooooo00?o0000
ooooool000000_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00Sooooo0_l00000
1?oooooo0000o`000?l00007ooooo`05o`000?oooooo0000o`000?ooool00_l00002ooooo`03o`00
0?oooooo000000?ooooo00?o0000ooooooooool01Oooool0037ooooo0_l00002ooooo`06o`000?oo
ooooooooo`000?oooooo00001_ooool01?l0003oooooo`000?l00003ooooo`04o`000?oooooo0000
o`0000?ooooo0ol000000ooooooo0000o`000007ooooo`;o00000_ooool2o`000003ooooool0003o
000000Cooooo00?o0000ooooooooool02?ooool4o`000003ooooool0003o000000Gooooo00?o0000
ooooooooool00_ooool3o`0000;ooooo00?o0000ooooool000000_ooool3o`0000;ooooo00Co0000
oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo00;o000000Coooooo`000?l0003o0000
0oooool00ol0003oooooooooo`05ooooo`06o`000?oooooo0000o`000?oooooo00000oooool2o`00
00Gooooo00?o0000ooooooooool00oooool01_l0003ooooooooooooooooo0000ooooo`?o000000?o
ooooo`000?ooool00oooool03?l0003oooooooooool0003oooooo`000?oooooo0000ooooool0003o
ooooo`0000;ooooo00?o0000ooooooooool01Oooool0037ooooo0_l00004ooooo`Go00001?ooool2
o`0000?ooooo00Co0000oooooooooooo00000oooool2o`000003ooooool0003o000000;o00000ooo
ool2o`0000;ooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo0_l00003ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`03o`0000;ooooo00?o0000oooooooo
ool00_ooool01Ol0003oooooo`000?l0003ooooo00;o000000Koooooo`000?l0003o0000ooooool0
0002ooooo`03o`000?oooooooooo00Co000000Goooooo`000?l0003oooooo`000006ooooo`?o0000
0oooool3o`000004ooooool0003oooooo`0000Sooooo00?o0000ooooooooool00_ooool01_l0003o
ooooo`000?l0003oooooo`0000;ooooo00?o0000ooooool000000oooool3o`0000?ooooo0_l00000
1?oooooo0000o`000?l00006ooooo`06o`000?ooooooooooo`000?oooooo00001oooool002Gooooo
1?l000000ol@413oooooooooo`05ooooo`;o000000?oooooo`000?l000000oooool01?l0003ooooo
o`000?l00004ooooo`05o`000?ooooooooooo`000?ooool00ol000000ooooooo0000ooooo`02o`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000004ooooo`04o`000?oooooo
ooooo`0000;ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`08ooooo`;o000000So
ooooo`000?oooooo0000ooooool0003oooooo`0000?ooooo00Go0000ooooooooooooooooo`00000<
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00Cooooo0ol0
00001?oooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool000000oooool2o`000003
ooooool0003o000000?ooooo0_l00002ooooo`;o000000Coooooo`000?oooooo00001?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo000Wooooo`03o`000?oooooooooo00Oo
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Gooooo0_l00005oooo
o`?o000000Goooooo`000?l0003oooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooool000000_ooool00ol0003oooooooooo`04o`000003ooooool0003ooooo00;ooooo0ol00004
ooooo`05o`000?ooooooooooooooool000000_ooool2o`000003ooooool0003ooooo00?o000000Co
ooooo`000?oooooo00001Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;o
00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo0000ooooo`;o00001Oooool4
o`0000?ooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
000000;o00000_ooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?ooool00_ooool0
0ol0003oooooo`000002o`000006ooooool0003o0000o`000?oooooo00001oooool002Oooooo00?o
0000ooooooooool01oooool2o`0000?ooooo0_l00002ooooo`;o000000Goooooo`000?oooooo0000
ooooo`03o`0000;ooooo0_l00004ooooo`04o`000?oooooo0000o`0000Gooooo00Go0000ooooool0
003oooooo`000002ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000;ooooo0ol00002
ooooo`;o00001oooool3o`0000?ooooo00Co0000ooooool0003ooooo1?l00003ooooo`Co000000?o
ooooo`000?ooool00_ooool3o`0000Kooooo00?o0000ooooool000000ol000000ooooooo0000oooo
o`02ooooo`Go000000?oooooo`000?ooool00ol000001ooooooo0000oooooooooooo0000ooooool0
00000_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`03o`0000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`000004ooooo`03o`000?oooooo000000;o
00000oooool01?l0003oooooo`000?l00007ooooo`009oooool00ol0003oooooooooo`07oooook?o
00001oooool002Oooooo00?o0000ooooooooool0`Oooool002Oooooo00?o0000ooooooooool0`Ooo
ool002Oooooo00?o0000ooooooooool0`Oooool002Oooooo00?o0000ooooooooool0`Oooool002Go
oooo00?o0000odA4A?l00000`oooool002Gooooo00?oc<c<oeEEEOl00000`oooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-0.279119, -0.240897, \
0.00562948, 0.00562948}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Quantum Standard Map", "Section"],

Cell["\<\
In this section we calculate the quasienergy eigenvalues for the \
quantum standard map.  The code below generates the Floquet matrix (or \
quantum map operator) and then determines the eigenvalues and eigenvectors.  \
We will need the eigenvectors later in order to separate the quasienergies \
for even and odd parity eigenstates.  Note: this calculation takes a long \
time (roughly 1 hour on a PowerMac G4 733 MHz).  You can shorten this time by \
reducing nq (the number of basis states / position grid pooints), but then \
the eigenvalues statistics will not be as good.\
\>", "Text"],

Cell[BoxData[{
    \(nq = 2000; k = 7;\), "\n", 
    \(\(U = 
        Table[N[Exp[I*Pi*\((i - j)\)^2/nq + I*k*nq*Cos[2*Pi*j/nq]/\((2*Pi)\)]/
              Sqrt[nq]], {i, 0, nq - 1}, {j, 0, nq - 1}];\)\), "\n", 
    \(\(Eval = Eigenvalues[U];\)\), "\n", 
    \(\(Evec = Eigenvectors[U];\)\)}], "Input"],

Cell["\<\
To verify that all of the eigenvalues have unit modulus (which they \
should, since the Floquet matrix is unitary) we can plot the eigenvalues in \
the complex plane as shown below.  It is clear that all points lie on the \
unit circle in the complex plane.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[Table[{Re[Eval[\([i]\)]], Im[Eval[\([i]\)]]}, {i, 1, nq}], 
      AspectRatio \[Rule] 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499994 0.476199 0.499999 0.476193 [
[.02379 .4875 -6 -9 ]
[.02379 .4875 6 0 ]
[.26189 .4875 -12 -9 ]
[.26189 .4875 12 0 ]
[.73809 .4875 -9 -9 ]
[.73809 .4875 9 0 ]
[.97619 .4875 -3 -9 ]
[.97619 .4875 3 0 ]
[.48749 .02381 -12 -4.5 ]
[.48749 .02381 0 4.5 ]
[.48749 .2619 -24 -4.5 ]
[.48749 .2619 0 4.5 ]
[.48749 .7381 -18 -4.5 ]
[.48749 .7381 0 4.5 ]
[.48749 .97619 -6 -4.5 ]
[.48749 .97619 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02379 .5 m
.02379 .50625 L
s
[(-1)] .02379 .4875 0 1 Mshowa
.26189 .5 m
.26189 .50625 L
s
[(-0.5)] .26189 .4875 0 1 Mshowa
.73809 .5 m
.73809 .50625 L
s
[(0.5)] .73809 .4875 0 1 Mshowa
.97619 .5 m
.97619 .50625 L
s
[(1)] .97619 .4875 0 1 Mshowa
.125 Mabswid
.07141 .5 m
.07141 .50375 L
s
.11903 .5 m
.11903 .50375 L
s
.16665 .5 m
.16665 .50375 L
s
.21427 .5 m
.21427 .50375 L
s
.30951 .5 m
.30951 .50375 L
s
.35713 .5 m
.35713 .50375 L
s
.40475 .5 m
.40475 .50375 L
s
.45237 .5 m
.45237 .50375 L
s
.54761 .5 m
.54761 .50375 L
s
.59523 .5 m
.59523 .50375 L
s
.64285 .5 m
.64285 .50375 L
s
.69047 .5 m
.69047 .50375 L
s
.78571 .5 m
.78571 .50375 L
s
.83333 .5 m
.83333 .50375 L
s
.88095 .5 m
.88095 .50375 L
s
.92857 .5 m
.92857 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.49999 .02381 m
.50624 .02381 L
s
[(-1)] .48749 .02381 1 0 Mshowa
.49999 .2619 m
.50624 .2619 L
s
[(-0.5)] .48749 .2619 1 0 Mshowa
.49999 .7381 m
.50624 .7381 L
s
[(0.5)] .48749 .7381 1 0 Mshowa
.49999 .97619 m
.50624 .97619 L
s
[(1)] .48749 .97619 1 0 Mshowa
.125 Mabswid
.49999 .07142 m
.50374 .07142 L
s
.49999 .11904 m
.50374 .11904 L
s
.49999 .16666 m
.50374 .16666 L
s
.49999 .21428 m
.50374 .21428 L
s
.49999 .30952 m
.50374 .30952 L
s
.49999 .35714 m
.50374 .35714 L
s
.49999 .40476 m
.50374 .40476 L
s
.49999 .45238 m
.50374 .45238 L
s
.49999 .54762 m
.50374 .54762 L
s
.49999 .59524 m
.50374 .59524 L
s
.49999 .64286 m
.50374 .64286 L
s
.49999 .69048 m
.50374 .69048 L
s
.49999 .78571 m
.50374 .78571 L
s
.49999 .83333 m
.50374 .83333 L
s
.49999 .88095 m
.50374 .88095 L
s
.49999 .92857 m
.50374 .92857 L
s
.25 Mabswid
.49999 0 m
.49999 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.46455 .97487 Mdot
.37256 .95882 Mdot
.67615 .94241 Mdot
.02735 .44194 Mdot
.53957 .97454 Mdot
.61307 .03743 Mdot
.95029 .34508 Mdot
.08731 .73761 Mdot
.33698 .94742 Mdot
.91237 .26186 Mdot
.12937 .799 Mdot
.07751 .71972 Mdot
.92704 .2893 Mdot
.75593 .09843 Mdot
.96374 .39182 Mdot
.0376 .61382 Mdot
.11857 .7851 Mdot
.83425 .83916 Mdot
.92649 .28818 Mdot
.89261 .76947 Mdot
.71017 .9273 Mdot
.04213 .63086 Mdot
.23665 .10325 Mdot
.95724 .36698 Mdot
.62975 .04182 Mdot
.95387 .64409 Mdot
.47972 .02424 Mdot
.66002 .0515 Mdot
.81685 .14452 Mdot
.9616 .61697 Mdot
.96165 .38323 Mdot
.28499 .07511 Mdot
.40613 .96685 Mdot
.05636 .67307 Mdot
.19315 .86415 Mdot
.81823 .14575 Mdot
.83564 .16221 Mdot
.03318 .40592 Mdot
.09342 .25208 Mdot
.59483 .96665 Mdot
.65693 .05041 Mdot
.11116 .77491 Mdot
.94895 .65876 Mdot
.25008 .09465 Mdot
.35347 .95309 Mdot
.91824 .27232 Mdot
.24077 .89946 Mdot
.40288 .03381 Mdot
.97582 .51885 Mdot
.06178 .68636 Mdot
.18547 .85754 Mdot
.16771 .1589 Mdot
.02438 .47632 Mdot
.0269 .55433 Mdot
.41768 .03097 Mdot
.97477 .53673 Mdot
.97481 .46369 Mdot
.02464 .47163 Mdot
.04179 .37033 Mdot
.11994 .78691 Mdot
.25471 .09184 Mdot
.25839 .91035 Mdot
.58227 .03097 Mdot
.65207 .04874 Mdot
.83788 .83555 Mdot
.95107 .65263 Mdot
.0629 .68897 Mdot
.79761 .12826 Mdot
.86178 .80964 Mdot
.0563 .32707 Mdot
.07953 .27644 Mdot
.33087 .05485 Mdot
.34044 .94867 Mdot
.46125 .02538 Mdot
.50475 .02383 Mdot
.87758 .79015 Mdot
.07282 .28955 Mdot
.13275 .80314 Mdot
.88354 .78223 Mdot
.92544 .71391 Mdot
.29745 .93097 Mdot
.13208 .19767 Mdot
.1466 .81917 Mdot
.29639 .06952 Mdot
.02381 .49591 Mdot
.02979 .42467 Mdot
.15785 .83121 Mdot
.40491 .03339 Mdot
.67441 .0569 Mdot
.70858 .07192 Mdot
.97194 .43654 Mdot
.03064 .58045 Mdot
.39303 .96402 Mdot
.84428 .17101 Mdot
.85595 .18368 Mdot
.07728 .28073 Mdot
.2216 .88634 Mdot
.24106 .10035 Mdot
.48732 .02397 Mdot
.48748 .97603 Mdot
.80968 .86174 Mdot
.96565 .40036 Mdot
.97611 .5087 Mdot
.02486 .46812 Mdot
.38209 .03863 Mdot
.39186 .96375 Mdot
.65988 .05145 Mdot
.71433 .07477 Mdot
.8851 .21989 Mdot
.907 .25279 Mdot
.22927 .89175 Mdot
.44132 .97256 Mdot
.66352 .94723 Mdot
.97535 .47173 Mdot
.04978 .34486 Mdot
.16048 .16609 Mdot
.72068 .07803 Mdot
.89771 .76189 Mdot
.96115 .38124 Mdot
.30984 .06342 Mdot
.33728 .94753 Mdot
.68855 .93727 Mdot
.90193 .75536 Mdot
.07143 .29241 Mdot
.25693 .90949 Mdot
.38823 .03711 Mdot
.43231 .02864 Mdot
.45735 .97428 Mdot
.88996 .77329 Mdot
.89751 .76219 Mdot
.94753 .6627 Mdot
.95328 .35406 Mdot
.2852 .925 Mdot
.76592 .10498 Mdot
.90524 .75007 Mdot
.90918 .25643 Mdot
.95878 .62759 Mdot
.97587 .48251 Mdot
.07921 .27705 Mdot
.18644 .85839 Mdot
.97534 .52855 Mdot
.02577 .45663 Mdot
.38896 .03693 Mdot
.41219 .03197 Mdot
.44041 .02755 Mdot
.62498 .0405 Mdot
.93396 .69605 Mdot
.95231 .64892 Mdot
.97054 .57314 Mdot
.97156 .56629 Mdot
.20255 .12813 Mdot
.68597 .06162 Mdot
.75928 .89942 Mdot
.77491 .11118 Mdot
.89506 .76587 Mdot
.1555 .82876 Mdot
.22497 .11126 Mdot
.49539 .97617 Mdot
.85152 .17877 Mdot
.93834 .31395 Mdot
.10635 .23203 Mdot
.72885 .0824 Mdot
.84544 .82777 Mdot
.04949 .34568 Mdot
.0953 .75098 Mdot
.42627 .97045 Mdot
.48078 .02419 Mdot
.79743 .12812 Mdot
.92937 .2941 Mdot
.94546 .3317 Mdot
.96812 .41268 Mdot
.03168 .58628 Mdot
.23258 .89402 Mdot
.97289 .44399 Mdot
.03799 .61542 Mdot
.32585 .05679 Mdot
.77904 .11413 Mdot
.03301 .59323 Mdot
.07124 .29279 Mdot
.09742 .24564 Mdot
.14259 .18531 Mdot
.22074 .11428 Mdot
.55015 .02645 Mdot
.81518 .85696 Mdot
.02786 .43789 Mdot
.52774 .97538 Mdot
.02384 .5068 Mdot
.02637 .54949 Mdot
.3029 .93349 Mdot
.63095 .95783 Mdot
.9686 .58472 Mdot
.02874 .43158 Mdot
.07773 .72013 Mdot
.31939 .94062 Mdot
.60184 .96517 Mdot
.61252 .96271 Mdot
.73332 .08489 Mdot
.80053 .86938 Mdot
.02927 .42798 Mdot
.20797 .12386 Mdot
.2976 .93104 Mdot
.74779 .90664 Mdot
.87321 .20424 Mdot
.9735 .55059 Mdot
.13319 .19633 Mdot
.2431 .09904 Mdot
.30766 .93562 Mdot
.46456 .02513 Mdot
.09776 .2451 Mdot
.16521 .16135 Mdot
.17395 .84707 Mdot
.9386 .68544 Mdot
.97608 .48968 Mdot
.08445 .73257 Mdot
.09771 .75481 Mdot
.39339 .03589 Mdot
.75135 .90445 Mdot
.79555 .87337 Mdot
.05472 .33119 Mdot
.36697 .04276 Mdot
.51355 .976 Mdot
.54349 .9742 Mdot
.66672 .05394 Mdot
.72061 .07799 Mdot
.791 .87693 Mdot
.02471 .52954 Mdot
.03554 .39488 Mdot
.04551 .35785 Mdot
.12555 .2058 Mdot
.58607 .03165 Mdot
.97596 .515 Mdot
.04478 .36019 Mdot
.51885 .02418 Mdot
.9112 .74015 Mdot
.03454 .39941 Mdot
.06273 .31141 Mdot
.06527 .69437 Mdot
.07079 .70628 Mdot
.1801 .14725 Mdot
.18606 .14194 Mdot
.82861 .15536 Mdot
.90416 .75182 Mdot
.49875 .97619 Mdot
.73242 .91562 Mdot
.97059 .57286 Mdot
.55682 .97279 Mdot
.73117 .91632 Mdot
.86888 .19886 Mdot
.88161 .21516 Mdot
.22873 .10862 Mdot
.47526 .02445 Mdot
.93795 .31303 Mdot
.42002 .96943 Mdot
.03663 .3902 Mdot
.04239 .36823 Mdot
.66697 .94596 Mdot
.68024 .05924 Mdot
.81936 .85323 Mdot
.97428 .54267 Mdot
.32394 .05754 Mdot
.74 .91129 Mdot
.97498 .46603 Mdot
.51534 .02405 Mdot
.52444 .02443 Mdot
.84821 .17517 Mdot
.94742 .33699 Mdot
.263 .91303 Mdot
.26395 .08642 Mdot
.28724 .92602 Mdot
.71434 .92522 Mdot
.06149 .68568 Mdot
.31633 .06065 Mdot
.45523 .02591 Mdot
.55977 .02757 Mdot
.58988 .03237 Mdot
.73051 .08332 Mdot
.78551 .88111 Mdot
.80927 .86209 Mdot
.96327 .61019 Mdot
.1059 .23269 Mdot
.12614 .79496 Mdot
.29857 .0685 Mdot
.81597 .14374 Mdot
.32822 .05587 Mdot
.4371 .02798 Mdot
.66796 .94559 Mdot
.71596 .07559 Mdot
.93785 .68721 Mdot
.05226 .66216 Mdot
.06014 .68246 Mdot
.97138 .43247 Mdot
.13617 .19276 Mdot
.63183 .95758 Mdot
.67632 .05765 Mdot
.76376 .10353 Mdot
.17436 .15254 Mdot
.19991 .13025 Mdot
.92929 .29391 Mdot
.19861 .86869 Mdot
.25003 .90531 Mdot
.48165 .97584 Mdot
.75879 .10027 Mdot
.77432 .88924 Mdot
.03523 .60371 Mdot
.49803 .02381 Mdot
.5379 .02532 Mdot
.8624 .19109 Mdot
.02409 .5169 Mdot
.02617 .54751 Mdot
.20487 .87372 Mdot
.55286 .97325 Mdot
.61057 .03682 Mdot
.89209 .22977 Mdot
.26957 .08326 Mdot
.56736 .0286 Mdot
.70114 .93162 Mdot
.96949 .57959 Mdot
.9733 .55242 Mdot
.08615 .73558 Mdot
.1312 .80125 Mdot
.1788 .14844 Mdot
.84133 .83204 Mdot
.03463 .60099 Mdot
.5246 .97556 Mdot
.79761 .87174 Mdot
.97435 .45819 Mdot
.65926 .94877 Mdot
.90079 .24285 Mdot
.9097 .74271 Mdot
.02798 .56301 Mdot
.09981 .7581 Mdot
.10422 .23518 Mdot
.19313 .13586 Mdot
.34875 .04846 Mdot
.36004 .04484 Mdot
.38563 .03774 Mdot
.42045 .0305 Mdot
.34821 .04864 Mdot
.59278 .96707 Mdot
.88261 .21651 Mdot
.03987 .37732 Mdot
.0827 .27059 Mdot
.10397 .76444 Mdot
.37292 .95892 Mdot
.57826 .96972 Mdot
.87565 .20735 Mdot
.26502 .08581 Mdot
.73481 .91427 Mdot
.04916 .65333 Mdot
.28249 .92362 Mdot
.80849 .13724 Mdot
.29523 .92992 Mdot
.05766 .32363 Mdot
.22077 .11426 Mdot
.24948 .90497 Mdot
.383 .0384 Mdot
.85618 .18394 Mdot
.02418 .51914 Mdot
.28737 .92609 Mdot
.96475 .39623 Mdot
.29329 .071 Mdot
.36692 .95722 Mdot
.37372 .04085 Mdot
.59697 .03378 Mdot
.69878 .06728 Mdot
.772 .89086 Mdot
.91907 .72614 Mdot
.95881 .3725 Mdot
.76027 .89877 Mdot
.13717 .80841 Mdot
.27301 .91862 Mdot
.86706 .80336 Mdot
.5207 .97574 Mdot
.92266 .71935 Mdot
.02479 .53081 Mdot
.03066 .41944 Mdot
.68249 .93984 Mdot
.19068 .86206 Mdot
.46953 .97522 Mdot
.56531 .02831 Mdot
.82368 .84926 Mdot
.04241 .36817 Mdot
.63326 .04283 Mdot
.76127 .89811 Mdot
.86832 .80183 Mdot
.02447 .5253 Mdot
.32925 .94453 Mdot
.87 .79977 Mdot
.02859 .56742 Mdot
.14702 .18036 Mdot
.56841 .97125 Mdot
.60882 .03641 Mdot
.04396 .63709 Mdot
.97619 .50138 Mdot
.15792 .16872 Mdot
.50367 .97618 Mdot
.11186 .77589 Mdot
.5343 .97495 Mdot
.76735 .10594 Mdot
.92223 .27982 Mdot
.14259 .81468 Mdot
.09375 .74845 Mdot
.10896 .22824 Mdot
.18787 .14036 Mdot
.2134 .8803 Mdot
.03627 .60828 Mdot
.04203 .63053 Mdot
.14527 .8177 Mdot
.65368 .95071 Mdot
.97177 .56474 Mdot
.86095 .18939 Mdot
.26491 .08587 Mdot
.44338 .97281 Mdot
.618 .96134 Mdot
.92318 .71835 Mdot
.96832 .58622 Mdot
.84741 .82568 Mdot
.05758 .67616 Mdot
.93684 .68955 Mdot
.97398 .45412 Mdot
.02558 .45883 Mdot
.17393 .84705 Mdot
.65083 .04832 Mdot
.8385 .83492 Mdot
.95589 .63756 Mdot
.96849 .41469 Mdot
.94198 .32275 Mdot
.96983 .4224 Mdot
.06873 .29807 Mdot
.36706 .04274 Mdot
.94352 .67334 Mdot
.58099 .96925 Mdot
.78964 .12202 Mdot
.84879 .8242 Mdot
.97429 .54248 Mdot
.94463 .32952 Mdot
.95202 .35022 Mdot
.02511 .53539 Mdot
.08475 .2669 Mdot
.2211 .88597 Mdot
.50542 .97616 Mdot
.43063 .02888 Mdot
.02381 .49623 Mdot
.13106 .19891 Mdot
.40935 .96749 Mdot
.53167 .02486 Mdot
.93589 .69172 Mdot
.97597 .48546 Mdot
.24238 .9005 Mdot
.27367 .08102 Mdot
.57656 .97 Mdot
.68847 .06269 Mdot
.02978 .57529 Mdot
.09364 .25172 Mdot
.26767 .91567 Mdot
.42218 .96979 Mdot
.62689 .95897 Mdot
.94714 .3362 Mdot
.03436 .59977 Mdot
.96182 .61611 Mdot
.04021 .37603 Mdot
.11875 .21466 Mdot
.64843 .95247 Mdot
.14235 .18559 Mdot
.81315 .14126 Mdot
.16651 .83993 Mdot
.97262 .4418 Mdot
.97583 .48146 Mdot
.96147 .3825 Mdot
.0271 .444 Mdot
.56243 .97208 Mdot
.45191 .97376 Mdot
.7365 .91331 Mdot
.33006 .94484 Mdot
.03127 .41594 Mdot
.12357 .79166 Mdot
.04393 .63701 Mdot
.85475 .81767 Mdot
.3451 .0497 Mdot
.52556 .02449 Mdot
.60822 .96373 Mdot
.38606 .96236 Mdot
.69275 .93544 Mdot
.57903 .03041 Mdot
.03761 .38613 Mdot
.84193 .16858 Mdot
.16823 .84161 Mdot
.96724 .40808 Mdot
.94466 .67041 Mdot
.07071 .7061 Mdot
.17853 .85131 Mdot
.92994 .70471 Mdot
.90141 .24382 Mdot
.047 .64685 Mdot
.4279 .9707 Mdot
.92433 .71611 Mdot
.7562 .0986 Mdot
.94141 .32136 Mdot
.88736 .22303 Mdot
.78735 .12028 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
07Gooooo00?o0000ooooooooool0Loooool007Gooooo00?o0000ooooooooool0Loooool007Gooooo
00?o0000ooooooooool0Loooool006gooooo0ol00005ooooo`03o`000?oooooooooo07?ooooo001^
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Loooool006Kooooo1Ol00003oooo
o`03o`000?oooooooooo00Cooooo0_l0001dooooo`00J_ooool3o`000003ooooool0003o000000;o
00000_ooool2o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`03o`000?oooooooooo06So
oooo001Qooooo`;o000000Coooooo`000?l0003o00001oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooool000000_ooool2o`0006;ooooo001Kooooo`06o`00
0?ooooooooooo`000?oooooo00003?ooool2o`0000Kooooo00?o0000ooooooooool04Oooool00ol0
003oooooo`00001Oooooo`00FOooool2o`0001?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Fooooo`;o0000Foooool005Gooooo00?o0000ooooool000007Oooool00ol0003ooooo
ooooo`0Jooooo`;o0000Eoooool0057ooooo00Co0000oooooooooooo00008?ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo053ooooo001@ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool08Oooool2o`00053ooooo001<ooooo`;o00009oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooo000004gooooo0019ooooo`03o`000?oooooo000002Wooooo00?o0000oooo
ooooool09_ooool00ol0003oooooo`00001:ooooo`00B?ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0B?ooool004Gooooo00?o0000ooooooooool0
;Oooool2o`0002cooooo00?o0000ooooooooool0AOooool004Cooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04?ooooo0012ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0;_ooool3o`0004;ooooo000oooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0nooooo`00?Oooool00ol0003o
ooooo`00000eooooo`03o`000?oooooooooo03;ooooo0_l0000oooooo`00MOooool00ol0003ooooo
ooooo`1cooooo`00>_ooool2o`0003Wooooo00?o0000ooooooooool0Loooool003Sooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Sooooo000goooo
o`;o0000??ooool00ol0003oooooooooo`0iooooo`;o0000>?ooool003Gooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0jooooo`;o0000=oooool003Cooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03?ooooo000cooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0booooo`00MOooool2
o`00043ooooo00?o0000ooooooooool0<Oooool0033ooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo033ooooo000_ooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0^ooooo`00;_ooool00ol0003ooooo
ooooo`14ooooo`03o`000?oooooooooo07?ooooo000]ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`0/ooooo`00:oooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0:oooool002[ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`16ooooo`;o0000:oooool002Wooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`1cooooo`00:?ooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool09oooool002Oooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`1cooooo`009_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool09Oooool002Gooooo00?o0000ooooooooool0COooool2o`00
04gooooo00?o0000ooooooooool09?ooool002Cooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo02?ooooo001eooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool0Coooool2o`0002;ooooo001eooooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool07oooool001oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Aooooo`03
o`000?oooooooooo01oooooo000Nooooo`;o0000EOooool00ol0003oooooooooo`1cooooo`007_oo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool07Ooo
ool001gooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo01cooooo001eooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool07?ooool001_o
oooo00?o0000ooooooooool0Eoooool2o`0005Kooooo00?o0000ooooooooool06oooool007Gooooo
00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Jooooo`00MOooool00ol0003ooooooooo
o`1Gooooo`03o`000?oooooooooo01Wooooo000Iooooo`03o`000?oooooooooo05Wooooo00?o0000
ooooooooool0Loooool001Sooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo01Sooooo000Hooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool0Loooool007Gooooo00?o0000ooooooooool0Loooool001Kooooo00?o0000ooooooooool0G?oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01Kooooo001Rooooo`;o00001?ooool0
0ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1cooooo`005Oooool00ol0
003oooooooooo`19ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool05Oooool005[ooooo1Ol00002
ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Looooo`03o`000?oooooooooo01Cooooo001Qooooo`04o`000?ooooooooooo`0000_ooooo00?o
0000ooooooooool00_ooool2o`0005kooooo00?o0000ooooooooool04oooool001?ooooo00?o0000
ooooooooool0Boooool01?l0003oooooooooool00007ooooo`Co00001Oooool00ol0003ooooooooo
o`1cooooo`004oooool00ol0003oooooooooo`1;ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1cooooo`00H_ooool2o`0000Sooooo1Ol00004
ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool04_ooool001;ooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo017ooooo000Booooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0Loooool007Gooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`0@ooooo`004?ooool2o`0006?ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`0@ooooo`00MOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo00oooooo000@ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Loooool007Go
oooo00?o0000ooooooooool0Loooool007Gooooo0_l0001dooooo`003_ooool00ol0003ooooooooo
o`1Tooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool03Oooool007Gooooo00?o0000
ooooooooool0Loooool007Gooooo00?o0000ooooooooool0Hoooool2o`0000kooooo000=ooooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool0Loooool000cooooo00?o0000ooooooooool0
I_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00cooooo001eooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool03?ooool007Gooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`0;ooooo`00MOooool00ol0003oooooooooo`1cooooo`002oooool00ol0003o
ooooooooo`1Wooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool02_ooool007Gooooo
00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0:ooooo`00MOooool2o`0006Oooooo00?o
0000ooooooooool02_ooool000[ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1c
ooooo`00MOooool00ol0003oooooooooo`1cooooo`002Oooool00ol0003oooooooooo`1Yooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool02Oooool000Wooooo00?o0000ooooooooool0
JOooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo06Wooooo00?o0000ooooooooool0Loooool007Gooooo00?o0000ooooooooool0J?ooool0
0ol0003oooooooooo`08ooooo`002?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo
06Sooooo00?o0000ooooooooool02?ooool000Sooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`1cooooo`002?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06Wooooo
00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool0J_ooool00ol0003ooooooooo
o`1Yooooo`03o`000?oooooooooo00Oooooo001eooooo`;o0000J_ooool00ol0003oooooooooo`07
ooooo`001oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06Wooooo00?o0000oooo
ooooool01oooool007Gooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`06ooooo`00
1oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
1_ooool000Oooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1cooooo`001oooool0
0ol0003oooooooooo`1[ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01_ooool0
00Kooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1cooooo`001_ooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01_ooool000Kooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Gooooo
0006ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`05ooooo`001_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06_ooooo00?o0000
ooooooooool01Oooool007Gooooo0_l0001dooooo`001oooool3o`0002oooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol0000^ooooo`03o`000?oooooooooo02gooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol0000_ooooo`?o00001_ooool000Kooooo00?o0000ooooool00000
;oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0
003oooooooooo`0/ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
000_ooooo`03o`000?oooooooooo00Gooooo0005o`0000?ooooo00?o0000ooooooooool09_ooool5
o`0000;ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo02cooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00Gooooo0005ooooo`04o`000?ooooooooooo`0002oooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02cooooo00Co0000oooooooo
oooo00002oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Gooooo0005ooooo`04
o`000?ooooooooooo`0002oooooo00Co0000oooooooooooo00001oooool4o`0002kooooo00?o0000
ooooooooool0;?ooool01?l0003oooooooooool00007ooooo`Co0000<?ooool00ol0003ooooooooo
o`05ooooo`001Oooool01?l0003oooooo`000?l0000_ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0/ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool0<?ooool2o`0000Oooooo0008ooooo`03o`000?oooooooooo02kooooo
0_l00008ooooo`Go0000;Oooool00ol0003oooooooooo`0]ooooo`;o00002?ooool5o`0002oooooo
00?o0000ooooooooool01Oooool007Gooooo00?o0000ooooooooool0Joooool2o`0000Kooooo001e
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool01?ooool007Gooooo00?o0000oooo
ooooool0Loooool00>_o00000006ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`04ooooo`001Oooool2o`0003Kooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01?oo
ool007Gooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`04ooooo`00MOooool00ol0
003oooooooooo`1/ooooo`03o`000?oooooooooo00Cooooo0005ooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`05ooooo`00MOooool00ol0003ooooo
ooooo`1cooooo`001Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo07?ooooo0005
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`05
ooooo`001Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06_ooooo00?o0000oooo
ooooool01Oooool007Gooooo00?o0000ooooooooool0Loooool007Gooooo00?o0000ooooooooool0
Joooool00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`1/ooooo`;o0000M?oo
ool007Gooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`05ooooo`001_ooool00ol0
003oooooooooo`1/ooooo`03o`000?oooooooooo07?ooooo001eooooo`03o`000?oooooooooo07?o
oooo0006ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0J_ooool2o`0000Oooooo
0006ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0Loooool000Oooooo00?o0000
ooooooooool0Joooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Kooooo001eoooo
o`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01_ooool000Oooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`1cooooo`001oooool00ol0003oooooooooo`1[ooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool01_ooool007Gooooo00?o0000ooooooooool0Looo
ool000Oooooo00?o0000ooooooooool0Joooool2o`0007Cooooo0008ooooo`03o`000?oooooooooo
06[ooooo00?o0000ooooooooool0Loooool000Sooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`1cooooo`002?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo07?ooooo
0008ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0JOooool00ol0003ooooooooo
o`07ooooo`002?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06Sooooo00?o0000
ooooooooool02?ooool007Gooooo00?o0000ooooooooool0Loooool007Gooooo00?o0000oooooooo
ool0Loooool000Wooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`1Wooooo`03o`00
0?oooooooooo00Wooooo001eooooo`03o`000?oooooooooo07?ooooo000:ooooo`03o`000?oooooo
oooo06Sooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`09ooooo`00MOooool2o`00
07Cooooo000;ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0I_ooool00ol0003o
ooooooooo`0:ooooo`00MOooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00[ooooo
000;ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0I_ooool00ol0003ooooooooo
o`0:ooooo`00MOooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00_ooooo000<oooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0;oooo
o`00MOooool00ol0003oooooooooo`1cooooo`003Oooool00ol0003oooooooooo`1Uooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`1cooooo`003_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo07?ooooo000>ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0Hoooool00ol0
003oooooooooo`0=ooooo`003_ooool00ol0003oooooooooo`1Tooooo`;o0000Hoooool2o`0000oo
oooo000?ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`0>ooooo`00MOooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00kooooo001e
ooooo`03o`000?oooooooooo07?ooooo000@ooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool0HOooool00ol0003oooooooooo`0?ooooo`00MOooool00ol0003oooooooooo`1cooooo`00
MOooool00ol0003oooooooooo`1Oooooo`;o00004_ooool001;ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo017ooooo001eooooo`03o`000?oooooo
oooo07?ooooo001Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0
003oooooooooo`1Nooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`000?oooooooooo04_o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool0Loooool001Cooooo00?o0000ooooooooool0B_ooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00;ooooo0_l0001dooooo`00HOooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0D
ooooo`00HOooool01?l0003oooooooooool00007ooooo`Co00001Oooool00ol0003oooooooooo`1L
ooooo`03o`000?oooooooooo01Cooooo000Eooooo`;o0000B_ooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0E
ooooo`005_ooool00ol0003oooooooooo`19ooooo`;o00002?ooool5o`0000Cooooo00?o0000oooo
ooooool0Foooool00ol0003oooooooooo`0Eooooo`005oooool00ol0003oooooooooo`1Kooooo`03
o`000?oooooooooo05[ooooo00?o0000ooooooooool05_ooool007Gooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0Gooooo`006?ooool00ol0003oooooooooo`1Jooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool05oooool007Gooooo00?o0000ooooooooool0F?ooool0
0ol0003oooooooooo`0Hooooo`006_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool06Oooool007Gooooo00?o0000ooooooooool0Loooool001_ooooo
00?o0000ooooooooool0Eoooool2o`0005Oooooo00?o0000ooooooooool06_ooool001cooooo00?o
0000ooooooooool0E_ooool00ol0003oooooooooo`1cooooo`007?ooool00ol0003oooooooooo`1F
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool06oooool001gooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`1cooooo`007_ooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo05;ooooo0_l0000Oooooo`007oooool00ol0003oooooooooo`1Cooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool07_ooool0023ooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo01oooooo000Qooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool0Loooool002;ooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`1?ooooo`03o`000?oooooooooo027ooooo001eooooo`03o`000?oooooooooo07?o
oooo001eooooo`03o`000?oooooooooo04gooooo0_l0000Tooooo`009?ooool00ol0003ooooooooo
o`1>ooooo`;o0000COooool00ol0003oooooooooo`0Tooooo`00MOooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo02Gooooo000Vooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`0Vooooo`009oooool00ol0003oooooooooo`1;ooooo`03
o`000?oooooooooo07?ooooo000Xooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0Xooooo`00:Oooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool0:Oooool002_ooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo02[ooooo000[ooooo`;o0000B?ooool00ol0
003oooooooooo`15ooooo`03o`000?oooooooooo02_ooooo000]ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool0Loooool002kooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo02gooooo000_ooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooooooool0@Oooool2o`00033ooooo001eooooo`;o0000@Oooool00ol0003oooooooooo`0`
ooooo`00<Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool0<Oooool003?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`1cooooo`00
=Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
=?ooool003Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1cooooo`00>?ooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0=oooool0
03[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
03Wooooo000jooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0jooooo`00??ooool2o`0003Oooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0looooo`00?_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03;ooooo0_l0
000oooooo`00?oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo07?ooooo0012oooo
o`;o0000<Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04;ooooo0015ooooo`03
o`000?oooooooooo02gooooo0_l0000^ooooo`03o`000?oooooooooo04?ooooo0015ooooo`;o0000
;_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04Gooooo0017ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0:?ooool2o`0004Wooooo001:ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool09Oooool00ol0003oooooo`00001;ooooo`00C?ooool3o`00
02Kooooo00?o0000ooooooooool08oooool2o`0004kooooo001?ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool08?ooool00ol0003oooooo`00001@ooooo`00D_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0DOooool005Gooooo00?o
0000ooooool000007Oooool00ol0003oooooooooo`0Jooooo`;o0000Eoooool005[ooooo0_l0000A
ooooo`?o00001Oooool00ol0003oooooooooo`0Fooooo`?o0000F_ooool005kooooo0_l0000>oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool01_l0003oooooooooool0003o
ooooo`0005kooooo001Rooooo`?o00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02Oooool4o`000003ooooool0003o000006?ooooo001Yoooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000;o000000?ooooo
o`000?l000000ol000000ooooooo0000o`00001[ooooo`00K_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo07?ooooo001]ooooo`;o00001_ooool00ol0003oooooooooo`1cooooo`00
K_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07?ooooo001eooooo`03o`000?oo
oooooooo07?ooooo001eooooo`03o`000?oooooooooo07?ooooo0000\
\>"],
  ImageRangeCache->{{{73.4375, 260.438}, {266.062, 79.0625}} -> {-1.88031, \
-0.162444, 0.00900121, 0.00900132}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The code below calculates the quasienergies (from the eigenvalues \
of the Floquet matrix), sorts these quasienergies, computes the spacings \
between consecutive quasienergies, normalizes the spacings so that the mean \
spacing is 1, and then plots a hisogram of the normalized spacings.  Since we \
are using all of the eigenvalues, what we expect to see is a mixture of 2 \
independent data sets (one for even parity states and one for odd parity \
states).  If each data set follows Poisson statistics then the mixture will \
also be Poisson, but if each data set follows GOE statistics then the mixture \
will follow statistics for 2 sets of GOE data (see previous section).\
\>", \
"Text"],

Cell[BoxData[
    \(<< Graphics`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Qnrg = Mod[Im[Log[Eval]], 2*Pi];\)\), "\[IndentingNewLine]", 
    \(\(SQnrg = Sort[Qnrg];\)\), "\[IndentingNewLine]", 
    \(\(int = Table[N[i*2*Pi/25], {i, 0, 25}];\)\), "\[IndentingNewLine]", 
    \(QHist = 
      Histogram[SQnrg, HistogramCategories \[Rule] int, 
        HistogramScale \[Rule] nq, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<s\>", "\<P(s)\>"}, 
        RotateLabel \[Rule] False]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.14203e-17 0.159155 0.0147151 0.0017611 [
[.15915 -0.0125 -6.78125 -18 ]
[.15915 -0.0125 6.78125 0 ]
[.31831 -0.0125 -6.78125 -18 ]
[.31831 -0.0125 6.78125 0 ]
[.47746 -0.0125 -6.78125 -18 ]
[.47746 -0.0125 6.78125 0 ]
[.63662 -0.0125 -6.78125 -18 ]
[.63662 -0.0125 6.78125 0 ]
[.79577 -0.0125 -6.78125 -18 ]
[.79577 -0.0125 6.78125 0 ]
[.95493 -0.0125 -6.78125 -18 ]
[.95493 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .10277 -23.125 -9 ]
[-0.0125 .10277 0 9 ]
[-0.0125 .19082 -32.6875 -9 ]
[-0.0125 .19082 0 9 ]
[-0.0125 .27888 -32.6875 -9 ]
[-0.0125 .27888 0 9 ]
[-0.0125 .36693 -32.6875 -9 ]
[-0.0125 .36693 0 9 ]
[-0.0125 .45499 -32.6875 -9 ]
[-0.0125 .45499 0 9 ]
[-0.0125 .54304 -32.6875 -9 ]
[-0.0125 .54304 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -74.9375 -9 ]
[-0.01875 .30902 -32.6875 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15915 0 m
.15915 .00625 L
s
gsave
.15915 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.31831 0 m
.31831 .00625 L
s
gsave
.31831 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.47746 0 m
.47746 .00625 L
s
gsave
.47746 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.63662 0 m
.63662 .00625 L
s
gsave
.63662 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.79577 0 m
.79577 .00625 L
s
gsave
.79577 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.95493 0 m
.95493 .00625 L
s
gsave
.95493 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.03183 0 m
.03183 .00375 L
s
.06366 0 m
.06366 .00375 L
s
.09549 0 m
.09549 .00375 L
s
.12732 0 m
.12732 .00375 L
s
.19099 0 m
.19099 .00375 L
s
.22282 0 m
.22282 .00375 L
s
.25465 0 m
.25465 .00375 L
s
.28648 0 m
.28648 .00375 L
s
.35014 0 m
.35014 .00375 L
s
.38197 0 m
.38197 .00375 L
s
.4138 0 m
.4138 .00375 L
s
.44563 0 m
.44563 .00375 L
s
.5093 0 m
.5093 .00375 L
s
.54113 0 m
.54113 .00375 L
s
.57296 0 m
.57296 .00375 L
s
.60479 0 m
.60479 .00375 L
s
.66845 0 m
.66845 .00375 L
s
.70028 0 m
.70028 .00375 L
s
.73211 0 m
.73211 .00375 L
s
.76394 0 m
.76394 .00375 L
s
.82761 0 m
.82761 .00375 L
s
.85944 0 m
.85944 .00375 L
s
.89127 0 m
.89127 .00375 L
s
.9231 0 m
.9231 .00375 L
s
.98676 0 m
.98676 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .10277 m
.00625 .10277 L
s
gsave
-0.0125 .10277 -84.125 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
0 .19082 m
.00625 .19082 L
s
gsave
-0.0125 .19082 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
0 .27888 m
.00625 .27888 L
s
gsave
-0.0125 .27888 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
0 .36693 m
.00625 .36693 L
s
gsave
-0.0125 .36693 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
0 .45499 m
.00625 .45499 L
s
gsave
-0.0125 .45499 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(250) show
1.000 setlinewidth
grestore
0 .54304 m
.00625 .54304 L
s
gsave
-0.0125 .54304 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03233 m
.00375 .03233 L
s
0 .04994 m
.00375 .04994 L
s
0 .06755 m
.00375 .06755 L
s
0 .08516 m
.00375 .08516 L
s
0 .12038 m
.00375 .12038 L
s
0 .13799 m
.00375 .13799 L
s
0 .1556 m
.00375 .1556 L
s
0 .17321 m
.00375 .17321 L
s
0 .20844 m
.00375 .20844 L
s
0 .22605 m
.00375 .22605 L
s
0 .24366 m
.00375 .24366 L
s
0 .26127 m
.00375 .26127 L
s
0 .29649 m
.00375 .29649 L
s
0 .3141 m
.00375 .3141 L
s
0 .33171 m
.00375 .33171 L
s
0 .34932 m
.00375 .34932 L
s
0 .38455 m
.00375 .38455 L
s
0 .40216 m
.00375 .40216 L
s
0 .41977 m
.00375 .41977 L
s
0 .43738 m
.00375 .43738 L
s
0 .4726 m
.00375 .4726 L
s
0 .49021 m
.00375 .49021 L
s
0 .50782 m
.00375 .50782 L
s
0 .52543 m
.00375 .52543 L
s
0 .56066 m
.00375 .56066 L
s
0 .57827 m
.00375 .57827 L
s
0 .59588 m
.00375 .59588 L
s
0 .61349 m
.00375 .61349 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.15915 .61178 m
.15915 .61803 L
s
.31831 .61178 m
.31831 .61803 L
s
.47746 .61178 m
.47746 .61803 L
s
.63662 .61178 m
.63662 .61803 L
s
.79577 .61178 m
.79577 .61803 L
s
.95493 .61178 m
.95493 .61803 L
s
.125 Mabswid
.03183 .61428 m
.03183 .61803 L
s
.06366 .61428 m
.06366 .61803 L
s
.09549 .61428 m
.09549 .61803 L
s
.12732 .61428 m
.12732 .61803 L
s
.19099 .61428 m
.19099 .61803 L
s
.22282 .61428 m
.22282 .61803 L
s
.25465 .61428 m
.25465 .61803 L
s
.28648 .61428 m
.28648 .61803 L
s
.35014 .61428 m
.35014 .61803 L
s
.38197 .61428 m
.38197 .61803 L
s
.4138 .61428 m
.4138 .61803 L
s
.44563 .61428 m
.44563 .61803 L
s
.5093 .61428 m
.5093 .61803 L
s
.54113 .61428 m
.54113 .61803 L
s
.57296 .61428 m
.57296 .61803 L
s
.60479 .61428 m
.60479 .61803 L
s
.66845 .61428 m
.66845 .61803 L
s
.70028 .61428 m
.70028 .61803 L
s
.73211 .61428 m
.73211 .61803 L
s
.76394 .61428 m
.76394 .61803 L
s
.82761 .61428 m
.82761 .61803 L
s
.85944 .61428 m
.85944 .61803 L
s
.89127 .61428 m
.89127 .61803 L
s
.9231 .61428 m
.9231 .61803 L
s
.98676 .61428 m
.98676 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10277 m
1 .10277 L
s
.99375 .19082 m
1 .19082 L
s
.99375 .27888 m
1 .27888 L
s
.99375 .36693 m
1 .36693 L
s
.99375 .45499 m
1 .45499 L
s
.99375 .54304 m
1 .54304 L
s
.125 Mabswid
.99625 .03233 m
1 .03233 L
s
.99625 .04994 m
1 .04994 L
s
.99625 .06755 m
1 .06755 L
s
.99625 .08516 m
1 .08516 L
s
.99625 .12038 m
1 .12038 L
s
.99625 .13799 m
1 .13799 L
s
.99625 .1556 m
1 .1556 L
s
.99625 .17321 m
1 .17321 L
s
.99625 .20844 m
1 .20844 L
s
.99625 .22605 m
1 .22605 L
s
.99625 .24366 m
1 .24366 L
s
.99625 .26127 m
1 .26127 L
s
.99625 .29649 m
1 .29649 L
s
.99625 .3141 m
1 .3141 L
s
.99625 .33171 m
1 .33171 L
s
.99625 .34932 m
1 .34932 L
s
.99625 .38455 m
1 .38455 L
s
.99625 .40216 m
1 .40216 L
s
.99625 .41977 m
1 .41977 L
s
.99625 .43738 m
1 .43738 L
s
.99625 .4726 m
1 .4726 L
s
.99625 .49021 m
1 .49021 L
s
.99625 .50782 m
1 .50782 L
s
.99625 .52543 m
1 .52543 L
s
.99625 .56066 m
1 .56066 L
s
.99625 .57827 m
1 .57827 L
s
.99625 .59588 m
1 .59588 L
s
.99625 .61349 m
1 .61349 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .57529 L
.04 .57529 L
.04 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .57529 L
.04 .57529 L
.04 .01472 L
0 .01472 L
s
1 0 0 r
.04 .01472 m
.04 .56128 L
.08 .56128 L
.08 .01472 L
F
0 g
.04 .01472 m
.04 .56128 L
.08 .56128 L
.08 .01472 L
.04 .01472 L
s
1 0 0 r
.08 .01472 m
.08 .56828 L
.12 .56828 L
.12 .01472 L
F
0 g
.08 .01472 m
.08 .56828 L
.12 .56828 L
.12 .01472 L
.08 .01472 L
s
1 0 0 r
.12 .01472 m
.12 .5823 L
.16 .5823 L
.16 .01472 L
F
0 g
.12 .01472 m
.12 .5823 L
.16 .5823 L
.16 .01472 L
.12 .01472 L
s
1 0 0 r
.16 .01472 m
.16 .57529 L
.2 .57529 L
.2 .01472 L
F
0 g
.16 .01472 m
.16 .57529 L
.2 .57529 L
.2 .01472 L
.16 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .56828 L
.24 .56828 L
.24 .01472 L
F
0 g
.2 .01472 m
.2 .56828 L
.24 .56828 L
.24 .01472 L
.2 .01472 L
s
1 0 0 r
.24 .01472 m
.24 .5893 L
.28 .5893 L
.28 .01472 L
F
0 g
.24 .01472 m
.24 .5893 L
.28 .5893 L
.28 .01472 L
.24 .01472 L
s
1 0 0 r
.28 .01472 m
.28 .57529 L
.32 .57529 L
.32 .01472 L
F
0 g
.28 .01472 m
.28 .57529 L
.32 .57529 L
.32 .01472 L
.28 .01472 L
s
1 0 0 r
.32 .01472 m
.32 .56828 L
.36 .56828 L
.36 .01472 L
F
0 g
.32 .01472 m
.32 .56828 L
.36 .56828 L
.36 .01472 L
.32 .01472 L
s
1 0 0 r
.36 .01472 m
.36 .56828 L
.4 .56828 L
.4 .01472 L
F
0 g
.36 .01472 m
.36 .56828 L
.4 .56828 L
.4 .01472 L
.36 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .5823 L
.44 .5823 L
.44 .01472 L
F
0 g
.4 .01472 m
.4 .5823 L
.44 .5823 L
.44 .01472 L
.4 .01472 L
s
1 0 0 r
.44 .01472 m
.44 .57529 L
.48 .57529 L
.48 .01472 L
F
0 g
.44 .01472 m
.44 .57529 L
.48 .57529 L
.48 .01472 L
.44 .01472 L
s
1 0 0 r
.48 .01472 m
.48 .56828 L
.52 .56828 L
.52 .01472 L
F
0 g
.48 .01472 m
.48 .56828 L
.52 .56828 L
.52 .01472 L
.48 .01472 L
s
1 0 0 r
.52 .01472 m
.52 .56828 L
.56 .56828 L
.56 .01472 L
F
0 g
.52 .01472 m
.52 .56828 L
.56 .56828 L
.56 .01472 L
.52 .01472 L
s
1 0 0 r
.56 .01472 m
.56 .5823 L
.6 .5823 L
.6 .01472 L
F
0 g
.56 .01472 m
.56 .5823 L
.6 .5823 L
.6 .01472 L
.56 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .5823 L
.64 .5823 L
.64 .01472 L
F
0 g
.6 .01472 m
.6 .5823 L
.64 .5823 L
.64 .01472 L
.6 .01472 L
s
1 0 0 r
.64 .01472 m
.64 .5823 L
.68 .5823 L
.68 .01472 L
F
0 g
.64 .01472 m
.64 .5823 L
.68 .5823 L
.68 .01472 L
.64 .01472 L
s
1 0 0 r
.68 .01472 m
.68 .57529 L
.72 .57529 L
.72 .01472 L
F
0 g
.68 .01472 m
.68 .57529 L
.72 .57529 L
.72 .01472 L
.68 .01472 L
s
1 0 0 r
.72 .01472 m
.72 .5823 L
.76 .5823 L
.76 .01472 L
F
0 g
.72 .01472 m
.72 .5823 L
.76 .5823 L
.76 .01472 L
.72 .01472 L
s
1 0 0 r
.76 .01472 m
.76 .56828 L
.8 .56828 L
.8 .01472 L
F
0 g
.76 .01472 m
.76 .56828 L
.8 .56828 L
.8 .01472 L
.76 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .54726 L
.84 .54726 L
.84 .01472 L
F
0 g
.8 .01472 m
.8 .54726 L
.84 .54726 L
.84 .01472 L
.8 .01472 L
s
1 0 0 r
.84 .01472 m
.84 .56828 L
.88 .56828 L
.88 .01472 L
F
0 g
.84 .01472 m
.84 .56828 L
.88 .56828 L
.88 .01472 L
.84 .01472 L
s
1 0 0 r
.88 .01472 m
.88 .5823 L
.92 .5823 L
.92 .01472 L
F
0 g
.88 .01472 m
.88 .5823 L
.92 .5823 L
.92 .01472 L
.88 .01472 L
s
1 0 0 r
.92 .01472 m
.92 .5823 L
.96 .5823 L
.96 .01472 L
F
0 g
.92 .01472 m
.92 .5823 L
.96 .5823 L
.96 .01472 L
.92 .01472 L
s
1 0 0 r
.96 .01472 m
.96 .60332 L
1 .60332 L
1 .01472 L
F
0 g
.96 .01472 m
.96 .60332 L
1 .60332 L
1 .01472 L
.96 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00/oooool0
0ol@413o<S8boa0@4002o`000003odA4A?o<c<cooooo06Gooooo002cooooo`03o`000?nHV9Sok^k^
00;ooooo00?oQhN7oa0@4?ooool0IOooool00;Sooooo00?o^[Zjo`000?ooool0IOooool00;?ooooo
00?oc<c<odA4A?l000000ol000000onHV9Soooooooooo`1Tooooo`00/oooool01Ol0003oQhN7okZj
^_nj^[[oc<c<06Sooooo002cooooo`03o`000?nHV9Sooooo00;ooooo00?oc<c<oa0@4?ooool0IOoo
ool00;?ooooo00Ooc<c<odA4A?l0003o0000oa0@4?lb<S;o000006Kooooo003oooooob7ooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo001]
ooooo`Co000000?o410@ooooooooool06Oooool6o`0001cooooo00GoZJVYob4Q8Ol0003o0000ofIV
IP0Oooooo`;o000000?o410@ooooooooool06Oooool01OnHV9So410@o`000?l0003oIVIV01cooooo
00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h8ooooo`00Koooool00ol0003oooooooooo`0Kooooo`03
oiRHV?l0003ogMgM00;ooooo00?o410@ooooooooool06_ooool01_l@413oc<c<ooooooooooooMgMg
ofIVIQoooooo00?o0000ooooooooool06_ooool01_l@413oQhN7ooooooooooooMgMgofIVIQ_ooooo
0_mgMgL2ooooo`03ogMgMomEEEGooooo00Oooooo001_ooooo`03o`000?oooooooooo01cooooo00?o
QhN7ob4Q8Oo^k^h08oooool00ol0003oooooooooo`0Iooooo`Ko00008?ooool00ol0003ooooooooo
o`0Iooooo`03ob4Q8Ooooooooooo00;ooooo00?o0000ooooooooool01_ooool006oooooo00?o0000
ooooooooool07Oooool00onYZJWo8B4Qonk^kP0Rooooo`03o`000?oooooooooo01Wooooo00GoA4A4
okZj^_ooooooooooo`00000Pooooo`03onk^k_l0003ooooo01[ooooo00?o0000onk^k_ooool00_oo
ool00ol0003oooooooooo`06ooooo`00Koooool00ol0003oooooooooo`0Nooooo`03oiRHV?lb<S;o
oooo023ooooo00?oZJVYodA4A?ooool06_ooool01OoMgMgo8B4Qoooooooooooo000001cooooo00Ko
410@oiRHV?ooooooooooogMgMomVIVHKooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE2?ooool0
06oooooo00?o0000ooooooooool07oooool00om4A4CoMgMgooooo`0Mooooo`04ob4Q8Ol0003o0000
omgMgAcooooo00CoMgMgoiRHV?oooooo00007?ooool01Ol0003o8B4Qo`000?l0003oIVIV01cooooo
00Ko0000ogMgMol0003o0000oeEEEOo^k^h8ooooo`00Koooool00ol0003oooooooooo`0Oooooo`03
omgMgOl@413ooooo01oooooo00?oZJVYoc8b<_ooool06oooool01?o^k^ko8B4Qooooool0000Loooo
o`03o`000?oooooooooo01kooooo00?oA4A4oiRHV?ooool02oooool006oooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01_ooooo00?oMgMgoiRHV?l0
00007?ooool00ol0003oooooooooo`0Nooooo`03okZj^_lQ8B7ooooo00_ooooo001]ooooo`03o`00
0?m4A4Co000001gooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEEDLooooo`06ob4Q8Onj^[[ooooo
oooooomVIVKo<S8b7Oooool00oo^k^ko<S8bo`00000Looooo`03o`000?oooooooooo01oooooo00?o
EEEEoc8b<_oMgMd02_ooool006gooooo00?oc<c<oeEEEOl000007Oooool01_nYZJWo<S8bo`000?l0
003oEEEEonk^kQcooooo00Ko^[ZjodA4A?l0003o0000odA4A?o^k^hNooooo`03oiRHV?l@413ooooo
01_ooooo1Ol0000Nooooo`04oiRHV?lQ8B7o0000ob4Q8@Sooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0013ooooo`04oiRHV?l0003o0000
oiRHV0Ooooood@000001ooooo`00@_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PKooooo00<0
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003ooooo00000001ooooo`00@_ooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A0Kooooo00<00000ooooooooool0cOooool10000007ooooo0012ooooo`06o`000?o^
k^koooooooooooo^k^ko00001_oooooA0000007ooooo0012ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l0004000000Oooool004;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`030000003o0000o`0000H0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`000@00
0001ooooo`00@_ooool01_l0003ok^k^ooooooooooook^k^o`0000Kooooo00<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00010000007ooooo0012ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41_ooool00`000000
o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000050?l0004000000Oooool004;ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X6oooo
o`030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0
00030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0
00030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0
00030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0
00030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`000@000001ooooo`00@oooool01?nHV9So0000o`000?nHV9P7oooo
o`030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0
00030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0
00030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0
00030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0
00030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`000@000001ooooo`00C_ooool00`000000o`000?l000060?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00040
00000Oooool004kooooo00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00010000007ooooo001>ooooo`030000003o
0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o
0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o
0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o
0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o
0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o
0000o`0000D0o`000@000001ooooo`00C_ooool00`000000o`000?l000060?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000
o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000
o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000
o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0004000000Oooool0
04kooooo00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00010000007ooooo001>ooooo`030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`000@000001ooooo`00C_ooool00`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l0004000000Oooool004kooooo00<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00010000007ooooo000iooooo`05oiRHV?l@413o0000o`000?mVIVH01_oo
ool01?nHV9So0000o`000?nHV9P6ooooo`030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`000@000001ooooo`00>Ooo
ool01_l@413oQhN7ooooooooooooMgMgofIVIPCooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5
ooooo`030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l00005
0?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l00005
0?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l00005
0?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l00005
0?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l00005
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l00005
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l00005
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l00005
0?l000030000003o0000o`0000D0o`000@000001ooooo`00?_ooool00ol0003oooooooooo`02oooo
o`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00`000000o`000?l000060?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o
0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o
0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o
0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0004000000Ooo
ool003gooooo00?ok^k^o`000?ooool00oooool01_l0003ok^k^ooooooooooook^k^o`0000Gooooo
00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00010000007ooooo000iooooo`06oa0@4?nHV9SooooooooooomgMgOo
IVIV1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001@3o00010000007ooooo000iooooo`05o`000?lQ8B7o0000o`000?mVIVH01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00<000000?l0003o00001P3o00000`000000
o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000
o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000
o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000
o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000
o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00010000007o
oooo000iooooo`03o`000?oooooooooo00Oooooo00Ko0000onk^k_ooooooooooonk^k_l00005oooo
o`030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0
00030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0
00030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0
00030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0
00030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`000@000001ooooo`00>Oooool00ol0003oooooooooo`07ooooo`06
odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00`000000o`000?l000060?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000
o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000
o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000
o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0004000000Oooool0
03Wooooo00?o0000ooooooooool01oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00010000007ooooo000iooooo`Go00001_ooool01?nHV9So0000o`000?nH
V9P6ooooo`030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`000@000001ooooo`00C_ooool00`000000o`000?l00006
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l00006
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l00006
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l00006
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l00006
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l00005
0?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l00005
0?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l00005
0?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l00005
0?l0004000000Oooool004kooooo00<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00010000007ooooo001>ooooo`03
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`000@000001ooooo`00C_ooool00`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000
003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000
003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000
003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000400000
0Oooool004kooooo00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001@3o00010000007ooooo001>ooooo`030000003o0000
o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000
o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000
o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000
o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000
o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`000@000001ooooo`00C_ooool00`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0004000000Oooool004ko
oooo00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001@3o00010000007ooooo001>ooooo`030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`00
0@000001ooooo`00;oooool4o`000003oa0@4?oooooooooo00Cooooo00CoV9RHo`000?l0003oV9RH
1_ooool01?nHV9So0000o`000?nHV9P6ooooo`030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`000@000001ooooo`00
<Oooool00ol0003oooooooooo`05ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_nj
^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00010000007ooooo000a
ooooo`03o`000?oooooooooo00Gooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@4ooooo`06odA4
A?nHV9SooooooooooonHV9SoA4A41Oooool00`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0004000000Oooool0037o
oooo00?o0000ooooooooool01Oooool01_l0003ok^k^ooooooooooook^k^o`0000Cooooo00Ko0000
onk^k_ooooooooooonk^k_l00005ooooo`030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`000@000001ooooo`00<Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00<000000?l0003o00001P3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o
00010000007ooooo000aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000050?l0004000000Oooool0037ooooo00?o0000ooooooooool01Oooool01_l0
003ok^k^ooooooooooook^k^o`0000Cooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooo`03
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`000@000001ooooo`00<Oooool00ol0003oooooooooo`05ooooo`06odA4
A?nHV9SooooooooooonHV9SoA4A41?ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00010000007ooooo000_ooooo`03o`000?m4A4Co000000Oooooo00Ko^[Zj
ob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool00`00
0000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l0004000000Oooool002oooooo00?oc<c<oeEEEOl000002?ooool01?nHV9So
0000o`000?nHV9P6ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00<000000?l0003o00001P3o0000
0`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o0000
0`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o0000
0`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o0000
0`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o0000
0`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o0001
0000007ooooo001>ooooo`030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`00
0000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`00
0000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`00
0000o`000?l000050?l000030000003o0000o`0000D0o`000@000001ooooo`00C_ooool00`000000
o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000050?l0004000000Oooool004kooooo00<000000?l0003o00001P3o00000`000000o`00
0?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`00
0?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`00
0?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`00
0?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`00
0?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`00
0?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`00
0?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`00
0?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00010000007ooooo
001>ooooo`030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`000@000001ooooo`00C_ooool00`000000o`000?l00006
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l00006
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l00006
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l00006
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l00006
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l00005
0?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l00005
0?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l00005
0?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l00005
0?l0004000000Oooool004kooooo00<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00010000007ooooo001>ooooo`03
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`000@000001ooooo`00C_ooool00`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000
003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000
003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000
003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000400000
0Oooool002oooooo1?l000000ol@413oooooooooo`03ooooo`05oiRHV?l@413o0000o`000?mVIVH0
1_ooool01?nHV9So0000o`000?nHV9P6ooooo`030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`000@000001ooooo`00
<Oooool00ol0003oooooooooo`05ooooo`06oa0@4?n7QhOooooooooooomgMgOoIVIV1?ooool01_nj
^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00010000007ooooo000a
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A0Gooooo00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00010000007ooooo000@ooooo`03okZj^_lb
<S;ooooo00kooooo00?o<S8bokZj^_ooool03Oooool00ol0003oooooooooo`09ooooo`03onk^k_l0
003ooooo00?ooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooo`030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`000@000001ooooo`004?ooool00olb<S;o^[Zjooooo`0>ooooo`03okZj^_lb<S;ooooo00gooooo
00?o0000ooooooooool01Oooool01_l@413oV9RHooooooooooooMgMgofIVIPCooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`030000003o0000o`0000H0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`000@000001oooo
o`003oooool00oo<c<co<S8booooo`0@ooooo`03oc8b<_o<c<cooooo00cooooo00?o0000oooooooo
ool01Oooool01Ol0003o8B4Qo`000?l0003oIVIV00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`00
0000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`00
0000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`00
0000o`000?l000050?l000030000003o0000o`0000D0o`000@000001ooooo`000_ooool01Ol@413o
0000o`000?l0003o410@00Sooooo00?oIVIVojVYZOooool01?ooool00ol@413o<S8boa0@4002o`00
0003odA4A?o<c<cooooo00Cooooo00?oV9RHofIVI_ooool03?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooo`030000003o
0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o
0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o
0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o
0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o
0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o
0000o`0000D0o`000@000001ooooo`001?ooool00ol0003oooooooooo`08ooooo`03oc8b<_oooooo
oooo00Cooooo00?o0000oiRHV?o^k^h00_ooool00on7QhOo410@ooooo`04ooooo`03onk^k_lb<S;o
oooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`06odA4A?nHV9So
oooooooooonHV9SoA4A41Oooool00`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l0004000000Oooool000Cooooo00?o
0000ooooooooool02?ooool00olb<S;oooooooooo`09ooooo`03okZj^_l0003ooooo00Gooooo00?o
0000ooooooooool02Oooool00ol0003oA4A4o`000007ooooo`03o`000?oooooooooo00Oooooo00Ko
^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`000@000001ooooo`00
1?ooool3o`000003oa0@4?mgMgOok^k^00Gooooo00?o<S8booooooooool01?ooool00oo<c<coA4A4
o`000003o`000003oiRHV?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00oo<c<coEEEE
o`000007ooooo`Go00001_ooool01?nHV9So0000o`000?nHV9P6ooooo`030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`000@000001ooooo`001?ooool01_l0003oooooooooooo^k^koMgMgoeEEE@Gooooo00?o8B4Qoooo
ooooool01?ooool01Ol0003oQhN7okZj^_nj^[[oc<c<00Sooooo00?o0000ooooooooool0:?ooool0
0`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000050?l0004000000Oooool000Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03oc8b<_o^k^kooooo00Cooooo00?o0000oiRHV?ooool00_ooool00oo<
c<co410@ooooo`04ooooo`03omgMgOlb<S;ooooo02Wooooo00<000000?l0003o00001P3o00000`00
0000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`00
0000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`00
0000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`00
0000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`00
0000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00010000
007ooooo0004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00omVIVKo
V9RHooooo`04ooooo`07olc<c?m4A4Co0000o`000?l@413o<S8bo`000005ooooo`03oiRHV?mVIVKo
oooo02Wooooo00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00010000007ooooo0004ooooo`06o`000?oooooooooo
onk^k_mgMgOoEEEE1Oooool00ooMgMgo8B4Qooooo`0@ooooo`03oa0@4?o<c<cooooo02Wooooo00<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00010000007ooooo0002ooooo`03oa0@4?l0003o000000;o000000?o410@
ogMgMoo^k^h01_ooool00olb<S;o^[Zjooooo`0>ooooo`03okZj^_lb<S;ooooo02[ooooo00<00000
0?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<00000
0?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<00000
0?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<00000
0?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<00000
0?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<00000
0?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<00000
0?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<00000
0?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<00000
0?l0003o00001@3o00010000007ooooo000@ooooo`03okZj^_lb<S;ooooo00kooooo00?o<S8bokZj
^_ooool0:_ooool00`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000050?l0004000000Oooool004kooooo00<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001@3o00010000007ooooo001>ooooo`030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`000@000001ooooo`00;_oo
ool6o`0000Kooooo00CoV9RHo`000?l0003oV9RH1_ooool01?nHV9So0000o`000?nHV9P6ooooo`03
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`000@000001ooooo`00;_ooool00onHV9So0000omgMg@02ooooo`03oa0@
4?oooooooooo00?ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`06okZj^_lQ8B7ogMgM
omgMgOlQ8B7o^[Zj1Oooool00`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000050?l0004000000Oooool002oooooo00?oQhN7
ob4Q8Oo^k^h01oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo00KoA4A4oiRHV?oooooo
oooooiRHV?m4A4@5ooooo`030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`00
0000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`00
0000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`00
0000o`000?l000050?l000030000003o0000o`0000D0o`000@000001ooooo`00<?ooool00onYZJWo
8B4Qonk^kP06ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool01_l0003ok^k^oooooooo
ooook^k^o`0000Gooooo00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000
003o0000o`0000D0o`0000<000000?l0003o00001@3o00010000007ooooo000aooooo`03oiRHV?lb
<S;ooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00`000000o`000?l000060?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o
0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o
0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o
0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o
0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0004000000Ooo
ool003;ooooo00?oA4A4ogMgMoooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`030000003o0000
o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000
o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000
o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000
o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000
o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`000@000001ooooo`00<_ooool00ooMgMgo410@ooooo`04ooooo`06o`000?o^k^kooooo
ooooooo^k^ko00001?ooool01_l0003ok^k^ooooooooooook^k^o`0000Gooooo00<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001@3o00010000007ooooo000cooooo`03o`000?oooooooooo00?ooooo00KoA4A4oiRHV?oooooo
oooooiRHV?m4A4@4ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l0004000000Oooool002kooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED5ooooo`06okZj
^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00010000007ooooo000^ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^
1_ooool01?nHV9So0000o`000?nHV9P6ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00<000000?l0
003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001@3o00010000007ooooo001>ooooo`030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`000@000001ooooo`00
C_ooool00`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l0004000000Oooool004kooooo00<000000?l0003o00001P3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o
00010000007ooooo001>ooooo`030000003o0000o`0000H0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o0000
0`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o0000
0`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o0000
0`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o0000
0`000000o`000?l000050?l000030000003o0000o`0000D0o`000@000001ooooo`00C_ooool00`00
0000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l0004000000Oooool004kooooo00<000000?l0003o00001P3o00000`000000
o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000
o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000
o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000
o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000
o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00010000007o
oooo001>ooooo`030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`00
0?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`00
0?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`00
0?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`00
0?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`00
0?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`00
0?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`00
0?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`00
0?l000050?l000030000003o0000o`0000D0o`000@000001ooooo`00C_ooool00`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00050?l0004000000Oooool004kooooo00<000000?l0003o00001P3o00000`000000o`000?l00005
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l00005
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l00005
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l00005
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l00005
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l00006
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l00006
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l00006
0?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00010000007ooooo000^oooo
o`Ko00001Oooool01OnHV9So410@o`000?l0003oIVIV00Kooooo00CoV9RHo`000?l0003oV9RH1_oo
ool00`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000050?l0004000000Oooool002kooooo00?oV9RHo`000?oMgMd00_ooool0
0ol@413oooooooooo`03ooooo`06oa0@4?n7QhOooooooooooomgMgOoIVIV1?ooool01_nj^[[o8B4Q
omgMgOoMgMgo8B4QokZj^PGooooo00<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00010000007ooooo000_ooooo`03
ohN7QolQ8B7ok^k^00cooooo00?o0000ooooooooool00_ooool01_m4A4CoV9RHooooooooooooV9RH
odA4A0Gooooo00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000
o`0000D0o`0000<000000?l0003o00001@3o00010000007ooooo000`ooooo`03ojVYZOlQ8B7ok^k^
00[ooooo00?ok^k^o`000?ooool00oooool01_l0003ok^k^ooooooooooook^k^o`0000Gooooo00<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00010000007ooooo000aooooo`03oiRHV?lb<S;ooooo00Gooooo00Ko410@
oiRHV?ooooooooooogMgMomVIVH4ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000050?l0004000000Oooool003;ooooo00?oA4A4ogMgMoooool01?oo
ool01Ol0003o8B4Qo`000?l0003oIVIV00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`00
0?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`00
0?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`00
0?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`00
0?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`00
0?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`00
0?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`00
0?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`00
0?l000050?l000030000003o0000o`0000D0o`000@000001ooooo`00<_ooool00ooMgMgo410@oooo
o`04ooooo`03o`000?oooooooooo00Oooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooo`03
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l00003
0000003o0000o`0000D0o`000@000001ooooo`00<oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`030000003o0000o`00
00H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`00
00D0o`000@000001ooooo`00;_ooool01_l0003oQhN7onk^k_ooooooV9RHoeEEE@Gooooo00?o0000
ooooooooool01oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00010000007ooooo000^ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^1Oooool5o`0000Ko
oooo00CoV9RHo`000?l0003oV9RH1_ooool00`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`00
00D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0004000000Oooool004ko
oooo00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001@3o00010000007ooooo001>ooooo`030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`00
00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`00
0@000001ooooo`00C_ooool00`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<0
00000?l0003o00001@3o00000`000000o`000?l000050?l0004000000Oooool004kooooo00<00000
0?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<00000
0?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<00000
0?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<00000
0?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<00000
0?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<00000
0?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<00000
0?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<00000
0?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<00000
0?l0003o00001@3o00010000007ooooo001>ooooo`030000003o0000o`0000H0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0
003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0
003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`000@000001oooo
o`00C_ooool00`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l0004000000Oooool004kooooo00<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o0000
1@3o00010000007ooooo001>ooooo`030000003o0000o`0000H0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`000@000001ooooo`00;oooool0
1OnYZJWo8B4Qo`000?l0003oIVIV00Kooooo00CoV9RHo`000?l0003oV9RH1_ooool01?nHV9So0000
o`000?nHV9P6ooooo`030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000
o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000
o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000
o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000
o`000?l000050?l000030000003o0000o`0000D0o`000@000001ooooo`00;oooool01_l@413oc<c<
ooooooooooooMgMgofIVIPCooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`06okZj^_lQ
8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool00`000000o`000?l000060?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l000030000003o0000o`0000D0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0
o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0004000000Oooool003Cooooo
00?o0000ooooooooool00_ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo00KoA4A4oiRH
V?oooooooooooiRHV?m4A4@5ooooo`030000003o0000o`0000H0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o
00000`000000o`000?l000050?l000030000003o0000o`0000D0o`000@000001ooooo`00=?ooool0
0ol0003oooooooooo`02ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool01_l0003ok^k^
ooooooooooook^k^o`0000Gooooo00<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l000050?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l0
00030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00010000007ooooo000cooooo`03
ojVYZOm4A4Cooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00`000000o`000?l000060?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000060?l00003
0000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l00003
0000003o0000o`0000H0o`002@0000070?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l0004000000Oooool0037ooooo00Co8B4Qo`000?l0003o
gMgM1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o
00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`00003oooooooooo`05ooooo`030000003o0000o`0000D0o`0000<000000?l0003o
00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`000@000001ooooo`00
<oooool00onYZJWo<S8booooo`03ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool01_l0
003ok^k^ooooooooooook^k^o`0000Gooooo00<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`000000o`000?l0
00060?l0000300000?oooooooooo00Gooooo00<000000?l0003o00001@3o00000`000000o`000?l0
00060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00010000007ooooo000d
ooooo`03o`000?oooooooooo00;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@4ooooo`06odA4
A?nHV9SooooooooooonHV9SoA4A41Oooool00`000000o`000?l000060?l000T000001`3o00000`00
0000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000060?l000030000003o0000o`0000D0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<00000ooooooooool01Oooool00`00
0000o`000?l000050?l000030000003o0000o`0000H0o`0000<000000?l0003o00001@3o00000`00
0000o`000?l000050?l0004000000Oooool002oooooo00Ko8B4QokZj^_ooooooooooofIVI_lb<S84
ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj
^PGooooo00<000000?l0003o00001P3o00000`00003oooooooooo`05ooooo`T00000203o00000`00
0000o`000?l000050?l000T00000203o00000`000000o`000?l000050?l0018000001`3o00000`00
0000o`000?l000050?l0018000001`3o00000`000000o`000?l000050?l000030000003o0000o`00
00H0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l000X000001oooool90000
00P0o`0000<000000?l0003o00001@3o00000`000000o`000?l000050?l0004000000Oooool002oo
oooo00Ko^[ZjodA4A?l0003o0000odA4A?o^k^h5ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00Co
V9RHo`000?l0003oV9RH1_ooool00`000000o`000?l000060?l0000300000?oooooooooo00gooooo
00<000000?l0003o00001P3o00000`000000o`000?l000050?l0000300000?oooooooooo00Gooooo
00<000000?l0003o00001P3o00000`000000o`000?l000050?l0000300000?oooooooooo00kooooo
00<000000?l0003o00001@3o00000`000000o`000?l000050?l0000300000?oooooooooo00kooooo
00<000000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`00
00<000000?l0003o00001@3o00000`000000o`000?l000050?l0000300000?oooooooooo01Kooooo
00<000000?l0003o00001P3o00000`000000o`000?l000050?l000030000003o0000o`0000D0o`00
0@000001ooooo`00C_ooool:000000oooooo00<000000?l0003o00001P3o0009000000Oooooo00<0
00000?l0003o00001P3o00090000013ooooo00<000000?l0003o00001@3o00090000013ooooo00<0
00000?l0003o00001@3o00000`000000o`000?l000050?l000030000003o0000o`0000H0o`002@00
00070?l0000300000?oooooooooo01Kooooo00<000000?l0003o00001P3o00000`000000o`000?l0
00050?l000030000003o0000o`0000D0o`000@000001ooooo`00C_ooool00`00003oooooooooo`0F
ooooo`X000003oooool00`000000o`000?l000060?l0000300000?oooooooooo01Kooooo2@00000H
oooooaX000001oooool9000001Sooooo4P0000070?l0004000000Oooool004kooooo00<00000oooo
ooooool0;oooool00`000000o`000?l000060?l0000300000?oooooooooo08[ooooo00<000000?l0
003o00001@3o00010000007ooooo001>ooooo`0300000?oooooooooo02oooooo2P00002<ooooo`03
0000003o0000o`0000D0o`000@000001ooooo`00C_ooool00`00003o0000ooooo`35ooooo`030000
003o0000o`0000D0o`000@000001ooooo`00C_ooool00`00003oooooooooo`35ooooo`030000003o
0000o`0000D0o`000@000001ooooo`00C_ooool00`00003oooooooooo`35ooooo`T000000Oooool0
04kooooo00<00000ooooooooool07_ooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo
01kooooo00<00000ooooooooool07_ooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo
01kooooo00<00000ooooooooool01_ooool10000007ooooo001>ooooo`0300000?l0003ooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00`00003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00<00000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00<00000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo00Co
oooo00?o0000ooooo`0000000Oooool004koooood@000001ooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.38115, -127.042, \
0.0302026, 2.72948}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Qnrg = Mod[\(-Im[Log[Eval]]\), 2*Pi];\)\), "\[IndentingNewLine]", 
    \(\(SQnrg = Sort[Qnrg];\)\), "\[IndentingNewLine]", 
    \(\(QSpc = 
        Join[Table[
            SQnrg[\([i + 1]\)] - SQnrg[\([i]\)], {i, 1, 
              nq - 1}], {SQnrg[\([1]\)] + 2*Pi - 
              SQnrg[\([nq]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QSpcNorm = QSpc/Mean[QSpc];\)\), "\[IndentingNewLine]", 
    \(\(int\  = \ Table[0 + i/8, {i, 0, 40}];\)\), "\n", 
    \(QHist2 = 
      Histogram[QSpcNorm, HistogramCategories \[Rule] int, 
        HistogramScale \[Rule] 1, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<s\>", "\<P(s)\>"}, 
        RotateLabel \[Rule] False]\)}], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(SQnrg\\)\\\" is similar to existing symbol \
\\\"\\!\\(Qnrg\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(QHist\\)\\\" is similar to existing symbol \
\\\"\\!\\(MHist\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.56125e-17 0.228571 0.0147151 0.891824 [
[.22857 -0.0125 -6.78125 -18 ]
[.22857 -0.0125 6.78125 0 ]
[.45714 -0.0125 -6.78125 -18 ]
[.45714 -0.0125 6.78125 0 ]
[.68571 -0.0125 -6.78125 -18 ]
[.68571 -0.0125 6.78125 0 ]
[.91429 -0.0125 -6.78125 -18 ]
[.91429 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .1039 -32.6875 -9 ]
[-0.0125 .1039 0 9 ]
[-0.0125 .19308 -32.6875 -9 ]
[-0.0125 .19308 0 9 ]
[-0.0125 .28226 -32.6875 -9 ]
[-0.0125 .28226 0 9 ]
[-0.0125 .37144 -32.6875 -9 ]
[-0.0125 .37144 0 9 ]
[-0.0125 .46063 -32.6875 -9 ]
[-0.0125 .46063 0 9 ]
[-0.0125 .54981 -32.6875 -9 ]
[-0.0125 .54981 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -74.9375 -9 ]
[-0.01875 .30902 -32.6875 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.22857 0 m
.22857 .00625 L
s
gsave
.22857 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.45714 0 m
.45714 .00625 L
s
gsave
.45714 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.68571 0 m
.68571 .00625 L
s
gsave
.68571 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.91429 0 m
.91429 .00625 L
s
gsave
.91429 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.04571 0 m
.04571 .00375 L
s
.09143 0 m
.09143 .00375 L
s
.13714 0 m
.13714 .00375 L
s
.18286 0 m
.18286 .00375 L
s
.27429 0 m
.27429 .00375 L
s
.32 0 m
.32 .00375 L
s
.36571 0 m
.36571 .00375 L
s
.41143 0 m
.41143 .00375 L
s
.50286 0 m
.50286 .00375 L
s
.54857 0 m
.54857 .00375 L
s
.59429 0 m
.59429 .00375 L
s
.64 0 m
.64 .00375 L
s
.73143 0 m
.73143 .00375 L
s
.77714 0 m
.77714 .00375 L
s
.82286 0 m
.82286 .00375 L
s
.86857 0 m
.86857 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .1039 m
.00625 .1039 L
s
gsave
-0.0125 .1039 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .19308 m
.00625 .19308 L
s
gsave
-0.0125 .19308 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .28226 m
.00625 .28226 L
s
gsave
-0.0125 .28226 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
0 .37144 m
.00625 .37144 L
s
gsave
-0.0125 .37144 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .46063 m
.00625 .46063 L
s
gsave
-0.0125 .46063 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .54981 m
.00625 .54981 L
s
gsave
-0.0125 .54981 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03255 m
.00375 .03255 L
s
0 .05039 m
.00375 .05039 L
s
0 .06822 m
.00375 .06822 L
s
0 .08606 m
.00375 .08606 L
s
0 .12173 m
.00375 .12173 L
s
0 .13957 m
.00375 .13957 L
s
0 .15741 m
.00375 .15741 L
s
0 .17524 m
.00375 .17524 L
s
0 .21092 m
.00375 .21092 L
s
0 .22875 m
.00375 .22875 L
s
0 .24659 m
.00375 .24659 L
s
0 .26443 m
.00375 .26443 L
s
0 .3001 m
.00375 .3001 L
s
0 .31794 m
.00375 .31794 L
s
0 .33577 m
.00375 .33577 L
s
0 .35361 m
.00375 .35361 L
s
0 .38928 m
.00375 .38928 L
s
0 .40712 m
.00375 .40712 L
s
0 .42495 m
.00375 .42495 L
s
0 .44279 m
.00375 .44279 L
s
0 .47846 m
.00375 .47846 L
s
0 .4963 m
.00375 .4963 L
s
0 .51414 m
.00375 .51414 L
s
0 .53197 m
.00375 .53197 L
s
0 .56765 m
.00375 .56765 L
s
0 .58548 m
.00375 .58548 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.22857 .61178 m
.22857 .61803 L
s
.45714 .61178 m
.45714 .61803 L
s
.68571 .61178 m
.68571 .61803 L
s
.91429 .61178 m
.91429 .61803 L
s
.125 Mabswid
.04571 .61428 m
.04571 .61803 L
s
.09143 .61428 m
.09143 .61803 L
s
.13714 .61428 m
.13714 .61803 L
s
.18286 .61428 m
.18286 .61803 L
s
.27429 .61428 m
.27429 .61803 L
s
.32 .61428 m
.32 .61803 L
s
.36571 .61428 m
.36571 .61803 L
s
.41143 .61428 m
.41143 .61803 L
s
.50286 .61428 m
.50286 .61803 L
s
.54857 .61428 m
.54857 .61803 L
s
.59429 .61428 m
.59429 .61803 L
s
.64 .61428 m
.64 .61803 L
s
.73143 .61428 m
.73143 .61803 L
s
.77714 .61428 m
.77714 .61803 L
s
.82286 .61428 m
.82286 .61803 L
s
.86857 .61428 m
.86857 .61803 L
s
.96 .61428 m
.96 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1039 m
1 .1039 L
s
.99375 .19308 m
1 .19308 L
s
.99375 .28226 m
1 .28226 L
s
.99375 .37144 m
1 .37144 L
s
.99375 .46063 m
1 .46063 L
s
.99375 .54981 m
1 .54981 L
s
.125 Mabswid
.99625 .03255 m
1 .03255 L
s
.99625 .05039 m
1 .05039 L
s
.99625 .06822 m
1 .06822 L
s
.99625 .08606 m
1 .08606 L
s
.99625 .12173 m
1 .12173 L
s
.99625 .13957 m
1 .13957 L
s
.99625 .15741 m
1 .15741 L
s
.99625 .17524 m
1 .17524 L
s
.99625 .21092 m
1 .21092 L
s
.99625 .22875 m
1 .22875 L
s
.99625 .24659 m
1 .24659 L
s
.99625 .26443 m
1 .26443 L
s
.99625 .3001 m
1 .3001 L
s
.99625 .31794 m
1 .31794 L
s
.99625 .33577 m
1 .33577 L
s
.99625 .35361 m
1 .35361 L
s
.99625 .38928 m
1 .38928 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .42495 m
1 .42495 L
s
.99625 .44279 m
1 .44279 L
s
.99625 .47846 m
1 .47846 L
s
.99625 .4963 m
1 .4963 L
s
.99625 .51414 m
1 .51414 L
s
.99625 .53197 m
1 .53197 L
s
.99625 .56765 m
1 .56765 L
s
.99625 .58548 m
1 .58548 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .46776 L
.02857 .46776 L
.02857 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .46776 L
.02857 .46776 L
.02857 .01472 L
0 .01472 L
s
1 0 0 r
.02857 .01472 m
.02857 .4749 L
.05714 .4749 L
.05714 .01472 L
F
0 g
.02857 .01472 m
.02857 .4749 L
.05714 .4749 L
.05714 .01472 L
.02857 .01472 L
s
1 0 0 r
.05714 .01472 m
.05714 .48917 L
.08571 .48917 L
.08571 .01472 L
F
0 g
.05714 .01472 m
.05714 .48917 L
.08571 .48917 L
.08571 .01472 L
.05714 .01472 L
s
1 0 0 r
.08571 .01472 m
.08571 .51057 L
.11429 .51057 L
.11429 .01472 L
F
0 g
.08571 .01472 m
.08571 .51057 L
.11429 .51057 L
.11429 .01472 L
.08571 .01472 L
s
1 0 0 r
.11429 .01472 m
.11429 .57478 L
.14286 .57478 L
.14286 .01472 L
F
0 g
.11429 .01472 m
.11429 .57478 L
.14286 .57478 L
.14286 .01472 L
.11429 .01472 L
s
1 0 0 r
.14286 .01472 m
.14286 .60332 L
.17143 .60332 L
.17143 .01472 L
F
0 g
.14286 .01472 m
.14286 .60332 L
.17143 .60332 L
.17143 .01472 L
.14286 .01472 L
s
1 0 0 r
.17143 .01472 m
.17143 .52127 L
.2 .52127 L
.2 .01472 L
F
0 g
.17143 .01472 m
.17143 .52127 L
.2 .52127 L
.2 .01472 L
.17143 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .507 L
.22857 .507 L
.22857 .01472 L
F
0 g
.2 .01472 m
.2 .507 L
.22857 .507 L
.22857 .01472 L
.2 .01472 L
s
1 0 0 r
.22857 .01472 m
.22857 .50343 L
.25714 .50343 L
.25714 .01472 L
F
0 g
.22857 .01472 m
.22857 .50343 L
.25714 .50343 L
.25714 .01472 L
.22857 .01472 L
s
1 0 0 r
.25714 .01472 m
.25714 .42139 L
.28571 .42139 L
.28571 .01472 L
F
0 g
.25714 .01472 m
.25714 .42139 L
.28571 .42139 L
.28571 .01472 L
.25714 .01472 L
s
1 0 0 r
.28571 .01472 m
.28571 .34647 L
.31429 .34647 L
.31429 .01472 L
F
0 g
.28571 .01472 m
.28571 .34647 L
.31429 .34647 L
.31429 .01472 L
.28571 .01472 L
s
1 0 0 r
.31429 .01472 m
.31429 .36074 L
.34286 .36074 L
.34286 .01472 L
F
0 g
.31429 .01472 m
.31429 .36074 L
.34286 .36074 L
.34286 .01472 L
.31429 .01472 L
s
1 0 0 r
.34286 .01472 m
.34286 .2894 L
.37143 .2894 L
.37143 .01472 L
F
0 g
.34286 .01472 m
.34286 .2894 L
.37143 .2894 L
.37143 .01472 L
.34286 .01472 L
s
1 0 0 r
.37143 .01472 m
.37143 .21092 L
.4 .21092 L
.4 .01472 L
F
0 g
.37143 .01472 m
.37143 .21092 L
.4 .21092 L
.4 .01472 L
.37143 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .22162 L
.42857 .22162 L
.42857 .01472 L
F
0 g
.4 .01472 m
.4 .22162 L
.42857 .22162 L
.42857 .01472 L
.4 .01472 L
s
1 0 0 r
.42857 .01472 m
.42857 .19665 L
.45714 .19665 L
.45714 .01472 L
F
0 g
.42857 .01472 m
.42857 .19665 L
.45714 .19665 L
.45714 .01472 L
.42857 .01472 L
s
1 0 0 r
.45714 .01472 m
.45714 .136 L
.48571 .136 L
.48571 .01472 L
F
0 g
.45714 .01472 m
.45714 .136 L
.48571 .136 L
.48571 .01472 L
.45714 .01472 L
s
1 0 0 r
.48571 .01472 m
.48571 .14671 L
.51429 .14671 L
.51429 .01472 L
F
0 g
.48571 .01472 m
.48571 .14671 L
.51429 .14671 L
.51429 .01472 L
.48571 .01472 L
s
1 0 0 r
.51429 .01472 m
.51429 .136 L
.54286 .136 L
.54286 .01472 L
F
0 g
.51429 .01472 m
.51429 .136 L
.54286 .136 L
.54286 .01472 L
.51429 .01472 L
s
1 0 0 r
.54286 .01472 m
.54286 .08606 L
.57143 .08606 L
.57143 .01472 L
F
0 g
.54286 .01472 m
.54286 .08606 L
.57143 .08606 L
.57143 .01472 L
.54286 .01472 L
s
1 0 0 r
.57143 .01472 m
.57143 .06466 L
.6 .06466 L
.6 .01472 L
F
0 g
.57143 .01472 m
.57143 .06466 L
.6 .06466 L
.6 .01472 L
.57143 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .04682 L
.62857 .04682 L
.62857 .01472 L
F
0 g
.6 .01472 m
.6 .04682 L
.62857 .04682 L
.62857 .01472 L
.6 .01472 L
s
1 0 0 r
.62857 .01472 m
.62857 .04682 L
.65714 .04682 L
.65714 .01472 L
F
0 g
.62857 .01472 m
.62857 .04682 L
.65714 .04682 L
.65714 .01472 L
.62857 .01472 L
s
1 0 0 r
.65714 .01472 m
.65714 .05396 L
.68571 .05396 L
.68571 .01472 L
F
0 g
.65714 .01472 m
.65714 .05396 L
.68571 .05396 L
.68571 .01472 L
.65714 .01472 L
s
1 0 0 r
.68571 .01472 m
.68571 .04325 L
.71429 .04325 L
.71429 .01472 L
F
0 g
.68571 .01472 m
.68571 .04325 L
.71429 .04325 L
.71429 .01472 L
.68571 .01472 L
s
1 0 0 r
.71429 .01472 m
.71429 .02898 L
.74286 .02898 L
.74286 .01472 L
F
0 g
.71429 .01472 m
.71429 .02898 L
.74286 .02898 L
.74286 .01472 L
.71429 .01472 L
s
1 0 0 r
.74286 .01472 m
.74286 .02542 L
.77143 .02542 L
.77143 .01472 L
F
0 g
.74286 .01472 m
.74286 .02542 L
.77143 .02542 L
.77143 .01472 L
.74286 .01472 L
s
1 0 0 r
.77143 .01472 m
.77143 .01472 L
.8 .01472 L
.8 .01472 L
F
0 g
.77143 .01472 m
.77143 .01472 L
.8 .01472 L
.8 .01472 L
.77143 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .02185 L
.82857 .02185 L
.82857 .01472 L
F
0 g
.8 .01472 m
.8 .02185 L
.82857 .02185 L
.82857 .01472 L
.8 .01472 L
s
1 0 0 r
.82857 .01472 m
.82857 .02185 L
.85714 .02185 L
.85714 .01472 L
F
0 g
.82857 .01472 m
.82857 .02185 L
.85714 .02185 L
.85714 .01472 L
.82857 .01472 L
s
1 0 0 r
.85714 .01472 m
.85714 .01472 L
.88571 .01472 L
.88571 .01472 L
F
0 g
.85714 .01472 m
.85714 .01472 L
.88571 .01472 L
.88571 .01472 L
.85714 .01472 L
s
1 0 0 r
.88571 .01472 m
.88571 .01472 L
.91429 .01472 L
.91429 .01472 L
F
0 g
.88571 .01472 m
.88571 .01472 L
.91429 .01472 L
.91429 .01472 L
.88571 .01472 L
s
1 0 0 r
.91429 .01472 m
.91429 .01472 L
.94286 .01472 L
.94286 .01472 L
F
0 g
.91429 .01472 m
.91429 .01472 L
.94286 .01472 L
.94286 .01472 L
.91429 .01472 L
s
1 0 0 r
.94286 .01472 m
.94286 .01472 L
.97143 .01472 L
.97143 .01472 L
F
0 g
.94286 .01472 m
.94286 .01472 L
.97143 .01472 L
.97143 .01472 L
.94286 .01472 L
s
1 0 0 r
.97143 .01472 m
.97143 .01828 L
1 .01828 L
1 .01472 L
F
0 g
.97143 .01472 m
.97143 .01828 L
1 .01828 L
1 .01472 L
.97143 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo002Hooooo`03oa0@4?lb<S;o410@00;o000000?oA4A4olc<
c?ooool0Boooool009Sooooo00?o0000oiRHV?o^k^h00_ooool00on7QhOo410@ooooo`1;ooooo`00
WOooool00onj^[[o0000ooooo`1;ooooo`00V?ooool00oo<c<coA4A4o`000003o`000003oiRHV?oo
oooooooo04[ooooo002Hooooo`05o`000?n7QhOo^[ZjokZj^_o<c<`0C_ooool009Sooooo00?o0000
oiRHV?ooool00_ooool00oo<c<co410@ooooo`1;ooooo`00V?ooool01oo<c<coA4A4o`000?l0003o
410@oc8b<_l00000C?ooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00K_ooool4o`000003oa0@4?oooooooooo
01cooooo1_l0000Oooooo`05ojVYZOlQ8B7o0000o`000?mVIVH08Oooool2o`000003oa0@4?oooooo
oooo00[ooooo001`ooooo`03o`000?oooooooooo01kooooo00?oV9RHo`000?oMgMd00_ooool00ol@
413oooooooooo`0Mooooo`06oa0@4?o<c<cooooooooooomgMgOoIVIV8Oooool00ol0003ooooooooo
o`0;ooooo`00L?ooool00ol0003oooooooooo`0Oooooo`03ohN7QolQ8B7ok^k^02Kooooo00?o0000
ooooooooool06oooool6o`0000cooooo001`ooooo`03o`000?oooooooooo023ooooo00?oZJVYob4Q
8Oo^k^h09Oooool00ol0003oooooooooo`0Kooooo`05odA4A?nj^[[oooooooooool000003Oooool0
073ooooo00?o0000ooooooooool08Oooool00onHV9So<S8booooo`0Sooooo`03ojVYZOm4A4Cooooo
01cooooo00GogMgMob4Q8Oooooooooooo`00000=ooooo`00L?ooool00ol0003oooooooooo`0Roooo
o`03odA4A?mgMgOooooo023ooooo00Co8B4Qo`000?l0003ogMgM7_ooool01?mgMgOoV9RHooooool0
000=ooooo`00L?ooool00ol0003oooooooooo`0Rooooo`03omgMgOl@413ooooo02;ooooo00?oZJVY
oc8b<_ooool07Oooool01?o^k^ko8B4Qooooool0000=ooooo`00L?ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07Oooool00omgMgOoV9RHo`00000=
ooooo`00K_ooool00ol0003oA4A4o`00000Pooooo`06o`000?n7QhOok^k^oooooonHV9SoEEEE7ooo
ool01_lQ8B7o^[ZjooooooooooooIVIVoc8b<Qoooooo00?ok^k^oc8b<_l000003Oooool006kooooo
00?oc<c<oeEEEOl000008?ooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kQoooooo00Ko^[ZjodA4
A?l0003o0000odA4A?o^k^hPooooo`03oiRHV?l@413ooooo00cooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00@oooool01?nHV9So0000o`000?nHV9P6oooooigo00000Oooool004;ooooo00Ko
^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00
@_ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?o0000ooooooooool0M_ooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`7o00000Oooool004;ooooo00Ko
0000onk^k_ooooooooooonk^k_l00005oooooigo00000Oooool004;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Co0000ool00?oo003oo`001_l00003oooo
o`[o00005Oooool1o`00007ooooo0012ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool000Go00009oooool1o`00007ooooo0012ooooo`06o`000?o^k^kooooooooo
ooo^k^ko00001Oooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oooooooooo02Wooooo0Ol00001ooooo`00@_ooool0
1_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00
ool00002ool00004o`000?oo003oo`00ool000Ko0000:oooool1o`00007ooooo0012ooooo`06okZj
^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Co0000ool00?oo003oo`002_l00003ool00003o`000?oooooooooo
02kooooo0Ol00001ooooo`00@oooool01?nHV9So0000o`000?nHV9P6ooooo`03o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Sooooo1Ol0000`ooooo`7o00000Oooool004gooooo00?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool000Go0000?Oooool1o`00007ooooo001=ooooo`03o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`0o
ooooo`7o00000Oooool004gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oooooooooo03oooooo0Ol00001ooooo`00<?ooool01?nHV9So0000
o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Kooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003ooooo
ooooo`0oooooo`7o00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o
00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00004o`000?oo
003oo`00ool000Ko0000@Oooool1o`00007ooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9So
A4A41Oooool00omEEEGo0000oeEEE@08ooooo`03o`000?oooooooooo00Gooooo00?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000016ooooo`7o00000Oooool002oooooo00Ko
0000onk^k_ooooooooooonk^k_l0000@ooooo`03o`000?oooooooooo00Gooooo00?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000015ooooo`;o00000Oooool002oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000016ooooo`7o00000Oooool0
02oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000016ooooo`7o
00000Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000@ooooo`03o`000?oooooooooo
00Gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000016ooooo`7o
00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@@ooooo`03o`000?oooooooooo
00Gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000016ooooo`7o
00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X>ooooo`03o`000?m4A4Co0000
00Oooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
0005o`0000Coo`001Ol00016ooooo`7o00000Oooool0033ooooo00CoV9RHo`000?l0003oV9RH3ooo
ool00oo<c<coEEEEo`000007ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ooooooooooooooooo`000004ool00003o`000?oooooooooo
04Sooooo0Ol00001ooooo`00COooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00004o`000?ooooooooooooooo`Ko0000B_ooool1o`00007ooooo001=
ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ooooooooool0DOooool1o`00007ooooo001=ooooo`03o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool0DOooool1o`00007o
oooo001=ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ooooooooool0DOooool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRH
V0Kooooo00?oEEEEo`000?mEEED01Oooool6o`0000Gooooo00?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`1Aooooo`7o00000Ooo
ool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001Oooool00onHV9So0000
omgMg@02ooooo`03oa0@4?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`1Aooooo`7o00000Oooool002oo
oooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?oQhN7
ob4Q8Oo^k^h01oooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oooooooooo057ooooo0Ol00001ooooo`00;oooool01_l0003ok^k^oooo
ooooooook^k^o`0000oooooo00?oZJVYob4Q8Oo^k^h01_ooool00ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooooooo053ooooo0_l00001
ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?oV9RHoc8b
<_ooool01Oooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Co0000ool00?oo003oo`001_l0
001Cooooo`7o00000Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?
ooooo`03odA4A?mgMgOooooo00Cooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l00000F?ooool1o`00007ooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko
00004Oooool00ooMgMgo410@ooooo`04ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00004o`000?oo003oo`00ool000Ko00000ooo00000ol0
003oooooooooo`1Fooooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@B
ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ooooo`05o`000?oo
003oo`00ool00?l00000F?ooool1o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o
^[Zj3Oooool01_l0003oQhN7onk^k_ooooooV9RHoeEEE@Gooooo00?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ooooo`Go0000F?ooool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0kooooo00Ko
ZJVYoc8b<_l0003o0000oeEEEOo^k^h5ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000HOooool1o`00
007ooooo001=ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l00000HOooool1o`00007ooooo001=ooooo`03
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l00000HOooool1o`00007ooooo001=ooooo`03o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l00000HOooool1o`00007ooooo001=ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000HOooool1o`00
007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01_ooool01OnY
ZJWo8B4Qo`000?l0003oIVIV00Gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00001Qooooo`7o00000Ooo
ool0013ooooo00?o^[Zjoc8b<_ooool03_ooool00olb<S;o^[Zjooooo`0;ooooo`06okZj^_lQ8B7o
gMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo00Ko410@olc<c?ooooooooooogMgMomVIVH4oooo
o`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l00000HOooool1o`00007ooooo000@ooooo`03oc8b<_nj^[[ooooo
00kooooo00?o^[Zjoc8b<_ooool02oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?o
EEEEo`000?mEEED02oooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
HOooool1o`00007ooooo000?ooooo`03olc<c?lb<S;ooooo013ooooo00?o<S8bolc<c?ooool02_oo
ool01_l0003ok^k^ooooooooooook^k^o`0001?ooooo00?o0000ooooooooool00_ooool00ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
0ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o0000063ooooo0_l00001ooooo`000_ooool01Ol@413o0000o`000?l0003o410@
00Sooooo00?oIVIVojVYZOooool01?ooool00ol@413o<S8boa0@4002o`000003odA4A?o<c<cooooo
00Cooooo00?oV9RHofIVI_ooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
013ooooo00?oZJVYodA4A?ooool00oooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo0005o`00067ooooo0Ol00001ooooo`001?ooool00ol0003o
ooooooooo`08ooooo`03oc8b<_oooooooooo00Cooooo00?o0000oiRHV?o^k^h00_ooool00on7QhOo
410@ooooo`04ooooo`03onk^k_lb<S;ooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0>ooooo`04ob4Q8Ol0003o0000omgMg@Cooooo00?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool0Hoooool1o`00
007ooooo0004ooooo`03o`000?oooooooooo00Sooooo00?o<S8booooooooool02Oooool00onj^[[o
0000ooooo`05ooooo`03o`000?oooooooooo00Wooooo00Ko0000onk^k_ooooooooooonk^k_l0000B
ooooo`03ojVYZOlb<S;ooooo00?ooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool0Hoooool1o`00007ooooo0004oooo
o`?o000000?o410@ogMgMoo^k^h01Oooool00olb<S;oooooooooo`04ooooo`03olc<c?m4A4Co0000
00?o000000?oV9RHooooooooool01?ooool00ol0003oooooooooo`09ooooo`06odA4A?nHV9Sooooo
oooooonHV9SoA4A44oooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooooooo06?ooooo0Ol0
0001ooooo`001?ooool01_l0003oooooooooooo^k^koMgMgoeEEE@Gooooo00?o8B4Qooooooooool0
1?ooool01Ol0003oQhN7okZj^_nj^[[oc<c<00Sooooo00?o0000ooooooooool02Oooool01_nj^[[o
8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00Ko8B4QokZj^_ooooooooooofIVI_lb<S84ooooo`03o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oooooooooo06?ooooo0Ol00001ooooo`001?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o<S8bonk^k_ooool01?ooool00ol0003oV9RHooooo`02ooooo`03olc<c?l@
413ooooo00Cooooo00?ogMgMoc8b<_ooool02oooool01?nHV9So0000o`000?nHV9P?ooooo`06okZj
^_m4A4Co0000o`000?m4A4Cok^k^1?ooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`1Sooooo`7o00000Oooool000Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03ofIVI_nHV9Sooooo00Co
oooo00Ooc<c<odA4A?l0003o0000oa0@4?lb<S;o000000Gooooo00?oV9RHofIVI_ooool0:?ooool0
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oooooooooo`1Sooooo`7o00000Oooool000Cooooo00Ko0000ooooooooooook^k^ogMgMomE
EED5ooooo`03omgMgOlQ8B7ooooo013ooooo00?o410@olc<c?ooool0:?ooool00ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003ooooooooo
o`1Sooooo`7o00000Oooool000;ooooo00?o410@o`000?l000000_l000000ol@413oMgMgonk^kP06
ooooo`03oc8b<_nj^[[ooooo00kooooo00?o^[Zjoc8b<_ooool0:Oooool00ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`1S
ooooo`7o00000Oooool0013ooooo00?o^[Zjoc8b<_ooool03_ooool00olb<S;o^[Zjooooo`0Yoooo
o`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000003ool00003o`000?oo003oo`0000;oo`001Ol00004ool00003o`000?oooooooooo06?o
oooo0Ol00001ooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Wo
oooo0_l000000ol@413oooooooooo`02ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`00
00Go0000ooooooooooooooooo`000004ool00003o`000?oooooooooo06?ooooo0Ol00001ooooo`00
;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol0000:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003ooooooooooooooooo0000
00Coo`0000?o0000ooooooooool0Hoooool1o`00007ooooo000_ooooo`06odA4A?nHV9Sooooooooo
oonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`Ko00001?ooool00ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0
003oo`00ool00002ool00004o`000?ooooooooooooooo`Ko0000IOooool1o`00007ooooo000_oooo
o`06o`000?o^k^koooooooooooo^k^ko00003_ooool01Om4A4Co^[Zjoooooooooooo000000Gooooo
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000?oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`1[ooooo`;o00000Ooo
ool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`05omgMgOlQ8B7o
ooooooooool000001Oooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00003o`000?oooooo
oooo06cooooo0Ol00001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00gooooo00CoMgMgoiRHV?oooooo00001Oooool00ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool0
0003o`000?oooooooooo06cooooo0Ol00001ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^
o`0000oooooo00Cok^k^ob4Q8Ooooooo00001Oooool00ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002
ool00003o`000?oooooooooo06cooooo0Ol00001ooooo`00;oooool01_m4A4CoV9RHoooooooooooo
V9RHodA4A13ooooo00?oMgMgoiRHV?l000001Oooool00ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002
ool00003o`000?oooooooooo06cooooo0Ol00001ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo
8B4QokZj^Q3ooooo00?ok^k^oc8b<_l000001Oooool00ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002
ool00003o`000?oooooooooo06cooooo0Ol00001ooooo`00<?ooool01?nHV9So0000o`000?nHV9PB
ooooo`03oiRHV?l@413ooooo00Cooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oooooooooo`1/ooooo`7o00000Oooool004gooooo00?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`1/ooooo`7o00000Oooool004gooooo00?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`001_l0001^
ooooo`7o00000Oooool004gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ooooooooool0LOooool1o`00007o
oooo001=ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000003ool00003o`000?oooooooooo077ooooo0Ol00001ooooo`00<?ooool0
1?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Kooooo00GoV9RHoa0@4?l0003o0000
ofIVIP05ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000003ool00003o`000?oooooooooo077ooooo0Ol00001ooooo`00;oooool0
1_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`06oa0@4?n7QhOooooooooooomg
MgOoIVIV1?ooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000000ooo00000ol0003oooooooooo`1aooooo`7o00000Oooool002oooooo
00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00_ooooo00?o0000oooo
ooooool00_ooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000000ooo00000ol0003oooooooooo`1aooooo`7o00000Oooool002oooooo
00Ko0000onk^k_ooooooooooonk^k_l0000Booooo`03onk^k_l0003ooooo00?ooooo00?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?o
o`0000?o0000ooooooooool0L?ooool2o`00007ooooo000_ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03?ooool01_l@413oV9RHooooooooooooMgMgofIVIPCooooo1_l00003ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ooooooooool0
LOooool1o`00007ooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?oo
ool01Ol0003o8B4Qo`000?l0003oIVIV00Gooooo00?o0000ooooooooool00_ooool5o`0000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000?oo`0000?o0000ooooooooool0LOooool1o`00007ooooo000_oooo
o`06o`000?o^k^koooooooooooo^k^ko00003_ooool00ol0003oooooooooo`07ooooo`;o00001ooo
ool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oooooooooo
077ooooo0Ol00001ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000?oo`0000?o0000ooooooooool0LOooool1o`00007ooooo000_ooooo`06okZj
^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo1_l00003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oooooooooo`1aooooo`7o00000Ooo
ool0033ooooo00CoV9RHo`000?l0003oV9RH3oooool5o`0000Gooooo0_l0000<ooooo`05o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000003ool00003o`000?oooooooooo077ooooo0Ol00001ooooo`00COooool00ol0003o
ooooooooo`0;ooooo`05o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`002Ol0001cooooo`7o00000Oooool004gooooo0_l0000<ooooo`Go00001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool0NOooool1o`00007ooooo001=oooo
o`03o`000?oooooooooo00oooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ooooooooool0NOooool1o`00007ooooo001=ooooo`03o`000?oooooooooo
00oooooo00?o0000ool00?oo00000_oo00001?l0003oo`00ool00?oo0006o`0007_ooooo0Ol00001
ooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Kooooo00Kok^k^
oeEEEOl0003o0000oeEEEOo^k^h4ooooo`;o00004?ooool00ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l00000P?ooool1o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ
8B7o^[Zj1Oooool3o`0000Kooooo0_mgMgL2ooooo`03ogMgMomEEEGooooo00?ooooo00?o0000oooo
ooooool03oooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000P?ooool1
o`00007ooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEE
E@06ooooo`03ob4Q8Ooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000020ooooo`7o0000
0Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`03o`000?o^k^kooooo00;o
oooo00?o0000ooooooooool00_ooool2o`00013ooooo00?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000007oooooo0_l00001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00cooooo00Ko0000oeEEEOo^k^koooooogMgMomEEED4ooooo`03o`000?oooooo
oooo00oooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000083ooooo0Ol0
0001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Ko0000
ogMgMol0003o0000oeEEEOo^k^h4ooooo`03o`000?oooooooooo00oooooo00?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o0000083ooooo0Ol00001ooooo`00;oooool01_l0003ok^k^
ooooooooooook^k^o`0000kooooo00?oA4A4oiRHV?ooool01oooool2o`00013ooooo00?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o0000083ooooo0Ol00001ooooo`00;oooool01_m4
A4CoV9RHooooooooooooV9RHodA4A0kooooo00?o^[Zjob4Q8Oooool01oooool00ol0003ooooooooo
o`0?ooooo`Ko00000ooo00000ol0003oooooooooo`1nooooo`7o00000Oooool002oooooo00Ko^[Zj
ob4Q8OoMgMgogMgMob4Q8Onj^[X?ooooo`03oeEEEOlb<S;ogMgM00Kooooo00?o0000ooooooooool0
5?ooool01Ol0003oo`00ool00?oo003o0000083ooooo0Ol00001ooooo`00<?ooool01?nHV9So0000
o`000?nHV9PAooooo`04oiRHV?lQ8B7o0000ob4Q8@Cooooo0_l0000Eooooo`05o`000?oo003oo`00
ool00?l00000P?ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo01Cooooo00Go0000ool0
0?oo003oo`00o`000020ooooo`7o00000Oooool004gooooo0_l0000Eooooo`Go0000P?ooool1o`00
007ooooo001=ooooo`03o`000?oooooooooo09Wooooo0Ol00001ooooo`00COooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`7o00000Oooool004goooooWOl00001ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00001\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-2.18353, -0.647297, 0.028043, \
0.00718731}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The plot below compares the mixed level spacing histogram to the \
theoretical distributions for Poisson statistics and for 2 sets of GOE data.  \
At high values of kick strength (large k) the histogram should match the 2 \
GOE curve.  At low kick strengths there are degeneracies that lead to \
deviations from Poisson statistics.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[QHist2, Curves2, AspectRatio \[Rule] 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.56125e-17 0.228571 0.0238095 0.952381 [
[.22857 -0.0125 -6.78125 -18 ]
[.22857 -0.0125 6.78125 0 ]
[.45714 -0.0125 -6.78125 -18 ]
[.45714 -0.0125 6.78125 0 ]
[.68571 -0.0125 -6.78125 -18 ]
[.68571 -0.0125 6.78125 0 ]
[.91429 -0.0125 -6.78125 -18 ]
[.91429 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .02381 -13.5625 -9 ]
[-0.0125 .02381 0 9 ]
[-0.0125 .21429 -32.6875 -9 ]
[-0.0125 .21429 0 9 ]
[-0.0125 .40476 -32.6875 -9 ]
[-0.0125 .40476 0 9 ]
[-0.0125 .59524 -32.6875 -9 ]
[-0.0125 .59524 0 9 ]
[-0.0125 .78571 -32.6875 -9 ]
[-0.0125 .78571 0 9 ]
[-0.0125 .97619 -13.5625 -9 ]
[-0.0125 .97619 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -74.9375 -9 ]
[-0.01875 .5 -32.6875 9 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.22857 0 m
.22857 .00625 L
s
gsave
.22857 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.45714 0 m
.45714 .00625 L
s
gsave
.45714 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.68571 0 m
.68571 .00625 L
s
gsave
.68571 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.91429 0 m
.91429 .00625 L
s
gsave
.91429 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.04571 0 m
.04571 .00375 L
s
.09143 0 m
.09143 .00375 L
s
.13714 0 m
.13714 .00375 L
s
.18286 0 m
.18286 .00375 L
s
.27429 0 m
.27429 .00375 L
s
.32 0 m
.32 .00375 L
s
.36571 0 m
.36571 .00375 L
s
.41143 0 m
.41143 .00375 L
s
.50286 0 m
.50286 .00375 L
s
.54857 0 m
.54857 .00375 L
s
.59429 0 m
.59429 .00375 L
s
.64 0 m
.64 .00375 L
s
.73143 0 m
.73143 .00375 L
s
.77714 0 m
.77714 .00375 L
s
.82286 0 m
.82286 .00375 L
s
.86857 0 m
.86857 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02381 m
.00625 .02381 L
s
gsave
-0.0125 .02381 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .21429 m
.00625 .21429 L
s
gsave
-0.0125 .21429 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .40476 m
.00625 .40476 L
s
gsave
-0.0125 .40476 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .59524 m
.00625 .59524 L
s
gsave
-0.0125 .59524 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .78571 m
.00625 .78571 L
s
gsave
-0.0125 .78571 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .97619 m
.00625 .97619 L
s
gsave
-0.0125 .97619 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07143 m
.00375 .07143 L
s
0 .11905 m
.00375 .11905 L
s
0 .16667 m
.00375 .16667 L
s
0 .2619 m
.00375 .2619 L
s
0 .30952 m
.00375 .30952 L
s
0 .35714 m
.00375 .35714 L
s
0 .45238 m
.00375 .45238 L
s
0 .5 m
.00375 .5 L
s
0 .54762 m
.00375 .54762 L
s
0 .64286 m
.00375 .64286 L
s
0 .69048 m
.00375 .69048 L
s
0 .7381 m
.00375 .7381 L
s
0 .83333 m
.00375 .83333 L
s
0 .88095 m
.00375 .88095 L
s
0 .92857 m
.00375 .92857 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.22857 .99375 m
.22857 1 L
s
.45714 .99375 m
.45714 1 L
s
.68571 .99375 m
.68571 1 L
s
.91429 .99375 m
.91429 1 L
s
.125 Mabswid
.04571 .99625 m
.04571 1 L
s
.09143 .99625 m
.09143 1 L
s
.13714 .99625 m
.13714 1 L
s
.18286 .99625 m
.18286 1 L
s
.27429 .99625 m
.27429 1 L
s
.32 .99625 m
.32 1 L
s
.36571 .99625 m
.36571 1 L
s
.41143 .99625 m
.41143 1 L
s
.50286 .99625 m
.50286 1 L
s
.54857 .99625 m
.54857 1 L
s
.59429 .99625 m
.59429 1 L
s
.64 .99625 m
.64 1 L
s
.73143 .99625 m
.73143 1 L
s
.77714 .99625 m
.77714 1 L
s
.82286 .99625 m
.82286 1 L
s
.86857 .99625 m
.86857 1 L
s
.96 .99625 m
.96 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .21429 m
1 .21429 L
s
.99375 .40476 m
1 .40476 L
s
.99375 .59524 m
1 .59524 L
s
.99375 .78571 m
1 .78571 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .07143 m
1 .07143 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .30952 m
1 .30952 L
s
.99625 .35714 m
1 .35714 L
s
.99625 .45238 m
1 .45238 L
s
.99625 .5 m
1 .5 L
s
.99625 .54762 m
1 .54762 L
s
.99625 .64286 m
1 .64286 L
s
.99625 .69048 m
1 .69048 L
s
.99625 .7381 m
1 .7381 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .88095 m
1 .88095 L
s
.99625 .92857 m
1 .92857 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .02381 m
1 .02381 L
s
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
0 .02381 m
0 .50762 L
.02857 .50762 L
.02857 .02381 L
F
0 g
.5 Mabswid
0 .02381 m
0 .50762 L
.02857 .50762 L
.02857 .02381 L
0 .02381 L
s
1 0 0 r
.02857 .02381 m
.02857 .51524 L
.05714 .51524 L
.05714 .02381 L
F
0 g
.02857 .02381 m
.02857 .51524 L
.05714 .51524 L
.05714 .02381 L
.02857 .02381 L
s
1 0 0 r
.05714 .02381 m
.05714 .53048 L
.08571 .53048 L
.08571 .02381 L
F
0 g
.05714 .02381 m
.05714 .53048 L
.08571 .53048 L
.08571 .02381 L
.05714 .02381 L
s
1 0 0 r
.08571 .02381 m
.08571 .55333 L
.11429 .55333 L
.11429 .02381 L
F
0 g
.08571 .02381 m
.08571 .55333 L
.11429 .55333 L
.11429 .02381 L
.08571 .02381 L
s
1 0 0 r
.11429 .02381 m
.11429 .6219 L
.14286 .6219 L
.14286 .02381 L
F
0 g
.11429 .02381 m
.11429 .6219 L
.14286 .6219 L
.14286 .02381 L
.11429 .02381 L
s
1 0 0 r
.14286 .02381 m
.14286 .65238 L
.17143 .65238 L
.17143 .02381 L
F
0 g
.14286 .02381 m
.14286 .65238 L
.17143 .65238 L
.17143 .02381 L
.14286 .02381 L
s
1 0 0 r
.17143 .02381 m
.17143 .56476 L
.2 .56476 L
.2 .02381 L
F
0 g
.17143 .02381 m
.17143 .56476 L
.2 .56476 L
.2 .02381 L
.17143 .02381 L
s
1 0 0 r
.2 .02381 m
.2 .54952 L
.22857 .54952 L
.22857 .02381 L
F
0 g
.2 .02381 m
.2 .54952 L
.22857 .54952 L
.22857 .02381 L
.2 .02381 L
s
1 0 0 r
.22857 .02381 m
.22857 .54571 L
.25714 .54571 L
.25714 .02381 L
F
0 g
.22857 .02381 m
.22857 .54571 L
.25714 .54571 L
.25714 .02381 L
.22857 .02381 L
s
1 0 0 r
.25714 .02381 m
.25714 .4581 L
.28571 .4581 L
.28571 .02381 L
F
0 g
.25714 .02381 m
.25714 .4581 L
.28571 .4581 L
.28571 .02381 L
.25714 .02381 L
s
1 0 0 r
.28571 .02381 m
.28571 .3781 L
.31429 .3781 L
.31429 .02381 L
F
0 g
.28571 .02381 m
.28571 .3781 L
.31429 .3781 L
.31429 .02381 L
.28571 .02381 L
s
1 0 0 r
.31429 .02381 m
.31429 .39333 L
.34286 .39333 L
.34286 .02381 L
F
0 g
.31429 .02381 m
.31429 .39333 L
.34286 .39333 L
.34286 .02381 L
.31429 .02381 L
s
1 0 0 r
.34286 .02381 m
.34286 .31714 L
.37143 .31714 L
.37143 .02381 L
F
0 g
.34286 .02381 m
.34286 .31714 L
.37143 .31714 L
.37143 .02381 L
.34286 .02381 L
s
1 0 0 r
.37143 .02381 m
.37143 .23333 L
.4 .23333 L
.4 .02381 L
F
0 g
.37143 .02381 m
.37143 .23333 L
.4 .23333 L
.4 .02381 L
.37143 .02381 L
s
1 0 0 r
.4 .02381 m
.4 .24476 L
.42857 .24476 L
.42857 .02381 L
F
0 g
.4 .02381 m
.4 .24476 L
.42857 .24476 L
.42857 .02381 L
.4 .02381 L
s
1 0 0 r
.42857 .02381 m
.42857 .2181 L
.45714 .2181 L
.45714 .02381 L
F
0 g
.42857 .02381 m
.42857 .2181 L
.45714 .2181 L
.45714 .02381 L
.42857 .02381 L
s
1 0 0 r
.45714 .02381 m
.45714 .15333 L
.48571 .15333 L
.48571 .02381 L
F
0 g
.45714 .02381 m
.45714 .15333 L
.48571 .15333 L
.48571 .02381 L
.45714 .02381 L
s
1 0 0 r
.48571 .02381 m
.48571 .16476 L
.51429 .16476 L
.51429 .02381 L
F
0 g
.48571 .02381 m
.48571 .16476 L
.51429 .16476 L
.51429 .02381 L
.48571 .02381 L
s
1 0 0 r
.51429 .02381 m
.51429 .15333 L
.54286 .15333 L
.54286 .02381 L
F
0 g
.51429 .02381 m
.51429 .15333 L
.54286 .15333 L
.54286 .02381 L
.51429 .02381 L
s
1 0 0 r
.54286 .02381 m
.54286 .1 L
.57143 .1 L
.57143 .02381 L
F
0 g
.54286 .02381 m
.54286 .1 L
.57143 .1 L
.57143 .02381 L
.54286 .02381 L
s
1 0 0 r
.57143 .02381 m
.57143 .07714 L
.6 .07714 L
.6 .02381 L
F
0 g
.57143 .02381 m
.57143 .07714 L
.6 .07714 L
.6 .02381 L
.57143 .02381 L
s
1 0 0 r
.6 .02381 m
.6 .0581 L
.62857 .0581 L
.62857 .02381 L
F
0 g
.6 .02381 m
.6 .0581 L
.62857 .0581 L
.62857 .02381 L
.6 .02381 L
s
1 0 0 r
.62857 .02381 m
.62857 .0581 L
.65714 .0581 L
.65714 .02381 L
F
0 g
.62857 .02381 m
.62857 .0581 L
.65714 .0581 L
.65714 .02381 L
.62857 .02381 L
s
1 0 0 r
.65714 .02381 m
.65714 .06571 L
.68571 .06571 L
.68571 .02381 L
F
0 g
.65714 .02381 m
.65714 .06571 L
.68571 .06571 L
.68571 .02381 L
.65714 .02381 L
s
1 0 0 r
.68571 .02381 m
.68571 .05429 L
.71429 .05429 L
.71429 .02381 L
F
0 g
.68571 .02381 m
.68571 .05429 L
.71429 .05429 L
.71429 .02381 L
.68571 .02381 L
s
1 0 0 r
.71429 .02381 m
.71429 .03905 L
.74286 .03905 L
.74286 .02381 L
F
0 g
.71429 .02381 m
.71429 .03905 L
.74286 .03905 L
.74286 .02381 L
.71429 .02381 L
s
1 0 0 r
.74286 .02381 m
.74286 .03524 L
.77143 .03524 L
.77143 .02381 L
F
0 g
.74286 .02381 m
.74286 .03524 L
.77143 .03524 L
.77143 .02381 L
.74286 .02381 L
s
1 0 0 r
.77143 .02381 m
.77143 .02381 L
.8 .02381 L
.8 .02381 L
F
0 g
.77143 .02381 m
.77143 .02381 L
.8 .02381 L
.8 .02381 L
.77143 .02381 L
s
1 0 0 r
.8 .02381 m
.8 .03143 L
.82857 .03143 L
.82857 .02381 L
F
0 g
.8 .02381 m
.8 .03143 L
.82857 .03143 L
.82857 .02381 L
.8 .02381 L
s
1 0 0 r
.82857 .02381 m
.82857 .03143 L
.85714 .03143 L
.85714 .02381 L
F
0 g
.82857 .02381 m
.82857 .03143 L
.85714 .03143 L
.85714 .02381 L
.82857 .02381 L
s
1 0 0 r
.85714 .02381 m
.85714 .02381 L
.88571 .02381 L
.88571 .02381 L
F
0 g
.85714 .02381 m
.85714 .02381 L
.88571 .02381 L
.88571 .02381 L
.85714 .02381 L
s
1 0 0 r
.88571 .02381 m
.88571 .02381 L
.91429 .02381 L
.91429 .02381 L
F
0 g
.88571 .02381 m
.88571 .02381 L
.91429 .02381 L
.91429 .02381 L
.88571 .02381 L
s
1 0 0 r
.91429 .02381 m
.91429 .02381 L
.94286 .02381 L
.94286 .02381 L
F
0 g
.91429 .02381 m
.91429 .02381 L
.94286 .02381 L
.94286 .02381 L
.91429 .02381 L
s
1 0 0 r
.94286 .02381 m
.94286 .02381 L
.97143 .02381 L
.97143 .02381 L
F
0 g
.94286 .02381 m
.94286 .02381 L
.97143 .02381 L
.97143 .02381 L
.94286 .02381 L
s
1 0 0 r
.97143 .02381 m
.97143 .02762 L
1 .02762 L
1 .02381 L
F
0 g
.97143 .02381 m
.97143 .02762 L
1 .02762 L
1 .02381 L
.97143 .02381 L
s
.01 w
[ .02 .02 ] 0 setdash
0 .97619 m
.04636 .80135 L
.09692 .64704 L
.14441 .53013 L
.19008 .43843 L
.23869 .359 L
.28548 .29695 L
.33521 .24354 L
.38313 .20198 L
.42923 .16944 L
.47827 .14132 L
.52549 .11939 L
.57089 .10217 L
.61924 .08723 L
.66576 .07555 L
.71523 .06548 L
.76288 .05764 L
.80871 .05149 L
.85749 .04617 L
.90444 .04202 L
.95434 .03845 L
s
.95434 .03845 m
1 .03581 L
s
[ ] 0 setdash
0 .5 m
.02257 .53322 L
.04636 .56001 L
.05885 .57063 L
.07049 .5784 L
.07706 .58189 L
.08326 .58459 L
.09042 .587 L
.09378 .58787 L
.09692 .58854 L
.09982 .58904 L
.10246 .58938 L
.10397 .58953 L
.1054 .58965 L
.10691 .58974 L
.10776 .58977 L
.10856 .5898 L
.10933 .58982 L
.11017 .58982 L
.11169 .58981 L
.11317 .58977 L
.11453 .58971 L
.116 .58961 L
.11762 .58947 L
.12089 .58907 L
.12378 .58861 L
.12642 .58808 L
.13234 .58658 L
.14302 .58274 L
.15492 .57683 L
.16592 .56991 L
.19084 .54958 L
.23796 .49676 L
.28326 .4343 L
.3315 .36272 L
.37792 .29507 L
.42729 .22951 L
.47484 .17551 L
.52057 .13314 L
.56924 .09818 L
.6161 .07335 L
.64171 .0629 L
.6659 .05478 L
.71206 .04317 L
.73591 .0388 L
.76116 .03514 L
.78492 .03243 L
.80662 .03048 L
.82996 .02883 L
.85503 .02747 L
Mistroke
.87786 .02654 L
.90274 .02577 L
.9264 .02523 L
.95158 .02481 L
.97732 .0245 L
Mfstroke
.97732 .0245 m
1 .0243 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00V?ooool00ol@413o<S8boa0@
4002o`000003odA4A?o<c<cooooo04_ooooo002Hooooo`03o`000?nHV9Sok^k^00;ooooo00?oQhN7
oa0@4?ooool0Boooool009gooooo00?o^[Zjo`000?ooool0Boooool009Sooooo00?oc<c<odA4A?l0
00000ol000000onHV9Soooooooooo`1:ooooo`00V?ooool01Ol0003oQhN7okZj^_nj^[[oc<c<04ko
oooo002Hooooo`03o`000?nHV9Sooooo00;ooooo00?oc<c<oa0@4?ooool0Boooool009Sooooo00Oo
c<c<odA4A?l0003o0000oa0@4?lb<S;o000004cooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool006kooooo1?l0
00000ol@413oooooooooo`0Looooo`Ko00007oooool01OnYZJWo8B4Qo`000?l0003oIVIV027ooooo
0_l000000ol@413oooooooooo`0:ooooo`00L?ooool00ol0003oooooooooo`0Nooooo`03oiRHV?l0
003ogMgM00;ooooo00?o410@ooooooooool07Oooool01_l@413oc<c<ooooooooooooMgMgofIVIR7o
oooo00?o0000ooooooooool02oooool0073ooooo00?o0000ooooooooool07oooool00on7QhOo8B4Q
onk^kP0Vooooo`03o`000?oooooooooo01_ooooo1_l0000<ooooo`00L?ooool00ol0003ooooooooo
o`0Pooooo`03ojVYZOlQ8B7ok^k^02Gooooo00?o0000ooooooooool06oooool01Om4A4Co^[Zjoooo
oooooooo000000gooooo001`ooooo`03o`000?oooooooooo027ooooo00?oV9RHoc8b<_ooool08ooo
ool00onYZJWoA4A4ooooo`0Looooo`05omgMgOlQ8B7oooooooooool000003Oooool0073ooooo00?o
0000ooooooooool08_ooool00om4A4CoMgMgooooo`0Pooooo`04ob4Q8Ol0003o0000omgMgAkooooo
00CoMgMgoiRHV?oooooo00003Oooool0073ooooo00?o0000ooooooooool08_ooool00ooMgMgo410@
ooooo`0Rooooo`03ojVYZOlb<S;ooooo01gooooo00Cok^k^ob4Q8Ooooooo00003Oooool0073ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01gooooo
00?oMgMgoiRHV?l000003Oooool006kooooo00?o0000odA4A?l000008?ooool01_l0003oQhN7onk^
k_ooooooV9RHoeEEEAoooooo00Ko8B4QokZj^_ooooooooooofIVI_lb<S8Oooooo`03onk^k_lb<S;o
000000gooooo001^ooooo`03olc<c?mEEEGo0000023ooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^
k^hOooooo`06okZj^_m4A4Co0000o`000?m4A4Cok^k^8?ooool00onHV9So410@ooooo`0<ooooo`00
joooool00>_ooooo003[ooooo`00joooool004goooooWOl00001ooooo`00@oooool01?nHV9So0000
o`000?nHV9P6ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02_ooool1o`00007o
oooo0012ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool00ol0003oooooooooo`2Ioooo
o`7o00000Oooool004;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03o`000?oooooo
oooo07Kooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool1o`00007o
oooo0012ooooo`06o`000?o^k^koooooooooooo^k^ko00001OoooonMo`00007ooooo0012ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00004o`000?oo003oo`00
ool001?o00005?ooool2o`00007ooooo0012ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool000Go00006_ooool4o`0000;ooooo1?l00003ooooo`7o00000Oooool0
04;ooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooo`03o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o
0000ool00?oo00000_oo00001?l0003oo`00ool00?oo0006o`00017ooooo1?l00002ooooo`Go0000
3oooool1o`00007ooooo0012ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
0ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000003ool00003o`000?oo003oo`0000;oo`002_l0000;ooooo`Co00007?ooool1o`00007o
oooo0012ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool00ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Co0000ool00?oo003oo`002_l00003ool0
0003o`000?oooooooooo00Sooooo1?l0000Rooooo`7o00000Oooool004?ooooo00CoV9RHo`000?l0
003oV9RH1_ooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000003ooooo`?o00000_ooool5o`0000Cooooo1?l0000Xoooo
o`7o00000Oooool004gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00004o`000?oo003oo`00ool000Co00002?ooool4o`0002kooooo0Ol00001ooooo`00
COooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`001Ol0
0006ooooo`?o0000=?ooool1o`00007ooooo001=ooooo`03o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooo`000006ooooo`;o0000=oooool1o`00
007ooooo001=ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo0002o`0000?ooooo0_l0000kooooo`7o00000Oooool004gooooo00?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Co0000ool00?oo003oo`001ol000000ooooooo0000o`00000mooooo`7o00000Oooool0
04gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Ko0000ool00?oo003oo`00o`000?ooool3o`00
04;ooooo0Ol00001ooooo`00COooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001?l0003oo`00ool0
0?oo0002o`0004Gooooo0Ol00001ooooo`00COooool00ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0005o`00
04Kooooo0Ol00001ooooo`00COooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0002o`000003ool00?l0
003o000004Kooooo0Ol00001ooooo`00COooool00ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00006o`000?oo003oo`00ool00?l0003oo`000_l000001_oo
003o0000ool00?l0003oo`00o`0004Kooooo0Ol00001ooooo`00COooool00ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00004o`000?oo003oo`00ool000;o
00000ooo0002o`0000;oo`0000?o0000ooooooooool0A?ooool1o`00007ooooo001=ooooo`03o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000003ool000;o00000ooo00000ol0003oooooooooo`14ooooo`7o00000Oooool0
04gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
0002o`0000;oo`0000Ko0000ool00?oo003o0000ool00?l00003ool00003o`000?oooooooooo04Co
oooo0Ol00001ooooo`00COooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000003ool000So00000_oo0005o`0004Kooooo0Ol00001ooooo`00COooool00ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
0ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oooooo
ooooooooool000001?oo00000ol0003oooooooooo`18ooooo`7o00000Oooool004gooooo00?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00004o`000?oo003oo`00ool000;o00000ooo00000ol0003ooooo
ooooo`07o`0004[ooooo0Ol00001ooooo`00COooool00ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_l00004ool00003o`000?oooooo0000057ooooo0Ol00001ooooo`00COoo
ool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?l0003oo`00o`000004ool00003
o`000?oooooo0000057ooooo0Ol00001ooooo`00COooool00ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?o
o`000_l00003ool00003o`000?oo003oo`0000;oo`000_l0001Booooo`7o00000Oooool0033ooooo
00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@05ooooo`Ko00001Oooool00ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
0ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000;oo`0000?o0000ool00?l000000ooo00000ol0003oo`00ool00002ool0
0003o`000?oooooooooo057ooooo0Ol00001ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4Q
okZj^PGooooo0ol00005ooooo`03oiRHV?l0003ogMgM00;ooooo00?o410@ooooooooool00oooool0
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
1ol0003oo`00ool00?oo003o0000ool00?l000000_oo00001Ol0003oo`00ool00?oo003o000000?o
o`000_l0001Cooooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5oooo
o`03oeEEEOl0003oEEEE00Kooooo00?oQhN7ob4Q8Oo^k^h01oooool00ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000002ool00003o`000?oo003o000005?ooooo0Ol0
0001ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000oooooo00?oZJVYob4Q8Oo^k^h0
1_ooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000002ool0
0003o`000?oo003o000005;ooooo0_l00001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00kooooo00?oV9RHoc8b<_ooool01Oooool00ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002o`0000Co
o`0000Co0000ool00?oo003oo`001_l0001Cooooo`7o00000Oooool002oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0?ooooo`03odA4A?mgMgOooooo00Cooooo00?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?l0
003oo`00o`000004ool00004o`000?oo003oo`00ool000;o0000Eoooool1o`00007ooooo000_oooo
o`06o`000?o^k^koooooooooooo^k^ko00004Oooool00ooMgMgo410@ooooo`04ooooo`03o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00004o`000?oo
003oo`00ool000Ko00000ooo00000ol0003oooooooooo`1Fooooo`7o00000Oooool002oooooo00Ko
A4A4oiRHV?oooooooooooiRHV?m4A4@Booooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000?oo`000_l00003ool00003
o`000?oooooooooo00;ooooo00Go0000ool00?oo003oo`00o`00001Hooooo`7o00000Oooool002oo
oooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X=ooooo`06o`000?n7QhOok^k^oooooonHV9SoEEEE
1Oooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
0ooo0002o`0000?oo`0000?o0000ooooooooool00_ooool5o`0005Sooooo0Ol00001ooooo`00<?oo
ool01?nHV9So0000o`000?nHV9P>ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^1Oooool00ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000000_oo00000ol0
003oo`00o`000003ool00003o`000?oooooooooo00Cooooo00?o0000ooooooooool0F?ooool1o`00
007ooooo001=ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Oo0000ool00?oo003o
o`00o`000?oo003o000000;oo`0000Go0000ool00?oo003oo`00o`000005ooooo`03o`000?oooooo
oooo05Wooooo0Ol00001ooooo`00COooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Cooooo00?o0000
ooooooooool0F_ooool1o`00007ooooo001=ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?ooool0
0ol0003oooooooooo`1Jooooo`7o00000Oooool004gooooo00?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002o`0000Coo`0000Go0000ool00?oo003oo`00o`000003oooo
o`03o`000?oooooooooo05_ooooo0Ol00001ooooo`00COooool00ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00
ool00002ool00005o`000?oo003o0000ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00;ooooo00?o0000ooooooooool0G?ooool1o`00007ooooo001=ooooo`03o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00007o`000?oo003oo`00ool0
0?l0003oooooo`00001Oooooo`7o00000Oooool004gooooo00?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Co0000ool00?oo003oo`000_l0001P
ooooo`7o00000Oooool004gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Co0000ool00?oo003oo`000_l0001Pooooo`7o00000Oooool0
04gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000?oo`0000Co0000ool00?oo003oo`000_l00003ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`00001Qooooo`7o00000Oooool004gooooo00?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?o
o`0000Ko0000ool00?oo003o0000ool00?l00003ool00003o`000?oo003oo`0000;oo`001Ol0001Q
ooooo`7o00000Oooool004gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Co0000oooooooooooo0000H_ooool1o`00007ooooo001=oooo
o`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000003ool000;o00000ooo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000oooo
ool00000Hoooool1o`00007ooooo001=ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool000;o00000ooo00001Ol0003oo`00
ool00?oo003o000000Coo`000_l0001Tooooo`7o00000Oooool004gooooo00?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool0
Hoooool1o`00007ooooo001=ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000002ool000;o00001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ooooooooool0Hoooool1o`00007ooooo001=ooooo`03o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000003ool000;o0000IOooool1
o`00007ooooo001=ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000002ool00003o`000?oo003o000006Gooooo0Ol00001ooooo`00COooool00ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00004o`000?oo003oo`00ool000;o0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000000_oo00000ol0003o
o`00o`00001Uooooo`7o00000Oooool004gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001?l0003oo`00ool00?oo0002o`0000;oo`0000?o0000ool00?oo00000_oo
00001ol0003oo`00ool00?oo003o0000ool00?l000000_oo00000ol0003oooooooooo`1Sooooo`7o
00000Oooool004gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo0005o`000005ool00?l0
003oo`00ool00?l00000IOooool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo
00?oEEEEo`000?mEEED02Oooool2o`000003oa0@4?oooooooooo00;ooooo00?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o
0000ool00?oo00000_oo00001?l0003oooooooooooooool2o`0000?oo`0000?o0000ooooooooool0
Hoooool1o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000[o
oooo00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00004o`00
0?ooooooooooooooo`Ko0000IOooool1o`00007ooooo000_ooooo`06odA4A?nHV9SooooooooooonH
V9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`Ko00001?ooool00ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003o0000ool00?l000000ooo00000ol0003o
o`00ool00002ool00005o`000?ooooooooooooooool00000J_ooool1o`00007ooooo000_ooooo`06
o`000?o^k^koooooooooooo^k^ko00003_ooool01Om4A4Co^[Zjoooooooooooo000000Gooooo00?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0002o`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00004o`000?ooooooooooo`0006[ooooo0_l00001ooooo`00;oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00GogMgMob4Q8Oooooooooooo`00
0005ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Co0000oooooooooooo0000Jooo
ool1o`00007ooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool0
1?mgMgOoV9RHooooool00005ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000?o0000
ooooool00000K?ooool1o`00007ooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00003ooo
ool01?o^k^ko8B4Qooooool00005ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`000_l0
001]ooooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@@ooooo`03ogMg
MonHV9So000000Gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo0002
o`0000?oo`0000Go0000ool00?oo003oo`00o`000004ool000;o0000KOooool1o`00007ooooo000_
ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj4?ooool00oo^k^ko<S8bo`000005ooooo`03o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000;oo`0000?o0000ool00?l000000ooo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool0K?ooool1o`00007ooooo000`
ooooo`04oiRHV?l0003o0000oiRHV1;ooooo00?oV9RHoa0@4?ooool01?ooool00ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000002ool00003o`000?oo003o000000?oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oooooooooo06cooooo0Ol00001ooooo`00COooool00ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Oo0000ool00?oo003oo`00o`000?oo003o000000;oo`0000Go0000ool00?oo
003oo`00o`000003ool00004o`000?oo003oo`00ool000;o0000K_ooool1o`00007ooooo001=oooo
o`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000003ool000Ko0000K_ooool1o`00007ooooo000@ooooo`03okZj^_lb<S;ooooo00kooooo
00?o<S8bokZj^_ooool0:Oooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oooooo`00001aooooo`7o00000Ooo
ool0013ooooo00?o<S8bokZj^_ooool03_ooool00onj^[[o<S8booooo`0Yooooo`03o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001?l0003oo`00ool00?oo0002o`0000?oo`0000Go0000ool00?oo003oo`00o`000003ool0
00;o0000L_ooool1o`00007ooooo000?ooooo`03olc<c?lb<S;ooooo013ooooo00?o<S8bolc<c?oo
ool0:?ooool00ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000000ooo00000ol0003oooooooooo`1aooooo`7o00000Oooool000;ooooo00Go
410@o`000?l0003o0000oa0@4008ooooo`03ofIVI_nYZJWooooo00Cooooo00?o410@oc8b<_l@4100
0_l000000om4A4Coc<c<ooooo`04ooooo`03oiRHV?mVIVKooooo02Sooooo00?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;o00001?oo00001Ol0003oo`00ool00?oo003o000000;oo`000_l0001c
ooooo`7o00000Oooool000Cooooo00?o0000ooooooooool02?ooool00olb<S;oooooooooo`04oooo
o`03o`000?nHV9Sok^k^00;ooooo00?oQhN7oa0@4?ooool01?ooool00oo^k^ko<S8booooo`0Xoooo
o`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Wo0000ool00?oo003o
o`00o`000?oo003o0000ool00?l00000Loooool1o`00007ooooo0004ooooo`03o`000?oooooooooo
00Sooooo00?o<S8booooooooool02Oooool00onj^[[o0000ooooo`05ooooo`03o`000?oooooooooo
02Oooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001?l0003oo`00
ool00?oo0002o`0000;oo`0000?o0000ooooooooool0LOooool1o`00007ooooo0004ooooo`?o0000
00?o410@ogMgMoo^k^h01Oooool00olb<S;oooooooooo`04ooooo`03olc<c?m4A4Co000000?o0000
00?oV9RHooooooooool01?ooool00ol0003oooooooooo`0Wooooo`03o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00o`000?oo003o000000Coo`0000Co0000ool00?oo003oo`000_l00002ool00003o`000?oo
oooooooo077ooooo0Ol00001ooooo`001?ooool01_l0003oooooooooooo^k^koMgMgoeEEE@Gooooo
00?o8B4Qooooooooool01?ooool01Ol0003oQhN7okZj^_nj^[[oc<c<00Sooooo00?o0000oooooooo
ool09oooool6o`0000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?l0003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo
00000ol0003oooooooooo`1aooooo`7o00000Oooool000Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03oc8b<_o^k^kooooo00Cooooo00?o0000oiRHV?ooool00_ooool0
0oo<c<co410@ooooo`04ooooo`03omgMgOlb<S;ooooo02Sooooo0_l00003ooooo`Go00001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`000_l00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_l00003ool00003o`000?oooooooooo077ooooo0Ol00001ooooo`001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?oIVIVoiRHV?ooool01?ooool0
1oo<c<coA4A4o`000?l0003o410@oc8b<_l000001Oooool00onHV9SoIVIVooooo`0Xooooo`03o`00
0?oooooo000000Kooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`000_l00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?l0003oo`00o`000003ool0
0003o`000?oooooooooo077ooooo0Ol00001ooooo`001?ooool01_l0003oooooooooooo^k^koMgMg
oeEEE@Gooooo00?ogMgMob4Q8Oooool04?ooool00ol@413oc<c<ooooo`0Xooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool000;o00000_oo00001Ol0003oo`00ool00?oo003o0000
07?ooooo0Ol00001ooooo`000_ooool00ol@413o0000o`000002o`000003oa0@4?mgMgOok^k^00Ko
oooo00?o<S8bokZj^_ooool03_ooool00onj^[[o<S8booooo`0Yooooo`05o`000?oooooooooooooo
ool000001?ooool6o`0000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`000_l00002ool00005o`000?oo003oo`00ool00?l00000Loooool1o`00007ooooo000@
ooooo`03okZj^_lb<S;ooooo00kooooo00?o<S8bokZj^_ooool0:Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo00Go0000ool00?oo003oo`00o`000003ool000;o00000ooo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003ooooo
ooooo`1aooooo`7o00000Oooool004gooooo0_l00004ooooo`03o`000?oooooooooo00Gooooo00Go
0000ool00?oo003oo`00o`000003ool000;o00000ooo00001?l0003oo`00ool00?oo0002o`0000?o
o`001Ol0001cooooo`7o00000Oooool004gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`Go00000_oo00000ol0003oo`00o`000003ool00005o`000?oo003o0000o`000?oo
00001Ol0001gooooo`7o00000Oooool004gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`07ooooo`06o`000?oo003oo`00o`000?oo003o00000ooo0002o`0000?oo`0000?o0000oooo
ooooool0NOooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oo`00ool00002ool00004o`000?oo003oo`00ool000Ko0000Noooool1o`00
007ooooo001=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;o0000P?ooool1o`00007ooooo000`ooooo`04oiRH
V?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01_ooool01_o^k^koEEEEo`000?l0003oEEEE
onk^kPCooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oo003o
000000;oo`000ol000000ooo003o0000ooooo`1oooooo`7o00000Oooool002oooooo00Ko^[Zjob4Q
8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001_ooool2ogMgM`;ooooo00?oMgMgoeEEEOooool00ooo
ool00ol0003oooooooooo`09ooooo`?o00000oooool00ol0003oo`00o`000003o`0000?oo`0000?o
0000ooooooooool0O_ooool1o`00007ooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A4
1Oooool00omEEEGo0000oeEEE@06ooooo`03ob4Q8Ooooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0<ooooo`Ko00000_oo00001Ol0003oo`00ool00?oo003o0000083o
oooo0Ol00001ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00?o0000onk^
k_ooool00_ooool00ol0003oooooooooo`02ooooo`;o00004?ooool2o`0000?oo`0000Go0000ool0
0?oo003oo`00o`00001oooooo`;o00000Oooool002oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0<ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE1?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000020ooooo`7o0000
0Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`06o`000?mg
MgOo0000o`000?mEEEGok^k^1?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000020ooooo`7o00000Oooool002oooooo00Ko0000onk^k_oo
ooooooooonk^k_l0000>ooooo`03odA4A?nHV9Sooooo00Oooooo00?o0000ooooooooool03oooool0
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000P?ooool1o`00007ooooo000_
ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A43_ooool00onj^[[o8B4Qooooo`07ooooo`03o`00
0?oooooooooo00kooooo1ol00003ool00003o`000?oooooooooo07kooooo0Ol00001ooooo`00;ooo
ool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Poooooo00?oEEEEoc8b<_oMgMd01_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00Go0000ool00?oo003oo`00o`000020oooo
o`7o00000Oooool0033ooooo00CoV9RHo`000?l0003oV9RH4Oooool01?nHV9So8B4Qo`000?lQ8B44
ooooo`03o`000?oooooooooo01Cooooo00Go0000ool00?oo003oo`00o`000020ooooo`7o00000Ooo
ool004gooooo0_l0000Eooooo`05o`000?oo003oo`00ool00?l00000P?ooool1o`00007ooooo001=
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool01Ol0003oo`00ool00?oo
003o0000083ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Gooooo1Ol00020ooooo`7o00000Oooool004gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`2;ooooo`7o00000Oooool004gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`2;ooooo`7o00000Oooool004gooooo00?o0000ooooooooool0VOooool1o`00007ooooo
001=ooooo`03o`000?oooooooooo09Wooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo08cooooo0Ol00001ooooo`00COooool2o`0000_ooooo00?o0000oooo
ooooool0S?ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0SOooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
SOooool1o`00007ooooo001=ooooo`03o`000?oooooooooo09Wooooo0Ol00001ooooo`00COooool0
0ol0003oooooooooo`2Iooooo`7o00000Oooool004gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`2>ooooo`7o00000Oooool004gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`2>ooooo`7o00000Oooool004gooooo0_l00008ooooo`03o`000?oooooooooo08oooooo
0Ol00001ooooo`00COooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08oooooo0Ol0
0001ooooo`00COooool00ol0003oooooooooo`2Iooooo`7o00000Oooool004gooooo00?o0000oooo
ooooool0VOooool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`00
0?mEEED01_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPCooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2@ooooo`7o00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q
8Onj^[X5ooooo`?o00001_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`2@ooooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oo
oooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0TOooool1
o`00007ooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00003_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`03o`000?oooooooooo093ooooo0_l0
0001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00KoEEEE
ogMgMoooooooooooogMgMomEEED4ooooo`03o`000?oooooooooo09Wooooo0Ol00001ooooo`00;ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?ogMgMo`000?l000000_l0
00000ooMgMgoooooooooo`02ooooo`03o`000?oooooooooo09Wooooo0Ol00001ooooo`00;oooool0
1_l0003ok^k^ooooooooooook^k^o`0000kooooo00Ko<S8bofIVI_o^k^kok^k^ofIVI_lb<S84oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0TOooool1o`00007ooooo000_ooooo`06
odA4A?nHV9SooooooooooonHV9SoA4A43_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Aooooo`7o00000Oooool0
02oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X>ooooo`06oc8b<_mVIVKok^k^onk^k_mVIVKo
<S8b1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09;ooooo0Ol00001ooooo`00
<?ooool01?nHV9So0000o`000?nHV9P?ooooo`06onk^k_m4A4Co0000o`000?m4A4Cok^k^1?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo09;ooooo0Ol00001ooooo`00COooool00ol0
003oooooooooo`2Iooooo`7o00000Oooool004gooooo0_l0002Jooooo`7o00000Oooool004gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`2Cooooo`7o00000Oooool004gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2Cooooo`7o00000Oooool004gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`2Dooooo`7o00000Oooool004gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`2Dooooo`7o00000Oooool004gooooo00?o0000oooooooo
ool0VOooool1o`00007ooooo001=ooooo`03o`000?oooooooooo09Wooooo0Ol00001ooooo`00COoo
ool2o`0000;ooooo00?o0000ooooooooool0UOooool1o`00007ooooo001=ooooo`05o`000?oooooo
ooooooooool00000Uoooool1o`00007ooooo001=ooooo`05o`000?ooooooooooooooool00000Uooo
ool1o`00007ooooo001=ooooo`05o`000?ooooooooooooooool00000Uoooool1o`00007ooooo001=
ooooo`03o`000?oooooooooo09Wooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`2Ioooo
o`7o00000Oooool004gooooo00Co0000oooooooooooo0000V?ooool1o`00007ooooo001=ooooo`04
o`000?ooooooooooo`0009Sooooo0Ol00001ooooo`00COooool3o`0009Wooooo0Ol00001ooooo`00
COooool00ol0003oooooo`00002Iooooo`7o00000Oooool004gooooo00?o0000ooooooooool0VOoo
ool1o`00007ooooo001=ooooo`03o`000?oooooooooo09Wooooo0Ol00001ooooo`00@_ooool4o`00
0003oa0@4?oooooooooo00Cooooo0_l0002Jooooo`7o00000Oooool004Cooooo00?o0000oooooooo
ool01_ooool2o`0009[ooooo0Ol00001ooooo`00A?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo09Wooooo0Ol00001ooooo`00A?ooool00ol0003oooooooooo`06ooooo`;o0000VOoo
ool2o`00007ooooo0014ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0VOooool1
o`00007ooooo0014ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0VOooool1o`00
007ooooo0014ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool1o`00007o
oooo0014ooooo`03o`000?oooooooooo00KoooooWOl00001ooooo`00@_ooool00ol0003oA4A4o`00
002Vooooo`00@_ooool00oo<c<coEEEEo`00002Vooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-2.18353, -0.397368, 0.028043, \
0.00673031}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The code below tests the parity of each of the eigenstates of the Floquet \
matrix, separates the eigenvalues of the even and odd states, computes the \
quasienergies for even and odd states, sorts each set of quasienergies, \
determines the spacings between consecutive quasienergies in each set, \
combines the spacing data from the two sets, normalizes the spacings so that \
the mean spacing is 1, and then generates a histogram of the level spacings.  \
By calculating level spacings only between members of the same parity class \
we avoid the problem of mixing two independent data sets that we encountered \
above.  Note that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " labels the basis vectors from 1 to N instead of from 0 to N-1, as is done \
in the article.  Also, the periodicity of the wavefunction is used in \
constructing the ParityTest function.  Because of these two issues the sum in \
the ParityTest function looks a bit different from the sum for testing parity \
mentioned in the article, but they are equivalent."
}], "Text"],

Cell[BoxData[{
    \(\(ParityTest[
          i_] := \((Sum[
                Abs[Evec[\([i, j]\)] + Evec[\([i, nq - j + 2]\)]]^2, {j, 2, 
                  nq/2}] + Abs[2*Evec[\([i, 1]\)]]^2 + 
              Abs[2*Evec[\([i, nq/2 + 1]\)]]^2 > 1)\);\)\), "\n", 
    \(EvalEven = Eval[\([Select[Range[1, nq], ParityTest[#] &]]\)]; 
    EvalOdd = 
      Eval[\([Select[Range[1, nq], Not[ParityTest[#]] &]]\)];\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(OQnrg = Mod[Im[Log[EvalOdd]], 2*Pi];\)\), "\[IndentingNewLine]", 
    \(\(SOQnrg = Sort[OQnrg];\)\), "\[IndentingNewLine]", 
    \(\(OQSpc = 
        Join[Table[
            SOQnrg[\([i + 1]\)] - SOQnrg[\([i]\)], {i, 1, 
              Length[SOQnrg] - 1}], {SOQnrg[\([1]\)] + 2*Pi - 
              SOQnrg[\([Length[SOQnrg]]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(EQnrg = Mod[Im[Log[EvalEven]], 2*Pi];\)\), "\[IndentingNewLine]", 
    \(\(SEQnrg = Sort[EQnrg];\)\), "\[IndentingNewLine]", 
    \(\(EQSpc = 
        Join[Table[
            SEQnrg[\([i + 1]\)] - SEQnrg[\([i]\)], {i, 1, 
              Length[SEQnrg] - 1}], {SEQnrg[\([1]\)] + 2*Pi - 
              SEQnrg[\([Length[SEQnrg]]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AllQSpc = Join[EQSpc, OQSpc];\)\), "\[IndentingNewLine]", 
    \(\(AllQSpcNorm = AllQSpc/Mean[AllQSpc];\)\), "\[IndentingNewLine]", 
    \(\(int\  = \ Table[0 + i/8, {i, 0, 40}];\)\), "\n", 
    \(QHist1 = 
      Histogram[AllQSpcNorm, HistogramCategories \[Rule] int, 
        HistogramScale \[Rule] 1, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<s\>", "\<P(s)\>"}, 
        RotateLabel \[Rule] False]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-17 0.296296 0.0147151 0.71781 [
[.14815 -0.0125 -16.3438 -18 ]
[.14815 -0.0125 16.3438 0 ]
[.2963 -0.0125 -6.78125 -18 ]
[.2963 -0.0125 6.78125 0 ]
[.44444 -0.0125 -16.3438 -18 ]
[.44444 -0.0125 16.3438 0 ]
[.59259 -0.0125 -6.78125 -18 ]
[.59259 -0.0125 6.78125 0 ]
[.74074 -0.0125 -16.3438 -18 ]
[.74074 -0.0125 16.3438 0 ]
[.88889 -0.0125 -6.78125 -18 ]
[.88889 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .15828 -32.6875 -9 ]
[-0.0125 .15828 0 9 ]
[-0.0125 .30184 -32.6875 -9 ]
[-0.0125 .30184 0 9 ]
[-0.0125 .4454 -32.6875 -9 ]
[-0.0125 .4454 0 9 ]
[-0.0125 .58896 -32.6875 -9 ]
[-0.0125 .58896 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -74.9375 -9 ]
[-0.01875 .30902 -32.6875 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14815 0 m
.14815 .00625 L
s
gsave
.14815 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.2963 0 m
.2963 .00625 L
s
gsave
.2963 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.44444 0 m
.44444 .00625 L
s
gsave
.44444 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.59259 0 m
.59259 .00625 L
s
gsave
.59259 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.74074 0 m
.74074 .00625 L
s
gsave
.74074 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.88889 0 m
.88889 .00625 L
s
gsave
.88889 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.02963 0 m
.02963 .00375 L
s
.05926 0 m
.05926 .00375 L
s
.08889 0 m
.08889 .00375 L
s
.11852 0 m
.11852 .00375 L
s
.17778 0 m
.17778 .00375 L
s
.20741 0 m
.20741 .00375 L
s
.23704 0 m
.23704 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.32593 0 m
.32593 .00375 L
s
.35556 0 m
.35556 .00375 L
s
.38519 0 m
.38519 .00375 L
s
.41481 0 m
.41481 .00375 L
s
.47407 0 m
.47407 .00375 L
s
.5037 0 m
.5037 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56296 0 m
.56296 .00375 L
s
.62222 0 m
.62222 .00375 L
s
.65185 0 m
.65185 .00375 L
s
.68148 0 m
.68148 .00375 L
s
.71111 0 m
.71111 .00375 L
s
.77037 0 m
.77037 .00375 L
s
.8 0 m
.8 .00375 L
s
.82963 0 m
.82963 .00375 L
s
.85926 0 m
.85926 .00375 L
s
.91852 0 m
.91852 .00375 L
s
.94815 0 m
.94815 .00375 L
s
.97778 0 m
.97778 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .15828 m
.00625 .15828 L
s
gsave
-0.0125 .15828 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .30184 m
.00625 .30184 L
s
gsave
-0.0125 .30184 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .4454 m
.00625 .4454 L
s
gsave
-0.0125 .4454 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .58896 m
.00625 .58896 L
s
gsave
-0.0125 .58896 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05061 m
.00375 .05061 L
s
0 .0865 m
.00375 .0865 L
s
0 .12239 m
.00375 .12239 L
s
0 .19417 m
.00375 .19417 L
s
0 .23006 m
.00375 .23006 L
s
0 .26595 m
.00375 .26595 L
s
0 .33773 m
.00375 .33773 L
s
0 .37362 m
.00375 .37362 L
s
0 .40951 m
.00375 .40951 L
s
0 .48129 m
.00375 .48129 L
s
0 .51718 m
.00375 .51718 L
s
0 .55307 m
.00375 .55307 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.14815 .61178 m
.14815 .61803 L
s
.2963 .61178 m
.2963 .61803 L
s
.44444 .61178 m
.44444 .61803 L
s
.59259 .61178 m
.59259 .61803 L
s
.74074 .61178 m
.74074 .61803 L
s
.88889 .61178 m
.88889 .61803 L
s
.125 Mabswid
.02963 .61428 m
.02963 .61803 L
s
.05926 .61428 m
.05926 .61803 L
s
.08889 .61428 m
.08889 .61803 L
s
.11852 .61428 m
.11852 .61803 L
s
.17778 .61428 m
.17778 .61803 L
s
.20741 .61428 m
.20741 .61803 L
s
.23704 .61428 m
.23704 .61803 L
s
.26667 .61428 m
.26667 .61803 L
s
.32593 .61428 m
.32593 .61803 L
s
.35556 .61428 m
.35556 .61803 L
s
.38519 .61428 m
.38519 .61803 L
s
.41481 .61428 m
.41481 .61803 L
s
.47407 .61428 m
.47407 .61803 L
s
.5037 .61428 m
.5037 .61803 L
s
.53333 .61428 m
.53333 .61803 L
s
.56296 .61428 m
.56296 .61803 L
s
.62222 .61428 m
.62222 .61803 L
s
.65185 .61428 m
.65185 .61803 L
s
.68148 .61428 m
.68148 .61803 L
s
.71111 .61428 m
.71111 .61803 L
s
.77037 .61428 m
.77037 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.82963 .61428 m
.82963 .61803 L
s
.85926 .61428 m
.85926 .61803 L
s
.91852 .61428 m
.91852 .61803 L
s
.94815 .61428 m
.94815 .61803 L
s
.97778 .61428 m
.97778 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15828 m
1 .15828 L
s
.99375 .30184 m
1 .30184 L
s
.99375 .4454 m
1 .4454 L
s
.99375 .58896 m
1 .58896 L
s
.125 Mabswid
.99625 .05061 m
1 .05061 L
s
.99625 .0865 m
1 .0865 L
s
.99625 .12239 m
1 .12239 L
s
.99625 .19417 m
1 .19417 L
s
.99625 .23006 m
1 .23006 L
s
.99625 .26595 m
1 .26595 L
s
.99625 .33773 m
1 .33773 L
s
.99625 .37362 m
1 .37362 L
s
.99625 .40951 m
1 .40951 L
s
.99625 .48129 m
1 .48129 L
s
.99625 .51718 m
1 .51718 L
s
.99625 .55307 m
1 .55307 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .07214 L
.03704 .07214 L
.03704 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .07214 L
.03704 .07214 L
.03704 .01472 L
0 .01472 L
s
1 0 0 r
.03704 .01472 m
.03704 .21283 L
.07407 .21283 L
.07407 .01472 L
F
0 g
.03704 .01472 m
.03704 .21283 L
.07407 .21283 L
.07407 .01472 L
.03704 .01472 L
s
1 0 0 r
.07407 .01472 m
.07407 .36788 L
.11111 .36788 L
.11111 .01472 L
F
0 g
.07407 .01472 m
.07407 .36788 L
.11111 .36788 L
.11111 .01472 L
.07407 .01472 L
s
1 0 0 r
.11111 .01472 m
.11111 .41095 L
.14815 .41095 L
.14815 .01472 L
F
0 g
.11111 .01472 m
.11111 .41095 L
.14815 .41095 L
.14815 .01472 L
.11111 .01472 L
s
1 0 0 r
.14815 .01472 m
.14815 .53441 L
.18519 .53441 L
.18519 .01472 L
F
0 g
.14815 .01472 m
.14815 .53441 L
.18519 .53441 L
.18519 .01472 L
.14815 .01472 L
s
1 0 0 r
.18519 .01472 m
.18519 .60332 L
.22222 .60332 L
.22222 .01472 L
F
0 g
.18519 .01472 m
.18519 .60332 L
.22222 .60332 L
.22222 .01472 L
.18519 .01472 L
s
1 0 0 r
.22222 .01472 m
.22222 .55451 L
.25926 .55451 L
.25926 .01472 L
F
0 g
.22222 .01472 m
.22222 .55451 L
.25926 .55451 L
.25926 .01472 L
.22222 .01472 L
s
1 0 0 r
.25926 .01472 m
.25926 .54302 L
.2963 .54302 L
.2963 .01472 L
F
0 g
.25926 .01472 m
.25926 .54302 L
.2963 .54302 L
.2963 .01472 L
.25926 .01472 L
s
1 0 0 r
.2963 .01472 m
.2963 .52005 L
.33333 .52005 L
.33333 .01472 L
F
0 g
.2963 .01472 m
.2963 .52005 L
.33333 .52005 L
.33333 .01472 L
.2963 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .41095 L
.37037 .41095 L
.37037 .01472 L
F
0 g
.33333 .01472 m
.33333 .41095 L
.37037 .41095 L
.37037 .01472 L
.33333 .01472 L
s
1 0 0 r
.37037 .01472 m
.37037 .36501 L
.40741 .36501 L
.40741 .01472 L
F
0 g
.37037 .01472 m
.37037 .36501 L
.40741 .36501 L
.40741 .01472 L
.37037 .01472 L
s
1 0 0 r
.40741 .01472 m
.40741 .30184 L
.44444 .30184 L
.44444 .01472 L
F
0 g
.40741 .01472 m
.40741 .30184 L
.44444 .30184 L
.44444 .01472 L
.40741 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .23293 L
.48148 .23293 L
.48148 .01472 L
F
0 g
.44444 .01472 m
.44444 .23293 L
.48148 .23293 L
.48148 .01472 L
.44444 .01472 L
s
1 0 0 r
.48148 .01472 m
.48148 .27887 L
.51852 .27887 L
.51852 .01472 L
F
0 g
.48148 .01472 m
.48148 .27887 L
.51852 .27887 L
.51852 .01472 L
.48148 .01472 L
s
1 0 0 r
.51852 .01472 m
.51852 .18412 L
.55556 .18412 L
.55556 .01472 L
F
0 g
.51852 .01472 m
.51852 .18412 L
.55556 .18412 L
.55556 .01472 L
.51852 .01472 L
s
1 0 0 r
.55556 .01472 m
.55556 .12669 L
.59259 .12669 L
.59259 .01472 L
F
0 g
.55556 .01472 m
.55556 .12669 L
.59259 .12669 L
.59259 .01472 L
.55556 .01472 L
s
1 0 0 r
.59259 .01472 m
.59259 .10085 L
.62963 .10085 L
.62963 .01472 L
F
0 g
.59259 .01472 m
.59259 .10085 L
.62963 .10085 L
.62963 .01472 L
.59259 .01472 L
s
1 0 0 r
.62963 .01472 m
.62963 .0865 L
.66667 .0865 L
.66667 .01472 L
F
0 g
.62963 .01472 m
.62963 .0865 L
.66667 .0865 L
.66667 .01472 L
.62963 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .03768 L
.7037 .03768 L
.7037 .01472 L
F
0 g
.66667 .01472 m
.66667 .03768 L
.7037 .03768 L
.7037 .01472 L
.66667 .01472 L
s
1 0 0 r
.7037 .01472 m
.7037 .05778 L
.74074 .05778 L
.74074 .01472 L
F
0 g
.7037 .01472 m
.7037 .05778 L
.74074 .05778 L
.74074 .01472 L
.7037 .01472 L
s
1 0 0 r
.74074 .01472 m
.74074 .0262 L
.77778 .0262 L
.77778 .01472 L
F
0 g
.74074 .01472 m
.74074 .0262 L
.77778 .0262 L
.77778 .01472 L
.74074 .01472 L
s
1 0 0 r
.77778 .01472 m
.77778 .01472 L
.81481 .01472 L
.81481 .01472 L
F
0 g
.77778 .01472 m
.77778 .01472 L
.81481 .01472 L
.81481 .01472 L
.77778 .01472 L
s
1 0 0 r
.81481 .01472 m
.81481 .02907 L
.85185 .02907 L
.85185 .01472 L
F
0 g
.81481 .01472 m
.81481 .02907 L
.85185 .02907 L
.85185 .01472 L
.81481 .01472 L
s
1 0 0 r
.85185 .01472 m
.85185 .01472 L
.88889 .01472 L
.88889 .01472 L
F
0 g
.85185 .01472 m
.85185 .01472 L
.88889 .01472 L
.88889 .01472 L
.85185 .01472 L
s
1 0 0 r
.88889 .01472 m
.88889 .01472 L
.92593 .01472 L
.92593 .01472 L
F
0 g
.88889 .01472 m
.88889 .01472 L
.92593 .01472 L
.92593 .01472 L
.88889 .01472 L
s
1 0 0 r
.92593 .01472 m
.92593 .01759 L
.96296 .01759 L
.96296 .01472 L
F
0 g
.92593 .01472 m
.92593 .01759 L
.96296 .01759 L
.96296 .01472 L
.92593 .01472 L
s
1 0 0 r
.96296 .01472 m
.96296 .02046 L
1 .02046 L
1 .01472 L
F
0 g
.96296 .01472 m
.96296 .02046 L
1 .02046 L
1 .01472 L
.96296 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00V?ooool00ol@413o<S8boa0@4002o`000003odA4A?o<c<cooooo04_ooooo002H
ooooo`03o`000?nHV9Sok^k^00;ooooo00?oQhN7oa0@4?ooool0Boooool009gooooo00?o^[Zjo`00
0?ooool0Boooool009Sooooo00?oc<c<odA4A?l000000ol000000onHV9Soooooooooo`1:ooooo`00
V?ooool01Ol0003oQhN7okZj^_nj^[[oc<c<04kooooo002Hooooo`03o`000?nHV9Sooooo00;ooooo
00?oc<c<oa0@4?ooool0Boooool009Sooooo00Ooc<c<odA4A?l0003o0000oa0@4?lb<S;o000004co
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool005Wooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000
oeEEE@06ooooo`05oiRHV?l@413o0000o`000?mVIVH02?ooool4o`000003oa0@4?oooooooooo00Ko
oooo1?l000000ol@413oooooooooo`04ooooo`03oeEEEOl0003oEEEE00Kooooo00GoV9RHoa0@4?l0
003o0000ofIVIP07ooooo`Ko00002?ooool6o`0000Kooooo00?oEEEEo`000?mEEED01_ooool01OnH
V9So410@o`000?l0003oIVIV00Oooooo00GoZJVYob4Q8Ol0003o0000ofIVIP0Aooooo`00F?ooool0
1_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`06oa0@4?n7QhOooooooooooomg
MgOoIVIV2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo0ol00006oooo
o`06oa0@4?n7QhOooooooooooomgMgOoIVIV1_ooool00onHV9So0000omgMg@02ooooo`03oa0@4?oo
oooooooo00Kooooo00?oV9RHo`000?oMgMd00_ooool00ol@413oooooooooo`04ooooo`?o00001_oo
ool01_l@413oQhN7ooooooooooooMgMgofIVIPKooooo00Ko410@olc<c?ooooooooooogMgMomVIVH@
ooooo`00F?ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED02ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_oo
ool00omEEEGo0000oeEEE@0;ooooo`03o`000?oooooooooo00Gooooo00?oQhN7ob4Q8Oo^k^h02ooo
ool00on7QhOo8B4Qonk^kP08ooooo`03oeEEEOl0003oEEEE00_ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0>ooooo`00F?ooool01_l0003ok^k^ooooooooooook^k^o`0001;ooooo
00?ok^k^o`000?ooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo
00?ok^k^o`000?ooool01oooool00onYZJWo8B4Qonk^kP0;ooooo`03ojVYZOlQ8B7ok^k^01Cooooo
00?ok^k^o`000?ooool02_ooool00ol0003oooooooooo`0>ooooo`00F?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00cooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH9ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool01_l@413oV9RHooooooooooooMgMg
ofIVIPWooooo00?oV9RHoc8b<_ooool02oooool00onHV9So<S8booooo`0?ooooo`06oa0@4?nHV9So
oooooooooomgMgOoIVIV2_ooool00onYZJWoA4A4ooooo`0?ooooo`00F?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00cooooo00Go0000ob4Q8Ol0003o0000ofIVIP0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03oooool01Ol0003o8B4Qo`000?l0003oIVIV00_o
oooo00?oA4A4ogMgMoooool02oooool00om4A4CoMgMgooooo`0>ooooo`05o`000?lQ8B7o0000o`00
0?mVIVH02Oooool01?lQ8B7o0000o`000?oMgMd@ooooo`00F?ooool01_l0003ok^k^oooooooooooo
k^k^o`0000kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03Oooool00ooMgMgo410@ooooo`0;ooooo`03omgMgOl@
413ooooo00kooooo00?o0000ooooooooool03Oooool00onYZJWo<S8booooo`0?ooooo`00F?ooool0
1_m4A4CoV9RHooooooooooooV9RHodA4A0kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0>ooooo`00F?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00?o0000oooooooo
ool02_ooool00ol0003oA4A4o`00000:ooooo`03o`000?m4A4Co0000017ooooo00?o0000oooooooo
ool02Oooool01_l0003oQhN7onk^k_ooooooV9RHoeEEE@Sooooo00Ko0000ohN7Qoo^k^kooooooiRH
V?mEEED?ooooo`03o`000?oooooooooo00Wooooo00Ko8B4QokZj^_ooooooooooofIVI_lb<S8@oooo
o`00FOooool01?nHV9So0000o`000?nHV9P?ooooo`Go00002?ooool00oo<c<coEEEEo`00000:oooo
o`03olc<c?mEEEGo0000017ooooo1Ol00007ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^2?oo
ool01_nYZJWo<S8bo`000?l0003oEEEEonk^kPoooooo1Ol00007ooooo`06okZj^_m4A4Co0000o`00
0?m4A4Cok^k^4?ooool00>_ooooo003[ooooo`00joooool004?ooooo00CoV9RHo`000?l0003oV9RH
Y?ooool004;ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5oooooigo00000Oooool004;ooooo
00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`04o`000?ooooooooooo`00007ooooo0012ooooo`06o`000?o^k^koooooooooooo^k^ko
00001OoooonMo`00007ooooo0012ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
2Oooool<o`00007ooooo0012ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001ol00004ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool05?ooool1o`00007ooooo0012ooooo`06o`000?o^k^ko
ooooooooooo^k^ko00001Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ooooooooool02?ooool7o`0001Kooooo0Ol00001ooooo`00@_ooool01_m4A4CoV9RHoooo
ooooooooV9RHodA4A0Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`001ol00005ool00003o`000?oooooooooo02Gooooo0Ol00001ooooo`00
@_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oooooooooo02Gooooo0Ol00001ooooo`00@oooool01?nHV9So
0000o`000?nHV9P6ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`0Uooooo`7o00000Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool00oooool7o`0002Oo
oooo0Ol00001ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0aooooo`7o00000Oooool004gooooo1ol0
0005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0<Oooool1o`00007ooooo001=
ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oooooooooo037ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0aoooo
o`7o00000Oooool004gooooo0_l00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001_l0000cooooo`7o
00000Oooool004gooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo03Kooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`03ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000Oo0000>?oo
ool1o`00007ooooo001=ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0??ooool1
o`00007ooooo001=ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0??ooool1o`00
007ooooo001=ooooo`;o00001?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0looooo`7o00000Oooool004gooooo
00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
1ol0000nooooo`7o00000Oooool004gooooo00?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0@_ooool1o`00007ooooo000`
ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01Oooool6o`0000Gooooo00?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0@_ooool1o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj
1Oooool3o`0000Gooooo00?oV9RHo`000?oMgMd00_ooool00ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo04;ooooo0Ol00001ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Go
oooo00?oEEEEo`000?mEEED01_ooool00on7QhOo8B4Qonk^kP07ooooo`03o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04;o
oooo0Ol00001ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000oooooo00?oZJVYob4Q
8Oo^k^h01_ooool2o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo047ooooo0_l00001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00kooooo00?oV9RHoc8b<_ooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`12ooooo`7o
00000Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03odA4
A?mgMgOooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0@_ooool1o`00007ooooo000_ooooo`06o`000?o^
k^koooooooooooo^k^ko00004Oooool00ooMgMgo410@ooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04;o
oooo0Ol00001ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A1;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`001ol00014oooo
o`7o00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X=ooooo`06o`000?n7QhOo
k^k^oooooonHV9SoEEEE1Oooool2o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`18ooooo`7o00000Oooool0033ooooo00CoV9RHo`000?l0003oV9RH3_ooool01_nYZJWo<S8b
o`000?l0003oEEEEonk^kPGooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo04Sooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0B?ooool1o`00007ooooo001=ooooo`03o`00
0?oooooooooo00?ooooo1ol00005ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`18ooooo`7o00000Oooool004gooooo00?o0000ooooooooool02Ooo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`18ooooo`7o00000Oooool004gooooo00?o0000ooooooooool02Oooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`18ooooo`7o00000Oooool004gooooo0_l0000:ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`001_l00005ool00003o`000?oooooooooo04Sooooo0Ol00001ooooo`00COooool00ol0003o
ooooooooo`09ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo04Sooooo0Ol00001ooooo`00COooool00ol0003ooooo
ooooo`09ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo04Sooooo0Ol00001ooooo`00COooool00ol0003ooooooooo
o`09ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo04Sooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`09
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo04Sooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`09oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo04Sooooo0Ol00001ooooo`004?ooool00onj^[[o<S8booooo`0>ooooo`03
oc8b<_nj^[[ooooo02Wooooo0_l0000:ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo04Sooooo0Ol00001ooooo`00
4?ooool00olb<S;o^[Zjooooo`0>ooooo`03okZj^_lb<S;ooooo02Wooooo00?o0000ooooooooool0
2Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00;ooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`18ooooo`7o00000Oooool000oooooo00?oc<c<oc8b<_ooool04?oo
ool00olb<S;oc<c<ooooo`0;ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED0
2Oooool2o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oooooooooo00;ooooo1ol0001:ooooo`7o00000Oooool000;ooooo00Go
410@o`000?l0003o0000oa0@4008ooooo`03ofIVI_nYZJWooooo00Cooooo00?o410@oc8b<_l@4100
0_l000000om4A4Coc<c<ooooo`04ooooo`03oiRHV?mVIVKooooo00[ooooo00Ko^[Zjob4Q8OoMgMgo
gMgMob4Q8Onj^[X5ooooo`?o00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Wooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Cooooo`7o00000Oooool000Co
oooo00?o0000ooooooooool02?ooool00olb<S;oooooooooo`04ooooo`03o`000?nHV9Sok^k^00;o
oooo00?oQhN7oa0@4?ooool01?ooool00oo^k^ko<S8booooo`0:ooooo`06odA4A?nHV9Sooooooooo
oonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`Ko00001?ooool00ol0003oooooooooo`09
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Doooool1o`00007ooooo0004oooo
o`03o`000?oooooooooo00Sooooo00?o<S8booooooooool02Oooool00onj^[[o0000ooooo`05oooo
o`03o`000?oooooooooo00Wooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`05odA4A?nj
^[[oooooooooool000001Oooool2o`0000[ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`001ol0001Dooooo`;o00000Oooool000Cooooo0ol0
00000ol@413oMgMgonk^kP05ooooo`03oc8b<_oooooooooo00Cooooo00?oc<c<odA4A?l000000ol0
00000onHV9Soooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0<ooooo`05omgMgOlQ8B7oooooooooool000001Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oooooooooo05Wooooo0Ol00001ooooo`001?ooool01_l0003ooooooooo
ooo^k^koMgMgoeEEE@Gooooo00?o8B4Qooooooooool01?ooool01Ol0003oQhN7okZj^_nj^[[oc<c<
00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00gooooo00CoMgMgoiRHV?oooooo00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo
oooo05Wooooo0Ol00001ooooo`001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o<S8bonk^k_ooool01?ooool00ol0003oV9RHooooo`02ooooo`03olc<c?l@413ooooo
00Cooooo00?ogMgMoc8b<_ooool02_ooool01_l0003ok^k^ooooooooooook^k^o`0000oooooo00Co
k^k^ob4Q8Ooooooo00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo05Wooooo
0Ol00001ooooo`001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
IVIVoiRHV?ooool01?ooool01oo<c<coA4A4o`000?l0003o410@oc8b<_l000001Oooool00onHV9So
IVIVooooo`0:ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A44?ooool00omgMgOoV9RHo`000005
ooooo`03o`000?oooooooooo00Wooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0FOooool1o`00007ooooo0004oooo
o`06o`000?ooooooooooonk^k_mgMgOoEEEE1Oooool00ooMgMgo8B4Qooooo`0@ooooo`03oa0@4?o<
c<cooooo00[ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X@ooooo`03onk^k_lb<S;o000000Go
oooo00?o0000ooooooooool02Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Iooooo`7o00000Oooool000;ooooo
00?o410@o`000?l000000_l000000ol@413oMgMgonk^kP06ooooo`03oc8b<_nj^[[ooooo00kooooo
00?o^[Zjoc8b<_ooool03?ooool01?nHV9So0000o`000?nHV9PBooooo`03oiRHV?l@413ooooo00Co
oooo0_l0000:ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo05Wooooo0Ol00001ooooo`004?ooool00onj^[[o<S8b
ooooo`0>ooooo`03oc8b<_nj^[[ooooo02Wooooo00?o0000ooooooooool02Oooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`1Iooooo`7o00000Oooool004gooooo00?o0000ooooooooool02Oooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`1Iooooo`7o00000Oooool004gooooo00?o0000ooooooooool02Oooool00ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1I
ooooo`7o00000Oooool004gooooo00?o0000ooooooooool02Oooool7o`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`001ol0001Koooo
o`7o00000Oooool004gooooo0_l0000@ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Goooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00oooooo00?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`1Oooooo`7o00000Oooool004gooooo00?o0000ooooooooool03ooo
ool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oooooooooo05oooooo0Ol00001ooooo`00COooool0
0ol0003oooooooooo`0?ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Goooool1
o`00007ooooo001=ooooo`03o`000?oooooooooo00oooooo00?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`1Oooooo`7o00000Oooool004gooooo00?o0000ooooooooool03oooool00ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo05oooooo0Ol00001ooooo`00COooool2o`00013ooooo
1_l00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`001ol0001Qooooo`7o00000Oooool004gooooo00?o
0000ooooooooool05?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0IOooool1o`00007ooooo001=ooooo`03o`000?oooooooooo01Cooooo00?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oooooooooo06Gooooo0Ol00001
ooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Kooooo00Kok^k^
oeEEEOl0003o0000oeEEEOo^k^h4ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oooooooooo06Gooooo0Ol00001ooooo`00;ooo
ool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`;oMgMg0_ooool00omgMgOo
EEEEooooo`03ooooo`03o`000?oooooooooo01Cooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oooooooooo06Gooooo0Ol00001ooooo`00;oooool01_m4A4CoV9RH
ooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool00olQ8B7oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0IOooool1o`00007ooooo000_ooooo`06
o`000?o^k^koooooooooooo^k^ko00003_ooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooo
oooo00;ooooo0_l0000Eooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`1Tooooo`;o00000Oooool002oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0<ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE1?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`1Uooooo`7o00000Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<
ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^1?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`1Uooooo`7o0000
0Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`03odA4A?nHV9Sooooo00Oo
oooo00?o0000ooooooooool05?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0IOooool1o`00007ooooo000_ooooo`06odA4A?nHV9SooooooooooonH
V9SoA4A43_ooool00onj^[[o8B4Qooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oooooooooo06Gooooo0Ol00001oooo
o`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Poooooo00?oEEEEoc8b<_oMgMd01_ooool2
o`0001Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oooooo
oooo06Gooooo0Ol00001ooooo`00<?ooool01?nHV9So0000o`000?nHV9PAooooo`04oiRHV?lQ8B7o
0000ob4Q8@Cooooo00?o0000ooooooooool05?ooool00ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0IOooool1o`00007ooooo001=ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oooooo
oooo06Gooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`1Uooooo`7o00000Oooool004go
oooo00?o0000ooooooooool05?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ooooooooool0IOooool1o`00007ooooo001=ooooo`03o`000?oooooooooo01Cooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oooooooooo06Gooooo
0Ol00001ooooo`00COooool2o`0001Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0006o`0006Oooooo0Ol0
0001ooooo`00COooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0J_ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo01Cooooo1ol00005ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Zoooo
o`7o00000Oooool004gooooo00?o0000ooooooooool06_ooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Zooooo`7o
00000Oooool004gooooo00?o0000ooooooooool06_ooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`001ol0001/ooooo`7o00000Oooool004gooooo0_l0000Kooooo`03o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1`ooooo`7o00000Ooo
ool004gooooo00?o0000ooooooooool06_ooool00ol0003oo`00ool00003ool000Oo0000L_ooool1
o`00007ooooo001=ooooo`03o`000?oooooooooo01[ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`1fooooo`7o00000Oooool0033ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omE
EEGo0000oeEEE@06ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^1?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0M_ooool1o`00007ooooo000_
ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo00KoEEEEogMgMooooooo
ooooogMgMomEEED4ooooo`03o`000?oooooooooo01[ooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`1fooooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5
ooooo`03oeEEEOl0003oEEEE00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01[ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1f
ooooo`7o00000Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0001_ooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`1eooooo`;o00000Oooool002oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0<ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE1?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0M_ooool1o`00007ooooo
000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ooMgMgo0000o`00
0002o`000003omgMgOoooooooooo00;ooooo00?o0000ooooooooool06_ooool7o`0007Sooooo0Ol0
0001ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00Ko<S8bofIVI_o^k^ko
k^k^ofIVI_lb<S84ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo0Ol00001ooooo`00;oooool01_m4A4Co
V9RHooooooooooooV9RHodA4A0kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
oooooigo00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X>ooooo`06oc8b<_mV
IVKok^k^onk^k_mVIVKo<S8bX_ooool0033ooooo00CoV9RHo`000?l0003oV9RH3oooool01_o^k^ko
A4A4o`000?l0003oA4A4onk^kZ;ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00001\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-1.68443, -0.784283, 0.0216332, \
0.00892968}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The plot below compares the separated level spacing histogram to \
the theoretical distributions for Poisson statistics and GOE statistics.  For \
weak kicks (k \[TildeTilde] 0) there are degeneracies that cause deviations \
from Poisson statistics, but the deviations are not as bad as for the mixed \
data and they mostly disappear as the kick strength is increased above 0 \
(while still remaining small).  For large k (when the classical system is \
fully chaotic) the data match the GOE distribution.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[QHist1, Curves1, AspectRatio \[Rule] 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-17 0.296296 0.0238095 0.952381 [
[.14815 -0.0125 -16.3438 -18 ]
[.14815 -0.0125 16.3438 0 ]
[.2963 -0.0125 -6.78125 -18 ]
[.2963 -0.0125 6.78125 0 ]
[.44444 -0.0125 -16.3438 -18 ]
[.44444 -0.0125 16.3438 0 ]
[.59259 -0.0125 -6.78125 -18 ]
[.59259 -0.0125 6.78125 0 ]
[.74074 -0.0125 -16.3438 -18 ]
[.74074 -0.0125 16.3438 0 ]
[.88889 -0.0125 -6.78125 -18 ]
[.88889 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .02381 -13.5625 -9 ]
[-0.0125 .02381 0 9 ]
[-0.0125 .21429 -32.6875 -9 ]
[-0.0125 .21429 0 9 ]
[-0.0125 .40476 -32.6875 -9 ]
[-0.0125 .40476 0 9 ]
[-0.0125 .59524 -32.6875 -9 ]
[-0.0125 .59524 0 9 ]
[-0.0125 .78571 -32.6875 -9 ]
[-0.0125 .78571 0 9 ]
[-0.0125 .97619 -13.5625 -9 ]
[-0.0125 .97619 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -74.9375 -9 ]
[-0.01875 .5 -32.6875 9 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14815 0 m
.14815 .00625 L
s
gsave
.14815 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.2963 0 m
.2963 .00625 L
s
gsave
.2963 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.44444 0 m
.44444 .00625 L
s
gsave
.44444 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.59259 0 m
.59259 .00625 L
s
gsave
.59259 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.74074 0 m
.74074 .00625 L
s
gsave
.74074 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.88889 0 m
.88889 .00625 L
s
gsave
.88889 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.02963 0 m
.02963 .00375 L
s
.05926 0 m
.05926 .00375 L
s
.08889 0 m
.08889 .00375 L
s
.11852 0 m
.11852 .00375 L
s
.17778 0 m
.17778 .00375 L
s
.20741 0 m
.20741 .00375 L
s
.23704 0 m
.23704 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.32593 0 m
.32593 .00375 L
s
.35556 0 m
.35556 .00375 L
s
.38519 0 m
.38519 .00375 L
s
.41481 0 m
.41481 .00375 L
s
.47407 0 m
.47407 .00375 L
s
.5037 0 m
.5037 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56296 0 m
.56296 .00375 L
s
.62222 0 m
.62222 .00375 L
s
.65185 0 m
.65185 .00375 L
s
.68148 0 m
.68148 .00375 L
s
.71111 0 m
.71111 .00375 L
s
.77037 0 m
.77037 .00375 L
s
.8 0 m
.8 .00375 L
s
.82963 0 m
.82963 .00375 L
s
.85926 0 m
.85926 .00375 L
s
.91852 0 m
.91852 .00375 L
s
.94815 0 m
.94815 .00375 L
s
.97778 0 m
.97778 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02381 m
.00625 .02381 L
s
gsave
-0.0125 .02381 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .21429 m
.00625 .21429 L
s
gsave
-0.0125 .21429 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .40476 m
.00625 .40476 L
s
gsave
-0.0125 .40476 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .59524 m
.00625 .59524 L
s
gsave
-0.0125 .59524 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .78571 m
.00625 .78571 L
s
gsave
-0.0125 .78571 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .97619 m
.00625 .97619 L
s
gsave
-0.0125 .97619 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07143 m
.00375 .07143 L
s
0 .11905 m
.00375 .11905 L
s
0 .16667 m
.00375 .16667 L
s
0 .2619 m
.00375 .2619 L
s
0 .30952 m
.00375 .30952 L
s
0 .35714 m
.00375 .35714 L
s
0 .45238 m
.00375 .45238 L
s
0 .5 m
.00375 .5 L
s
0 .54762 m
.00375 .54762 L
s
0 .64286 m
.00375 .64286 L
s
0 .69048 m
.00375 .69048 L
s
0 .7381 m
.00375 .7381 L
s
0 .83333 m
.00375 .83333 L
s
0 .88095 m
.00375 .88095 L
s
0 .92857 m
.00375 .92857 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.14815 .99375 m
.14815 1 L
s
.2963 .99375 m
.2963 1 L
s
.44444 .99375 m
.44444 1 L
s
.59259 .99375 m
.59259 1 L
s
.74074 .99375 m
.74074 1 L
s
.88889 .99375 m
.88889 1 L
s
.125 Mabswid
.02963 .99625 m
.02963 1 L
s
.05926 .99625 m
.05926 1 L
s
.08889 .99625 m
.08889 1 L
s
.11852 .99625 m
.11852 1 L
s
.17778 .99625 m
.17778 1 L
s
.20741 .99625 m
.20741 1 L
s
.23704 .99625 m
.23704 1 L
s
.26667 .99625 m
.26667 1 L
s
.32593 .99625 m
.32593 1 L
s
.35556 .99625 m
.35556 1 L
s
.38519 .99625 m
.38519 1 L
s
.41481 .99625 m
.41481 1 L
s
.47407 .99625 m
.47407 1 L
s
.5037 .99625 m
.5037 1 L
s
.53333 .99625 m
.53333 1 L
s
.56296 .99625 m
.56296 1 L
s
.62222 .99625 m
.62222 1 L
s
.65185 .99625 m
.65185 1 L
s
.68148 .99625 m
.68148 1 L
s
.71111 .99625 m
.71111 1 L
s
.77037 .99625 m
.77037 1 L
s
.8 .99625 m
.8 1 L
s
.82963 .99625 m
.82963 1 L
s
.85926 .99625 m
.85926 1 L
s
.91852 .99625 m
.91852 1 L
s
.94815 .99625 m
.94815 1 L
s
.97778 .99625 m
.97778 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .21429 m
1 .21429 L
s
.99375 .40476 m
1 .40476 L
s
.99375 .59524 m
1 .59524 L
s
.99375 .78571 m
1 .78571 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .07143 m
1 .07143 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .30952 m
1 .30952 L
s
.99625 .35714 m
1 .35714 L
s
.99625 .45238 m
1 .45238 L
s
.99625 .5 m
1 .5 L
s
.99625 .54762 m
1 .54762 L
s
.99625 .64286 m
1 .64286 L
s
.99625 .69048 m
1 .69048 L
s
.99625 .7381 m
1 .7381 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .88095 m
1 .88095 L
s
.99625 .92857 m
1 .92857 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .02381 m
1 .02381 L
s
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
0 .02381 m
0 .1 L
.03704 .1 L
.03704 .02381 L
F
0 g
.5 Mabswid
0 .02381 m
0 .1 L
.03704 .1 L
.03704 .02381 L
0 .02381 L
s
1 0 0 r
.03704 .02381 m
.03704 .28667 L
.07407 .28667 L
.07407 .02381 L
F
0 g
.03704 .02381 m
.03704 .28667 L
.07407 .28667 L
.07407 .02381 L
.03704 .02381 L
s
1 0 0 r
.07407 .02381 m
.07407 .49238 L
.11111 .49238 L
.11111 .02381 L
F
0 g
.07407 .02381 m
.07407 .49238 L
.11111 .49238 L
.11111 .02381 L
.07407 .02381 L
s
1 0 0 r
.11111 .02381 m
.11111 .54952 L
.14815 .54952 L
.14815 .02381 L
F
0 g
.11111 .02381 m
.11111 .54952 L
.14815 .54952 L
.14815 .02381 L
.11111 .02381 L
s
1 0 0 r
.14815 .02381 m
.14815 .71333 L
.18519 .71333 L
.18519 .02381 L
F
0 g
.14815 .02381 m
.14815 .71333 L
.18519 .71333 L
.18519 .02381 L
.14815 .02381 L
s
1 0 0 r
.18519 .02381 m
.18519 .80476 L
.22222 .80476 L
.22222 .02381 L
F
0 g
.18519 .02381 m
.18519 .80476 L
.22222 .80476 L
.22222 .02381 L
.18519 .02381 L
s
1 0 0 r
.22222 .02381 m
.22222 .74 L
.25926 .74 L
.25926 .02381 L
F
0 g
.22222 .02381 m
.22222 .74 L
.25926 .74 L
.25926 .02381 L
.22222 .02381 L
s
1 0 0 r
.25926 .02381 m
.25926 .72476 L
.2963 .72476 L
.2963 .02381 L
F
0 g
.25926 .02381 m
.25926 .72476 L
.2963 .72476 L
.2963 .02381 L
.25926 .02381 L
s
1 0 0 r
.2963 .02381 m
.2963 .69429 L
.33333 .69429 L
.33333 .02381 L
F
0 g
.2963 .02381 m
.2963 .69429 L
.33333 .69429 L
.33333 .02381 L
.2963 .02381 L
s
1 0 0 r
.33333 .02381 m
.33333 .54952 L
.37037 .54952 L
.37037 .02381 L
F
0 g
.33333 .02381 m
.33333 .54952 L
.37037 .54952 L
.37037 .02381 L
.33333 .02381 L
s
1 0 0 r
.37037 .02381 m
.37037 .48857 L
.40741 .48857 L
.40741 .02381 L
F
0 g
.37037 .02381 m
.37037 .48857 L
.40741 .48857 L
.40741 .02381 L
.37037 .02381 L
s
1 0 0 r
.40741 .02381 m
.40741 .40476 L
.44444 .40476 L
.44444 .02381 L
F
0 g
.40741 .02381 m
.40741 .40476 L
.44444 .40476 L
.44444 .02381 L
.40741 .02381 L
s
1 0 0 r
.44444 .02381 m
.44444 .31333 L
.48148 .31333 L
.48148 .02381 L
F
0 g
.44444 .02381 m
.44444 .31333 L
.48148 .31333 L
.48148 .02381 L
.44444 .02381 L
s
1 0 0 r
.48148 .02381 m
.48148 .37429 L
.51852 .37429 L
.51852 .02381 L
F
0 g
.48148 .02381 m
.48148 .37429 L
.51852 .37429 L
.51852 .02381 L
.48148 .02381 L
s
1 0 0 r
.51852 .02381 m
.51852 .24857 L
.55556 .24857 L
.55556 .02381 L
F
0 g
.51852 .02381 m
.51852 .24857 L
.55556 .24857 L
.55556 .02381 L
.51852 .02381 L
s
1 0 0 r
.55556 .02381 m
.55556 .17238 L
.59259 .17238 L
.59259 .02381 L
F
0 g
.55556 .02381 m
.55556 .17238 L
.59259 .17238 L
.59259 .02381 L
.55556 .02381 L
s
1 0 0 r
.59259 .02381 m
.59259 .1381 L
.62963 .1381 L
.62963 .02381 L
F
0 g
.59259 .02381 m
.59259 .1381 L
.62963 .1381 L
.62963 .02381 L
.59259 .02381 L
s
1 0 0 r
.62963 .02381 m
.62963 .11905 L
.66667 .11905 L
.66667 .02381 L
F
0 g
.62963 .02381 m
.62963 .11905 L
.66667 .11905 L
.66667 .02381 L
.62963 .02381 L
s
1 0 0 r
.66667 .02381 m
.66667 .05429 L
.7037 .05429 L
.7037 .02381 L
F
0 g
.66667 .02381 m
.66667 .05429 L
.7037 .05429 L
.7037 .02381 L
.66667 .02381 L
s
1 0 0 r
.7037 .02381 m
.7037 .08095 L
.74074 .08095 L
.74074 .02381 L
F
0 g
.7037 .02381 m
.7037 .08095 L
.74074 .08095 L
.74074 .02381 L
.7037 .02381 L
s
1 0 0 r
.74074 .02381 m
.74074 .03905 L
.77778 .03905 L
.77778 .02381 L
F
0 g
.74074 .02381 m
.74074 .03905 L
.77778 .03905 L
.77778 .02381 L
.74074 .02381 L
s
1 0 0 r
.77778 .02381 m
.77778 .02381 L
.81481 .02381 L
.81481 .02381 L
F
0 g
.77778 .02381 m
.77778 .02381 L
.81481 .02381 L
.81481 .02381 L
.77778 .02381 L
s
1 0 0 r
.81481 .02381 m
.81481 .04286 L
.85185 .04286 L
.85185 .02381 L
F
0 g
.81481 .02381 m
.81481 .04286 L
.85185 .04286 L
.85185 .02381 L
.81481 .02381 L
s
1 0 0 r
.85185 .02381 m
.85185 .02381 L
.88889 .02381 L
.88889 .02381 L
F
0 g
.85185 .02381 m
.85185 .02381 L
.88889 .02381 L
.88889 .02381 L
.85185 .02381 L
s
1 0 0 r
.88889 .02381 m
.88889 .02381 L
.92593 .02381 L
.92593 .02381 L
F
0 g
.88889 .02381 m
.88889 .02381 L
.92593 .02381 L
.92593 .02381 L
.88889 .02381 L
s
1 0 0 r
.92593 .02381 m
.92593 .02762 L
.96296 .02762 L
.96296 .02381 L
F
0 g
.92593 .02381 m
.92593 .02762 L
.96296 .02762 L
.96296 .02381 L
.92593 .02381 L
s
1 0 0 r
.96296 .02381 m
.96296 .03143 L
1 .03143 L
1 .02381 L
F
0 g
.96296 .02381 m
.96296 .03143 L
1 .03143 L
1 .02381 L
.96296 .02381 L
s
.01 w
[ .02 .02 ] 0 setdash
0 .97619 m
.0601 .80135 L
.12564 .64704 L
.1872 .53013 L
.2464 .43843 L
.30941 .359 L
.37007 .29695 L
.43454 .24354 L
.49665 .20198 L
.55641 .16944 L
.61998 .14132 L
.68119 .11939 L
.74004 .10217 L
.80271 .08723 L
.86302 .07555 L
.92715 .06548 L
.98892 .05764 L
s
.98892 .05764 m
1 .05649 L
s
[ ] 0 setdash
0 .02381 m
.0601 .3176 L
.09138 .45198 L
.12564 .57463 L
.14104 .61983 L
.15751 .66078 L
.17295 .69201 L
.1872 .71461 L
.19476 .72419 L
.20309 .7328 L
.21146 .73946 L
.21605 .74227 L
.22034 .74437 L
.22438 .74588 L
.22637 .74646 L
.22822 .74691 L
.23003 .74725 L
.23167 .74749 L
.23349 .74767 L
.23543 .74777 L
.23645 .74778 L
.23753 .74777 L
.23945 .74767 L
.24052 .74757 L
.24152 .74745 L
.24379 .74709 L
.24578 .74666 L
.2476 .74619 L
.25167 .74484 L
.25915 .74132 L
.26709 .73617 L
.28136 .72348 L
.29671 .70535 L
.31365 .6806 L
.37619 .55933 L
.43637 .42489 L
.50037 .29281 L
.562 .192 L
.62128 .12308 L
.65179 .09739 L
.68438 .07614 L
.71758 .05999 L
.74893 .04884 L
.78006 .04084 L
.80877 .03555 L
.83795 .03172 L
.85454 .03009 L
.87006 .02884 L
.88625 .02778 L
.90162 .02697 L
Mistroke
.93045 .02584 L
.9454 .02542 L
.96132 .02506 L
.98995 .02459 L
Mfstroke
.98995 .02459 m
1 .02447 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00V?ooool00ol@413o<S8boa0@
4002o`000003odA4A?o<c<cooooo04_ooooo002Hooooo`03o`000?nHV9Sok^k^00;ooooo00?oQhN7
oa0@4?ooool0Boooool009gooooo00?o^[Zjo`000?ooool0Boooool009Sooooo00?oc<c<odA4A?l0
00000ol000000onHV9Soooooooooo`1:ooooo`00V?ooool01Ol0003oQhN7okZj^_nj^[[oc<c<04ko
oooo002Hooooo`03o`000?nHV9Sooooo00;ooooo00?oc<c<oa0@4?ooool0Boooool009Sooooo00Oo
c<c<odA4A?l0003o0000oa0@4?lb<S;o000004cooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool005Wooooo00Co
V9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@06ooooo`05oiRHV?l@413o0000o`000?mV
IVH02?ooool4o`000003oa0@4?oooooooooo00Kooooo1?l000000ol@413oooooooooo`04ooooo`03
oeEEEOl0003oEEEE00Kooooo00GoV9RHoa0@4?l0003o0000ofIVIP07ooooo`Ko00002?ooool6o`00
00Kooooo00?oEEEEo`000?mEEED01_ooool01OnHV9So410@o`000?l0003oIVIV00Oooooo00GoZJVY
ob4Q8Ol0003o0000ofIVIP0Aooooo`00F?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo
0ol00006ooooo`06oa0@4?n7QhOooooooooooomgMgOoIVIV2Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Kooooo0ol00006ooooo`06oa0@4?n7QhOooooooooooomgMgOoIVIV1_oo
ool00onHV9So0000omgMg@02ooooo`03oa0@4?oooooooooo00Kooooo00?oV9RHo`000?oMgMd00_oo
ool00ol@413oooooooooo`04ooooo`?o00001_ooool01_l@413oQhN7ooooooooooooMgMgofIVIPKo
oooo00Ko410@olc<c?ooooooooooogMgMomVIVH@ooooo`00F?ooool01_m4A4CoV9RHoooooooooooo
V9RHodA4A0Gooooo00?oEEEEo`000?mEEED02oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01_ooool00omEEEGo0000oeEEE@0;ooooo`03o`000?oo
oooooooo00Gooooo00?oQhN7ob4Q8Oo^k^h02oooool00on7QhOo8B4Qonk^kP08ooooo`03oeEEEOl0
003oEEEE00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`00F?ooool0
1_l0003ok^k^ooooooooooook^k^o`0001;ooooo00?ok^k^o`000?ooool02?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?ok^k^o`000?ooool01oooool00onYZJWo8B4Q
onk^kP0;ooooo`03ojVYZOlQ8B7ok^k^01Cooooo00?ok^k^o`000?ooool02_ooool00ol0003ooooo
ooooo`0>ooooo`00F?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Ko
410@oiRHV?ooooooooooogMgMomVIVH9ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03oooool01_l@413oV9RHooooooooooooMgMgofIVIPWooooo00?oV9RHoc8b<_ooool02oooool0
0onHV9So<S8booooo`0?ooooo`06oa0@4?nHV9SooooooooooomgMgOoIVIV2_ooool00onYZJWoA4A4
ooooo`0?ooooo`00F?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Go
0000ob4Q8Ol0003o0000ofIVIP0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
3oooool01Ol0003o8B4Qo`000?l0003oIVIV00_ooooo00?oA4A4ogMgMoooool02oooool00om4A4Co
MgMgooooo`0>ooooo`05o`000?lQ8B7o0000o`000?mVIVH02Oooool01?lQ8B7o0000o`000?oMgMd@
ooooo`00F?ooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Ooo
ool00ooMgMgo410@ooooo`0;ooooo`03omgMgOl@413ooooo00kooooo00?o0000ooooooooool03Ooo
ool00onYZJWo<S8booooo`0?ooooo`00F?ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`00F?ooool01_nj^[[o8B4QomgM
gOoMgMgo8B4QokZj^Pkooooo00?o0000ooooooooool02_ooool00ol0003oA4A4o`00000:ooooo`03
o`000?m4A4Co0000017ooooo00?o0000ooooooooool02Oooool01_l0003oQhN7onk^k_ooooooV9RH
oeEEE@Sooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED?ooooo`03o`000?oooooooooo00Wooooo
00Ko8B4QokZj^_ooooooooooofIVI_lb<S8@ooooo`00FOooool01?nHV9So0000o`000?nHV9P?oooo
o`Go00002?ooool00oo<c<coEEEEo`00000:ooooo`03olc<c?mEEEGo0000017ooooo1Ol00007oooo
o`06ojVYZOlb<S;o0000o`000?mEEEGok^k^2?ooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kPoo
oooo1Ol00007ooooo`06okZj^_m4A4Co0000o`000?m4A4Cok^k^4?ooool00>_ooooo003[ooooo`00
joooool00>_ooooo001=oooooigo00000Oooool004?ooooo00CoV9RHo`000?l0003oV9RH1_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0>ooooo`7o00000Oooool004;ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj
^[X5ooooo`03o`000?oooooooooo09Wooooo0Ol00001ooooo`00@_ooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A0Gooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Sooooo0Ol00001ooooo`00@_ooool01_l0003ok^k^ooooooooooook^k^o`0000Go
ooooWOl00001ooooo`00@_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ooooooooool02_l0000@ooooo`Ko00000Oooool004;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
0009o`0000;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0Dooooo`7o00000Ooo
ool004;ooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooo`;o00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool000Co00001oooool7o`0001Kooooo0Ol00001ooooo`00@_ooool01_m4A4CoV9RHoooo
ooooooooV9RHodA4A0Gooooo0_l00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo0007o`0000;oo`001?l0000Wooooo`7o00000Oooool004;ooooo00Ko^[Zjob4Q8OoMgMgo
gMgMob4Q8Onj^[X5ooooo`;o00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ooooooooool00oooool3o`0000?oo`0000?o0000ooooooooool08Oooool5o`00
007ooooo0013ooooo`04oiRHV?l0003o0000oiRHV0Kooooo0_l00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`02ooooo`;o00001Ooo00000ol0
003oooooooooo`0Gooooo`;o00000_ooool4o`0000Kooooo0Ol00001ooooo`00COooool2o`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00007o`000?oooooooooooooo
ool0003oooooo`000005ool00003o`000?oooooooooo017ooooo0_l00002ooooo`;o00003_ooool1
o`00007ooooo001=ooooo`03o`000?oo003o000000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00004o`000?oooooo0000o`0000;ooooo1ol0000@ooooo`?o00005?ooool1
o`00007ooooo001=ooooo`03o`000?oo003o000000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool000;o00005Oooool4o`0001Wooooo0Ol00001ooooo`00COooool00ol0003o
o`00o`000003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000ool00?oo003oo`000_l0000@oooo
o`Co00007oooool1o`00007ooooo001=ooooo`Oo00001Ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001_l0003oo`00o`000?l0003oo`00
o`0000cooooo0_l0000Uooooo`7o00000Oooool004gooooo00Co0000oooooooooooo00000_ooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool000;o00000ooo00000ol0003oooooooooo`08ooooo`;o00009oooool1
o`00007ooooo001=ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oooooooooo00Cooooo0_l0000[ooooo`7o00000Oooool0
04gooooo0_l000001Ooooooo0000oooooooooooo000000Goo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`001ol00004ooooo`;o0000;Oooool1
o`00007ooooo001=ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Oo0000ool00?oo003oo`00o`00
0?oo003o000000Gooooo0_l0000aooooo`7o00000Oooool004gooooo00Co0000oooooooooooo0000
0_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00001ol0003oo`00ool00?oo003o0000ool00?l000000oooool2o`0003?ooooo0Ol00001oooo
o`00COooool01ol0003ooooooooooooooooo0000ooooool000001Ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`002?l0000gooooo`7o00000Oooool004gooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00004o`000?oooooo0000ooooo`;o0000>Oooool1o`00007ooooo001=ooooo`07o`000?oo
ooooooooooooool0003oooooo`000005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo0003o`0003cooooo0Ol00001ooooo`00COooool01ol0003ooooooooooooooooo0000oooo
ool000001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`000_l0000noooo
o`7o00000Oooool004gooooo00?o0000ooooooooool00_ooool2o`0000Goo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool000;o0000?_ooool1o`00007ooooo001=ooooo`;o0000
0oooool2o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0003o`0000;oo`000_l0000nooooo`7o0000
0Oooool004gooooo00?o0000ooooooooool00_ooool2o`0000Goo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
0008o`0003kooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`02ooooo`;o00001Ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00o`000003ool00004o`000?ooooooooooo`00047ooooo0Ol00001ooooo`00COooool0
0ol0003oooooooooo`02ooooo`;o00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo0002o`0000Coo`0000?o0000ooooool00000@_ooool1
o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01Oooool6
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`000_l00013ooooo`7o00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj
^[X5ooooo`?o00001Oooool00onHV9So0000omgMg@02ooooo`03oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00001?l0003oo`00o`000?l00002ool00003o`000?oo003oo`0000?oo`00
0_l00013ooooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03
oeEEEOl0003oEEEE00Kooooo00?oQhN7ob4Q8Oo^k^h01oooool00ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool000;o
00001?oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04;ooooo0Ol00001ooooo`00
;oooool01_l0003ok^k^ooooooooooook^k^o`0000oooooo00?oZJVYob4Q8Oo^k^h01_ooool2o`00
00Cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool000;o0000@oooool2o`00
007ooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00onHV9So
<S8booooo`05ooooo`03o`000?oooooooooo00?ooooo0_l00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`000_l00014ooooo`7o00000Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0?ooooo`03odA4A?mgMgOooooo00Cooooo00?o0000ooooooooool00oooool2o`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00001_l0003oo`00o`000?l0003oo`00o`0000Goo`0000Oo0000ool0
0?oo003oo`00o`000?oo003o000004Cooooo0Ol00001ooooo`00;oooool01_l0003ok^k^oooooooo
ooook^k^o`00017ooooo00?ogMgMoa0@4?ooool01?ooool00ol0003oooooooooo`03ooooo`;o0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool000;o00000ooo00000ol0003oo`00ool00003ool00007o`00
0?oo003oo`00ool00?l0003oo`00o`000014ooooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oo
oooooooooiRHV?m4A4@Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool2
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000Co0000ool00?oo003o00000_oo00000ol0003oooooooooo`12ooooo`7o00000Ooo
ool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X=ooooo`06o`000?n7QhOok^k^oooooonH
V9SoEEEE1Oooool00ol0003oooooooooo`03ooooo`;o00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003oo`00ool00?l00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00o`000003
ool00003o`000?oooooooooo04;ooooo0Ol00001ooooo`00<?ooool01?nHV9So0000o`000?nHV9P>
ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^1Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oo003o000000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?l000000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`001ol00014ooooo`7o00000Oooool004gooooo00?o0000ooooooooool00ooo
ool00ol0003oo`00o`000003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool000;o00001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`000_l00019ooooo`7o00000Oooool004gooooo0_l00004ooooo`03o`000?oo003o
000000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0B?ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo
00?ooooo00?o0000ool00?l000000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000Co0000ool00?oo003oo`000ol00005ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`18ooooo`7o00000Oooool004gooooo00?o0000oooo
ooooool00oooool01?l0003oo`00ool00?l00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00001?l0003oo`00ool00?l00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000;o0000B_ooool1o`00007ooooo001=
ooooo`03o`000?oooooooooo00?ooooo00Co0000ool00?oo003o00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?l000000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0002o`0004[ooooo0Ol0
0001ooooo`00COooool00ol0003oooooooooo`03ooooo`Oo00001Ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00007o`000?oo003oo`00ool00?l0003oo`00o`00001:ooooo`7o00000Oooool004gooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool00005ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00Co0000ool00?oo003o00000_oo00000ol0003oooooooooo`18ooooo`7o00000Oooool004gooooo
00?o0000ooooooooool01_ooool01?l0003oooooooooool00005ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000Co0000ool00?oo003o00000_oo00000ol0003oooooooooo`18ooooo`7o00000Oooool004go
oooo0_l00008ooooo`03o`000?oooooo000000Goo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0002o`0000Go
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o000000?o
o`0000?o0000ooooooooool0B?ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooool000001Ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00001ol0003oo`00ool00?oo003o0000ool00?l000001Ooo00000ol0
003oo`00ool00003ool000Ko000000?oo`00o`000?oo00000_oo00000ol0003oooooooooo`18oooo
o`7o00000Oooool004gooooo00?o0000ooooooooool01oooool00ol0003oooooo`000005ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo00;ooooo0_l00004ool00003o`000?oooooooooo04Sooooo0Ol00001ooooo`00
COooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Goo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`000ol00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`02ooooo`;o0000
1?oo00000ol0003oooooooooo`18ooooo`7o00000Oooool004gooooo00?o0000ooooooooool02?oo
ool2o`0000Goo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo04Sooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`08ooooo`;o00001Ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000ool00?oo003oo`000_l0
0005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0B?ooool1o`00007ooooo001=
ooooo`03o`000?oooooooooo00Sooooo0_l00005ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?ooooooooooooooo`;o00001Ooo
00000ol0003oooooooooo`18ooooo`7o00000Oooool004gooooo00?o0000ooooooooool02?ooool2
o`0000Goo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
000000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000Co0000oooooooooooooooo0_l00005ool00003o`000?oooooooooo04Sooooo0Ol0
0001ooooo`00COooool2o`0000[ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?l000000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001_l0003oooooooooool0
003oooooo`0000Goo`0000?o0000ooooooooool0B?ooool1o`00007ooooo001=ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`000_l00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00006o`000?ooooooooooo`000?oooooo00001Ooo00000ol0003o
ooooooooo`18ooooo`7o00000Oooool004gooooo00?o0000ooooooooool02Oooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oooooo000000;ooooo1ol0001:ooooo`7o00000Oooool004gooooo00?o
0000ooooooooool02Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo000005?ooooo0Ol0
0001ooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Wooooo0_l0
00000ol@413oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo0_l00004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000Oo0000ool00?oo003oo`00o`000?oo003o000000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000_l0001Dooooo`7o
00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00002_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo0_l00004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000Oo0000ool00?oo003oo`00o`000?oo003o000000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000_l0001Dooooo`7o00000Ooo
ool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo
1_l00004ooooo`03o`000?oooooooooo00Wooooo0_l00004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00Co0000ool00?oo003o00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo05?o
oooo0Ol00001ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00GoA4A4okZj
^_ooooooooooo`000005ooooo`;o00002_ooool2o`0000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool000Oo0000E?ooool2o`00007ooooo000_ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03?ooool01OoMgMgo8B4Qoooooooooooo000000Gooooo00?o0000
ooooooooool02Oooool2o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo00;ooooo00?o0000ooooooooool0E?ooool1o`00007ooooo000_oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01?mgMgOoV9RHooooool00005
ooooo`03o`000?oooooooooo00Wooooo00?o0000ool00?l000000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`1D
ooooo`7o00000Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000?ooooo`04onk^k_lQ
8B7oooooo`0000Gooooo00?o0000ooooooooool02Oooool00ol0003oo`00o`000003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`000_l00005ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00005o`000?ooooooooooooooool00000Eoooool1o`00007o
oooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A44?ooool00omgMgOoV9RHo`000005oooo
o`03o`000?oooooooooo00Wooooo00?o0000ool00?l000000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001ol0003oo`00ool00?oo003o
0000ool00?l000001Ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00001Ol0003ooooooooooooooooo000005Oooooo0Ol00001ooooo`00;ooo
ool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Q3ooooo00?ok^k^oc8b<_l000001Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oo003o000000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00004o`000?ooooooooooo`0005Sooooo0Ol00001ooooo`00<?ooool01?nHV9So
0000o`000?nHV9PBooooo`03oiRHV?l@413ooooo00Cooooo00?o0000ooooooooool02Oooool01?l0
003oo`00ool00?l00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
1?l0003oooooooooool0001Hooooo`7o00000Oooool004gooooo0_l0000:ooooo`04o`000?oo003o
o`00o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000Co0000ool00?oo003o00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooo000005Wooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`09ooooo`04o`000?oo
003oo`00o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000Co0000ool00?oo003o00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oooooo000005Wooooo0Ol00001ooooo`004?ooool00onj^[[o<S8booooo`0>ooooo`03oc8b
<_nj^[[ooooo02Wooooo00?o0000ooooooooool02Oooool01?l0003oo`00ool00?l00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003o000000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooo`00001Iooooo`7o
00000Oooool0013ooooo00?o<S8bokZj^_ooool03_ooool00onj^[[o<S8booooo`0Yooooo`03o`00
0?oooooooooo00Wooooo00Oo0000ool00?oo003oo`00o`000?oo003o000000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool000;o00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
00;o0000F_ooool1o`00007ooooo000?ooooo`03olc<c?lb<S;ooooo013ooooo00?o<S8bolc<c?oo
ool0:?ooool00ol0003oooooooooo`09ooooo`07o`000?oo003oo`00ool00?l0003oo`00o`000004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`000_l0001Jooooo`7o00000Oooool000;ooooo00Go410@o`00
0?l0003o0000oa0@4008ooooo`03ofIVI_nYZJWooooo00Cooooo00?o410@oc8b<_l@41000_l00000
0om4A4Coc<c<ooooo`04ooooo`03oiRHV?mVIVKooooo02Sooooo00?o0000ooooooooool02Oooool0
1ol0003oo`00ool00?oo003o0000ool00?l000001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`000_l00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
FOooool1o`00007ooooo0004ooooo`03o`000?oooooooooo00Sooooo00?o<S8booooooooool01?oo
ool00ol0003oV9RHonk^kP02ooooo`03ohN7Qol@413ooooo00Cooooo00?ok^k^oc8b<_ooool0:?oo
ool00ol0003oooooooooo`09ooooo`07o`000?oo003oo`00ool00?l0003oo`00o`000004ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0002o`0000Goo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`001ol0001Kooooo`7o
00000Oooool000Cooooo00?o0000ooooooooool02?ooool00olb<S;oooooooooo`09ooooo`03okZj
^_l0003ooooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`09ooooo`Oo0000
1?oo00000ol0003oo`00ool00003ool00007o`000?oo003oo`00ool00?l0003oo`00o`000005ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo00;ooooo00?o0000ooooooooool0F_ooool1o`00007ooooo0004ooooo`?o
000000?o410@ogMgMoo^k^h01Oooool00olb<S;oooooooooo`04ooooo`03olc<c?m4A4Co000000?o
000000?oV9RHooooooooool01?ooool00ol0003oooooooooo`0Wooooo`;o00003oooool2o`0000Co
o`0000?o0000ool00?oo00000ooo00001ol0003oo`00ool00?oo003o0000ool00?l000001Ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo05[ooooo0Ol00001ooooo`001?ooool01_l0
003oooooooooooo^k^koMgMgoeEEE@Gooooo00?o8B4Qooooooooool01?ooool01Ol0003oQhN7okZj
^_nj^[[oc<c<00Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0>ooooo`;o0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo05[ooooo0Ol00001ooooo`001?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o<S8bonk^k_ooool01?oo
ool00ol0003oV9RHooooo`02ooooo`03olc<c?l@413ooooo00Cooooo00?ogMgMoc8b<_ooool0:?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000Go0000oooooooooooooooo
o`00001Mooooo`7o00000Oooool000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03ofIVI_nHV9Sooooo00Cooooo00Ooc<c<odA4A?l0003o0000oa0@4?lb<S;o000000Go
oooo00?oV9RHofIVI_ooool0:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00o`000003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000Go0000ooooooooooooooooo`00001Mooooo`7o00000Oooool000Cooooo00Ko0000oooooooo
ooook^k^ogMgMomEEED5ooooo`03omgMgOlQ8B7ooooo013ooooo00?o410@olc<c?ooool0:?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00o`000003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000Co0000oooooooooooo0000G_oo
ool1o`00007ooooo0002ooooo`03oa0@4?l0003o000000;o000000?o410@ogMgMoo^k^h01_ooool0
0olb<S;o^[Zjooooo`0>ooooo`03okZj^_lb<S;ooooo02Wooooo00?o0000ooooooooool03oooool0
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`000_l00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000Co0000oooooooooooo0000G_ooool1o`00007ooooo000@ooooo`03okZj^_lb<S;o
oooo00kooooo00?o<S8bokZj^_ooool0:Oooool00ol0003oooooooooo`0?ooooo`;o00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooo`00001Oooooo`7o00000Oooool004gooooo0_l0000@ooooo`;o00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooo`00001Oooooo`7o00000Oooool004gooooo00?o0000ooooooooool03oooool6o`0000Co
o`000_l00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool000Oo000000?oooooo`000?ooool0G_ooool1o`00007ooooo001=ooooo`03o`00
0?oooooooooo013ooooo00Go0000ooooooooooooooooo`000004ool000;o00001Ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo05kooooo0Ol00001ooooo`00COooool00ol0003ooooo
ooooo`0Aooooo`04o`000?ooooooooooo`0000?oo`0000?o0000ool00?l000001Ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo05kooooo0Ol00001ooooo`00COooool00ol0003ooooo
ooooo`0Aooooo`04o`000?ooooooooooo`0000;oo`0000Co0000ool00?oo003o00001Ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oooooooooo`03ooooo`03o`000?oooooooooo05oooooo0Ol00001ooooo`00<?ooool01?nHV9So
0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Kooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^
k^h4ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo00001Ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool1o`00007ooooo
000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo0_mgMgL2ooooo`03
ogMgMomEEEGooooo00?ooooo00?o0000ooooooooool04Oooool01_l0003oooooooooool0003oo`00
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo063ooooo0Ol00001ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?o
EEEEo`000?mEEED01_ooool00olQ8B7oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool04_ooool01Ol0003oooooo`000?oo003o000000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo063ooooo0Ol00001ooooo`00;ooo
ool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00?o0000onk^k_ooool00_ooool00ol0003o
ooooooooo`02ooooo`;o00004oooool01?l0003oooooo`000?l00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000Go0000ooooooooooooooooo`00001Rooooo`;o00000Oooool002oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0<ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE1?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooo000000Goo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00001Ol0003ooooooooooooooooo000006?ooooo0Ol00001ooooo`00;oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00cooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^h4ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooool000001Ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00004
o`000?ooooooooooo`0006Cooooo0Ol00001ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^
o`0000kooooo00?oA4A4oiRHV?ooool01oooool00ol0003oooooooooo`0Cooooo`;o00001Ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00004o`000?ooooooooooo`0006Cooooo0Ol00001ooooo`00;oooool0
1_m4A4CoV9RHooooooooooooV9RHodA4A0kooooo00?o^[Zjob4Q8Oooool01oooool00ol0003ooooo
ooooo`0Cooooo`;o00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oooooo000006Gooooo
0Ol00001ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Poooooo00?oEEEEoc8b<_oM
gMd01_ooool00ol0003oooooooooo`0Cooooo`;o00001Ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool000;o
0000I_ooool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV17ooooo00CoV9RHob4Q8Ol0
003o8B4Q1?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo000000Goo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo0002o`0006Kooooo0Ol00001ooooo`00COooool2o`0001;ooooo00Co0000oooooooo
oooo00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oooooooooo06Gooooo0Ol00001oooo
o`00COooool00ol0003oooooooooo`0Dooooo`;o00001?oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oooooooooo06Gooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Dooooo`;o0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00001?l0003oo`00ool00?oo0002o`0006Oooooo0Ol00001ooooo`00COooool00ol0003ooooo
ooooo`0@ooooo`07o`000?ooooooooooooooool0003oo`00o`000003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?oo003oo`00
ool000;o0000Ioooool1o`00007ooooo001=ooooo`03o`000?oooooooooo013ooooo00Oo0000oooo
ooooooooooooo`000?oo003o000000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000Ko0000ool00?oo003o0000ool00?l0001Wooooo`7o
00000Oooool004gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`04o`00
0?oo003oo`00o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000Ko0000ool00?oo003o0000ool00?l0001Wooooo`7o00000Oooool0
04gooooo00?o0000ooooooooool05?ooool01?l0003oo`00ool00?l00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
000000;oo`0000?o0000ooooooooool0IOooool1o`00007ooooo001=ooooo`03o`000?oooooooooo
01Cooooo00Co0000ool00?oo003o00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00o`000002ool00003o`000?oooooo
oooo06Gooooo0Ol00001ooooo`00COooool2o`0000oooooo00?o0000ooooooooool00oooool01ol0
003oo`00ool00?oo003o0000ool00?l000001Ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`001_l0001Wooooo`7o00000Oooool004gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`000_l00005ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo0002o`0006_ooooo0Ol00001ooooo`00COooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`1Zooooo`7o00000Oooool004gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`04ooooo`So00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`000_l0001/ooooo`7o00000Oooool004gooooo00?o0000ooooooooool06_ooool2o`0000Coo`00
00?o0000ool00?oo00000ooo00001ol0003oo`00ool00?oo003o0000ool00?l00000K?ooool1o`00
007ooooo001=ooooo`03o`000?oooooooooo01[ooooo00?o0000ool00?l000000ooo00000ol0003o
o`00ool00003ool000Oo0000K?ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool01?l0003oo`00ool00?l00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ooooool00000L?ooool1o`00007ooooo001=ooooo`;o00003?ooool00ol0003ooooo
ooooo`0<ooooo`06o`000?oo003oo`00ool00?l0003oo`002?l0001aooooo`7o00000Oooool004go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo003oo`0000;o
o`001ol0001cooooo`7o00000Oooool004gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0M_ooool1o`00007ooooo
001=ooooo`03o`000?oooooooooo01[ooooo00?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`1fooooo`7o00000Oooool0033ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEE
E@06ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^1?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0M_ooool1o`00007ooooo000_ooooo`06okZj
^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo00KoEEEEogMgMoooooooooooogMgMomE
EED4ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo07Kooooo0Ol00001ooooo`00;oooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0M_ooool1o`00007ooooo000_ooooo`06o`000?o^
k^koooooooooooo^k^ko00003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo0_l00009ooooo`03o`000?oooooooooo00oooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`1eooooo`;o00000Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0<ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE1?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1foooo
o`7o00000Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03
omgMgOl0003o000000;o000000?ogMgMooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0M_ooool1o`00007ooooo000_ooooo`06o`00
0?o^k^koooooooooooo^k^ko00003_ooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<PCooooo00?o
0000ooooooooool06_ooool7o`0007Sooooo0Ol00001ooooo`00;oooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A0kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0T?ooool1o`00007ooooo000_ooooo`06okZj^_lQ
8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<PCooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2@ooooo`7o00000Oooool0033ooooo00CoV9RHo`00
0?l0003oV9RH3oooool01_o^k^koA4A4o`000?l0003oA4A4onk^kPCooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2Aooooo`7o00000Oooool004gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2Aooooo`7o00000Oooool004gooooo0_l0002Jooooo`7o00000Oooool0
04gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Booooo`7o00000Oooool004go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Booooo`7o00000Oooool004gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`2Cooooo`7o00000Oooool004gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2Cooooo`7o00000Oooool004gooooo00?o0000
ooooooooool0VOooool1o`00007ooooo001=ooooo`03o`000?oooooooooo09Wooooo0Ol00001oooo
o`00COooool2o`0000?ooooo00?o0000ooooooooool0U?ooool1o`00007ooooo001=ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0U?ooool1o`00007ooooo001=ooooo`05o`000?oo
ooooooooooooool00000Uoooool1o`00007ooooo001=ooooo`05o`000?ooooooooooooooool00000
Uoooool1o`00007ooooo001=ooooo`03o`000?oooooooooo09Wooooo0Ol00001ooooo`00COooool0
0ol0003oooooooooo`2Iooooo`7o00000Oooool004gooooo00Co0000oooooooooooo0000V?ooool1
o`00007ooooo001=ooooo`04o`000?ooooooooooo`0009Sooooo0Ol00001ooooo`00COooool3o`00
09Wooooo0Ol00001ooooo`00COooool00ol0003oooooo`00002Iooooo`7o00000Oooool004gooooo
00?o0000ooooooooool0VOooool1o`00007ooooo001=ooooo`03o`000?oooooooooo09Wooooo0Ol0
0001ooooo`00@_ooool4o`000003oa0@4?oooooooooo00Cooooo0_l0002Jooooo`7o00000Oooool0
04Cooooo00?o0000ooooooooool01_ooool2o`0009[ooooo0Ol00001ooooo`00A?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo09Wooooo0Ol00001ooooo`00A?ooool00ol0003ooooo
ooooo`06ooooo`;o0000VOooool2o`00007ooooo0014ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0VOooool1o`00007ooooo0014ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0VOooool1o`00007ooooo0014ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00000Oooool004Cooooo00?o
0000ooooooooool01_oooonMo`00007ooooo0012ooooo`03o`000?m4A4Co00000:Kooooo0012oooo
o`03olc<c?mEEEGo00000:Kooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00001\
\>"],
  ImageRangeCache->{{{73.4375, 260.438}, {266.062, 79.0625}} -> {-3.67597, \
0.268283, 0.0216672, 0.00674091}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Prime Numbers", "Section"],

Cell["\<\
The code below generates a list of the first 10,000 prime numbers \
and creates a histogram to show the density of the primes as a function of \
the size of the primes.\
\>", "Text"],

Cell[BoxData[
    \(<< Graphics`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n = 10000;\)\), "\n", 
    \(\(P = Table[Prime[i], {i, 1, n}];\)\), "\n", 
    \(\(int = 
        Table[P[\([1]\)] + i*\((P[\([n]\)] - P[\([1]\)])\)/25, {i, 0, 
            25}];\)\), "\n", 
    \(PDensity = 
      Histogram[P, HistogramScale \[Rule] n, HistogramCategories \[Rule] int, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<p\>", "\<\[Rho](p)\>"}, 
        RotateLabel \[Rule] False]\)}], "Input"],

Cell[BoxData[
    \(Histogram::"rtail1" \(\(:\)\(\ \)\) 
      "Warning: One point from the right tail of the data, greater than or \
equal to \!\(104729\), is not included in histogram."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.90973e-05 9.54864e-06 0.0147151 4.29523 [
[.19095 -0.0125 -25.9062 -18 ]
[.19095 -0.0125 25.9062 0 ]
[.38193 -0.0125 -25.9062 -18 ]
[.38193 -0.0125 25.9062 0 ]
[.5729 -0.0125 -25.9062 -18 ]
[.5729 -0.0125 25.9062 0 ]
[.76387 -0.0125 -25.9062 -18 ]
[.76387 -0.0125 25.9062 0 ]
[.95484 -0.0125 -30.6875 -18 ]
[.95484 -0.0125 30.6875 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .10062 -42.25 -9 ]
[-0.0125 .10062 0 9 ]
[-0.0125 .18652 -42.25 -9 ]
[-0.0125 .18652 0 9 ]
[-0.0125 .27243 -42.25 -9 ]
[-0.0125 .27243 0 9 ]
[-0.0125 .35833 -42.25 -9 ]
[-0.0125 .35833 0 9 ]
[-0.0125 .44424 -32.6875 -9 ]
[-0.0125 .44424 0 9 ]
[-0.0125 .53014 -42.25 -9 ]
[-0.0125 .53014 0 9 ]
[-0.0125 .61605 -42.25 -9 ]
[-0.0125 .61605 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -84.5 -9 ]
[-0.01875 .30902 -42.25 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.19095 0 m
.19095 .00625 L
s
gsave
.19095 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20000) show
1.000 setlinewidth
grestore
.38193 0 m
.38193 .00625 L
s
gsave
.38193 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40000) show
1.000 setlinewidth
grestore
.5729 0 m
.5729 .00625 L
s
gsave
.5729 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60000) show
1.000 setlinewidth
grestore
.76387 0 m
.76387 .00625 L
s
gsave
.76387 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80000) show
1.000 setlinewidth
grestore
.95484 0 m
.95484 .00625 L
s
gsave
.95484 -0.0125 -91.6875 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100000) show
1.000 setlinewidth
grestore
.125 Mabswid
.04772 0 m
.04772 .00375 L
s
.09547 0 m
.09547 .00375 L
s
.14321 0 m
.14321 .00375 L
s
.2387 0 m
.2387 .00375 L
s
.28644 0 m
.28644 .00375 L
s
.33418 0 m
.33418 .00375 L
s
.42967 0 m
.42967 .00375 L
s
.47741 0 m
.47741 .00375 L
s
.52516 0 m
.52516 .00375 L
s
.62064 0 m
.62064 .00375 L
s
.66839 0 m
.66839 .00375 L
s
.71613 0 m
.71613 .00375 L
s
.81161 0 m
.81161 .00375 L
s
.85936 0 m
.85936 .00375 L
s
.9071 0 m
.9071 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .10062 m
.00625 .10062 L
s
gsave
-0.0125 .10062 -103.25 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
1.000 setlinewidth
grestore
0 .18652 m
.00625 .18652 L
s
gsave
-0.0125 .18652 -103.25 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
1.000 setlinewidth
grestore
0 .27243 m
.00625 .27243 L
s
gsave
-0.0125 .27243 -103.25 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
1.000 setlinewidth
grestore
0 .35833 m
.00625 .35833 L
s
gsave
-0.0125 .35833 -103.25 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
1.000 setlinewidth
grestore
0 .44424 m
.00625 .44424 L
s
gsave
-0.0125 .44424 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .53014 m
.00625 .53014 L
s
gsave
-0.0125 .53014 -103.25 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
1.000 setlinewidth
grestore
0 .61605 m
.00625 .61605 L
s
gsave
-0.0125 .61605 -103.25 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03619 m
.00375 .03619 L
s
0 .05767 m
.00375 .05767 L
s
0 .07914 m
.00375 .07914 L
s
0 .1221 m
.00375 .1221 L
s
0 .14357 m
.00375 .14357 L
s
0 .16505 m
.00375 .16505 L
s
0 .208 m
.00375 .208 L
s
0 .22948 m
.00375 .22948 L
s
0 .25095 m
.00375 .25095 L
s
0 .29391 m
.00375 .29391 L
s
0 .31538 m
.00375 .31538 L
s
0 .33686 m
.00375 .33686 L
s
0 .37981 m
.00375 .37981 L
s
0 .40129 m
.00375 .40129 L
s
0 .42276 m
.00375 .42276 L
s
0 .46571 m
.00375 .46571 L
s
0 .48719 m
.00375 .48719 L
s
0 .50867 m
.00375 .50867 L
s
0 .55162 m
.00375 .55162 L
s
0 .57309 m
.00375 .57309 L
s
0 .59457 m
.00375 .59457 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -145.5 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.19095 .61178 m
.19095 .61803 L
s
.38193 .61178 m
.38193 .61803 L
s
.5729 .61178 m
.5729 .61803 L
s
.76387 .61178 m
.76387 .61803 L
s
.95484 .61178 m
.95484 .61803 L
s
.125 Mabswid
.04772 .61428 m
.04772 .61803 L
s
.09547 .61428 m
.09547 .61803 L
s
.14321 .61428 m
.14321 .61803 L
s
.2387 .61428 m
.2387 .61803 L
s
.28644 .61428 m
.28644 .61803 L
s
.33418 .61428 m
.33418 .61803 L
s
.42967 .61428 m
.42967 .61803 L
s
.47741 .61428 m
.47741 .61803 L
s
.52516 .61428 m
.52516 .61803 L
s
.62064 .61428 m
.62064 .61803 L
s
.66839 .61428 m
.66839 .61803 L
s
.71613 .61428 m
.71613 .61803 L
s
.81161 .61428 m
.81161 .61803 L
s
.85936 .61428 m
.85936 .61803 L
s
.9071 .61428 m
.9071 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10062 m
1 .10062 L
s
.99375 .18652 m
1 .18652 L
s
.99375 .27243 m
1 .27243 L
s
.99375 .35833 m
1 .35833 L
s
.99375 .44424 m
1 .44424 L
s
.99375 .53014 m
1 .53014 L
s
.99375 .61605 m
1 .61605 L
s
.125 Mabswid
.99625 .03619 m
1 .03619 L
s
.99625 .05767 m
1 .05767 L
s
.99625 .07914 m
1 .07914 L
s
.99625 .1221 m
1 .1221 L
s
.99625 .14357 m
1 .14357 L
s
.99625 .16505 m
1 .16505 L
s
.99625 .208 m
1 .208 L
s
.99625 .22948 m
1 .22948 L
s
.99625 .25095 m
1 .25095 L
s
.99625 .29391 m
1 .29391 L
s
.99625 .31538 m
1 .31538 L
s
.99625 .33686 m
1 .33686 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .40129 m
1 .40129 L
s
.99625 .42276 m
1 .42276 L
s
.99625 .46571 m
1 .46571 L
s
.99625 .48719 m
1 .48719 L
s
.99625 .50867 m
1 .50867 L
s
.99625 .55162 m
1 .55162 L
s
.99625 .57309 m
1 .57309 L
s
.99625 .59457 m
1 .59457 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .60332 L
.04 .60332 L
.04 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .60332 L
.04 .60332 L
.04 .01472 L
0 .01472 L
s
1 0 0 r
.04 .01472 m
.04 .5018 L
.08 .5018 L
.08 .01472 L
F
0 g
.04 .01472 m
.04 .5018 L
.08 .5018 L
.08 .01472 L
.04 .01472 L
s
1 0 0 r
.08 .01472 m
.08 .47821 L
.12 .47821 L
.12 .01472 L
F
0 g
.08 .01472 m
.08 .47821 L
.12 .47821 L
.12 .01472 L
.08 .01472 L
s
1 0 0 r
.12 .01472 m
.12 .46078 L
.16 .46078 L
.16 .01472 L
F
0 g
.12 .01472 m
.12 .46078 L
.16 .46078 L
.16 .01472 L
.12 .01472 L
s
1 0 0 r
.16 .01472 m
.16 .4454 L
.2 .4454 L
.2 .01472 L
F
0 g
.16 .01472 m
.16 .4454 L
.2 .4454 L
.2 .01472 L
.16 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .44335 L
.24 .44335 L
.24 .01472 L
F
0 g
.2 .01472 m
.2 .44335 L
.24 .44335 L
.24 .01472 L
.2 .01472 L
s
1 0 0 r
.24 .01472 m
.24 .43617 L
.28 .43617 L
.28 .01472 L
F
0 g
.24 .01472 m
.24 .43617 L
.28 .43617 L
.28 .01472 L
.24 .01472 L
s
1 0 0 r
.28 .01472 m
.28 .42694 L
.32 .42694 L
.32 .01472 L
F
0 g
.28 .01472 m
.28 .42694 L
.32 .42694 L
.32 .01472 L
.28 .01472 L
s
1 0 0 r
.32 .01472 m
.32 .43104 L
.36 .43104 L
.36 .01472 L
F
0 g
.32 .01472 m
.32 .43104 L
.36 .43104 L
.36 .01472 L
.32 .01472 L
s
1 0 0 r
.36 .01472 m
.36 .40951 L
.4 .40951 L
.4 .01472 L
F
0 g
.36 .01472 m
.36 .40951 L
.4 .40951 L
.4 .01472 L
.36 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .41361 L
.44 .41361 L
.44 .01472 L
F
0 g
.4 .01472 m
.4 .41361 L
.44 .41361 L
.44 .01472 L
.4 .01472 L
s
1 0 0 r
.44 .01472 m
.44 .41669 L
.48 .41669 L
.48 .01472 L
F
0 g
.44 .01472 m
.44 .41669 L
.48 .41669 L
.48 .01472 L
.44 .01472 L
s
1 0 0 r
.48 .01472 m
.48 .40643 L
.52 .40643 L
.52 .01472 L
F
0 g
.48 .01472 m
.48 .40643 L
.52 .40643 L
.52 .01472 L
.48 .01472 L
s
1 0 0 r
.52 .01472 m
.52 .41669 L
.56 .41669 L
.56 .01472 L
F
0 g
.52 .01472 m
.52 .41669 L
.56 .41669 L
.56 .01472 L
.52 .01472 L
s
1 0 0 r
.56 .01472 m
.56 .39515 L
.6 .39515 L
.6 .01472 L
F
0 g
.56 .01472 m
.56 .39515 L
.6 .39515 L
.6 .01472 L
.56 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .39721 L
.64 .39721 L
.64 .01472 L
F
0 g
.6 .01472 m
.6 .39721 L
.64 .39721 L
.64 .01472 L
.6 .01472 L
s
1 0 0 r
.64 .01472 m
.64 .39721 L
.68 .39721 L
.68 .01472 L
F
0 g
.64 .01472 m
.64 .39721 L
.68 .39721 L
.68 .01472 L
.64 .01472 L
s
1 0 0 r
.68 .01472 m
.68 .40541 L
.72 .40541 L
.72 .01472 L
F
0 g
.68 .01472 m
.68 .40541 L
.72 .40541 L
.72 .01472 L
.68 .01472 L
s
1 0 0 r
.72 .01472 m
.72 .389 L
.76 .389 L
.76 .01472 L
F
0 g
.72 .01472 m
.72 .389 L
.76 .389 L
.76 .01472 L
.72 .01472 L
s
1 0 0 r
.76 .01472 m
.76 .40233 L
.8 .40233 L
.8 .01472 L
F
0 g
.76 .01472 m
.76 .40233 L
.8 .40233 L
.8 .01472 L
.76 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .39003 L
.84 .39003 L
.84 .01472 L
F
0 g
.8 .01472 m
.8 .39003 L
.84 .39003 L
.84 .01472 L
.8 .01472 L
s
1 0 0 r
.84 .01472 m
.84 .38285 L
.88 .38285 L
.88 .01472 L
F
0 g
.84 .01472 m
.84 .38285 L
.88 .38285 L
.88 .01472 L
.84 .01472 L
s
1 0 0 r
.88 .01472 m
.88 .40643 L
.92 .40643 L
.92 .01472 L
F
0 g
.88 .01472 m
.88 .40643 L
.92 .40643 L
.92 .01472 L
.88 .01472 L
s
1 0 0 r
.92 .01472 m
.92 .3808 L
.96 .3808 L
.96 .01472 L
F
0 g
.92 .01472 m
.92 .3808 L
.96 .3808 L
.96 .01472 L
.92 .01472 L
s
1 0 0 r
.96 .01472 m
.96 .3849 L
1 .3849 L
1 .01472 L
F
0 g
.96 .01472 m
.96 .3849 L
1 .3849 L
1 .01472 L
.96 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00T?ooool0
1?l@413o0000o`000?l0001Gooooo`00TOooool00ol0003oooooooooo`1Gooooo`00TOooool00ol0
003oooooooooo`1Gooooo`00TOooool01_l0003oQhN7oa0@4?l0003o410@ogMgMeCooooo002Aoooo
o`07o`000?lQ8B7oc<c<ooooooo<c<co8B4QogMgM`1Cooooo`00TOooool00ol0003oc<c<ooooo`02
ooooo`03olc<c?l@413ooooo05;ooooo002Aooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0DOooool0097ooooo00?o0000olc<c?ooool00_ooool00oo<c<co410@ooooo`1Booooo`00
TOooool01ol0003o8B4Qolc<c?oooooo^[Zjob4Q8OnYZJT0Doooool0093ooooo00Oo410@o`000?n7
QhOo410@o`000?l@413oZJVY05Cooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool005Oooooo1_l00006ooooo`04
oiRHV?l0003o0000oiRHV0Kooooo00GoV9RHo`000?l0003oV9RHooooo`02o`000004oa0@4?oooooo
oooooiRHV0;o000000CoV9RHo`000?l0003oV9RH0oooool01?nHV9So0000o`000?nHV9P2o`000005
oc8b<_l0003o0000oeEEEOo^k^h00_ooool01?nHV9So0000o`000?nHV9P2o`000005oiRHV?oooooo
oooooooooonHV9P00_l000001OnHV9So0000o`000?n=SHgoEEEE00;o000000CoEEEEonk^k_oooooo
V9RH0_l00002oiRHV0;o000000CoV9RHooooooooooooV9RH1_l000000onHV9Soooooooooo`02oooo
o`03oiRHV?l0003o000000;o000000?oV9RHooooooooool00_ooool00onHV9So0000o`000002o`00
0003oiRHV?oooooooooo00;ooooo00CoV9RHo`000?l0003oV9RH1_ooool01?nHV9So0000o`000?nH
V9P6ooooo`04oiRHV?l0003o0000oiRHV0Cooooo001Gooooo`03oiRHV?l0003ogMgM00;ooooo00?o
410@ooooooooool00oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PCooooo00So^[Zjob4Q8OoM
gMgogMgMob4Q8Onj^[[oooooo`0000;ooooo02[o^[Zjob4Q8OoMgMgoXZ:Rob4Q8OnQXJ7ogMgMob4Q
8Onj^[[ooooookZj^_lQ8B7ogMgMoj:RX_lQ8B7oXJ6QofMWIol?3`oo^[ZjoooooomgMgOoEEEEoooo
oonj^[[o8B4QomgMgOnRXZ;o8B4Qoj6QXOoMgMgo8B4QokZj^_oooooo^[Zjob4Q8OoMgMgoXZ:Rob4Q
8OnQXJ7ogMgMo`/;2omFEUH2ooooo`04ogMgMomEEEGo^[Zjob4Q8@;ogMgM0_lH61P2omgMg@04ob4Q
8Onj^[[o^[Zjob4Q8@;ogMgM00Ko0000oaPH6?oMgMgogMgMob4Q8Onj^[X2ooooo`08okZj^_lQ8B7o
XJ6Qoa`L7?lM7AgoXZ:Rob4Q8Onj^[X2ooooo`08okZj^_lQ8B7oXJ6Qoa`L7?lM7AgoXZ:Rob4Q8Onj
^[X2ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4Q
okZj^PCooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X3ooooo`00F?ooool00on7QhOo8B4Qonk^
kP07ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41?ooool00om4A4CoV9RHooooo`06o`00000D
oooooom4A4CoV9RHoooooom4A4CoV9RHodA4A?ooooooV9RHodA4A?ooooooA4A4oiRHV?ooooooA4A4
oiRHV?m4A4Co8B4QoiRHV?m4A4@2ooooo`0Eo`000?ooooooA4A4oiRHV?ooooooA4A4oiRHV?m4A4Co
oooooiRHV?m4A4CoooooodA4A?nHV9SoooooodA4A?nHV9SoA4A4ooooool0003oA4A400?ooooo00?o
0000odA4A?nHV9P00_ooool2obPX:0;ooooo00CoV9RHodA4A?m4A4CoV9RH0_ooool01_l0003o:2PX
ooooooooooooV9RHodA4A0;ooooo00?oA4A4oiRHV?m4A4@00_nHV9P00om4A4CoV9RHodA4A002oooo
o`03odA4A?nHV9SoA4A400;oV9RH00?oA4A4oiRHV?m4A4@00_ooool01_m4A4CoV9RHoooooooooooo
V9RHodA4A0Cooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@4ooooo`06odA4A?nHV9Sooooooooo
oonHV9SoA4A40oooool005Wooooo00?oZJVYob4Q8Oo^k^h01_ooool01_l0003ok^k^oooooooooooo
k^k^o`0000Cooooo00So0000onk^k_ooooooA4A4ojj^[_l0003oooooo`0000;ooooo00oo0000onk^
k_oooooo0000onk^k_l0003oooooonk^k_l0003oooooo`000?o^k^koooooo`000?o^k^h00_l00000
5oo^k^ko0000oooooooooooo0000ooooool0003ok^k^ooooool0003ok^k^o`000?ooooook^k^o`00
0?oooooo0000onk^k_oooooo0000onk^k_l0003ooooo00;o00000oooool2o`000003onk^k_oooooo
oooo00;o00000_ooool01?o^k^ko0000o`000?o^k^h2ooooo`;o00000_ooool01oo^k^ko0000oooo
oooooooo0000onk^k_l000000_o^k^h00ol0003ok^k^o`000002ooooo`03o`000?o^k^ko000000;o
k^k^00?o0000onk^k_l000000_ooool01_l0003ok^k^ooooooooooook^k^o`0000Cooooo00Ko0000
onk^k_ooooooooooonk^k_l00004ooooo`06o`000?o^k^koooooooooooo^k^ko00000oooool005[o
oooo00?oV9RHoc8b<_ooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00So0000oooooooooooogMgMob4Q8Ol0003oooooo`0000;ooooo00Ko0000oooooooooooo0000
ooooool00002ooooo`03o`000?oooooo000000;ooooo00_o0000ooooool0003o0000oeEEEOl0003o
ooooogMgMomEEEGoooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool00000
0_ooool01_l0003oooooo`000?ooooooEEEEo`0000;ooooo00?oMgMgoeEEEOl000000oooool2o`00
00?ooooo0_l00003ooooo`;o00000oooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o
0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo007ooooo001K
ooooo`03odA4A?mgMgOooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`08o`000?oooooooooooooooomgMgOo0000ooooool00002ooooo`06o`000?ooooooooooo`00
0?oooooo00000_ooool00ol0003oooooo`000002ooooo`05o`000?oooooo0000o`000?mgMgL00_l0
00001?mEEEGok^k^ooooool00002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool00000
0_ooool01Ol0003oooooo`000?oooooogMgM00Co000000?ogMgMo`000?ooool00_ooool2o`0000?o
oooo0_l00003ooooo`;o00000oooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000
ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo007ooooo001Koooo
o`03omgMgOl@413ooooo00Cooooo00Ko0000onk^k_ooooooooooonk^k_l00004ooooo`08o`000?o^
k^koooooooooooo^k^ko0000ooooool00002ooooo`0Co`000?o^k^koooooo`000?o^k^ko0000oooo
ooo^k^ko0000ooooool0003ok^k^ooooool0003ok^k^o`000?m4A4CoSXj>o`000004ooooo`0Co`00
0?o^k^koooooo`000?o^k^ko0000ooooooo^k^ko0000ooooool0003ok^k^ooooool0003ok^k^o`00
0?oooooo;bl_o`000002onk^kP04ofIVI_lb<S;o0000onk^kP;ooooo0_l00002ooooo`04onk^k_l0
003o0000onk^kP;ooooo0_l00002ooooo`07onk^k_l0003oooooooooool0003ok^k^o`000002onk^
kP03o`000?o^k^ko000000;ooooo00?o0000onk^k_l000000_o^k^h00ol0003ok^k^o`000002oooo
o`06o`000?o^k^koooooooooooo^k^ko00001?ooool01_l0003ok^k^ooooooooooook^k^o`0000Co
oooo00Ko0000onk^k_ooooooooooonk^k_l00003ooooo`00G?ooool00ol0003oooooooooo`03oooo
o`06odA4A?nHV9SooooooooooonHV9SoA4A41?ooool02?m4A4CoV9RHooooooooooooV9RHoalO7onH
V9So00000_ooool04om4A4CoV9RHoooooom4A4CoV9RHodA4A?ooooooV9RHodA4A?ooooooA4A4oiRH
V?ooooooA4A4oiRHV?m4A4Co^[Zjoa@D5?m4A4@01?ooool04om4A4CoV9RHoooooom4A4CoV9RHodA4
A?ooooooV9RHodA4A?ooooooA4A4oiRHV?ooooooA4A4oiRHV?m4A4Coooooo`000?m4A4@00oooool0
0ol0003oA4A4oiRHV002ooooo`;o:2PX0_ooool01?nHV9SoA4A4odA4A?nHV9P2ooooo`06o`000?lX
:2SooooooooooonHV9SoA4A40_ooool00om4A4CoV9RHodA4A002oiRHV003odA4A?nHV9SoA4A400;o
oooo00?oA4A4oiRHV?m4A4@00_nHV9P00om4A4CoV9RHodA4A002ooooo`06odA4A?nHV9Sooooooooo
oonHV9SoA4A41?ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo00KoA4A4oiRHV?oooooo
oooooiRHV?m4A4@3ooooo`00Eoooool01_l0003oQhN7onk^k_ooooooV9RHoeEEE@Gooooo00Ko^[Zj
ob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`08okZj^_lQ8B7ogMgMomgMgOlQ8B7o[Jf]oc8b<_l00002
ooooo`0DokZj^_lQ8B7ogMgMoj:RX_lQ8B7oXJ6QomgMgOlQ8B7o^[Zjoooooonj^[[o8B4QomgMgOnR
XZ;o8B4Qoj6QXOoMgMgo2`/;obDU9OoMgMd3ooooo`0CokZj^_lQ8B7ogMgMoj:RX_lQ8B7oXJ6QomgM
gOlQ8B7o^[Zjoooooonj^[[o8B4QomgMgOnRXZ;o8B4Qoj6QXOoMgMgo1PH6odY:BP02onk^kP04ofIV
I_lb<S;o^[Zjob4Q8@;ogMgM0_lH61P2omgMg@08ob4Q8Onj^[[o^[Zjob4Q8Ol0003o>SXjo`000?lH
61P2omgMg@0<ob4Q8Onj^[[ooooooooooonj^[[o8B4Qoj6QXOlL71co7AdMoj:RX_lQ8B7o^[Zj0_oo
ool02?nj^[[o8B4Qoj6QXOlL71co7AdMoj:RX_lQ8B7o^[Zj0_ooool01_nj^[[o8B4QomgMgOoMgMgo
8B4QokZj^PCooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`06okZj^_lQ8B7ogMgMomgM
gOlQ8B7o^[Zj0oooool005Oooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h6ooooo`04oiRHV?l0
003o0000oiRHV0Kooooo00OoV9RHo`000?l0003oV9RHoooooonHV9So410@00?ooooo00CoV9RHo`00
0?l0003oV9RH0_l000001OnHV9SoooooooooooooooooV9RH00;o000000?oV9RHo`000?l000000_nH
V9P00olQ8B7o0000ob4Q8@02ooooo`04oiRHV?l0003o0000oiRHV0;o000000GoV9RHoooooooooooo
oooooiRHV002o`000005oiRHV?l0003o0000ohf=SOm4A4@00_l000001?m4A4Cok^k^oooooonHV9P2
o`0000;oV9RH0_l000001?nHV9SooooooooooonHV9P3o`000004oiRHV?l0003o0000oiRHV0Cooooo
00?oV9RHo`000?l000000_l000000onHV9Soooooooooo`02ooooo`03oiRHV?l0003o000000;o0000
00?oV9RHooooooooool00_ooool01?nHV9So0000o`000?nHV9P6ooooo`04oiRHV?l0003o0000oiRH
V0Kooooo00CoV9RHo`000?l0003oV9RH1?ooool00>_ooooo003[ooooo`00C?ooool01?nHV9So0000
o`000?nHV9RKooooo`00Boooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGoooooNol0000Joooo
o`00Boooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool0
04_ooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooog_o00006_ooool004_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ooooooooool06?ooool004_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ooooooooool06?ooool004_ooooo00Ko0000onk^k_ooooooooooonk^k_l0
0005ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000oooo
ooooool06?ooool004_ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool06?ooool004_ooooo
00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ooooooooool06?ooool004cooooo00CoV9RHo`000?l0003oV9RH
1_ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooo
oooo01Sooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01oooool0
1?nHV9So0000o`000?nHV9P4ooooo`Ko00001?ooool00ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oooooooooo01Sooooo000_ooooo`06okZj^_lQ8B7ogMgMomgM
gOlQ8B7o^[Zj1Oooool3o`0000Kooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X3ooooo`03oiRH
V?l0003ogMgM00;ooooo00?o410@ooooooooool00_ooool00ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oooooooooo01Sooooo000_ooooo`06odA4A?nHV9Sooooo
oooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`06odA4A?nHV9SooooooooooonHV9So
A4A41?ooool00on7QhOo8B4Qonk^kP06ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ooooooooool06?ooool002oooooo00Ko0000onk^k_ooooooooooonk^
k_l0000>ooooo`06o`000?o^k^koooooooooooo^k^ko00001Oooool00onYZJWo8B4Qonk^kP05oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool0
6?ooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00onHV9So<S8booooo`04ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool06?ooool002oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00om4A4CoMgMgooooo`03ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool06?ooool002oooooo00Ko0000
onk^k_ooooooooooonk^k_l0000>ooooo`06o`000?o^k^koooooooooooo^k^ko00001oooool00ooM
gMgo410@ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ooooooooool06?ooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@>ooooo`06
odA4A?nHV9SooooooooooonHV9SoA4A42?ooool00ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool06?ooool002oooooo
00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X>ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj0ooo
ool01_l0003oQhN7onk^k_ooooooV9RHoeEEE@Cooooo00?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`00<?ooool01?nHV9So0000o`000?nH
V9P@ooooo`04oiRHV?l0003o0000oiRHV0Cooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h4oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool0
6?ooool005Kooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oooooooooo`0Hooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE
00Oooooo00CoV9RHo`000?l0003oV9RH2?ooool2o`000005oa0@4?ooooooooooooooool000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`00;oooool01_nj^[[o
8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ooooooooool06?ooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4
A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@4ooooo`Ko
00000oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
oooooooo01Sooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00003_ooool01_l0003ok^k^
ooooooooooook^k^o`0000Cooooo00GoA4A4okZj^_ooooooooooo`000004ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool06?ooool002oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01OoMgMgo8B4Qoooooooooooo000000Cooooo00?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`00;oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`04ogMgMonHV9Soooooo`0000Cooooo00?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`00;oooool01_l0003o
k^k^ooooooooooook^k^o`0000kooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooo`04onk^
k_lQ8B7oooooo`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oooooooooo`0Hooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0kooooo
00KoA4A4oiRHV?oooooooooooiRHV?m4A4@6ooooo`03ogMgMonHV9So000000Cooooo00?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`00;ooo
ool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X6
ooooo`03onk^k_lb<S;o000000Cooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oooooooooo`0Hooooo`00<?ooool01?nHV9So0000o`000?nHV9P@ooooo`04
oiRHV?l0003o0000oiRHV0Sooooo00?oV9RHoa0@4?ooool00oooool00ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oooooooooo01Sooooo000`ooooo`04oiRHV?l0
003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01oooool01?nHV9So0000o`000?nHV9P5ooooo`06
onk^k_mEEEGo0000o`000?mEEEGok^k^0oooool00ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oooooooooo01Sooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ
8B7o^[Zj1Oooool3o`0000Kooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`;oMgMg0_oo
ool00omgMgOoEEEEooooo`02ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ooooooooool06?ooool0013ooooo00?o^[Zjoc8b<_ooool00oooool01?l@413o
0000o`000?l00007ooooo`03oc8b<_nj^[[ooooo00_ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4
A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@4ooooo`03
ob4Q8Ooooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oooooooooo01Sooooo0003ooooo`03o`000?oooooooooo00[ooooo00?o
<S8bokZj^_ooool01?ooool00ol0003oooooooooo`07ooooo`03okZj^_lb<S;ooooo00_ooooo00Ko
0000onk^k_ooooooooooonk^k_l0000>ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool0
0ol0003ok^k^ooooo`02ooooo`05o`000?ooooooooooooooool000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oooooooooo`0Hooooo`000oooool00olb<S;o^[Zjooooo`09ooooo`03
olc<c?lb<S;ooooo00Gooooo00?o0000ooooooooool02?ooool00olb<S;oc<c<ooooo`0:ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEED3ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool06?ooool000?ooooo
00?oMgMgohN7QomgMgL00_l000000om4A4Coc<c<ooooo`04ooooo`03ofIVI_nYZJWooooo00Gooooo
00Ko0000ohN7Qol@413o0000oa0@4?mgMgL5ooooo`03oiRHV?mVIVKooooo00[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01_l0003oMgMgo`000?l0003oEEEEonk^kP?ooooo00?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`000oooool02?nHV9So
410@ohN7Qoo^k^kooooooiRHV?l@413oc<c<1?ooool00olb<S;oooooooooo`05ooooo`07o`000?lQ
8B7oc<c<ooooooo<c<co8B4QogMgM`04ooooo`03onk^k_lb<S;ooooo00[ooooo00Ko0000onk^k_oo
ooooooooonk^k_l0000>ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool00om4A4CoV9RH
ooooo`06ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ooooooooool06?ooool000?ooooo00?o^[Zjoc8b<_ooool00oooool00onHV9SoA4A4ooooo`03oooo
o`03oc8b<_oooooooooo00Gooooo00?o0000olc<c?ooool00_ooool00oo<c<co410@ooooo`04oooo
o`03o`000?oooooooooo00Wooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@>ooooo`06odA4A?nH
V9SooooooooooonHV9SoA4A41?ooool00onj^[[o8B4Qooooo`06ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool06?ooool000Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03oc8b<_oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00Ko^[Zj
ob4Q8OoMgMgogMgMob4Q8Onj^[X>ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool00omE
EEGo<S8bomgMg@05ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ooooooooool06?ooool000Cooooo00?oA4A4oiRHV?ooool00_ooool00oo^k^ko0000oooo
o`03ooooo`03ob4Q8Ooooooooooo00Gooooo00?o0000olc<c?ooool00_ooool00oo<c<co410@oooo
o`04ooooo`03o`000?oooooooooo00[ooooo00CoV9RHo`000?l0003oV9RH4?ooool01?nHV9So0000
o`000?nHV9P7ooooo`04oiRHV?lQ8B7o0000ob4Q8@?ooooo00?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`001?ooool01onj^[[o0000okZj
^_ooooook^k^ofIVI_mEEED01?ooool00olb<S;ok^k^ooooo`05ooooo`07o`000?lQ8B7oc<c<oooo
oonj^[[o8B4QojVYZ@04ooooo`03omgMgOlb<S;ooooo037ooooo00?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`001Oooool01_nYZJWo8B4Q
o`000?l0003oEEEEonk^kPCooooo00?oIVIVoiRHV?ooool01?ooool01ol@413o0000ohN7Qol@413o
0000oa0@4?nYZJT01Oooool00onHV9SoIVIVooooo`0;ooooo`04oiRHV?l0003o0000oiRHV0Kooooo
00?oEEEEo`000?mEEED01oooool01?nHV9So0000o`000?nHV9P5ooooo`06onk^k_mEEEGo0000o`00
0?mEEEGok^k^0oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oooooooooo01Sooooo000?ooooo`03omgMgOlQ8B7ooooo013ooooo00?o410@olc<c?ooool0
2_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`06okZj^_lQ8B7ogMgM
omgMgOlQ8B7o^[Zj1?ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`004?ooool0
0olb<S;o^[Zjooooo`0>ooooo`03okZj^_lb<S;ooooo00_ooooo00KoA4A4oiRHV?oooooooooooiRH
V?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@4oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oooooooooo01Sooooo000@ooooo`03okZj^_lb<S;ooooo00kooooo
00?o<S8bokZj^_ooool02oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00Ko0000onk^
k_ooooooooooonk^k_l00004ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooooooo01Sooooo000_oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool06?ooool002oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ooMgMgo0000o`000002o`000005omgMgOoooooooooooooo
ool000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`00;ooo
ool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00Ko0000onk^k_ooooooooooonk^k_l00004
ooooo`06oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b0oooool00ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo0006o`0000Coo`002_l0000Jooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RH
odA4A0kooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@4ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`001_l00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo0006o`0000Coo`001_l00004ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`00;oooool01_nj^[[o
8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`06oc8b
<_mVIVKok^k^onk^k_mVIVKo<S8b0oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ooooooooool00_ooool:o`0000Coo`0000?o0000ooooooooool00_ooool6o`0000Wooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo000`oooo
o`04oiRHV?l0003o0000oiRHV13ooooo00CoV9RHo`000?l0003oV9RH1Oooool01_o^k^koA4A4o`00
0?l0003oA4A4onk^kP?ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`001_l00004ool00003o`000?oo003oo`0000;oo`001_l00004ool00003o`000?oooooooooo
00_ooooo1_l0000Cooooo`Ko00002?ooool00ol0003oooooooooo`0Hooooo`00>Oooool01?nHV9So
0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Kooooo1?l000000ol@413oooooooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oooooo
oooo00;ooooo2ol00004ooooo`Ko0000=?ooool00ol0003oooooooooo`0Hooooo`00>?ooool01_nj
^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol00008ooooo`03o`000?oooooooooo00Gooooo00?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Co
0000ool00?oo003oo`001_l00004ool00003o`000?oooooooooo04_ooooo00?o0000ooooooooool0
6?ooool003Sooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00So
oooo00?o0000ooooooooool01Oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo0005o`0000Cooooo1_l0001=ooooo`03o`000?oooooooooo01So
oooo000hooooo`06o`000?o^k^koooooooooooo^k^ko00004?ooool00ol0003oooooooooo`05oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0006o`0005_ooooo00?o0000oooo
ooooool06?ooool003Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Gooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0006o`00063ooooo00?o0000oooooooo
ool06?ooool003Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`001_l0001Uooooo`03o`000?oooooooooo01Sooooo000hooooo`06o`000?o^
k^koooooooooooo^k^ko00004?ooool00ol0003oooooooooo`05ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo06So
oooo00?o0000ooooooooool06?ooool003Sooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@@oooo
o`03o`000?oooooooooo00Gooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Hoooo
o`00>?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00?o0000odA4A?l000001oooool0
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`001_l0001Zooooo`03o`000?oooooo
oooo01Sooooo000iooooo`04oiRHV?l0003o0000oiRHV0oooooo00?oc<c<oeEEEOl000001oooool0
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0Hooooo`00E_ooool00ol0003oo`00ool00002ool000Ko0000Koooool00ol0
003oooooooooo`0Hooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE
00Kooooo1?l000000ol@413oooooooooo`02ooooo`Ko00001?ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo07;ooooo00?o0000ooooooooool06?ooool002oooooo00Ko^[Zjob4Q8OoM
gMgogMgMob4Q8Onj^[X5ooooo`?o00002?ooool00ol0003oooooooooo`04ooooo`03oiRHV?l0003o
gMgM00;ooooo00?o410@ooooooooool00_ooool00ol0003oo`00ool00002ool00003o`000?oooooo
oooo07;ooooo00?o0000ooooooooool06?ooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4
A4@5ooooo`03oeEEEOl0003oEEEE00Sooooo00?o0000ooooooooool01Oooool00on7QhOo8B4Qonk^
kP06ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`0Hooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`00013ooooo00?o0000ooooooooool0
1_ooool00onYZJWo8B4Qonk^kP05ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
L_ooool00ol0003oooooooooo`0Hooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01oooool00onHV9So<S8booooo`04ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Hooooo`00;oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool0
0om4A4CoMgMgooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0L_ooool0
0ol0003oooooooooo`0Hooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`00013ooooo00?o
0000ooooooooool02?ooool00ooMgMgo410@ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ooooooooool0L_ooool00ol0003oooooooooo`0Hooooo`00;oooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A13ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Hooooo`00;ooo
ool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00?o0000odA4A?l000001_ooool01_l0003o
QhN7onk^k_ooooooV9RHoeEEE@Cooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo01Sooooo000`ooooo`04oiRHV?l0003o0000oiRHV0oooooo00?oc<c<
oeEEEOl000001_ooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kPCooooo00?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`1booooo`03o`000?oooooooooo01Sooooo000`ooooo`04oiRHV?l0
003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01_ooool4o`000003oa0@4?oooooooooo00Kooooo
0_l000001Ol@413ooooooooooooooooo000000Coo`0000?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`0Hooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol00008oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oo`00ool00002ool0
0003o`000?oooooooooo07;ooooo00?o0000ooooooooool06?ooool002oooooo00KoA4A4oiRHV?oo
oooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Sooooo00?o0000ooooooooool01Oooool6
o`0000?ooooo1_l0001dooooo`03o`000?oooooooooo01Sooooo000_ooooo`06o`000?o^k^kooooo
ooooooo^k^ko00004?ooool00ol0003oooooooooo`05ooooo`05odA4A?nj^[[oooooooooool00000
1?ooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Sooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`05ooooo`05omgMgOlQ8B7oooooooooool000001?oooomko`0001[ooooo
000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`06ooooo`04ogMgMonHV9Soooooo`0009Wooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko
00004?ooool00ol0003oooooooooo`06ooooo`04onk^k_lQ8B7oooooo`0009Wooooo000_ooooo`06
odA4A?nHV9SooooooooooonHV9SoA4A44?ooool00ol0003oooooooooo`07ooooo`03ogMgMonHV9So
000009Wooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool00ol0003oA4A4o`00
0009ooooo`03onk^k_lb<S;o000009Wooooo000`ooooo`04oiRHV?l0003o0000oiRHV0oooooo00?o
c<c<oeEEEOl000002_ooool00onHV9So410@ooooo`2Hooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo0000\
\>"],
  ImageRangeCache->{{{73.4375, 260.438}, {347.062, 160.062}} -> {-153575, \
0.200092, 859.986, 0.00191182}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Number theory tells us that the density of primes near the prime p \
should be 1/ln(p).  Below we plot this reciprocal logarithm function.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PD = 
      Plot[1/\((Log[x])\), {x, 2, 1.25*10^5}, 
        PlotStyle \[Rule] {Thickness[0.015]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 7.61905e-06 -0.350847 4.29026 [
[.17619 .06568 -15 -9 ]
[.17619 .06568 15 0 ]
[.32857 .06568 -15 -9 ]
[.32857 .06568 15 0 ]
[.48095 .06568 -15 -9 ]
[.48095 .06568 15 0 ]
[.63333 .06568 -15 -9 ]
[.63333 .06568 15 0 ]
[.78571 .06568 -18 -9 ]
[.78571 .06568 18 0 ]
[.9381 .06568 -18 -9 ]
[.9381 .06568 18 0 ]
[.01131 .16398 -24 -4.5 ]
[.01131 .16398 0 4.5 ]
[.01131 .24979 -24 -4.5 ]
[.01131 .24979 0 4.5 ]
[.01131 .3356 -24 -4.5 ]
[.01131 .3356 0 4.5 ]
[.01131 .4214 -24 -4.5 ]
[.01131 .4214 0 4.5 ]
[.01131 .50721 -18 -4.5 ]
[.01131 .50721 0 4.5 ]
[.01131 .59301 -24 -4.5 ]
[.01131 .59301 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17619 .07818 m
.17619 .08443 L
s
[(20000)] .17619 .06568 0 1 Mshowa
.32857 .07818 m
.32857 .08443 L
s
[(40000)] .32857 .06568 0 1 Mshowa
.48095 .07818 m
.48095 .08443 L
s
[(60000)] .48095 .06568 0 1 Mshowa
.63333 .07818 m
.63333 .08443 L
s
[(80000)] .63333 .06568 0 1 Mshowa
.78571 .07818 m
.78571 .08443 L
s
[(100000)] .78571 .06568 0 1 Mshowa
.9381 .07818 m
.9381 .08443 L
s
[(120000)] .9381 .06568 0 1 Mshowa
.125 Mabswid
.0619 .07818 m
.0619 .08193 L
s
.1 .07818 m
.1 .08193 L
s
.1381 .07818 m
.1381 .08193 L
s
.21429 .07818 m
.21429 .08193 L
s
.25238 .07818 m
.25238 .08193 L
s
.29048 .07818 m
.29048 .08193 L
s
.36667 .07818 m
.36667 .08193 L
s
.40476 .07818 m
.40476 .08193 L
s
.44286 .07818 m
.44286 .08193 L
s
.51905 .07818 m
.51905 .08193 L
s
.55714 .07818 m
.55714 .08193 L
s
.59524 .07818 m
.59524 .08193 L
s
.67143 .07818 m
.67143 .08193 L
s
.70952 .07818 m
.70952 .08193 L
s
.74762 .07818 m
.74762 .08193 L
s
.82381 .07818 m
.82381 .08193 L
s
.8619 .07818 m
.8619 .08193 L
s
.9 .07818 m
.9 .08193 L
s
.97619 .07818 m
.97619 .08193 L
s
.25 Mabswid
0 .07818 m
1 .07818 L
s
.02381 .16398 m
.03006 .16398 L
s
[(0.12)] .01131 .16398 1 0 Mshowa
.02381 .24979 m
.03006 .24979 L
s
[(0.14)] .01131 .24979 1 0 Mshowa
.02381 .3356 m
.03006 .3356 L
s
[(0.16)] .01131 .3356 1 0 Mshowa
.02381 .4214 m
.03006 .4214 L
s
[(0.18)] .01131 .4214 1 0 Mshowa
.02381 .50721 m
.03006 .50721 L
s
[(0.2)] .01131 .50721 1 0 Mshowa
.02381 .59301 m
.03006 .59301 L
s
[(0.22)] .01131 .59301 1 0 Mshowa
.125 Mabswid
.02381 .09963 m
.02756 .09963 L
s
.02381 .12108 m
.02756 .12108 L
s
.02381 .14253 m
.02756 .14253 L
s
.02381 .18544 m
.02756 .18544 L
s
.02381 .20689 m
.02756 .20689 L
s
.02381 .22834 m
.02756 .22834 L
s
.02381 .27124 m
.02756 .27124 L
s
.02381 .29269 m
.02756 .29269 L
s
.02381 .31414 m
.02756 .31414 L
s
.02381 .35705 m
.02756 .35705 L
s
.02381 .3785 m
.02756 .3785 L
s
.02381 .39995 m
.02756 .39995 L
s
.02381 .44285 m
.02756 .44285 L
s
.02381 .4643 m
.02756 .4643 L
s
.02381 .48575 m
.02756 .48575 L
s
.02381 .52866 m
.02756 .52866 L
s
.02381 .55011 m
.02756 .55011 L
s
.02381 .57156 m
.02756 .57156 L
s
.02381 .05673 m
.02756 .05673 L
s
.02381 .03528 m
.02756 .03528 L
s
.02381 .01383 m
.02756 .01383 L
s
.02381 .61446 m
.02756 .61446 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.015 w
.02497 .61803 m
.025 .49841 L
.02607 .4028 L
.0273 .34921 L
.02847 .31777 L
.02955 .29676 L
.03055 .28148 L
.0328 .25569 L
.03507 .23698 L
.03757 .22125 L
.04263 .19833 L
.04756 .18244 L
.05287 .16941 L
.06246 .15202 L
.07374 .13736 L
.08446 .12679 L
.10459 .11202 L
.1244 .10132 L
.14279 .09346 L
.18192 .08075 L
.2235 .07085 L
.26356 .0634 L
.30211 .05752 L
.34312 .05225 L
.3826 .04788 L
.42057 .04419 L
.461 .04069 L
.4999 .03767 L
.54127 .03476 L
.58111 .0322 L
.61944 .02994 L
.66022 .02772 L
.69949 .02573 L
.73724 .02394 L
.77744 .02215 L
.81613 .02054 L
.85726 .01892 L
.89689 .01744 L
.935 .0161 L
.97556 .01474 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo000Jooooo`03o`000?oooooooooo0<kooooo000Jooooo`03o`000?oooooooooo0<kooooo000J
ooooo`03o`000?oooooooooo0<kooooo000Jooooo`;o0000Y_oooolOo`0000[ooooo000Jooooo`03
o`000?oooooooooo08cooooo>?l0000:ooooo`006_ooool00ol0003oooooooooo`1looooodSo0000
2_ooool001[ooooo00?o0000ooooooooool03_ooool5o`0000?ooooo0_l00004ooooo`;o00001?oo
ool2o`0000Cooooo0_l00005ooooo`?o00000oooool2o`0000Cooooo0_l00004ooooo`;o00001?oo
ool2o`0000Gooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00000ooo
oolko`0000;ooooo1?l00002ooooo`Go00000oooool2o`0000Cooooo0_l00004ooooo`;o00001?oo
ool2o`0000?ooooo000Jooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00005ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`0do`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool001[ooooo0_l0000Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool5o`0000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000oooool01_l0003ooooooooooooooooo0000ooooob_o000000Goooooo`000?ooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`006_ooool00ol0003oooooooooo`0A
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`05o`00
0?ooooooooooo`000?ooool0;_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`7o00000Ooo
ool1ooooo`006_ooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00Co0000
oooooooooooo00000_oooolTo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`006_ooool00ol0003oooooooooo`0>ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`;o0000
0ooooolQo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?oooooo0000o`0000Cooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooo`000?l00003ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`006_ooool2o`00013ooooo0ol00004
ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001_oooolDo`0000?ooooo0_l00006
ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0ol00004
ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00000oooool00ol0003oooooooooo`03
ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool3o`0000Cooooo0ol00004
ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00000oooool001[ooooo00?o0000oooo
ooooool0:_oooolBo`0009;ooooo000Jooooo`03o`000?oooooooooo02?ooooo4ol0002Hooooo`00
6_ooool00ol0003oooooooooo`0Ooooooa?o0000W?ooool001[ooooo00?o0000ooooooooool07?oo
ool@o`000:;ooooo000Eooooom3o00001_ooool001[ooooo00?o0000ooooooooool05_ooool;o`00
01_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0@ooooo`006_ooool00ol0003o
ooooooooo`0Cooooo`_o0000/?ooool001[ooooo00?o0000ooooooooool04?ooool;o`000;?ooooo
000Jooooo`;o00004?ooool9o`000;Kooooo000Jooooo`03o`000?oooooooooo00kooooo1ol0002i
ooooo`006_ooool00ol0003oooooooooo`0<ooooo`Ko0000_?ooool001[ooooo00?o0000oooooooo
ool02oooool6o`000;gooooo000Jooooo`03o`000?oooooooooo00[ooooo1_l0002nooooo`006_oo
ool2o`0000Wooooo1_l00030ooooo`006_ooool00ol0003oooooooooo`07ooooo`Ko0000`Oooool0
01[ooooo00?o0000ooooooooool01_ooool6o`000<;ooooo000Jooooo`03o`000?oooooooooo00Ko
oooo1?l00034ooooo`006_ooool2o`0000Kooooo1?l00035ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`Go0000aOooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00002
ooooo`Go00000oooool00ol0003oooooooooo`04ooooo`Co0000a_ooool00005ooooool0003ooooo
ooooool000002Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool00oooool4o`000<Oooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`;o00001?ooool4o`000<Oooooo0000
1Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo1?l00038ooooo`0000Goooooo`000?ooooooooooo`00
0009ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Co
oooo1?l00038ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`;o00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooooooo1?l00039ooooo`000_ooool2o`00
00[ooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00Co0000oooooooooooooooo1?l00039
ooooo`006_ooool2o`0000;ooooo0ol0003:ooooo`006_ooool00ol0003oooooooooo`04o`000<[o
oooo000Jooooo`03o`000?oooooooooo00Co0000b_ooool001[ooooo00?o0000ooooooooool00ol0
003;ooooo`006_ooool2o`000004ooooool0003o0000o`000<_ooooo000Jooooo`03o`000?oooooo
000000?o0000boooool001[ooooo00?o0000ooooool000000ol0003;ooooo`006_ooool00ol0003o
ooooo`000002o`000<cooooo000Jooooo`03o`000?oooooo000000;o0000c?ooool001[ooooo1Ol0
003<ooooo`006_ooool5o`000<cooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`?o00001?ooool3o`0000?ooooo1?l0003=ooooo`0000Goooooo`000?ooooooooooo`000009oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool4o`000<gooooo00001Ooooooo
0000oooooooooooo000000Wooooo00Co0000oooooooooooooooo1Ol00003ooooo`Co0000cOooool0
0005ooooool0003oooooooooool000002Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooooooool00_ooool4o`000<gooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`000004ooooo`Co0000cOooool00005ooooool0003o
ooooooooool000002?ooool2o`0000Gooooo0_l00004ooooo`Co0000cOooool000;ooooo0_l0000:
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool4o`000<gooooo000Joooo
o`Co0000cOooool001[ooooo0ol0003>ooooo`006_ooool3o`000<kooooo000Jooooo`?o0000c_oo
ool001[ooooo0ol0003>ooooo`006_ooool3o`000<kooooo000Jooooo`?o0000c_ooool001[ooooo
0ol0003>ooooo`006_ooool3o`000<kooooo000Jooooo`?o0000c_ooool001[ooooo0ol0003>oooo
o`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo0ol00004ooooo`?o
0000c_ooool00005ooooool0003oooooooooool000002Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooooooo0ol0003>ooooo`0000Goooooo`000?ooooooooooo`000009
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooooooool3o`000<kooooo
00001Ooooooo0000oooooooooooo000000Wooooo00Co0000oooooooooooooooo1?l00004ooooo`?o
0000c_ooool00005ooooool0003oooooooooool000002Oooool01Ol0003ooooooooooooooooo0000
00Oooooo0ol0003>ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`;o00001?ooool00ol0
003oooooooooo`04ooooo`?o0000c_ooool000;ooooo0_l0000:ooooo`03o`000?oooooooooo00?o
oooo0_l00004ooooo`?o0000c_ooool001[ooooo0ol0003>ooooo`006_ooool3o`000<kooooo000J
ooooo`?o0000c_ooool001[ooooo0ol0003>ooooo`006_ooool3o`000<kooooo000Jooooo`?o0000
c_ooool001[ooooo0ol0003>ooooo`006_ooool3o`000<kooooo000Jooooo`?o0000c_ooool001[o
oooo0ol0003>ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo
0ol00004ooooo`?o0000c_ooool00005ooooool0003oooooooooool000002Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooooooo0ol0003>ooooo`0000Goooooo`000?oo
ooooooooo`000009ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooooooo
ool3o`000<kooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool00_oo
ool3o`0000Cooooo0ol0003>ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooooooool3o`000<kooooo00001Ooooooo0000
oooooooooooo000000Sooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool3o`00
0<kooooo0002ooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`?o00001?ooool3o`000<ko
oooo000Jooooo`?o0000c_ooool001[ooooo0ol0003>ooooo`006Oooool4o`000<kooooo000Ioooo
o`Co0000c_ooool001Wooooo0ol0003?ooooo`006Oooool3o`000<oooooo000Iooooo`?o0000cooo
ool001Wooooo0ol0003?ooooo`006Oooool3o`000<oooooo000Iooooo`?o0000coooool001Wooooo
0ol0003?ooooo`002?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00002ooooo`?o0000
coooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`?o
0000coooool000Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`?o
0000coooool000Oooooo00Co0000oooooooooooo00002_ooool01?l0003oooooooooooooool3o`00
0<oooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000002
ooooo`?o0000coooool000Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000;ooooo0ol0003?ooooo`002?ooool2o`0000Wooooo0ol00003ooooo`?o0000coooool0
01Wooooo0ol0003?ooooo`006Oooool3o`000<oooooo000Iooooo`?o0000coooool001Wooooo0ol0
003?ooooo`006Oooool3o`000<oooooo000Iooooo`?o0000coooool001Wooooo0ol0003?ooooo`00
6Oooool3o`000<oooooo000Iooooo`?o0000coooool001Wooooo0ol0003?ooooo`006Oooool3o`00
0<oooooo0002ooooo`;o00001?ooool01?l0003oooooooooooooool5o`000003ooooool0003o0000
00?o00000_ooool3o`000<oooooo00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`?o0000coooool00005ooooool0003o
ooooooooool000002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0
003?ooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooooooo0ol0003?ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`07o`00
0?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00?o0000coooool00005
ooooool0003oooooooooool000001oooool01ol0003ooooooooooooooooo0000ooooool000000ooo
ool00ol0003oooooooooo`03o`000<oooooo0002ooooo`;o00002Oooool3o`0000?ooooo0ol00003
ooooo`?o0000coooool001Wooooo0ol0003?ooooo`006Oooool3o`000<oooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-16846.5, 0.022165, 633.554, \
0.00112513}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The plot below compares the computed density of primes with the \
theoretical (1/ln(p)) prediction.  The agreement is very good.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[PDensity, PD, AspectRatio \[Rule] 1, 
      PlotRange \[Rule] {{0, 10^5}, {0, 0.15}}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-4.09015e-17 1e-05 0 6.66667 [
[.2 -0.0125 -25.9062 -18 ]
[.2 -0.0125 25.9062 0 ]
[.4 -0.0125 -25.9062 -18 ]
[.4 -0.0125 25.9062 0 ]
[.6 -0.0125 -25.9062 -18 ]
[.6 -0.0125 25.9062 0 ]
[.8 -0.0125 -25.9062 -18 ]
[.8 -0.0125 25.9062 0 ]
[1 -0.0125 -30.6875 -18 ]
[1 -0.0125 30.6875 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .13333 -42.25 -9 ]
[-0.0125 .13333 0 9 ]
[-0.0125 .26667 -42.25 -9 ]
[-0.0125 .26667 0 9 ]
[-0.0125 .4 -42.25 -9 ]
[-0.0125 .4 0 9 ]
[-0.0125 .53333 -42.25 -9 ]
[-0.0125 .53333 0 9 ]
[-0.0125 .66667 -32.6875 -9 ]
[-0.0125 .66667 0 9 ]
[-0.0125 .8 -42.25 -9 ]
[-0.0125 .8 0 9 ]
[-0.0125 .93333 -42.25 -9 ]
[-0.0125 .93333 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -84.5 -9 ]
[-0.01875 .5 -42.25 9 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
gsave
.2 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20000) show
1.000 setlinewidth
grestore
.4 0 m
.4 .00625 L
s
gsave
.4 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40000) show
1.000 setlinewidth
grestore
.6 0 m
.6 .00625 L
s
gsave
.6 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60000) show
1.000 setlinewidth
grestore
.8 0 m
.8 .00625 L
s
gsave
.8 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80000) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -91.6875 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100000) show
1.000 setlinewidth
grestore
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .13333 m
.00625 .13333 L
s
gsave
-0.0125 .13333 -103.25 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
1.000 setlinewidth
grestore
0 .26667 m
.00625 .26667 L
s
gsave
-0.0125 .26667 -103.25 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
1.000 setlinewidth
grestore
0 .4 m
.00625 .4 L
s
gsave
-0.0125 .4 -103.25 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
1.000 setlinewidth
grestore
0 .53333 m
.00625 .53333 L
s
gsave
-0.0125 .53333 -103.25 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
1.000 setlinewidth
grestore
0 .66667 m
.00625 .66667 L
s
gsave
-0.0125 .66667 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .8 m
.00625 .8 L
s
gsave
-0.0125 .8 -103.25 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
1.000 setlinewidth
grestore
0 .93333 m
.00625 .93333 L
s
gsave
-0.0125 .93333 -103.25 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03333 m
.00375 .03333 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .16667 m
.00375 .16667 L
s
0 .2 m
.00375 .2 L
s
0 .23333 m
.00375 .23333 L
s
0 .3 m
.00375 .3 L
s
0 .33333 m
.00375 .33333 L
s
0 .36667 m
.00375 .36667 L
s
0 .43333 m
.00375 .43333 L
s
0 .46667 m
.00375 .46667 L
s
0 .5 m
.00375 .5 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .63333 m
.00375 .63333 L
s
0 .7 m
.00375 .7 L
s
0 .73333 m
.00375 .73333 L
s
0 .76667 m
.00375 .76667 L
s
0 .83333 m
.00375 .83333 L
s
0 .86667 m
.00375 .86667 L
s
0 .9 m
.00375 .9 L
s
0 .96667 m
.00375 .96667 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -145.5 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.2 .99375 m
.2 1 L
s
.4 .99375 m
.4 1 L
s
.6 .99375 m
.6 1 L
s
.8 .99375 m
.8 1 L
s
.125 Mabswid
.05 .99625 m
.05 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.25 .99625 m
.25 1 L
s
.3 .99625 m
.3 1 L
s
.35 .99625 m
.35 1 L
s
.45 .99625 m
.45 1 L
s
.5 .99625 m
.5 1 L
s
.55 .99625 m
.55 1 L
s
.65 .99625 m
.65 1 L
s
.7 .99625 m
.7 1 L
s
.75 .99625 m
.75 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .13333 m
1 .13333 L
s
.99375 .26667 m
1 .26667 L
s
.99375 .4 m
1 .4 L
s
.99375 .53333 m
1 .53333 L
s
.99375 .66667 m
1 .66667 L
s
.99375 .8 m
1 .8 L
s
.99375 .93333 m
1 .93333 L
s
.125 Mabswid
.99625 .03333 m
1 .03333 L
s
.99625 .06667 m
1 .06667 L
s
.99625 .1 m
1 .1 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .2 m
1 .2 L
s
.99625 .23333 m
1 .23333 L
s
.99625 .3 m
1 .3 L
s
.99625 .33333 m
1 .33333 L
s
.99625 .36667 m
1 .36667 L
s
.99625 .43333 m
1 .43333 L
s
.99625 .46667 m
1 .46667 L
s
.99625 .5 m
1 .5 L
s
.99625 .56667 m
1 .56667 L
s
.99625 .6 m
1 .6 L
s
.99625 .63333 m
1 .63333 L
s
.99625 .7 m
1 .7 L
s
.99625 .73333 m
1 .73333 L
s
.99625 .76667 m
1 .76667 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .86667 m
1 .86667 L
s
.99625 .9 m
1 .9 L
s
.99625 .96667 m
1 .96667 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
2e-05 0 m
2e-05 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
2e-05 0 m
2e-05 .91358 L
.04191 .91358 L
.04191 0 L
F
0 g
.5 Mabswid
2e-05 0 m
2e-05 .91358 L
.04191 .91358 L
.04191 0 L
2e-05 0 L
s
1 0 0 r
.04191 0 m
.04191 .75601 L
.0838 .75601 L
.0838 0 L
F
0 g
.04191 0 m
.04191 .75601 L
.0838 .75601 L
.0838 0 L
.04191 0 L
s
1 0 0 r
.0838 0 m
.0838 .7194 L
.12569 .7194 L
.12569 0 L
F
0 g
.0838 0 m
.0838 .7194 L
.12569 .7194 L
.12569 0 L
.0838 0 L
s
1 0 0 r
.12569 0 m
.12569 .69235 L
.16758 .69235 L
.16758 0 L
F
0 g
.12569 0 m
.12569 .69235 L
.16758 .69235 L
.16758 0 L
.12569 0 L
s
1 0 0 r
.16758 0 m
.16758 .66847 L
.20947 .66847 L
.20947 0 L
F
0 g
.16758 0 m
.16758 .66847 L
.20947 .66847 L
.20947 0 L
.16758 0 L
s
1 0 0 r
.20947 0 m
.20947 .66529 L
.25136 .66529 L
.25136 0 L
F
0 g
.20947 0 m
.20947 .66529 L
.25136 .66529 L
.25136 0 L
.20947 0 L
s
1 0 0 r
.25136 0 m
.25136 .65415 L
.29326 .65415 L
.29326 0 L
F
0 g
.25136 0 m
.25136 .65415 L
.29326 .65415 L
.29326 0 L
.25136 0 L
s
1 0 0 r
.29326 0 m
.29326 .63982 L
.33515 .63982 L
.33515 0 L
F
0 g
.29326 0 m
.29326 .63982 L
.33515 .63982 L
.33515 0 L
.29326 0 L
s
1 0 0 r
.33515 0 m
.33515 .64619 L
.37704 .64619 L
.37704 0 L
F
0 g
.33515 0 m
.33515 .64619 L
.37704 .64619 L
.37704 0 L
.33515 0 L
s
1 0 0 r
.37704 0 m
.37704 .61277 L
.41893 .61277 L
.41893 0 L
F
0 g
.37704 0 m
.37704 .61277 L
.41893 .61277 L
.41893 0 L
.37704 0 L
s
1 0 0 r
.41893 0 m
.41893 .61913 L
.46082 .61913 L
.46082 0 L
F
0 g
.41893 0 m
.41893 .61913 L
.46082 .61913 L
.46082 0 L
.41893 0 L
s
1 0 0 r
.46082 0 m
.46082 .62391 L
.50271 .62391 L
.50271 0 L
F
0 g
.46082 0 m
.46082 .62391 L
.50271 .62391 L
.50271 0 L
.46082 0 L
s
1 0 0 r
.50271 0 m
.50271 .60799 L
.5446 .60799 L
.5446 0 L
F
0 g
.50271 0 m
.50271 .60799 L
.5446 .60799 L
.5446 0 L
.50271 0 L
s
1 0 0 r
.5446 0 m
.5446 .62391 L
.58649 .62391 L
.58649 0 L
F
0 g
.5446 0 m
.5446 .62391 L
.58649 .62391 L
.58649 0 L
.5446 0 L
s
1 0 0 r
.58649 0 m
.58649 .59048 L
.62838 .59048 L
.62838 0 L
F
0 g
.58649 0 m
.58649 .59048 L
.62838 .59048 L
.62838 0 L
.58649 0 L
s
1 0 0 r
.62838 0 m
.62838 .59367 L
.67027 .59367 L
.67027 0 L
F
0 g
.62838 0 m
.62838 .59367 L
.67027 .59367 L
.67027 0 L
.62838 0 L
s
1 0 0 r
.67027 0 m
.67027 .59367 L
.71216 .59367 L
.71216 0 L
F
0 g
.67027 0 m
.67027 .59367 L
.71216 .59367 L
.71216 0 L
.67027 0 L
s
1 0 0 r
.71216 0 m
.71216 .6064 L
.75405 .6064 L
.75405 0 L
F
0 g
.71216 0 m
.71216 .6064 L
.75405 .6064 L
.75405 0 L
.71216 0 L
s
1 0 0 r
.75405 0 m
.75405 .58093 L
.79595 .58093 L
.79595 0 L
F
0 g
.75405 0 m
.75405 .58093 L
.79595 .58093 L
.79595 0 L
.75405 0 L
s
1 0 0 r
.79595 0 m
.79595 .60162 L
.83784 .60162 L
.83784 0 L
F
0 g
.79595 0 m
.79595 .60162 L
.83784 .60162 L
.83784 0 L
.79595 0 L
s
1 0 0 r
.83784 0 m
.83784 .58253 L
.87973 .58253 L
.87973 0 L
F
0 g
.83784 0 m
.83784 .58253 L
.87973 .58253 L
.87973 0 L
.83784 0 L
s
1 0 0 r
.87973 0 m
.87973 .57138 L
.92162 .57138 L
.92162 0 L
F
0 g
.87973 0 m
.87973 .57138 L
.92162 .57138 L
.92162 0 L
.87973 0 L
s
1 0 0 r
.92162 0 m
.92162 .60799 L
.96351 .60799 L
.96351 0 L
F
0 g
.92162 0 m
.92162 .60799 L
.96351 .60799 L
.96351 0 L
.92162 0 L
s
1 0 0 r
.96351 0 m
.96351 .5682 L
1.0054 .5682 L
1.0054 0 L
F
0 g
.96351 0 m
.96351 .5682 L
s
.96351 .5682 m
1 .5682 L
s
.96351 0 m
0 0 rlineto s
1 0 0 r
1.0054 0 m
1.0054 .57457 L
1.04729 .57457 L
1.04729 0 L
F
0 g
.015 w
.00788 1 m
.00884 .98258 L
.0118 .9425 L
.01478 .91342 L
.01806 .88899 L
.0247 .85337 L
.03118 .82868 L
.03814 .80843 L
.05073 .7814 L
.06553 .75863 L
.07961 .7422 L
.10603 .71925 L
.13202 .70263 L
.15616 .69041 L
.20751 .67067 L
.26209 .65527 L
.31468 .6437 L
.36527 .63457 L
.41909 .62637 L
.47092 .61959 L
.52075 .61385 L
.57381 .60841 L
.62487 .60372 L
.67916 .5992 L
.73146 .59523 L
.78176 .59171 L
.83529 .58826 L
.88683 .58516 L
.93637 .58238 L
.98914 .57961 L
s
.98914 .57961 m
1 .57907 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool008gooooo
00Co410@o`000?l0003o0000F_ooool008kooooo00?o0000ooooooooool0F_ooool008kooooo00?o
0000ooooooooool0F_ooool008kooooo00Ko0000ohN7Qol@413o0000oa0@4?mgMgMGooooo`00S_oo
ool01ol0003o8B4Qolc<c?ooooooc<c<ob4Q8OmgMgL0E_ooool008kooooo00?o0000olc<c?ooool0
0_ooool00oo<c<co410@ooooo`1Eooooo`00S_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo05Cooooo002>ooooo`03o`000?o<c<cooooo00;ooooo00?oc<c<oa0@4?ooool0EOooool0
08kooooo00Oo0000ob4Q8Oo<c<cooooookZj^_lQ8B7oZJVY05Kooooo002=ooooo`07oa0@4?l0003o
QhN7oa0@4?l0003o410@ojVYZ@1Gooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo001Gooooo`Ko00001_ooool0
1?nHV9So0000o`000?nHV9P6ooooo`05oiRHV?l0003o0000oiRHV?ooool00_l000001?l@413ooooo
oooooonHV9P2o`000004oiRHV?l0003o0000oiRHV0?ooooo00CoV9RHo`000?l0003oV9RH0_l00000
1Olb<S;o0000o`000?mEEEGok^k^00;ooooo00CoV9RHo`000?l0003oV9RH0_l000001OnHV9Sooooo
ooooooooooooV9RH00;o000000GoV9RHo`000?l0003oSHf=oeEEE@02o`000004oeEEEOo^k^kooooo
oiRHV0;o00000_nHV9P2o`000004oiRHV?oooooooooooiRHV0Ko000000?oV9RHooooooooool00_oo
ool00onHV9So0000o`000002o`000003oiRHV?oooooooooo00;ooooo00?oV9RHo`000?l000000_l0
00000onHV9Soooooooooo`02ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00CoV9RHo`000?l0003o
V9RH1_ooool01?nHV9So0000o`000?nHV9P4ooooo`00Eoooool00onHV9So0000omgMg@02ooooo`03
oa0@4?oooooooooo00?ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`08okZj^_lQ8B7o
gMgMomgMgOlQ8B7o^[Zjooooool00002ooooo`0ZokZj^_lQ8B7ogMgMoj:RX_lQ8B7oXJ6QomgMgOlQ
8B7o^[Zjoooooonj^[[o8B4QomgMgOnRXZ;o8B4Qoj6QXOmWIfOo3`l?okZj^_ooooooMgMgoeEEEOoo
oooo^[Zjob4Q8OoMgMgoXZ:Rob4Q8OnQXJ7ogMgMob4Q8Onj^[[ooooookZj^_lQ8B7ogMgMoj:RX_lQ
8B7oXJ6QomgMgOl;2`_oEUIF0_ooool01?mgMgOoEEEEokZj^_lQ8B42omgMg@;o61PH0_oMgMd01?lQ
8B7o^[ZjokZj^_lQ8B42omgMg@06o`000?lH61SogMgMomgMgOlQ8B7o^[Zj0_ooool02?nj^[[o8B4Q
oj6QXOlL71co7AdMoj:RX_lQ8B7o^[Zj0_ooool02?nj^[[o8B4Qoj6QXOlL71co7AdMoj:RX_lQ8B7o
^[Zj0_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PCooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q
8Onj^[X4ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj0oooool005Sooooo00?oQhN7ob4Q8Oo^
k^h01oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo00?oA4A4oiRHV?ooool01_l00000
5?ooooooA4A4oiRHV?ooooooA4A4oiRHV?m4A4CooooooiRHV?m4A4CoooooodA4A?nHV9SoooooodA4
A?nHV9SoA4A4ob4Q8OnHV9SoA4A40_ooool05Ol0003oooooodA4A?nHV9SoooooodA4A?nHV9SoA4A4
oooooonHV9SoA4A4oooooom4A4CoV9RHoooooom4A4CoV9RHodA4A?oooooo0000odA4A003ooooo`03
o`000?m4A4CoV9RH00;ooooo0_lX:2P2ooooo`04oiRHV?m4A4CoA4A4oiRHV0;ooooo00Ko0000obPX
:?oooooooooooiRHV?m4A4@2ooooo`03odA4A?nHV9SoA4A400;oV9RH00?oA4A4oiRHV?m4A4@00_oo
ool00om4A4CoV9RHodA4A002oiRHV003odA4A?nHV9SoA4A400;ooooo00KoA4A4oiRHV?oooooooooo
oiRHV?m4A4@4ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41?ooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A0?ooooo001Iooooo`03ojVYZOlQ8B7ok^k^00Kooooo00Ko0000onk^k_oooooooooo
onk^k_l00004ooooo`08o`000?o^k^koooooodA4A?n^[Zko0000ooooool00002ooooo`0?o`000?o^
k^koooooo`000?o^k^ko0000ooooooo^k^ko0000ooooool0003ok^k^ooooool0003ok^k^00;o0000
01Ook^k^o`000?ooooooooooo`000?oooooo0000onk^k_oooooo0000onk^k_l0003oooooonk^k_l0
003oooooo`000?o^k^koooooo`000?o^k^ko0000ooooo`02o`0000?ooooo0_l000000oo^k^kooooo
ooooo`02o`0000;ooooo00Cok^k^o`000?l0003ok^k^0_ooool2o`0000;ooooo00Ook^k^o`000?oo
ooooooooo`000?o^k^ko000000;ok^k^00?o0000onk^k_l000000_ooool00ol0003ok^k^o`000002
onk^kP03o`000?o^k^ko000000;ooooo00Ko0000onk^k_ooooooooooonk^k_l00004ooooo`06o`00
0?o^k^koooooooooooo^k^ko00001?ooool01_l0003ok^k^ooooooooooook^k^o`0000?ooooo001J
ooooo`03oiRHV?lb<S;ooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`08o`000?ooooooooooomgMgOlQ8B7o0000ooooool00002ooooo`06o`000?ooooooooooo`00
0?oooooo00000_ooool00ol0003oooooo`000002ooooo`0;o`000?oooooo0000o`000?mEEEGo0000
oooooomgMgOoEEEEooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo0000
00;ooooo00Ko0000ooooool0003ooooooeEEEOl00002ooooo`03ogMgMomEEEGo000000?ooooo0_l0
0003ooooo`;o00000oooool2o`0000?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`01ooooo`00
Foooool00om4A4CoMgMgooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool02?l0003oooooooooooooooooMgMgo`000?oooooo00000_ooool01_l0003oooooooooool0
003oooooo`0000;ooooo00?o0000ooooool000000_ooool01Ol0003oooooo`000?l0003oMgMg00;o
000000CoEEEEonk^k_oooooo00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo0000
00;ooooo00Go0000ooooool0003oooooomgMg@04o`000003omgMgOl0003ooooo00;ooooo0_l00003
ooooo`;o00000oooool2o`0000?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`01ooooo`00Fooo
ool00ooMgMgo410@ooooo`04ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool02?l0003o
k^k^ooooooooooook^k^o`000?oooooo00000_ooool04ol0003ok^k^ooooool0003ok^k^o`000?oo
ooook^k^o`000?oooooo0000onk^k_oooooo0000onk^k_l0003oA4A4ohj>S_l000001?ooool04ol0
003ok^k^ooooool0003ok^k^o`000?ooooook^k^o`000?oooooo0000onk^k_oooooo0000onk^k_l0
003oooooobl_;ol000000_o^k^h01?mVIVKo<S8bo`000?o^k^h2ooooo`;o00000_ooool01?o^k^ko
0000o`000?o^k^h2ooooo`;o00000_ooool01oo^k^ko0000oooooooooooo0000onk^k_l000000_o^
k^h00ol0003ok^k^o`000002ooooo`03o`000?o^k^ko000000;ok^k^00?o0000onk^k_l000000_oo
ool01_l0003ok^k^ooooooooooook^k^o`0000Cooooo00Ko0000onk^k_ooooooooooonk^k_l00004
ooooo`06o`000?o^k^koooooooooooo^k^ko00000oooool005cooooo00?o0000ooooooooool00ooo
ool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo00SoA4A4oiRHV?oooooooooooiRHV?lO7aoo
V9RHo`0000;ooooo01?oA4A4oiRHV?ooooooA4A4oiRHV?m4A4CooooooiRHV?m4A4CoooooodA4A?nH
V9SoooooodA4A?nHV9SoA4A4okZj^_lD51CoA4A400Cooooo01?oA4A4oiRHV?ooooooA4A4oiRHV?m4
A4CooooooiRHV?m4A4CoooooodA4A?nHV9SoooooodA4A?nHV9SoA4A4ooooool0003oA4A400?ooooo
00?o0000odA4A?nHV9P00_ooool2obPX:0;ooooo00CoV9RHodA4A?m4A4CoV9RH0_ooool01_l0003o
:2PXooooooooooooV9RHodA4A0;ooooo00?oA4A4oiRHV?m4A4@00_nHV9P00om4A4CoV9RHodA4A002
ooooo`03odA4A?nHV9SoA4A400;oV9RH00?oA4A4oiRHV?m4A4@00_ooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A0Cooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@4ooooo`06odA4A?nHV9Sooooo
oooooonHV9SoA4A40oooool005Oooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED5ooooo`06okZj
^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool02?nj^[[o8B4QomgMgOoMgMgo8B4Qojf][Olb<S;o0000
0_ooool05?nj^[[o8B4QomgMgOnRXZ;o8B4Qoj6QXOoMgMgo8B4QokZj^_oooooo^[Zjob4Q8OoMgMgo
XZ:Rob4Q8OnQXJ7ogMgMo`/;2olU9BGogMgM0oooool04onj^[[o8B4QomgMgOnRXZ;o8B4Qoj6QXOoM
gMgo8B4QokZj^_oooooo^[Zjob4Q8OoMgMgoXZ:Rob4Q8OnQXJ7ogMgMo`H61_m:BTX00_o^k^h01?mV
IVKo<S8bokZj^_lQ8B42omgMg@;o61PH0_oMgMd02?lQ8B7o^[ZjokZj^_lQ8B7o0000ocXj>_l0003o
61PH0_oMgMd03?lQ8B7o^[Zjoooooooooooo^[Zjob4Q8OnQXJ7o71`LoadM7OnRXZ;o8B4QokZj^P;o
oooo00So^[Zjob4Q8OnQXJ7o71`LoadM7OnRXZ;o8B4QokZj^P;ooooo00Ko^[Zjob4Q8OoMgMgogMgM
ob4Q8Onj^[X4ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_nj^[[o8B4QomgMgOoM
gMgo8B4QokZj^P?ooooo001Gooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^1_ooool01?nHV9So
0000o`000?nHV9P6ooooo`07oiRHV?l0003o0000oiRHV?ooooooV9RHoa0@4003ooooo`04oiRHV?l0
003o0000oiRHV0;o000000GoV9RHoooooooooooooooooiRHV002o`000003oiRHV?l0003o000000;o
V9RH00?o8B4Qo`000?lQ8B400_ooool01?nHV9So0000o`000?nHV9P2o`000005oiRHV?oooooooooo
oooooonHV9P00_l000001OnHV9So0000o`000?n=SHgoA4A400;o000000CoA4A4onk^k_ooooooV9RH
0_l00002oiRHV0;o000000CoV9RHooooooooooooV9RH0ol000001?nHV9So0000o`000?nHV9P4oooo
o`03oiRHV?l0003o000000;o000000?oV9RHooooooooool00_ooool00onHV9So0000o`000002o`00
0003oiRHV?oooooooooo00;ooooo00CoV9RHo`000?l0003oV9RH1_ooool01?nHV9So0000o`000?nH
V9P6ooooo`04oiRHV?l0003o0000oiRHV0Cooooo003[ooooo`00joooool00>_ooooo001FooooogKo
00007oooool005Kooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`007oooool005Ko
oooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`007oooool005Kooooo00?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`007oooool005Kooooo00?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`007oooool005Kooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`007oooool005Kooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`007oooool005Ko
oooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`007oooool005Kooooo00?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`007oooool005Kooooo00?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`007oooool005Kooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`007oooool005Kooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`007oooool005Ko
oooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`007oooool0033ooooo00CoV9RHo`00
0?l0003oV9RH1_ooool00omEEEGo0000oeEEE@07ooooo`04oiRHV?l0003o0000oiRHV0Cooooo1_l0
0004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool001oooooo000_ooooo`06okZj
^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj
^[X3ooooo`03oiRHV?l0003ogMgM00;ooooo00?o410@ooooooooool00_ooool00ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo000Oooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4
A0Gooooo00?oEEEEo`000?mEEED01_ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo00?o
QhN7ob4Q8Oo^k^h01_ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo000Oooooo`00
;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00Ko0000onk^k_ooooooooooonk^k_l0
0005ooooo`03ojVYZOlQ8B7ok^k^00Gooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`007oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00onHV9So<S8booooo`04ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool001oooooo000_ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00?oA4A4ogMgMoooool00oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo000O
ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00Ko0000onk^k_oooooooooo
onk^k_l00007ooooo`03omgMgOl@413ooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`007oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@>ooooo`06odA4A?nH
V9SooooooooooonHV9SoA4A42?ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool001oooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_oo
ool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^P?ooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED4
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool001oooooo000`ooooo`04oiRHV?l0
003o0000oiRHV13ooooo00CoV9RHo`000?l0003oV9RH1?ooool01_nYZJWo<S8bo`000?l0003oEEEE
onk^kPCooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`007oooool005Kooooo00?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`007oooool005Kooooo00?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`007oooool005Kooooo00?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`007oooool005Kooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`007ooo
ool005Kooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`007oooool0033ooooo00Co
V9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@07ooooo`04oiRHV?l0003o0000oiRHV0So
oooo0_l000001Ol@413ooooooooooooooooo000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool001oooooo000_
ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo00Ko^[Zjob4Q8OoMgMgo
gMgMob4Q8Onj^[X8ooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`007oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEE
EOl0003oEEEE00Kooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@4ooooo`Ko00000oooool00ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo000Oooooo`00;oooool01_l0003ok^k^oooooooo
ooook^k^o`0000kooooo00Ko0000onk^k_ooooooooooonk^k_l00004ooooo`05odA4A?nj^[[ooooo
ooooool000001?ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo000Oooooo`00;ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`05omgMgOlQ8B7oooooooooool000001?ooool00ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo000Oooooo`00;oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04
ogMgMonHV9Soooooo`0000Cooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`007ooo
ool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`06o`000?o^k^koooooooooooo^
k^ko00001Oooool01?o^k^ko8B4Qooooool00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool001oooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A43_ooool01_m4A4Co
V9RHooooooooooooV9RHodA4A0Kooooo00?oMgMgoiRHV?l000001?ooool00ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo000Oooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pko
oooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X6ooooo`03onk^k_lb<S;o000000Cooooo00?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`007oooool0033ooooo00CoV9RHo`000?l0003oV9RH
4?ooool01?nHV9So0000o`000?nHV9P8ooooo`03oiRHV?l@413ooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`007oooool005Kooooo00?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`007oooool005Kooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
7oooool005Kooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`007oooool005Kooooo
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`007oooool005Kooooo00?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`007oooool005Kooooo00?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`007oooool0033ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEE
E@07ooooo`04oiRHV?l0003o0000oiRHV0Gooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h3oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool001oooooo000_ooooo`06okZj^_lQ8B7o
gMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4oooo
o`;oMgMg0_ooool00omgMgOoEEEEooooo`02ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool001oooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000
oeEEE@06ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41?ooool00olQ8B7oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`007oooool002oooooo00Ko
0000onk^k_ooooooooooonk^k_l0000>ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool0
0ol0003ok^k^ooooo`02ooooo`05o`000?ooooooooooooooool000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`007oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01_l0003oEEEEonk^k_ooooooMgMgoeEE
E@?ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`007oooool002oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool01_l0003oMgMgo`000?l0003oEEEEonk^kP?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`007oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>
ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool00om4A4CoV9RHooooo`06ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool001oooooo000_ooooo`06odA4A?nHV9Sooooooooo
oonHV9SoA4A43_ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo00?o^[Zjob4Q8Oooool0
1_ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo000Oooooo`00;oooool01_nj^[[o
8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`03oeEE
EOlb<S;ogMgM00Gooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`007oooool0013o
oooo00?o^[Zjoc8b<_ooool00oooool01?l@413o0000o`000?l00007ooooo`03oc8b<_nj^[[ooooo
00cooooo00CoV9RHo`000?l0003oV9RH4?ooool01?nHV9So0000o`000?nHV9P7ooooo`04oiRHV?lQ
8B7o0000ob4Q8@?ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`007oooool000?o
oooo00?o0000ooooooooool02_ooool00olb<S;o^[Zjooooo`04ooooo`03o`000?oooooooooo00Oo
oooo00?o^[Zjoc8b<_ooool0<_ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo000O
ooooo`000oooool00olb<S;o^[Zjooooo`09ooooo`03olc<c?lb<S;ooooo00Gooooo00?o0000oooo
ooooool02?ooool00olb<S;oc<c<ooooo`0aooooo`03o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool001oooooo0003ooooo`03ogMgMon7QhOoMgMg00;o000000?oA4A4olc<c?ooool01?ooool0
0omVIVKoZJVYooooo`05ooooo`06o`000?n7QhOo410@o`000?l@413oMgMg1Oooool00onHV9SoIVIV
ooooo`0aooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool001oooooo0003ooooo`08
oiRHV?l@413oQhN7onk^k_ooooooV9RHoa0@4?o<c<`4ooooo`03oc8b<_oooooooooo00Gooooo00Oo
0000ob4Q8Oo<c<coooooolc<c?lQ8B7oMgMg00Cooooo00?ok^k^oc8b<_ooool0<Oooool00ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo000Oooooo`000oooool00onj^[[o<S8booooo`03oooo
o`03oiRHV?m4A4Cooooo00?ooooo00?o<S8booooooooool01Oooool00ol0003oc<c<ooooo`02oooo
o`03olc<c?l@413ooooo00Cooooo00?o0000ooooooooool0<?ooool00ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo000Oooooo`001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o<S8booooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0<?ooool00ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo000Oooooo`001?ooool00om4A4CoV9RHooooo`02ooooo`03onk^k_l0003ooooo00?ooooo00?o
8B4Qooooooooool01Oooool00ol0003oc<c<ooooo`02ooooo`03olc<c?l@413ooooo00Cooooo00?o
0000ooooooooool02_ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Oooooo
00CoV9RHo`000?l0003oV9RH1Oooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP?ooooo00?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`007oooool000Cooooo00Oo^[Zjo`000?nj^[[ooooo
onk^k_mVIVKoEEEE00Cooooo00?o<S8bonk^k_ooool01Oooool01ol0003o8B4Qolc<c?oooooo^[Zj
ob4Q8OnYZJT01?ooool00ooMgMgo<S8booooo`0:ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj
1Oooool3o`0000Kooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`06oeEEEOmgMgOooooo
oooooomgMgOoEEEE0oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo000Oooooo`00
1Oooool01_nYZJWo8B4Qo`000?l0003oEEEEonk^kPCooooo00?oIVIVoiRHV?ooool01?ooool01ol@
413o0000ohN7Qol@413o0000oa0@4?nYZJT01Oooool00onHV9SoIVIVooooo`0:ooooo`06odA4A?nH
V9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`06odA4A?nHV9Sooooooooo
oonHV9SoA4A41?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`007oooool000oooooo00?ogMgMob4Q8Oooool04?ooool00ol@413oc<c<
ooooo`0:ooooo`06o`000?o^k^koooooooooooo^k^ko00003_ooool01_l0003ok^k^oooooooooooo
k^k^o`0000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool001oooooo000@ooooo`03oc8b<_nj^[[ooooo00kooooo00?o^[Zjoc8b<_oo
ool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool0
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo000Oooooo`004?ooool00onj^[[o<S8boooo
o`0>ooooo`03oc8b<_nj^[[ooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ooMgMgo0000o`00
0002o`000005omgMgOooooooooooooooool000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`007oooool002oo
oooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`06o`000?o^k^koooooooooooo^k^ko0000
1?ooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<P?ooooo00?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`007oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@>ooooo`06odA4
A?nHV9SooooooooooonHV9SoA4A41?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`001_l00004ool000Co000000?oo`00ooooooooool0
7Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X>ooooo`06okZj^_lQ8B7ogMgMomgM
gOlQ8B7o^[Zj1?ooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<P?ooooo00?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`001_l00004ool000Ko00000oooool;o`0001oooooo000`ooooo`04
oiRHV?l0003o0000oiRHV13ooooo00CoV9RHo`000?l0003oV9RH1Oooool01_o^k^koA4A4o`000?l0
003oA4A4onk^kP?ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000Go00001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`004ol000000ooooooo0000ool00003ool00005
o`000?ooooooooooooooool000007oooool005Kooooo00?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0004o`000?oooooooooooooooa3o00001?ooool6o`0000Wooooo00?o0000ool00?oo00000_oo0000
0ol0003oooooooooo`02o`0001oooooo001Fooooo`03o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool0017o00001oooool6o`0001?ooooo1_l00003ooooo`03o`000?oooooo
oooo01gooooo001Fooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool000Ko00001?oo00001?l0003oo`00ool00?oo0007o`0000Coo`0000?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0Mooooo`00E_ooool00ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oooooo`00000=o`0000Cooooo1_l0000_ooooo`03o`000?oo
oooooooo01gooooo001Fooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0007o`0004Kooooo0_l0
000Oooooo`00>Oooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Kooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00004o`000?oo003oo`00ool000Ko00001?oo00000ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo01gooooo000hooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o
^[Zj1Oooool3o`0000Sooooo00?o0000ooooooooool01Oooool00ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003o`0000?o
oooo1_l00018ooooo`03o`000?oooooooooo01gooooo000hooooo`06odA4A?nHV9SooooooooooonH
V9SoA4A41Oooool00omEEEGo0000oeEEE@08ooooo`03o`000?oooooooooo00Gooooo00?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00004o`000?oo003oo`00ool000Ko0000D_ooool0
0ol0003oooooooooo`0Mooooo`00>?ooool01_l0003ok^k^ooooooooooook^k^o`00013ooooo00?o
0000ooooooooool01Oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000_o0000EOooool2o`0001oooooo000h
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool00ol0001Kooooo`03o`000?oooooo
oooo01gooooo000hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`05ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`000ol0001Nooooo`03o`000?oooooooooo
01gooooo000hooooo`06o`000?o^k^koooooooooooo^k^ko00004?ooool00ol0003oooooooooo`05
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool000Ko0000H?ooool00ol0003oooooooooo`0Mooooo`00>?ooool01_m4A4CoV9RHoooooooooooo
V9RHodA4A13ooooo00?o0000ooooooooool01Oooool00ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo0002o`0006?ooooo0_l0000Oooooo`00>?ooool0
1_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00?o0000odA4A?l000001oooool00ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Co0000ool00?oo003oo`000_l0001Uooooo`03
o`000?oooooooooo01gooooo000iooooo`04oiRHV?l0003o0000oiRHV0oooooo00?oc<c<oeEEEOl0
00001oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`001_l0001Uooooo`03
o`000?oooooooooo01gooooo001Fooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo0002o`0006Wooooo00?o0000ooooooooool07Oooool005Kooooo00?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oooooooooo06Oooooo0_l0000Oooooo`00E_ooool0
0ol0003oo`00ool00002ool00004o`000?oo003oo`00ool000;o0000J_ooool00ol0003ooooooooo
o`0Mooooo`00E_ooool00ol0003oo`00ool00002ool000Ko0000J_ooool00ol0003oooooooooo`0M
ooooo`00E_ooool00ol0003oo`00ool00002ool00004o`000?ooooooooooo`0006cooooo00?o0000
ooooooooool07Oooool005Kooooo00?o0000ool00?oo00000_oo00000ol0003oooooo`00001/oooo
o`;o00007oooool0033ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@06oooo
o`Co000000?o410@ooooooooool00_ooool6o`0000Cooooo00?o0000ool00?oo00000_oo0002o`00
06kooooo00?o0000ooooooooool07Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5
ooooo`?o00002?ooool00ol0003oooooooooo`04ooooo`03oiRHV?l0003ogMgM00;ooooo00?o410@
ooooooooool00_ooool00ol0003oo`00ool00002ool000;o0000K_ooool00ol0003oooooooooo`0M
ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED02?oo
ool00ol0003oooooooooo`05ooooo`03ohN7QolQ8B7ok^k^00Kooooo00?o0000ool00?oo00000_oo
0002o`0006kooooo00?o0000ooooooooool07Oooool002oooooo00Ko0000onk^k_ooooooooooonk^
k_l0000@ooooo`03o`000?oooooooooo00Kooooo00?oZJVYob4Q8Oo^k^h01Oooool00ol0003oo`00
ool00002ool00003o`000?oooooooooo06cooooo0_l0000Oooooo`00;oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00onHV9So<S8boooo
o`04ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0Mooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool02?ooool00om4A4CoMgMgooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ooooooooool0KOooool00ol0003oooooooooo`0Mooooo`00;oooool01_l0003ok^k^oooooooooooo
k^k^o`00013ooooo00?o0000ooooooooool02?ooool00ooMgMgo410@ooooo`03ooooo`04o`000?oo
003oo`00ool000;o0000K_ooool2o`0001oooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9So
A4A44?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00Co0000ool00?oo
003oo`000_l0001_ooooo`03o`000?oooooooooo01gooooo000_ooooo`06okZj^_lQ8B7ogMgMomgM
gOlQ8B7o^[Zj3_ooool00ol0003oA4A4o`000006ooooo`06o`000?n7QhOok^k^oooooonHV9SoEEEE
1?ooool01_l0003oo`00ool00?l0003oo`00o`0006oooooo00?o0000ooooooooool07Oooool0033o
oooo00CoV9RHo`000?l0003oV9RH3oooool00oo<c<coEEEEo`000006ooooo`06ojVYZOlb<S;o0000
o`000?mEEEGok^k^1?ooool01_l0003oo`00ool00?l0003oo`00o`0006oooooo00?o0000oooooooo
ool07Oooool005Kooooo00Ko0000ool00?oo003o0000ool00?l0001^ooooo`;o00007oooool005Ko
oooo00Ko0000ool00?oo003o0000ool00?l0001_ooooo`03o`000?oooooooooo01gooooo001Foooo
o`03o`000?oo003o000000;oo`0000?o0000ooooooooool0KOooool00ol0003oooooooooo`0Moooo
o`00E_ooool00ol0003oo`00o`000002ool00003o`000?oooooooooo06gooooo00?o0000oooooooo
ool07Oooool005Kooooo00?o0000ool00?l000000_oo00000ol0003oooooooooo`1/ooooo`;o0000
7oooool0033ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@06ooooo`Co0000
00?o410@ooooooooool01_ooool2o`000007oa0@4?ooooooooooooooool0003oo`00o`000002ool0
0003o`000?oooooooooo06gooooo00?o0000ooooooooool07Oooool002oooooo00Ko^[Zjob4Q8OoM
gMgogMgMob4Q8Onj^[X5ooooo`?o00002?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00;ooooo1_l0001_ooooo`03o`000?oooooooooo01gooooo000_ooooo`06odA4A?nHV9Sooooo
oooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@08ooooo`03o`000?oooooooooo00Gooooo1_l0
0003ooooo`03o`000?oooooo000007;ooooo00?o0000ooooooooool07Oooool002oooooo00Ko0000
onk^k_ooooooooooonk^k_l0000@ooooo`03o`000?oooooooooo00Gooooo00GoA4A4okZj^_oooooo
ooooo`000004ooooo`?o0000LOooool2o`0001oooooo000_ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`05omgMgOlQ8B7oooooooooool0
00001?ooool00ol0003oooooo`00001booooo`03o`000?oooooooooo01gooooo000_ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`04ogMg
MonHV9Soooooo`0000Cooooo00?o0000ooooool00000L_ooool00ol0003oooooooooo`0Mooooo`00
;oooool01_l0003ok^k^ooooooooooook^k^o`00013ooooo00?o0000ooooooooool01_ooool01?o^
k^ko8B4Qooooool00004ooooo`03o`000?oooooo000007;ooooo00?o0000ooooooooool07Oooool0
02oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@@ooooo`03o`000?oooooooooo00Oooooo00?o
MgMgoiRHV?l000001?ooool2o`0007;ooooo0_l0000Oooooo`00;oooool01_nj^[[o8B4QomgMgOoM
gMgo8B4QokZj^Pkooooo00?o0000odA4A?l000002Oooool00oo^k^ko<S8bo`000004ooooo`;o0000
Loooool00ol0003oooooooooo`0Mooooo`00<?ooool01?nHV9So0000o`000?nHV9P?ooooo`03olc<
c?mEEEGo000000[ooooo00?oV9RHoa0@4?ooool00oooool2o`0007?ooooo00?o0000ooooooooool0
7Oooool005Kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07Ooo
ool005KoooooM_l0000Oooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0001\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-74330.2, -0.0987839, 857.452, \
0.00128618}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
To analyze the spacings between primes we must first account for \
their non-uniform density.  To do this we must \"unfold\" the sequence of \
primes.  For the primes, this means rescaling each prime p to e=Li(p), where \
Li(x) is the Log Integral function.  The code below carries out this \
unfolding and then computes a histogram displaying the density of the \
unfolded primes.  Note that the density is essentially uniform \
throughout.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n = 10000;\)\), "\n", 
    \(\(UP = Table[N[LogIntegral[Prime[i]]], {i, 1, n + 1}];\)\), "\n", 
    \(\(int = 
        Table[UP[\([1]\)] + i*\((UP[\([n]\)] - UP[\([1]\)])\)/25, {i, 0, 
            25}];\)\), "\n", 
    \(UPHist = 
      Histogram[UP, HistogramCategories \[Rule] int, 
        HistogramScale \[Rule] n, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<e\>", "\<\[Rho](e)\>"}, 
        RotateLabel \[Rule] False]\)}], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(UPHist\\)\\\" is similar to existing symbol \
\\\"\\!\\(PHist\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(Histogram::"rtail" \(\(:\)\(\ \)\) 
      "Warning: \!\(2\) points from the right tail of the data, greater than \
or equal to \!\(10039.736337105796`\), are not included in histogram."\)], \
"Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.000104114 9.96146e-05 0.0147151 0.572225 [
[.19913 -0.0125 -21.125 -18 ]
[.19913 -0.0125 21.125 0 ]
[.39835 -0.0125 -21.125 -18 ]
[.39835 -0.0125 21.125 0 ]
[.59758 -0.0125 -21.125 -18 ]
[.59758 -0.0125 21.125 0 ]
[.79681 -0.0125 -21.125 -18 ]
[.79681 -0.0125 21.125 0 ]
[.99604 -0.0125 -25.9062 -18 ]
[.99604 -0.0125 25.9062 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .12916 -32.6875 -9 ]
[-0.0125 .12916 0 9 ]
[-0.0125 .24361 -32.6875 -9 ]
[-0.0125 .24361 0 9 ]
[-0.0125 .35805 -32.6875 -9 ]
[-0.0125 .35805 0 9 ]
[-0.0125 .47249 -32.6875 -9 ]
[-0.0125 .47249 0 9 ]
[-0.0125 .58694 -13.5625 -9 ]
[-0.0125 .58694 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -74.9375 -9 ]
[-0.01875 .30902 -32.6875 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.19913 0 m
.19913 .00625 L
s
gsave
.19913 -0.0125 -82.125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
1.000 setlinewidth
grestore
.39835 0 m
.39835 .00625 L
s
gsave
.39835 -0.0125 -82.125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4000) show
1.000 setlinewidth
grestore
.59758 0 m
.59758 .00625 L
s
gsave
.59758 -0.0125 -82.125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6000) show
1.000 setlinewidth
grestore
.79681 0 m
.79681 .00625 L
s
gsave
.79681 -0.0125 -82.125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8000) show
1.000 setlinewidth
grestore
.99604 0 m
.99604 .00625 L
s
gsave
.99604 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10000) show
1.000 setlinewidth
grestore
.125 Mabswid
.0497 0 m
.0497 .00375 L
s
.09951 0 m
.09951 .00375 L
s
.14932 0 m
.14932 .00375 L
s
.24893 0 m
.24893 .00375 L
s
.29874 0 m
.29874 .00375 L
s
.34855 0 m
.34855 .00375 L
s
.44816 0 m
.44816 .00375 L
s
.49797 0 m
.49797 .00375 L
s
.54778 0 m
.54778 .00375 L
s
.64739 0 m
.64739 .00375 L
s
.6972 0 m
.6972 .00375 L
s
.74701 0 m
.74701 .00375 L
s
.84662 0 m
.84662 .00375 L
s
.89643 0 m
.89643 .00375 L
s
.94623 0 m
.94623 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .12916 m
.00625 .12916 L
s
gsave
-0.0125 .12916 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .24361 m
.00625 .24361 L
s
gsave
-0.0125 .24361 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .35805 m
.00625 .35805 L
s
gsave
-0.0125 .35805 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .47249 m
.00625 .47249 L
s
gsave
-0.0125 .47249 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .58694 m
.00625 .58694 L
s
gsave
-0.0125 .58694 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04333 m
.00375 .04333 L
s
0 .07194 m
.00375 .07194 L
s
0 .10055 m
.00375 .10055 L
s
0 .15777 m
.00375 .15777 L
s
0 .18638 m
.00375 .18638 L
s
0 .21499 m
.00375 .21499 L
s
0 .27222 m
.00375 .27222 L
s
0 .30083 m
.00375 .30083 L
s
0 .32944 m
.00375 .32944 L
s
0 .38666 m
.00375 .38666 L
s
0 .41527 m
.00375 .41527 L
s
0 .44388 m
.00375 .44388 L
s
0 .50111 m
.00375 .50111 L
s
0 .52972 m
.00375 .52972 L
s
0 .55833 m
.00375 .55833 L
s
0 .61555 m
.00375 .61555 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.19913 .61178 m
.19913 .61803 L
s
.39835 .61178 m
.39835 .61803 L
s
.59758 .61178 m
.59758 .61803 L
s
.79681 .61178 m
.79681 .61803 L
s
.99604 .61178 m
.99604 .61803 L
s
.125 Mabswid
.0497 .61428 m
.0497 .61803 L
s
.09951 .61428 m
.09951 .61803 L
s
.14932 .61428 m
.14932 .61803 L
s
.24893 .61428 m
.24893 .61803 L
s
.29874 .61428 m
.29874 .61803 L
s
.34855 .61428 m
.34855 .61803 L
s
.44816 .61428 m
.44816 .61803 L
s
.49797 .61428 m
.49797 .61803 L
s
.54778 .61428 m
.54778 .61803 L
s
.64739 .61428 m
.64739 .61803 L
s
.6972 .61428 m
.6972 .61803 L
s
.74701 .61428 m
.74701 .61803 L
s
.84662 .61428 m
.84662 .61803 L
s
.89643 .61428 m
.89643 .61803 L
s
.94623 .61428 m
.94623 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12916 m
1 .12916 L
s
.99375 .24361 m
1 .24361 L
s
.99375 .35805 m
1 .35805 L
s
.99375 .47249 m
1 .47249 L
s
.99375 .58694 m
1 .58694 L
s
.125 Mabswid
.99625 .04333 m
1 .04333 L
s
.99625 .07194 m
1 .07194 L
s
.99625 .10055 m
1 .10055 L
s
.99625 .15777 m
1 .15777 L
s
.99625 .18638 m
1 .18638 L
s
.99625 .21499 m
1 .21499 L
s
.99625 .27222 m
1 .27222 L
s
.99625 .30083 m
1 .30083 L
s
.99625 .32944 m
1 .32944 L
s
.99625 .38666 m
1 .38666 L
s
.99625 .41527 m
1 .41527 L
s
.99625 .44388 m
1 .44388 L
s
.99625 .50111 m
1 .50111 L
s
.99625 .52972 m
1 .52972 L
s
.99625 .55833 m
1 .55833 L
s
.99625 .61555 m
1 .61555 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .56769 L
.04 .56769 L
.04 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .56769 L
.04 .56769 L
.04 .01472 L
0 .01472 L
s
1 0 0 r
.04 .01472 m
.04 .58194 L
.08 .58194 L
.08 .01472 L
F
0 g
.04 .01472 m
.04 .58194 L
.08 .58194 L
.08 .01472 L
.04 .01472 L
s
1 0 0 r
.08 .01472 m
.08 .58764 L
.12 .58764 L
.12 .01472 L
F
0 g
.08 .01472 m
.08 .58764 L
.12 .58764 L
.12 .01472 L
.08 .01472 L
s
1 0 0 r
.12 .01472 m
.12 .58194 L
.16 .58194 L
.16 .01472 L
F
0 g
.12 .01472 m
.12 .58194 L
.16 .58194 L
.16 .01472 L
.12 .01472 L
s
1 0 0 r
.16 .01472 m
.16 .58337 L
.2 .58337 L
.2 .01472 L
F
0 g
.16 .01472 m
.16 .58337 L
.2 .58337 L
.2 .01472 L
.16 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .58337 L
.24 .58337 L
.24 .01472 L
F
0 g
.2 .01472 m
.2 .58337 L
.24 .58337 L
.24 .01472 L
.2 .01472 L
s
1 0 0 r
.24 .01472 m
.24 .58622 L
.28 .58622 L
.28 .01472 L
F
0 g
.24 .01472 m
.24 .58622 L
.28 .58622 L
.28 .01472 L
.24 .01472 L
s
1 0 0 r
.28 .01472 m
.28 .58907 L
.32 .58907 L
.32 .01472 L
F
0 g
.28 .01472 m
.28 .58907 L
.32 .58907 L
.32 .01472 L
.28 .01472 L
s
1 0 0 r
.32 .01472 m
.32 .58337 L
.36 .58337 L
.36 .01472 L
F
0 g
.32 .01472 m
.32 .58337 L
.36 .58337 L
.36 .01472 L
.32 .01472 L
s
1 0 0 r
.36 .01472 m
.36 .59334 L
.4 .59334 L
.4 .01472 L
F
0 g
.36 .01472 m
.36 .59334 L
.4 .59334 L
.4 .01472 L
.36 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .57767 L
.44 .57767 L
.44 .01472 L
F
0 g
.4 .01472 m
.4 .57767 L
.44 .57767 L
.44 .01472 L
.4 .01472 L
s
1 0 0 r
.44 .01472 m
.44 .57767 L
.48 .57767 L
.48 .01472 L
F
0 g
.44 .01472 m
.44 .57767 L
.48 .57767 L
.48 .01472 L
.44 .01472 L
s
1 0 0 r
.48 .01472 m
.48 .59334 L
.52 .59334 L
.52 .01472 L
F
0 g
.48 .01472 m
.48 .59334 L
.52 .59334 L
.52 .01472 L
.48 .01472 L
s
1 0 0 r
.52 .01472 m
.52 .58052 L
.56 .58052 L
.56 .01472 L
F
0 g
.52 .01472 m
.52 .58052 L
.56 .58052 L
.56 .01472 L
.52 .01472 L
s
1 0 0 r
.56 .01472 m
.56 .60189 L
.6 .60189 L
.6 .01472 L
F
0 g
.56 .01472 m
.56 .60189 L
.6 .60189 L
.6 .01472 L
.56 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .58194 L
.64 .58194 L
.64 .01472 L
F
0 g
.6 .01472 m
.6 .58194 L
.64 .58194 L
.64 .01472 L
.6 .01472 L
s
1 0 0 r
.64 .01472 m
.64 .58052 L
.68 .58052 L
.68 .01472 L
F
0 g
.64 .01472 m
.64 .58052 L
.68 .58052 L
.68 .01472 L
.64 .01472 L
s
1 0 0 r
.68 .01472 m
.68 .58337 L
.72 .58337 L
.72 .01472 L
F
0 g
.68 .01472 m
.68 .58337 L
.72 .58337 L
.72 .01472 L
.68 .01472 L
s
1 0 0 r
.72 .01472 m
.72 .57482 L
.76 .57482 L
.76 .01472 L
F
0 g
.72 .01472 m
.72 .57482 L
.76 .57482 L
.76 .01472 L
.72 .01472 L
s
1 0 0 r
.76 .01472 m
.76 .60047 L
.8 .60047 L
.8 .01472 L
F
0 g
.76 .01472 m
.76 .60047 L
.8 .60047 L
.8 .01472 L
.76 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .58052 L
.84 .58052 L
.84 .01472 L
F
0 g
.8 .01472 m
.8 .58052 L
.84 .58052 L
.84 .01472 L
.8 .01472 L
s
1 0 0 r
.84 .01472 m
.84 .58337 L
.88 .58337 L
.88 .01472 L
F
0 g
.84 .01472 m
.84 .58337 L
.88 .58337 L
.88 .01472 L
.84 .01472 L
s
1 0 0 r
.88 .01472 m
.88 .60332 L
.92 .60332 L
.92 .01472 L
F
0 g
.88 .01472 m
.88 .60332 L
.92 .60332 L
.92 .01472 L
.88 .01472 L
s
1 0 0 r
.92 .01472 m
.92 .57482 L
.96 .57482 L
.96 .01472 L
F
0 g
.92 .01472 m
.92 .57482 L
.96 .57482 L
.96 .01472 L
.92 .01472 L
s
1 0 0 r
.96 .01472 m
.96 .58622 L
1 .58622 L
1 .01472 L
F
0 g
.96 .01472 m
.96 .58622 L
1 .58622 L
1 .01472 L
.96 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo002<ooooo`06ogMgMol@413o0000oa0@4?mEEEGogMgMFOooool008_ooooo00OoMgMgodA4
A?oMgMgoooooomgMgOn7QhOo8B4Q05Wooooo002;ooooo`03oa0@4?o^k^kooooo05gooooo002;oooo
o`Oo0000FOooool008_ooooo00?o410@omgMgOooool00_ooool00ooMgMgo0000ooooo`1Hooooo`00
Roooool01on7QhOo8B4QokZj^_oooooogMgMob4Q8OmgMgL0FOooool008cooooo00GoQhN7oa0@4?l0
003o410@ogMgM`1Jooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo001Eooooo`Ko00001_ooool01?nHV9So0000
o`000?nHV9P6ooooo`04oiRHV?l0003o0000oiRHV0Cooooo0_l000001?l:2P[o0000o`000?nHV9P2
ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00OoV9RHo`000?l0003oV9RHooooooo^k^koEEEE00;o
000000GoEEEEohf=SOl0003o0000oiRHV002ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00OoV9RH
o`000?l0003oV9RHooooooo^k^koEEEE00;o000000GoEEEEohf=SOl0003o0000oiRHV002ooooo`04
oiRHV?l0003o0000oiRHV0Kooooo00?oV9RHo`000?l000000_l000000ol@413oooooooooo`02oooo
o`03oiRHV?l0003o000000;o000000?oV9RHooooooooool01?ooool01?nHV9So0000o`000?nHV9P6
ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00CoV9RHo`000?l0003oV9RH1?ooool005Gooooo00?o
V9RHo`000?oMgMd00_ooool00ol@413oooooooooo`03ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o
^[Zj1?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PCooooo00Go0000ob4Q8OoMgMgogMgMob4Q
8@02okZj^P05ob4Q8OoMgMgogMgMob4Q8Onj^[X01?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj
^P;oMgMg0_ooool01OmFEUKo2`/;omgMgOoMgMgo8B4Q00;o^[Zj00Go8B4QomgMgOoMgMgo8B4QokZj
^P04ooooo`08okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[ZjoeEEEOmgMgL2ooooo`05oeIFE_l;2`_ogMgM
omgMgOlQ8B400_nj^[X01OlQ8B7ogMgMomgMgOlQ8B7o^[Zj00Cooooo00Ko^[Zjob4Q8OoMgMgogMgM
o`000?nj^[X4ooooo`08okZj^_lQ8B7oXZ:RoadM7OlL71coXJ6Qob4Q8Onj^[X4ooooo`06okZj^_lQ
8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PCooooo00Ko^[Zj
ob4Q8OoMgMgogMgMob4Q8Onj^[X3ooooo`00E_ooool00on7QhOo8B4Qonk^kP07ooooo`06odA4A?nH
V9SooooooooooonHV9SoA4A41?ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Ko00000_ooool0
1?nHV9SoA4A4odA4A?nHV9P2ooooo`03oiRHV?m4A4Cooooo00?ooooo00OoA4A4oiRHV?oooooooooo
oiRHV?m4A4Co8B4Q00?ooooo00GoA4A4o`000?oooooooooooiRHV002odA4A005oiRHV?oooooooooo
oiRHV?m4A4@01?ooool01om4A4CoV9RHooooooooooooV9RHodA4A?l000000oooool01Om4A4Co0000
ooooooooooooV9RH00;oA4A400GoV9RHooooooooooooV9RHodA4A004ooooo`06odA4A?nHV9Sooooo
ooooool0003oA4A41?ooool00om4A4CoV9RHodA4A002oiRHV003odA4A?nHV9SoA4A400Cooooo00Ko
A4A4oiRHV?oooooooooooiRHV?m4A4@4ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41?ooool0
1_m4A4CoV9RHooooooooooooV9RHodA4A0?ooooo001Gooooo`03ojVYZOlQ8B7ok^k^00Kooooo00Ko
0000onk^k_ooooooooooonk^k_l00004ooooo`08o`000?o^k^koooooooooooo^k^ko0000odA4A?nj
^[X2ooooo`05o`000?o^k^koooooooooooo^k^h00_l000001Oo^k^koooooooooooo^k^ko000000Co
oooo00Go0000onk^k_ooooooooooonk^kP02o`000003onk^k_oooooooooo00;o00000_ooool01?o^
k^ko0000o`000?o^k^h2ooooo`03onk^k_l0003ooooo00?ooooo00Go0000onk^k_ooooooooooonk^
kP02o`0000?ooooo0_l00002ooooo`04onk^k_l0003o0000onk^kP;ooooo00?ok^k^o`000?ooool0
0oooool01?l0003ok^k^ooooooooool2o`0000Cooooo00?o0000onk^k_l000000_o^k^h00ol0003o
k^k^o`000004ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool01_l0003ok^k^oooooooo
ooook^k^o`0000Cooooo00Ko0000onk^k_ooooooooooonk^k_l00003ooooo`00F?ooool00onHV9So
<S8booooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oMgMgo8B4Q00;ooooo00?o0000ooooooooool00_ooool2o`0000Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o000000GoEEEEonk^k_oo
oooo0000oeEEE@03ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000oeEEEOmgMgL00_ooool00ol0003oEEEEooooo`02ooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00001?ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo007ooooo001Iooooo`03odA4A?mgMgOooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooo
oomgMgOoV9RHooooool00004ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo0_l000001OmgMgOo0000o`000?l0003ok^k^00?ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ogMgMo`000003o`000004omgM
gOooooooooooooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooooooo
o`;o00001?ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo007ooooo001Iooooo`03
omgMgOl@413ooooo00Cooooo00Ko0000onk^k_ooooooooooonk^k_l00004ooooo`0<o`000?o^k^ko
ooooooooooo^k^ko0000ooooooo^k^ko8B4Qooooool0003ok^k^0_ooool01?o^k^ko0000o`000?o^
k^h2ooooo`03onk^k_l0003ooooo00?ooooo00So0000onk^k_ooooooooooonk^k_l0003oA4A4oiRH
V0;ooooo00Go0000onk^k_ooooooooooonk^kP02o`000005onk^k_ooooooooooonk^k_l000001?oo
ool02?l0003ok^k^ooooooooooook^k^o`000?lb<S;oIVIV0_o^k^h01Ol0003o;bl_oooooooooooo
k^k^00;o000000Gok^k^ooooooooooook^k^o`000004ooooo`04o`000?o^k^koooooooooo`;o0000
1?ooool00ol0003ok^k^o`000002onk^kP03o`000?o^k^ko000000Cooooo00Ko0000onk^k_oooooo
ooooonk^k_l00004ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool01_l0003ok^k^oooo
ooooooook^k^o`0000?ooooo001Jooooo`03o`000?oooooooooo00?ooooo00KoA4A4oiRHV?oooooo
oooooiRHV?m4A4@4ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A40_ooool01?mgMgOoV9RHo`00
0?nHV9P2ooooo`04oiRHV?m4A4CoA4A4oiRHV0;ooooo00?oV9RHodA4A?ooool00oooool02?m4A4Co
V9RHooooooooooooV9RHodA4A?nj^[[o8B4Q0_ooool01Om4A4CoV9RHooooooooooooV9RH00;oA4A4
00GoV9RHooooooooooooV9RHodA4A004ooooo`07odA4A?nHV9SooooooooooonHV9SoA4A4o`000003
ooooo`05odA4A?l0003ooooooooooonHV9P00_m4A4@01OnHV9SooooooooooonHV9SoA4A400Cooooo
00KoA4A4oiRHV?ooooooooooo`000?m4A4@4ooooo`03odA4A?nHV9SoA4A400;oV9RH00?oA4A4oiRH
V?m4A4@01?ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo00KoA4A4oiRHV?oooooooooo
oiRHV?m4A4@4ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A40oooool005Gooooo00Ko0000ohN7
Qoo^k^kooooooiRHV?mEEED5ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_nj^[[o
8B4QomgMgOoMgMgo8B4QokZj^P;ooooo00Cok^k^oc8b<_l0003o8B4Q0_oMgMd01?lQ8B7o^[ZjokZj
^_lQ8B42omgMg@03ob4Q8Onj^[[ooooo00?ooooo00co^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[[ooooo
oeEEEOlb<S;ogMgMokZj^_lQ8B42omgMg@04ob4Q8Onj^[[o^[Zjob4Q8@;ogMgM00?o8B4QokZj^_oo
ool00oooool02?nj^[[o8B4QomgMgOoMgMgo8B4QokZj^_lb<S;oIVIV0_o^k^h01Om:BT[o1PH6omgM
gOoMgMgo8B4Q00;o^[Zj00Go8B4QomgMgOoMgMgo8B4QokZj^P04ooooo`06okZj^_lQ8B7o0000ocXj
>_l0003o^[Zj1?ooool02?nj^[[o8B4Qoj:RX_lM7Ago71`Loj6QXOlQ8B7o^[Zj1?ooool01_nj^[[o
8B4QomgMgOoMgMgo8B4QokZj^PCooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`06okZj
^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj0oooool005Gooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h6
ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00CoV9RHo`000?l0003oV9RH1?ooool00onHV9So410@
oiRHV002o`000004oiRHV?oooooooooooiRHV0;o000000?oV9RHooooooooool01?ooool01?nHV9So
0000o`000?nHV9P3ooooo`04oiRHV?lQ8B7o0000oa@D50;o000000CoV9RHooooooooooooV9RH0_l0
00000onHV9Soooooooooo`04ooooo`07oiRHV?l0003o0000oiRHV?ooooook^k^odA4A002o`000005
odA4A?n=SHgo0000o`000?nHV9P00_ooool01?nHV9So0000o`000?nHV9P6ooooo`04oiRHV?l0003o
0000o`0000Kooooo00?oV9RHo`000?l000000_l000000onHV9Soooooooooo`04ooooo`04oiRHV?l0
003o0000oiRHV0Kooooo00CoV9RHo`000?l0003oV9RH1_ooool01?nHV9So0000o`000?nHV9P4oooo
o`00joooool00>_ooooo0013ooooo`04oiRHV?l0003o0000oiRHV:Cooooo0012ooooo`06okZj^_lQ
8B7ogMgMomgMgOlQ8B7o^[Zj1Ooooon4o`0001[ooooo0012ooooo`06odA4A?nHV9SooooooooooonH
V9SoA4A41Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool06?ooool004;ooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooohCo00006_ooool0
04;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ooooooooool06?ooool004;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool06?ooool004;ooooo
00Ko0000onk^k_ooooooooooonk^k_l00005ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool06?ooool004;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ooooooooool06?ooool004;ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj
^[X5ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool06?ooool004?ooooo00CoV9RH
o`000?l0003oV9RH1_ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo01Sooooo001=
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool06?ooool004gooooo00?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`0Hooooo`00COooool00ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oooooooooo01Sooooo001=ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
6?ooool004gooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0Hooooo`00<?ooool0
1?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Gooooo1_l00005ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ooooooooool06?ooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q
8Onj^[X5ooooo`?o00001Oooool00onHV9So0000omgMg@02ooooo`03oa0@4?oooooooooo00?ooooo
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0Hooooo`00;oooool01_m4A4CoV9RHoooo
ooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool00on7QhOo8B4Qonk^kP07ooooo`03
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ooooooooool06?ooool002oooooo00Ko0000onk^k_oooooo
ooooonk^k_l0000?ooooo`03ojVYZOlQ8B7ok^k^00Kooooo00?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oooooooooo`0Hooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00ko
oooo00?oV9RHoc8b<_ooool01Oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo01So
oooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool00om4A4CoMgMg
ooooo`04ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool06?ooool002oooooo00Ko
0000onk^k_ooooooooooonk^k_l0000Aooooo`03omgMgOl@413ooooo00Cooooo00?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oooooooooo`0Hooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4
A1;ooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo
01Sooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3Oooool01_l0003oQhN7onk^k_oo
ooooV9RHoeEEE@Gooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0Hooooo`00<?oo
ool01?nHV9So0000o`000?nHV9P>ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^1Oooool00ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oooooooooo01Sooooo001=ooooo`03o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ooooooooool06?ooool004gooooo00?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`0Hooooo`00COooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo01Sooooo001=
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool06?ooool004gooooo00?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`0Hooooo`00<?ooool01?nHV9So0000o`000?nHV9P6oooo
o`03oeEEEOl0003oEEEE00Wooooo0_l000000ol@413oooooooooo`02ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ooooooooool06?ooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5
ooooo`?o00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ooooooooool06?ooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0
003oEEEE00Kooooo1_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool06?oo
ool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`05odA4A?nj^[[oooooooooool0
00001Oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo01Sooooo000_ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01OoMgMgo8B4Qoooooooooooo000000Go
oooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0Hooooo`00;oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00gooooo00CoMgMgoiRHV?oooooo00001Oooool00ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oooooooooo01Sooooo000@ooooo`03okZj^_lb<S;ooooo00kooooo
00?o<S8bokZj^_ooool02oooool01_l0003ok^k^ooooooooooook^k^o`0000oooooo00Cok^k^ob4Q
8Ooooooo00001Oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo01Sooooo0003oooo
o`03o`000?oooooooooo00[ooooo00?o<S8bokZj^_ooool03_ooool00onj^[[o<S8booooo`0;oooo
o`06odA4A?nHV9SooooooooooonHV9SoA4A44?ooool00omgMgOoV9RHo`000005ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ooooooooool06?ooool000?ooooo00?o<S8bokZj^_ooool02Oooool0
0oo<c<co<S8booooo`0@ooooo`03oc8b<_o<c<cooooo00[ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q
8Onj^[X@ooooo`03onk^k_lb<S;o000000Gooooo00?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`0Hooooo`000oooool00omgMgOoQhN7ogMgM`02o`000003odA4A?o<c<cooooo00Cooooo00?o
IVIVojVYZOooool01Oooool01_mgMgOo410@o`000?l@413oEEEEomgMg@Gooooo00?oV9RHofIVI_oo
ool02oooool01?nHV9So0000o`000?nHV9PBooooo`03oiRHV?l@413ooooo00Cooooo00?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`0Hooooo`000oooool02?nHV9So410@ohN7Qoo^k^kooooo
oiRHV?l@413oc<c<1?ooool00olb<S;oooooooooo`04ooooo`07ogMgMom4A4CogMgMoooooooMgMgo
QhN7ob4Q8@05ooooo`03onk^k_lb<S;ooooo02Sooooo00?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`0Hooooo`000oooool00onj^[[o<S8booooo`03ooooo`03oiRHV?m4A4Cooooo00?ooooo
00?o<S8booooooooool01?ooool00ol@413ok^k^ooooo`0:ooooo`03o`000?oooooooooo02Oooooo
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0Hooooo`001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o<S8booooooooool01?ooool7o`0000Kooooo00?o
0000ooooooooool09oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo01Sooooo0004
ooooo`03odA4A?nHV9Sooooo00;ooooo00?ok^k^o`000?ooool00oooool00olQ8B7oooooooooo`04
ooooo`03oa0@4?oMgMgooooo00;ooooo00?ogMgMo`000?ooool01Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool06?ooool000Cooooo00Oo^[Zjo`00
0?nj^[[oooooonk^k_mVIVKoEEEE00Cooooo00?o<S8bonk^k_ooool01?ooool01on7QhOo8B4QokZj
^_oooooogMgMob4Q8OmgMgL01Oooool00ooMgMgo<S8booooo`0Xooooo`03o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ooooooooool06?ooool000Gooooo00KoZJVYob4Q8Ol0003o0000oeEEEOo^k^h4oooo
o`03ofIVI_nHV9Sooooo00Gooooo00GoQhN7oa0@4?l0003o410@ogMgM`06ooooo`03oiRHV?mVIVKo
oooo00_ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@06ooooo`06onk^k_mE
EEGo0000o`000?mEEEGok^k^1?ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo01So
oooo000?ooooo`03omgMgOlQ8B7ooooo013ooooo00?o410@olc<c?ooool02_ooool01_nj^[[o8B4Q
omgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`;oMgMg0_ooool00omgMgOoEEEEooooo`03oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ooooooooool06?ooool0013ooooo00?o<S8bokZj^_oo
ool03_ooool00onj^[[o<S8booooo`0;ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool0
0omEEEGo0000oeEEE@06ooooo`03ob4Q8Ooooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oooooooooo01Sooooo000@ooooo`03okZj^_lb<S;ooooo
00kooooo00?o<S8bokZj^_ooool02oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00?o
0000onk^k_ooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ooooooooool06?ooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<
ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE1?ooool00ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oooooooooo01Sooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?oo
ool01_l0003oMgMgo`000?l0003oEEEEonk^kPCooooo00?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`0Hooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00?oA4A4oiRH
V?ooool01oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo01Sooooo000_ooooo`06
odA4A?nHV9SooooooooooonHV9SoA4A43_ooool00onj^[[o8B4Qooooo`07ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ooooooooool06?ooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj
^[X?ooooo`03oeEEEOlb<S;ogMgM00Kooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`0Hooooo`00<?ooool01?nHV9So0000o`000?nHV9PAooooo`04oiRHV?lQ8B7o0000ob4Q8@Cooooo
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oooooooooo`0Hooooo`00COooool00ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oooooooooo01Sooooo001=ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ooooooooool06?ooool004gooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0Hoooo
o`00COooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo01Sooooo001=ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool06?ooool0033ooooo00CoV9RHo`000?l0003oV9RH
1_ooool00omEEEGo0000oeEEE@06ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^1?ooool00ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oooooooooo01Sooooo000_ooooo`06okZj^_lQ8B7ogMgMomgM
gOlQ8B7o^[Zj1Oooool3o`0000Kooooo00KoEEEEogMgMoooooooooooogMgMomEEED4ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool06?ooool002oooooo00KoA4A4oiRHV?oooooooooo
oiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool06?ooool002oooooo
00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo01Sooooo000_ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01_mEEEGoMgMgooooooooooooMgMg
oeEEE@Cooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0Hooooo`00;oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?ogMgMo`000?l000000_l000000ooM
gMgoooooooooo`02ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool06?ooool002oo
oooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`06oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b
1?ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo01Sooooo000_ooooo`06odA4A?nH
V9SooooooooooonHV9SoA4A43_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0Hooooo`00;oooool01_nj^[[o8B4Q
omgMgOoMgMgo8B4QokZj^Pkooooo00Ko<S8bofIVI_o^k^kok^k^ofIVI_lb<S84ooooo`03o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ooooooooool06?ooool0033ooooo00CoV9RHo`000?l0003oV9RH3ooo
ool01_o^k^koA4A4o`000?l0003oA4A4onk^kPCooooo00?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`0Hooooo`00COooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo01Sooooo
001=ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool06?ooool004gooooo00?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oooooooooo`0Hooooo`00COooool00ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oooooooooo01Sooooo001=ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000oooooooo
ool06?ooool004;ooooo1?l000000ol@413oooooooooo`04ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ooooooooool06?ooool004Cooooo00?o0000ooooooooool01_ooool6o`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo01Sooooo0014
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo000<o`0000Coo`001_l00005
ool00003o`000?oo003oo`0000;oo`001_l00004ool000Oo00001?oo0006o`0000Coo`0000?o0000
ool00?oo00000ooo0006o`0000Coo`0000?o0000ooooooooool06?ooool004Cooooo00?o0000oooo
ooooool01_ooool2o`0000?ooooo8Ol00004ool000Ko00001?oo00000ol0003oooooooooo`08oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool0
00Ko00001?ooool6o`0000Gooooo00?o0000ool00?oo00000_oo00000ol0003oooooooooo`02oooo
o`Ko00001Ooo00000ol0003oooooooooo`02ooooo`Ko00006_ooool004Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Rooooo`Ko00001?ooool6o`0000[ooooo1_l00004ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool04_ooool00ol0003oo`00ool00002ool00003
o`000?oooooooooo00Oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01Sooooo0014ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
A_ooool7o`0001Cooooo1_l00009ooooo`Oo00002Oooool00ol0003oooooooooo`0Hooooo`00A?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool06?oo
ool004Cooooo00?o0000ooooooooool01_oooon4o`0001[ooooo0012ooooo`03o`000?m4A4Co0000
0:Kooooo0012ooooo`03olc<c?mEEEGo00000:Kooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-5920.4, -1.26183, 76.5061, \
0.0133184}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The code in this section computes the spacings between the first \
10,000 primes (unfolded so that the spacings are roughly uniform), rescales \
the spacings so that the mean is 1, and creates a histogram of the level \
spacings.  Again, we need the Graphics package to create the histogram.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(PSpacing = 
        Table[UP[\([i + 1]\)] - UP[\([i]\)], {i, 1, n}];\)\), "\n", 
    \(\(PSpacingNorm = PSpacing/Mean[PSpacing];\)\), "\n", 
    \(\(int\  = \ Table[0 + i/5, {i, 0, 25}];\)\), "\n", 
    \(PHist = 
      Histogram[PSpacingNorm, HistogramCategories \[Rule] int, 
        HistogramScale \[Rule] 1, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<s\>", "\<P(s)\>"}, 
        RotateLabel \[Rule] False]\)}], "Input"],

Cell[BoxData[
    \(Histogram::"rtail" \(\(:\)\(\ \)\) 
      "Warning: \!\(14\) points from the right tail of the data, greater than \
or equal to \!\(5\), are not included in histogram."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.2 0.0147151 0.652002 [
[.2 -0.0125 -6.78125 -18 ]
[.2 -0.0125 6.78125 0 ]
[.4 -0.0125 -6.78125 -18 ]
[.4 -0.0125 6.78125 0 ]
[.6 -0.0125 -6.78125 -18 ]
[.6 -0.0125 6.78125 0 ]
[.8 -0.0125 -6.78125 -18 ]
[.8 -0.0125 6.78125 0 ]
[1 -0.0125 -6.78125 -18 ]
[1 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .14512 -32.6875 -9 ]
[-0.0125 .14512 0 9 ]
[-0.0125 .27552 -32.6875 -9 ]
[-0.0125 .27552 0 9 ]
[-0.0125 .40592 -32.6875 -9 ]
[-0.0125 .40592 0 9 ]
[-0.0125 .53632 -32.6875 -9 ]
[-0.0125 .53632 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -74.9375 -9 ]
[-0.01875 .30902 -32.6875 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
gsave
.2 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.4 0 m
.4 .00625 L
s
gsave
.4 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.6 0 m
.6 .00625 L
s
gsave
.6 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.8 0 m
.8 .00625 L
s
gsave
.8 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .14512 m
.00625 .14512 L
s
gsave
-0.0125 .14512 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .27552 m
.00625 .27552 L
s
gsave
-0.0125 .27552 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .40592 m
.00625 .40592 L
s
gsave
-0.0125 .40592 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .53632 m
.00625 .53632 L
s
gsave
-0.0125 .53632 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04732 m
.00375 .04732 L
s
0 .07992 m
.00375 .07992 L
s
0 .11252 m
.00375 .11252 L
s
0 .17772 m
.00375 .17772 L
s
0 .21032 m
.00375 .21032 L
s
0 .24292 m
.00375 .24292 L
s
0 .30812 m
.00375 .30812 L
s
0 .34072 m
.00375 .34072 L
s
0 .37332 m
.00375 .37332 L
s
0 .43852 m
.00375 .43852 L
s
0 .47112 m
.00375 .47112 L
s
0 .50372 m
.00375 .50372 L
s
0 .56892 m
.00375 .56892 L
s
0 .60152 m
.00375 .60152 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.04 .61428 m
.04 .61803 L
s
.08 .61428 m
.08 .61803 L
s
.12 .61428 m
.12 .61803 L
s
.16 .61428 m
.16 .61803 L
s
.24 .61428 m
.24 .61803 L
s
.28 .61428 m
.28 .61803 L
s
.32 .61428 m
.32 .61803 L
s
.36 .61428 m
.36 .61803 L
s
.44 .61428 m
.44 .61803 L
s
.48 .61428 m
.48 .61803 L
s
.52 .61428 m
.52 .61803 L
s
.56 .61428 m
.56 .61803 L
s
.64 .61428 m
.64 .61803 L
s
.68 .61428 m
.68 .61803 L
s
.72 .61428 m
.72 .61803 L
s
.76 .61428 m
.76 .61803 L
s
.84 .61428 m
.84 .61803 L
s
.88 .61428 m
.88 .61803 L
s
.92 .61428 m
.92 .61803 L
s
.96 .61428 m
.96 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14512 m
1 .14512 L
s
.99375 .27552 m
1 .27552 L
s
.99375 .40592 m
1 .40592 L
s
.99375 .53632 m
1 .53632 L
s
.125 Mabswid
.99625 .04732 m
1 .04732 L
s
.99625 .07992 m
1 .07992 L
s
.99625 .11252 m
1 .11252 L
s
.99625 .17772 m
1 .17772 L
s
.99625 .21032 m
1 .21032 L
s
.99625 .24292 m
1 .24292 L
s
.99625 .30812 m
1 .30812 L
s
.99625 .34072 m
1 .34072 L
s
.99625 .37332 m
1 .37332 L
s
.99625 .43852 m
1 .43852 L
s
.99625 .47112 m
1 .47112 L
s
.99625 .50372 m
1 .50372 L
s
.99625 .56892 m
1 .56892 L
s
.99625 .60152 m
1 .60152 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .31179 L
.04 .31179 L
.04 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .31179 L
.04 .31179 L
.04 .01472 L
0 .01472 L
s
1 0 0 r
.04 .01472 m
.04 .42377 L
.08 .42377 L
.08 .01472 L
F
0 g
.04 .01472 m
.04 .42377 L
.08 .42377 L
.08 .01472 L
.04 .01472 L
s
1 0 0 r
.08 .01472 m
.08 .60332 L
.12 .60332 L
.12 .01472 L
F
0 g
.08 .01472 m
.08 .60332 L
.12 .60332 L
.12 .01472 L
.08 .01472 L
s
1 0 0 r
.12 .01472 m
.12 .37317 L
.16 .37317 L
.16 .01472 L
F
0 g
.12 .01472 m
.12 .37317 L
.16 .37317 L
.16 .01472 L
.12 .01472 L
s
1 0 0 r
.16 .01472 m
.16 .32387 L
.2 .32387 L
.2 .01472 L
F
0 g
.16 .01472 m
.16 .32387 L
.2 .32387 L
.2 .01472 L
.16 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .33791 L
.24 .33791 L
.24 .01472 L
F
0 g
.2 .01472 m
.2 .33791 L
.24 .33791 L
.24 .01472 L
.2 .01472 L
s
1 0 0 r
.24 .01472 m
.24 .23638 L
.28 .23638 L
.28 .01472 L
F
0 g
.24 .01472 m
.24 .23638 L
.28 .23638 L
.28 .01472 L
.24 .01472 L
s
1 0 0 r
.28 .01472 m
.28 .18023 L
.32 .18023 L
.32 .01472 L
F
0 g
.28 .01472 m
.28 .18023 L
.32 .18023 L
.32 .01472 L
.28 .01472 L
s
1 0 0 r
.32 .01472 m
.32 .17566 L
.36 .17566 L
.36 .01472 L
F
0 g
.32 .01472 m
.32 .17566 L
.36 .17566 L
.36 .01472 L
.32 .01472 L
s
1 0 0 r
.36 .01472 m
.36 .112 L
.4 .112 L
.4 .01472 L
F
0 g
.36 .01472 m
.36 .112 L
.4 .112 L
.4 .01472 L
.36 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .10776 L
.44 .10776 L
.44 .01472 L
F
0 g
.4 .01472 m
.4 .10776 L
.44 .10776 L
.44 .01472 L
.4 .01472 L
s
1 0 0 r
.44 .01472 m
.44 .06401 L
.48 .06401 L
.48 .01472 L
F
0 g
.44 .01472 m
.44 .06401 L
.48 .06401 L
.48 .01472 L
.44 .01472 L
s
1 0 0 r
.48 .01472 m
.48 .05781 L
.52 .05781 L
.52 .01472 L
F
0 g
.48 .01472 m
.48 .05781 L
.52 .05781 L
.52 .01472 L
.48 .01472 L
s
1 0 0 r
.52 .01472 m
.52 .05879 L
.56 .05879 L
.56 .01472 L
F
0 g
.52 .01472 m
.52 .05879 L
.56 .05879 L
.56 .01472 L
.52 .01472 L
s
1 0 0 r
.56 .01472 m
.56 .04246 L
.6 .04246 L
.6 .01472 L
F
0 g
.56 .01472 m
.56 .04246 L
.6 .04246 L
.6 .01472 L
.56 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .03365 L
.64 .03365 L
.64 .01472 L
F
0 g
.6 .01472 m
.6 .03365 L
.64 .03365 L
.64 .01472 L
.6 .01472 L
s
1 0 0 r
.64 .01472 m
.64 .02973 L
.68 .02973 L
.68 .01472 L
F
0 g
.64 .01472 m
.64 .02973 L
.68 .02973 L
.68 .01472 L
.64 .01472 L
s
1 0 0 r
.68 .01472 m
.68 .02908 L
.72 .02908 L
.72 .01472 L
F
0 g
.68 .01472 m
.68 .02908 L
.72 .02908 L
.72 .01472 L
.68 .01472 L
s
1 0 0 r
.72 .01472 m
.72 .02451 L
.76 .02451 L
.76 .01472 L
F
0 g
.72 .01472 m
.72 .02451 L
.76 .02451 L
.76 .01472 L
.72 .01472 L
s
1 0 0 r
.76 .01472 m
.76 .01929 L
.8 .01929 L
.8 .01472 L
F
0 g
.76 .01472 m
.76 .01929 L
.8 .01929 L
.8 .01472 L
.76 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .01733 L
.84 .01733 L
.84 .01472 L
F
0 g
.8 .01472 m
.8 .01733 L
.84 .01733 L
.84 .01472 L
.8 .01472 L
s
1 0 0 r
.84 .01472 m
.84 .01602 L
.88 .01602 L
.88 .01472 L
F
0 g
.84 .01472 m
.84 .01602 L
.88 .01602 L
.88 .01472 L
.84 .01472 L
s
1 0 0 r
.88 .01472 m
.88 .01602 L
.92 .01602 L
.92 .01472 L
F
0 g
.88 .01472 m
.88 .01602 L
.92 .01602 L
.92 .01472 L
.88 .01472 L
s
1 0 0 r
.92 .01472 m
.92 .01733 L
.96 .01733 L
.96 .01472 L
F
0 g
.92 .01472 m
.92 .01733 L
.96 .01733 L
.96 .01472 L
.92 .01472 L
s
1 0 0 r
.96 .01472 m
.96 .01602 L
1 .01602 L
1 .01472 L
F
0 g
.96 .01472 m
.96 .01602 L
1 .01602 L
1 .01472 L
.96 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool009Cooooo00?o410@oc8b<_l@4100
0_l000000om4A4Coc<c<ooooo`1?ooooo`00U?ooool00ol0003oV9RHonk^kP02ooooo`03ohN7Qol@
413ooooo04oooooo002Iooooo`03okZj^_l0003ooooo04oooooo002Dooooo`03olc<c?m4A4Co0000
00?o000000?oV9RHooooooooool0C_ooool009Cooooo00Go0000ohN7Qonj^[[o^[Zjolc<c01Boooo
o`00U?ooool00ol0003oV9RHooooo`02ooooo`03olc<c?l@413ooooo04oooooo002Dooooo`07olc<
c?m4A4Co0000o`000?l@413o<S8bo`00001@ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo001Xooooo`Co0000
00?o410@ooooooooool05_ooool6o`0001Wooooo00GoZJVYob4Q8Ol0003o0000ofIVIP0Looooo`;o
000000?o410@ooooooooool05_ooool01OnHV9So410@o`000?l0003oIVIV00Kooooo001Zooooo`03
o`000?oooooooooo01Sooooo00?oV9RHo`000?oMgMd00_ooool00ol@413oooooooooo`0Gooooo`06
oa0@4?o<c<cooooooooooomgMgOoIVIV7?ooool00ol0003oooooooooo`0Gooooo`06oa0@4?n7QhOo
oooooooooomgMgOoIVIV1Oooool006[ooooo00?o0000ooooooooool06Oooool00on7QhOo8B4Qonk^
kP0Pooooo`03o`000?oooooooooo01Kooooo1_l0000Mooooo`03o`000?oooooooooo00?ooooo001Z
ooooo`03o`000?oooooooooo01[ooooo00?oZJVYob4Q8Oo^k^h07oooool00ol0003oooooooooo`0F
ooooo`05odA4A?nj^[[oooooooooool000007Oooool00oo^k^ko0000ooooo`04ooooo`00J_ooool0
0ol0003oooooooooo`0Kooooo`03oiRHV?lb<S;ooooo01gooooo00?oZJVYodA4A?ooool05oooool0
1OoMgMgo8B4Qoooooooooooo000001Wooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH5ooooo`00
J_ooool00ol0003oooooooooo`0Looooo`03odA4A?mgMgOooooo01[ooooo00Co8B4Qo`000?l0003o
gMgM6Oooool01?mgMgOoV9RHooooool0000Iooooo`05o`000?lQ8B7o0000o`000?mVIVH01_ooool0
06[ooooo00?o0000ooooooooool07?ooool00ooMgMgo410@ooooo`0Looooo`03ojVYZOlb<S;ooooo
01Sooooo00Cok^k^ob4Q8Ooooooo00006Oooool00ol0003oooooooooo`08ooooo`00J_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06?ooool00omg
MgOoV9RHo`00000Iooooo`03o`000?oooooooooo00Sooooo001Xooooo`03o`000?m4A4Co000001[o
oooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEEDIooooo`06ob4Q8Onj^[[ooooooooooomVIVKo<S8b
6_ooool00oo^k^ko<S8bo`00000Iooooo`03o`000?oooooooooo00Sooooo001Xooooo`03olc<c?mE
EEGo000001[ooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^hIooooo`06okZj^_m4A4Co0000o`00
0?m4A4Cok^k^6oooool00onHV9So410@ooooo`0Hooooo`Go00001_ooool00>_ooooo003[ooooo`00
joooool004?ooooo00CoV9RHo`000?l0003oV9RHY?ooool004;ooooo00Ko^[Zjob4Q8OoMgMgogMgM
ob4Q8Onj^[X5oooooiOo00001oooool004;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool004;ooooo00Ko0000onk^k_oo
ooooooooonk^k_l00005oooooiOo00001oooool004;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`009Ol00007ooooo`00@_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`001ol0000Sooooo`03o`000?oooooooooo00Go
oooo0012ooooo`06o`000?o^k^koooooooooooo^k^ko00001Oooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo000Co`0002Wooooo00?o0000oooo
ooooool01Oooool004;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo
oooo03Wooooo00?o0000ooooooooool01Oooool004;ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj
^[X5ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0007o`0003[ooooo0_l0
0007ooooo`00@oooool01?nHV9So0000o`000?nHV9P6ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Gooooo001=
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool000go0000@Oooool00ol0003oooooooooo`05ooooo`00COooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`001ol0001=ooooo`03o`000?oooooooooo00Gooooo001=ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Aooooo`03
o`000?oooooooooo00Gooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`1@ooooo`;o00001oooool004gooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oooooooooo057ooooo00?o0000ooooooooool01Ooo
ool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo
oooo057ooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo057ooooo00?o0000ooooooooool01Oooool004go
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo0007o`0005?ooooo00?o0000ooooooooool01Oooool004gooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
1ol0001Hooooo`;o00001oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0GOooool00ol0003ooooooooo
o`05ooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Gooooo1_l0
0005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo05gooooo00?o0000ooooooooool01Oooool002oooooo00Ko^[Zj
ob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001Oooool00onHV9So0000omgMg@02ooooo`03oa0@
4?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0GOooool00ol0003oooooooooo`05ooooo`00;ooo
ool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool00on7QhOo
8B4Qonk^kP07ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo05gooooo00?o0000ooooooooool01Oooool002oooooo
00Ko0000onk^k_ooooooooooonk^k_l0000?ooooo`03ojVYZOlQ8B7ok^k^00Kooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0G?ooool2o`0000Oooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03_ooool00onHV9So<S8booooo`05ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo05gooooo00?o0000oooooooo
ool01Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03odA4
A?mgMgOooooo00Cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0GOooool00ol0003oooooooooo`05ooooo`00;ooo
ool01_l0003ok^k^ooooooooooook^k^o`00017ooooo00?ogMgMoa0@4?ooool01?ooool00ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`1Mooooo`03o`000?oooooooooo00Gooooo000_ooooo`06odA4A?nHV9SooooooooooonH
V9SoA4A44_ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo0007o`0005oooooo00?o0000ooooooooool01Oooool002oooooo00Ko^[Zjob4Q8OoM
gMgogMgMob4Q8Onj^[X=ooooo`06o`000?n7QhOok^k^oooooonHV9SoEEEE1Oooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool000Oo0000I?ooool2o`0000Oooooo000`ooooo`04oiRHV?l0003o0000oiRHV0kooooo
00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h5ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0JOooool00ol0003oooooooooo`05ooooo`00COooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo06Wooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0JOooool00ol0003oooooooooo`05ooooo`00COooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oooooooooo06Sooooo0_l00007ooooo`00COooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo06Wooooo00?o0000ooooooooool01Oooool004go
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Go
oooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0JOooool00ol0003ooooo
ooooo`05ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo0007o`0006_ooooo00?o0000ooooooooool01Oooool004gooooo00?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0K_ooool2o`0000Oooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEE
o`000?mEEED02Oooool2o`000003oa0@4?oooooooooo00;ooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Koooool0
0ol0003oooooooooo`05ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol0
000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Koooool00ol0003ooooooooo
o`05ooooo`004?ooool00onj^[[o<S8booooo`0>ooooo`03oc8b<_nj^[[ooooo00_ooooo00KoA4A4
oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo1_l00004ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo06oooooo00?o0000ooooooooool01Oooool0013ooooo00?o<S8bokZj^_ooool03_oo
ool00onj^[[o<S8booooo`0;ooooo`06o`000?o^k^koooooooooooo^k^ko00003_ooool01Om4A4Co
^[Zjoooooooooooo000000Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0K_ooool2o`0000Oooooo000?ooooo`03
olc<c?lb<S;ooooo013ooooo00?o<S8bolc<c?ooool02_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00cooooo00GogMgMob4Q8Oooooooooooo`000005ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
06oooooo00?o0000ooooooooool01Oooool000;ooooo00Go410@o`000?l0003o0000oa0@4008oooo
o`03ofIVI_nYZJWooooo00Cooooo00?o410@oc8b<_l@41000_l000000om4A4Coc<c<ooooo`04oooo
o`03oiRHV?mVIVKooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=oooo
o`04ogMgMonHV9Soooooo`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Koooool00ol0003oooooooooo`05
ooooo`001?ooool00ol0003oooooooooo`08ooooo`03oc8b<_oooooooooo00Cooooo00?o0000oiRH
V?o^k^h00_ooool00on7QhOo410@ooooo`04ooooo`03onk^k_lb<S;ooooo00[ooooo00Ko0000onk^
k_ooooooooooonk^k_l0000?ooooo`04onk^k_lQ8B7oooooo`0000Gooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
Koooool00ol0003oooooooooo`05ooooo`001?ooool00ol0003oooooooooo`08ooooo`03oc8b<_oo
oooooooo00Wooooo00?o^[Zjo`000?ooool01Oooool00ol0003oooooooooo`09ooooo`06odA4A?nH
V9SooooooooooonHV9SoA4A44?ooool00omgMgOoV9RHo`000005ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo06oo
oooo00?o0000ooooooooool01Oooool000Cooooo0ol000000ol@413oMgMgonk^kP05ooooo`03oc8b
<_oooooooooo00Cooooo00?oc<c<odA4A?l000000ol000000onHV9Soooooooooo`04ooooo`03o`00
0?oooooooooo00Wooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X@ooooo`03onk^k_lb<S;o0000
00Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0K_ooool2o`0000Oooooo0004ooooo`06o`000?ooooooooooonk^
k_mgMgOoEEEE1Oooool00olQ8B7oooooooooo`04ooooo`05o`000?n7QhOo^[ZjokZj^_o<c<`02?oo
ool00ol0003oooooooooo`0:ooooo`04oiRHV?l0003o0000oiRHV1;ooooo00?oV9RHoa0@4?ooool0
1?ooool7o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo00Gooooo0004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00olb<S;ok^k^ooooo`04ooooo`03o`000?nHV9Sooooo00;ooooo00?oc<c<oa0@4?ooool01?oo
ool00ooMgMgo<S8booooo`0Xooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oooooooooo06oooooo00?o0000ooooooooool01Ooo
ool000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03ofIVI_nHV9So
oooo00Cooooo00Ooc<c<odA4A?l0003o0000oa0@4?lb<S;o000000Gooooo00?oV9RHofIVI_ooool0
:?ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool000Oo00001Ooo00000ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo00Gooooo0004ooooo`06o`000?ooooooooooonk^k_mgMgOoEEEE1Oooool00ooMgMgo
8B4Qooooo`0@ooooo`03oa0@4?o<c<cooooo02Sooooo00?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Koooool00ol0003o
ooooooooo`05ooooo`000_ooool00ol@413o0000o`000002o`000003oa0@4?mgMgOok^k^00Kooooo
00?o<S8bokZj^_ooool03_ooool00onj^[[o<S8booooo`0Yooooo`;o00001?ooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`03ooooo`Oo0000L?ooool2o`0000Oooooo000@ooooo`03okZj^_lb<S;ooooo00kooooo00?o
<S8bokZj^_ooool0:Oooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo07_ooooo00?o
0000ooooooooool01Oooool004gooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1k
ooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0Noooool00ol0003oooooooooo`05ooooo`00COooool00ol0003oooooooooo`03ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo07_ooooo00?o0000ooooooooool01Oooool004gooooo0_l00004ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0007o`0007cooooo0_l00007ooooo`00COoo
ool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`21ooooo`03o`000?oooooooooo00Gooooo000`ooooo`04oiRHV?l0003o
0000oiRHV0Kooooo00?oEEEEo`000?mEEED01_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPCo
oooo00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0POooool00ol0003oooooooooo`05ooooo`00;oooool01_nj^[[o8B4Q
omgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`;oMgMg0_ooool00omgMgOoEEEEooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool002oooooo00KoA4A4oiRHV?oo
oooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?o8B4Qooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool0
02oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`03o`000?o^k^kooooo00;ooooo00?o
0000ooooooooool00_ooool2o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo083ooooo0_l00007ooooo`00;oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00cooooo00Ko0000oeEEEOo^k^koooooogMgMomEEED4ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo087ooooo00?o0000ooooooooool01Oooool002oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0<ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^1?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`21ooooo`03o`000?oooooooooo00Gooooo000_ooooo`06o`000?o^k^koooooooooooo^
k^ko00003_ooool00om4A4CoV9RHooooo`07ooooo`03o`000?oooooooooo00?ooooo1ol00005ool0
0003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool002oooooo00KoA4A4oiRHV?oo
oooooooooiRHV?m4A4@>ooooo`03okZj^_lQ8B7ooooo00Oooooo00?o0000ooooooooool02Oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool0
02oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X?ooooo`03oeEEEOlb<S;ogMgM00Kooooo0_l0
000:ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0P?ooool2o`0000Oooooo000`
ooooo`04oiRHV?l0003o0000oiRHV17ooooo00CoV9RHob4Q8Ol0003o8B4Q1?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0POooool00ol0003ooooo
ooooo`05ooooo`00COooool00ol0003oooooooooo`09ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0POooool00ol0003oooooooooo`05ooooo`00COooool00ol0003oooooooooo`09
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0POooool00ol0003oooooooooo`05
ooooo`00COooool00ol0003oooooooooo`09ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0POooool00ol0003oooooooooo`05ooooo`00COooool2o`0000[ooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`20ooooo`;o00001oooool004gooooo00?o0000ooooooooool0
2Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo087ooooo00?o0000ooooooooool0
1Oooool004gooooo00?o0000ooooooooool02Oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo087ooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ooooooooool02Oooool0
0ol0003oo`00ool00003ool00003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool0
04gooooo00?o0000ooooooooool02Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
087ooooo00?o0000ooooooooool01Oooool004gooooo0_l0000:ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0P?ooool2o`0000Oooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Ko
oooo00?oEEEEo`000?mEEED01_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPCooooo00?o0000
ooooooooool02Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo087ooooo00?o0000
ooooooooool01Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001_oo
ool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Cooooo00?o0000ooooooooool02Oooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool002oooooo
00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`21ooooo`03o`000?oooooooooo00Gooooo000_ooooo`06
o`000?o^k^koooooooooooo^k^ko00003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo0_l0000:ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0P?ooool2
o`0000Oooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01_mE
EEGoMgMgooooooooooooMgMgoeEEE@Cooooo00?o0000ooooooooool02Oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool002oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03omgMgOl0003o000000;o000000?ogMgM
ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0POooool00ol0003oooooooooo`05ooooo`00;oooool01_l0003ok^k^oooooooooooo
k^k^o`0000kooooo00Ko<S8bofIVI_o^k^kok^k^ofIVI_lb<S84ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`21ooooo`03o`000?oooooooooo00Go
oooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A43_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oo`00ool00003ool0
0003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool002oooooo00Ko^[Zjob4Q8OoM
gMgogMgMob4Q8Onj^[X>ooooo`06oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b1?ooool2o`0000[ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`20ooooo`;o00001oooool0033ooooo00Co
V9RHo`000?l0003oV9RH3oooool01_o^k^koA4A4o`000?l0003oA4A4onk^kPCooooo00?o0000oooo
ooooool02Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo087ooooo00?o0000oooo
ooooool01Oooool004gooooo00?o0000ooooooooool02Oooool00ol0003oo`00ool00003ool00003
o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ooooooooool0
2Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo087ooooo00?o0000ooooooooool0
1Oooool004gooooo00?o0000ooooooooool02Oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo087ooooo00?o0000ooooooooool01Oooool004gooooo0_l0000:ooooo`Oo0000P_ooool2
o`0000Oooooo001=ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool01Oooool004go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`00COoooonGo`0000Oooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-2.60043, -0.9434, 0.03345, \
0.0102607}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The plot below compares the spacing distribution for the first \
10,000 unfolded primes to the Poisson distribution.  While the prime spacings \
do seem to exhibit an exponential decay, there is a noticeable shortage of \
small spacings that leads to a discrepancy between the primes spacings and \
the Poisson distribution.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[PHist, Poisson, AspectRatio \[Rule] 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.2 0.0238095 0.952381 [
[.2 -0.0125 -6.78125 -18 ]
[.2 -0.0125 6.78125 0 ]
[.4 -0.0125 -6.78125 -18 ]
[.4 -0.0125 6.78125 0 ]
[.6 -0.0125 -6.78125 -18 ]
[.6 -0.0125 6.78125 0 ]
[.8 -0.0125 -6.78125 -18 ]
[.8 -0.0125 6.78125 0 ]
[1 -0.0125 -6.78125 -18 ]
[1 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .02381 -13.5625 -9 ]
[-0.0125 .02381 0 9 ]
[-0.0125 .21429 -32.6875 -9 ]
[-0.0125 .21429 0 9 ]
[-0.0125 .40476 -32.6875 -9 ]
[-0.0125 .40476 0 9 ]
[-0.0125 .59524 -32.6875 -9 ]
[-0.0125 .59524 0 9 ]
[-0.0125 .78571 -32.6875 -9 ]
[-0.0125 .78571 0 9 ]
[-0.0125 .97619 -13.5625 -9 ]
[-0.0125 .97619 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -74.9375 -9 ]
[-0.01875 .5 -32.6875 9 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
gsave
.2 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.4 0 m
.4 .00625 L
s
gsave
.4 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.6 0 m
.6 .00625 L
s
gsave
.6 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.8 0 m
.8 .00625 L
s
gsave
.8 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02381 m
.00625 .02381 L
s
gsave
-0.0125 .02381 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .21429 m
.00625 .21429 L
s
gsave
-0.0125 .21429 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .40476 m
.00625 .40476 L
s
gsave
-0.0125 .40476 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .59524 m
.00625 .59524 L
s
gsave
-0.0125 .59524 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .78571 m
.00625 .78571 L
s
gsave
-0.0125 .78571 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .97619 m
.00625 .97619 L
s
gsave
-0.0125 .97619 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07143 m
.00375 .07143 L
s
0 .11905 m
.00375 .11905 L
s
0 .16667 m
.00375 .16667 L
s
0 .2619 m
.00375 .2619 L
s
0 .30952 m
.00375 .30952 L
s
0 .35714 m
.00375 .35714 L
s
0 .45238 m
.00375 .45238 L
s
0 .5 m
.00375 .5 L
s
0 .54762 m
.00375 .54762 L
s
0 .64286 m
.00375 .64286 L
s
0 .69048 m
.00375 .69048 L
s
0 .7381 m
.00375 .7381 L
s
0 .83333 m
.00375 .83333 L
s
0 .88095 m
.00375 .88095 L
s
0 .92857 m
.00375 .92857 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.2 .99375 m
.2 1 L
s
.4 .99375 m
.4 1 L
s
.6 .99375 m
.6 1 L
s
.8 .99375 m
.8 1 L
s
.125 Mabswid
.04 .99625 m
.04 1 L
s
.08 .99625 m
.08 1 L
s
.12 .99625 m
.12 1 L
s
.16 .99625 m
.16 1 L
s
.24 .99625 m
.24 1 L
s
.28 .99625 m
.28 1 L
s
.32 .99625 m
.32 1 L
s
.36 .99625 m
.36 1 L
s
.44 .99625 m
.44 1 L
s
.48 .99625 m
.48 1 L
s
.52 .99625 m
.52 1 L
s
.56 .99625 m
.56 1 L
s
.64 .99625 m
.64 1 L
s
.68 .99625 m
.68 1 L
s
.72 .99625 m
.72 1 L
s
.76 .99625 m
.76 1 L
s
.84 .99625 m
.84 1 L
s
.88 .99625 m
.88 1 L
s
.92 .99625 m
.92 1 L
s
.96 .99625 m
.96 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .21429 m
1 .21429 L
s
.99375 .40476 m
1 .40476 L
s
.99375 .59524 m
1 .59524 L
s
.99375 .78571 m
1 .78571 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .07143 m
1 .07143 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .30952 m
1 .30952 L
s
.99625 .35714 m
1 .35714 L
s
.99625 .45238 m
1 .45238 L
s
.99625 .5 m
1 .5 L
s
.99625 .54762 m
1 .54762 L
s
.99625 .64286 m
1 .64286 L
s
.99625 .69048 m
1 .69048 L
s
.99625 .7381 m
1 .7381 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .88095 m
1 .88095 L
s
.99625 .92857 m
1 .92857 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .02381 m
1 .02381 L
s
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
0 .02381 m
0 .45775 L
.04 .45775 L
.04 .02381 L
F
0 g
.5 Mabswid
0 .02381 m
0 .45775 L
.04 .45775 L
.04 .02381 L
0 .02381 L
s
1 0 0 r
.04 .02381 m
.04 .62131 L
.08 .62131 L
.08 .02381 L
F
0 g
.04 .02381 m
.04 .62131 L
.08 .62131 L
.08 .02381 L
.04 .02381 L
s
1 0 0 r
.08 .02381 m
.08 .88358 L
.12 .88358 L
.12 .02381 L
F
0 g
.08 .02381 m
.08 .88358 L
.12 .88358 L
.12 .02381 L
.08 .02381 L
s
1 0 0 r
.12 .02381 m
.12 .5474 L
.16 .5474 L
.16 .02381 L
F
0 g
.12 .02381 m
.12 .5474 L
.16 .5474 L
.16 .02381 L
.12 .02381 L
s
1 0 0 r
.16 .02381 m
.16 .47539 L
.2 .47539 L
.2 .02381 L
F
0 g
.16 .02381 m
.16 .47539 L
.2 .47539 L
.2 .02381 L
.16 .02381 L
s
1 0 0 r
.2 .02381 m
.2 .4959 L
.24 .4959 L
.24 .02381 L
F
0 g
.2 .02381 m
.2 .4959 L
.24 .4959 L
.24 .02381 L
.2 .02381 L
s
1 0 0 r
.24 .02381 m
.24 .3476 L
.28 .3476 L
.28 .02381 L
F
0 g
.24 .02381 m
.24 .3476 L
.28 .3476 L
.28 .02381 L
.24 .02381 L
s
1 0 0 r
.28 .02381 m
.28 .26558 L
.32 .26558 L
.32 .02381 L
F
0 g
.28 .02381 m
.28 .26558 L
.32 .26558 L
.32 .02381 L
.28 .02381 L
s
1 0 0 r
.32 .02381 m
.32 .2589 L
.36 .2589 L
.36 .02381 L
F
0 g
.32 .02381 m
.32 .2589 L
.36 .2589 L
.36 .02381 L
.32 .02381 L
s
1 0 0 r
.36 .02381 m
.36 .16591 L
.4 .16591 L
.4 .02381 L
F
0 g
.36 .02381 m
.36 .16591 L
.4 .16591 L
.4 .02381 L
.36 .02381 L
s
1 0 0 r
.4 .02381 m
.4 .15971 L
.44 .15971 L
.44 .02381 L
F
0 g
.4 .02381 m
.4 .15971 L
.44 .15971 L
.44 .02381 L
.4 .02381 L
s
1 0 0 r
.44 .02381 m
.44 .09582 L
.48 .09582 L
.48 .02381 L
F
0 g
.44 .02381 m
.44 .09582 L
.48 .09582 L
.48 .02381 L
.44 .02381 L
s
1 0 0 r
.48 .02381 m
.48 .08675 L
.52 .08675 L
.52 .02381 L
F
0 g
.48 .02381 m
.48 .08675 L
.52 .08675 L
.52 .02381 L
.48 .02381 L
s
1 0 0 r
.52 .02381 m
.52 .08819 L
.56 .08819 L
.56 .02381 L
F
0 g
.52 .02381 m
.52 .08819 L
.56 .08819 L
.56 .02381 L
.52 .02381 L
s
1 0 0 r
.56 .02381 m
.56 .06434 L
.6 .06434 L
.6 .02381 L
F
0 g
.56 .02381 m
.56 .06434 L
.6 .06434 L
.6 .02381 L
.56 .02381 L
s
1 0 0 r
.6 .02381 m
.6 .05147 L
.64 .05147 L
.64 .02381 L
F
0 g
.6 .02381 m
.6 .05147 L
.64 .05147 L
.64 .02381 L
.6 .02381 L
s
1 0 0 r
.64 .02381 m
.64 .04574 L
.68 .04574 L
.68 .02381 L
F
0 g
.64 .02381 m
.64 .04574 L
.68 .04574 L
.68 .02381 L
.64 .02381 L
s
1 0 0 r
.68 .02381 m
.68 .04479 L
.72 .04479 L
.72 .02381 L
F
0 g
.68 .02381 m
.68 .04479 L
.72 .04479 L
.72 .02381 L
.68 .02381 L
s
1 0 0 r
.72 .02381 m
.72 .03812 L
.76 .03812 L
.76 .02381 L
F
0 g
.72 .02381 m
.72 .03812 L
.76 .03812 L
.76 .02381 L
.72 .02381 L
s
1 0 0 r
.76 .02381 m
.76 .03049 L
.8 .03049 L
.8 .02381 L
F
0 g
.76 .02381 m
.76 .03049 L
.8 .03049 L
.8 .02381 L
.76 .02381 L
s
1 0 0 r
.8 .02381 m
.8 .02762 L
.84 .02762 L
.84 .02381 L
F
0 g
.8 .02381 m
.8 .02762 L
.84 .02762 L
.84 .02381 L
.8 .02381 L
s
1 0 0 r
.84 .02381 m
.84 .02572 L
.88 .02572 L
.88 .02381 L
F
0 g
.84 .02381 m
.84 .02572 L
.88 .02572 L
.88 .02381 L
.84 .02381 L
s
1 0 0 r
.88 .02381 m
.88 .02572 L
.92 .02572 L
.92 .02381 L
F
0 g
.88 .02381 m
.88 .02572 L
.92 .02572 L
.92 .02381 L
.88 .02381 L
s
1 0 0 r
.92 .02381 m
.92 .02762 L
.96 .02762 L
.96 .02381 L
F
0 g
.92 .02381 m
.92 .02762 L
.96 .02762 L
.96 .02381 L
.92 .02381 L
s
1 0 0 r
.96 .02381 m
.96 .02572 L
1 .02572 L
1 .02381 L
F
0 g
.96 .02381 m
.96 .02572 L
1 .02572 L
1 .02381 L
.96 .02381 L
s
.015 w
0 .97619 m
.04057 .80135 L
.08481 .64704 L
.12636 .53013 L
.16632 .43843 L
.20885 .359 L
.2498 .29695 L
.29331 .24354 L
.33524 .20198 L
.37557 .16944 L
.41848 .14132 L
.4598 .11939 L
.49953 .10217 L
.54183 .08723 L
.58254 .07555 L
.62583 .06548 L
.66752 .05764 L
.70762 .05149 L
.7503 .04617 L
.79139 .04202 L
.83505 .03845 L
.87712 .03567 L
.9176 .0335 L
.96065 .03162 L
1 .03023 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00U?ooool00ol@413o<S8boa0@4002o`000003odA4A?o<c<cooooo04oooooo002Dooooo`03o`00
0?nHV9Sok^k^00;ooooo00?oQhN7oa0@4?ooool0Coooool009Wooooo00?o^[Zjo`000?ooool0Cooo
ool009Cooooo00?oc<c<odA4A?l000000ol000000onHV9Soooooooooo`1>ooooo`00U?ooool01Ol0
003oQhN7okZj^_nj^[[oc<c<05;ooooo002Dooooo`03o`000?nHV9Sooooo00;ooooo00?oc<c<oa0@
4?ooool0Coooool009Cooooo00Ooc<c<odA4A?l0003o0000oa0@4?lb<S;o0000053ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool006Sooooo1?l000000ol@413oooooooooo`0Fooooo`Ko00006Oooool01OnYZJWo
8B4Qo`000?l0003oIVIV01cooooo0_l000000ol@413oooooooooo`0Fooooo`05oiRHV?l@413o0000
o`000?mVIVH01_ooool006[ooooo00?o0000ooooooooool06?ooool00onHV9So0000omgMg@02oooo
o`03oa0@4?oooooooooo01Oooooo00Ko410@olc<c?ooooooooooogMgMomVIVHLooooo`03o`000?oo
oooooooo01Oooooo00Ko410@ohN7QoooooooooooogMgMomVIVH5ooooo`00J_ooool00ol0003ooooo
ooooo`0Iooooo`03ohN7QolQ8B7ok^k^023ooooo00?o0000ooooooooool05_ooool6o`0001gooooo
00?o0000ooooooooool00oooool006[ooooo00?o0000ooooooooool06_ooool00onYZJWo8B4Qonk^
kP0Oooooo`03o`000?oooooooooo01Kooooo00GoA4A4okZj^_ooooooooooo`00000Mooooo`03onk^
k_l0003ooooo00Cooooo001Zooooo`03o`000?oooooooooo01_ooooo00?oV9RHoc8b<_ooool07Ooo
ool00onYZJWoA4A4ooooo`0Gooooo`05omgMgOlQ8B7oooooooooool000006Oooool01_l@413oV9RH
ooooooooooooMgMgofIVIPGooooo001Zooooo`03o`000?oooooooooo01cooooo00?oA4A4ogMgMooo
ool06_ooool01?lQ8B7o0000o`000?oMgMdIooooo`04ogMgMonHV9Soooooo`0001Wooooo00Go0000
ob4Q8Ol0003o0000ofIVIP06ooooo`00J_ooool00ol0003oooooooooo`0Looooo`03omgMgOl@413o
oooo01cooooo00?oZJVYoc8b<_ooool06?ooool01?o^k^ko8B4Qooooool0000Iooooo`03o`000?oo
oooooooo00Sooooo001Zooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Hooooo`03ogMgMonHV9So000001Wooooo00?o0000ooooooooool02?ooool0
06Sooooo00?o0000odA4A?l000006_ooool01_l0003oQhN7onk^k_ooooooV9RHoeEEEAWooooo00Ko
8B4QokZj^_ooooooooooofIVI_lb<S8Jooooo`03onk^k_lb<S;o000001Wooooo00?o0000oooooooo
ool02?ooool006Sooooo00?oc<c<oeEEEOl000006_ooool01_nYZJWo<S8bo`000?l0003oEEEEonk^
kQWooooo00Ko^[ZjodA4A?l0003o0000odA4A?o^k^hKooooo`03oiRHV?l@413ooooo01Sooooo1Ol0
0006ooooo`00joooool00>_ooooo003[ooooo`00joooool004goooooUol00007ooooo`00@oooool0
1?nHV9So0000o`000?nHV9P6ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool004;ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`03o`000?oooooooooo09?ooooo
00?o0000ooooooooool01Oooool004;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03
o`000?oooooooooo09?ooooo00?o0000ooooooooool01Oooool004;ooooo00Ko0000onk^k_oooooo
ooooonk^k_l00005oooooiOo00001oooool004;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`001ol00006oooooaSo00001oooool004;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool002Oo00000oooool00ol0003ooooo
ooooo`05ooooo`00@_ooool01_l0003ok^k^ooooooooooook^k^o`0000Gooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo000Po`0001Kooooo00?o0000ooooooooool01Oooool004;ooooo00KoA4A4oiRHV?oooooo
oooooiRHV?m4A4@5ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool000Oo00001Oooool>o`0002;ooooo00?o0000ooooooooool01Oooool004;o
oooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo3Ol0000Y
ooooo`03o`000?oooooooooo00Gooooo0013ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool001?o0000;oooool00ol0003oooooooooo`05
ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`003Ol0000doooo
o`;o00001oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003oo`00ool00?oo0009o`00
03_ooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`003_l00010ooooo`03o`000?oooooooooo00Go
oooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0007o`0000?ooooo
1ol00013ooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oooooooooo`04ooooo`Oo0000A_ooool00ol0003ooooooooo
o`05ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00_ooool6o`0004Wooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00Go0000C?ooool00ol0
003oooooooooo`05ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`001_l0001=ooooo`;o00001oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool000Go0000D?ooool00ol0003oooooooooo`05ooooo`00COooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Go0000D_ooool00ol0003oooooooooo`05ooooo`00COooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool000Oo0000Doooool00ol0003oooooooooo`05ooooo`00COooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool000Go00000_oo00000ol0003oooooooooo`1Aooooo`03o`000?oooooooooo
00Gooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00004o`000?oo003oo`00ool000Co00001?oo00000ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o000000[o0000Doooool00ol0003o
ooooooooo`05ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo0007o`0005Sooooo0_l00007ooooo`00COooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0004o`0005gooooo00?o
0000ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00004o`000?oo003oo`00ool000?o0000Goooool00ol0003oooooooooo`05ooooo`00COooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?l0001O
ooooo`03o`000?oooooooooo00Gooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEE
o`000?mEEED01Oooool6o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003o000000;o000000?oo`00o`000?ooool0G_ooool00ol0003oooooooooo`05
ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol00005ooooo`03oiRHV?l0
003ogMgM00;ooooo00?o410@ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`001?l00002ool00003o`000?oooooooooo05gooooo00?o0000ooooooooool01Ooo
ool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo
00?oQhN7ob4Q8Oo^k^h01oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
0ol00003ool00003o`000?oooooooooo05gooooo00?o0000ooooooooool01Oooool002oooooo00Ko
0000onk^k_ooooooooooonk^k_l0000?ooooo`03ojVYZOlQ8B7ok^k^00Kooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool000?o00001?oo00000ol0003oooooooooo`1Looooo`;o
00001oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03oiRH
V?lb<S;ooooo00Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003oo`00ool00?oo0003o`0000Go
o`0000?o0000ooooooooool0GOooool00ol0003oooooooooo`05ooooo`00;oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00oooooo00?oA4A4ogMgMoooool01?ooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Co00001Ooo00000ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo00Gooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00004Oooool00ooMgMgo
410@ooooo`04ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?l000000_l000000ooo003o
0000ool00004ool00003o`000?oooooooooo05gooooo00?o0000ooooooooool01Oooool002oooooo
00KoA4A4oiRHV?oooooooooooiRHV?m4A4@Booooo`03o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo0004o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Moooo
o`03o`000?oooooooooo00Gooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3Oooool0
1_l0003oQhN7onk^k_ooooooV9RHoeEEE@Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0003o`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Gooooo
000`ooooo`04oiRHV?l0003o0000oiRHV0kooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h5oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`000ol00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0GOooool00ol0003oooooooooo`05ooooo`00COooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool000?o
00001?oo0007o`0005kooooo0_l00007ooooo`00COooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003oo`00ool00?oo0009o`0006Go
oooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000ool00?oo003oo`000ol0001[ooooo`03
o`000?oooooooooo00Gooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co0000Joooool00ol0003ooooo
ooooo`05ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00o`000002o`000003ool00?l0003ooooo06[ooooo00?o
0000ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`001?l00002ool00003o`000?oooooooooo06Wooooo00?o0000
ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`000ol00003ool00003o`000?oooooooooo06Wooooo00?o0000oooo
ooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`000ol00003ool00003o`000?oooooooooo06Sooooo0_l00007ooooo`00
COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo0003o`0000Coo`0000?o0000ooooooooool0JOooool00ol0003oooooooooo`05ooooo`00COoo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
0002o`0000Goo`0000?o0000ooooooooool0JOooool00ol0003oooooooooo`05ooooo`00COooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000ool00?oo003oo`000ol0
0005ool00003o`000?oooooooooo06Wooooo00?o0000ooooooooool01Oooool004gooooo00?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co00001Ooo0000
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00o`000002o`000003ool00?l0003oo`00
00Coo`0000?o0000ooooooooool0JOooool00ol0003oooooooooo`05ooooo`00COooool00ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000ool00?l0003o00000_oo0007o`00
06_ooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool000Co00000_oo00000ol0003oooooooooo`1^ooooo`;o00001oooool004gooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000?o00000ooo00000ol0003ooooo
ooooo`1_ooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo0002o`0000Coo`0000?o0000ooooooooool0Koooool00ol0003ooooooooo
o`05ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`000ol00004
ool00003o`000?oooooooooo06oooooo00?o0000ooooooooool01Oooool0033ooooo00CoV9RHo`00
0?l0003oV9RH1_ooool00omEEEGo0000oeEEE@09ooooo`;o000000?o410@ooooooooool00_ooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`000_l00005ool00003o`000?oooooo
oooo06oooooo00?o0000ooooooooool01Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj
^[X5ooooo`?o00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co
0000ool00?oo003oo`000ol00005ool00003o`000?oooooooooo06oooooo00?o0000ooooooooool0
1Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Ko
oooo1_l00004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000ool00?oo003oo`000ol00005ool0
0003o`000?oooooooooo06oooooo00?o0000ooooooooool01Oooool002oooooo00Ko0000onk^k_oo
ooooooooonk^k_l0000>ooooo`05odA4A?nj^[[oooooooooool000001Oooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Co00001Ooo00000ol0003oooooooooo`1^ooooo`;o00001ooo
ool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`05omgMgOlQ8B7o
ooooooooool000001Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o000000?o
o`00o`000?oo00001?oo00000ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Gooooo000_
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01?mgMgOoV9RHooooool0
0005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?l000000_l000000ooo003o0000ool0
0004ool00003o`000?oooooooooo06oooooo00?o0000ooooooooool01Oooool002oooooo00Ko0000
onk^k_ooooooooooonk^k_l0000?ooooo`04onk^k_lQ8B7oooooo`0000Gooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00001?l0003oo`00o`000?l00002ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0Koooool00ol0003oooooooooo`05ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RH
odA4A13ooooo00?oMgMgoiRHV?l000001Oooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000Co00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oooooooooo06oooooo00?o0000ooooooooool01Oooool0
02oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X@ooooo`03onk^k_lb<S;o000000Gooooo00?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo0003o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo00Gooooo000`ooooo`04oiRHV?l0003o0000oiRHV1;ooooo00?o
V9RHoa0@4?ooool01?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000?o00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo06oooooo00?o0000ooooooooool01Oooool004gooooo00?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo0002o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1_
ooooo`03o`000?oooooooooo00Gooooo001=ooooo`Oo00001Ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`000ol00004ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0K_ooool2o`0000Oooooo000@ooooo`03okZj^_lb<S;ooooo00kooooo00?o<S8bokZj^_oo
ool0:Oooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool000;o00001Ooo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo06oooooo00?o0000ooooooooool01Oooool0013ooooo00?o<S8bokZj^_ooool0
3_ooool00onj^[[o<S8booooo`0Yooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00004o`000?oo003oo`00ool000?o00001Ooo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo06oooooo00?o0000ooooooooool01Oooool000oooooo
00?oc<c<oc8b<_ooool04?ooool00olb<S;oc<c<ooooo`0Xooooo`03o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?oo003oo`00ool000Wo
00001Ooo00000ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Gooooo0002ooooo`05oa0@
4?l0003o0000o`000?l@41002?ooool00omVIVKoZJVYooooo`04ooooo`03oa0@4?lb<S;o410@00;o
000000?oA4A4olc<c?ooool01?ooool00onHV9SoIVIVooooo`0Xooooo`03o`000?oooooooooo00?o
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
00001Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo06oooooo00?o0000oooooooo
ool01Oooool000Cooooo00?o0000ooooooooool02?ooool00olb<S;oooooooooo`04ooooo`03o`00
0?nHV9Sok^k^00;ooooo00?oQhN7oa0@4?ooool01?ooool00oo^k^ko<S8booooo`0Xooooo`03o`00
0?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;o000000?oo`00o`000?ooool01?ooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo06oooooo00?o0000ooooooooool01Oooool000Cooooo00?o0000ooooooooool02?oo
ool00olb<S;oooooooooo`09ooooo`03okZj^_l0003ooooo00Gooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002o`000003ool00?l0003ooooo00Cooooo1ol0001aooooo`03o`000?oo
oooooooo00Gooooo0004ooooo`?o000000?o410@ogMgMoo^k^h01Oooool00olb<S;oooooooooo`04
ooooo`03olc<c?m4A4Co000000?o000000?oV9RHooooooooool01?ooool00ol0003oooooooooo`0W
ooooo`;o00001?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?l000000_l000000ooo003o0000ooooo`1kooooo`;o00001oooool000Cooooo00Ko0000oooo
ooooooook^k^ogMgMomEEED5ooooo`03ob4Q8Ooooooooooo00Cooooo00Go0000ohN7Qonj^[[o^[Zj
olc<c008ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00oooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000ool00?l0003o00000_oo00000ol0003o
ooooooooo`1kooooo`03o`000?oooooooooo00Gooooo0004ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00olb<S;ok^k^ooooo`04ooooo`03o`000?nHV9Sooooo00;ooooo
00?oc<c<oa0@4?ooool01?ooool00ooMgMgo<S8booooo`0Xooooo`03o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000Co00000_oo00000ol0003ooooo
ooooo`1kooooo`03o`000?oooooooooo00Gooooo0004ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00omVIVKoV9RHooooo`04ooooo`07olc<c?m4A4Co0000o`000?l@413o
<S8bo`000005ooooo`03oiRHV?mVIVKooooo02Sooooo00?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`000ol00003ool00003o`000?oooooooooo07_o
oooo00?o0000ooooooooool01Oooool000Cooooo00Ko0000ooooooooooook^k^ogMgMomEEED5oooo
o`03omgMgOlQ8B7ooooo013ooooo00?o410@olc<c?ooool0:?ooool00ol0003oooooooooo`03oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0003o`0000?oo`0000?o0000oooo
ooooool0Noooool00ol0003oooooooooo`05ooooo`000_ooool00ol@413o0000o`000002o`000003
oa0@4?mgMgOok^k^00Kooooo00?o<S8bokZj^_ooool03_ooool00onj^[[o<S8booooo`0Yooooo`03
o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000;o
00001?oo00000ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Gooooo000@ooooo`03okZj
^_lb<S;ooooo00kooooo00?o<S8bokZj^_ooool0:Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0003o`0000Coo`0000?o0000ooooooooool0
Noooool00ol0003oooooooooo`05ooooo`00COooool2o`0000Cooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool000So0000O?ooool2o`0000Oooooo001=ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool000;o0000Poooool0
0ol0003oooooooooo`05ooooo`00COooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000Co0000ool00?oo003oo`000ol00023ooooo`03o`000?oooooooooo00Gooooo001=oooo
o`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00001?l0003oo`00ool00?oo0003
o`0008?ooooo00?o0000ooooooooool01Oooool0033ooooo00CoV9RHo`000?l0003oV9RH1_ooool0
0omEEEGo0000oeEEE@06ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^1?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000Co0000ool00?oo003oo`000ol00023ooooo`03
o`000?oooooooooo00Gooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`00
00Kooooo0_mgMgL2ooooo`03ogMgMomEEEGooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Co0000Poooool00ol0003oooooooooo`05oooo
o`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool0
0olQ8B7oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o000000?oo`00o`000?ooool0P_ooool0
0ol0003oooooooooo`05ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00?o
0000onk^k_ooool00_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;o000000?oo`00o`000?ooool0POooool2o`0000Oooooo000_
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01_l0003oEEEEonk^k_oo
ooooMgMgoeEEE@Cooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`00
0?oo003o000000;o000000?oo`00o`000?ooool0P_ooool00ol0003oooooooooo`05ooooo`00;ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Ko0000ogMgMol0003o0000
oeEEEOo^k^h4ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00001?l0003o
o`00o`000?l00002ool00003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool002oo
oooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`03odA4A?nHV9Sooooo00Oooooo00?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00004o`000?oo003o0000o`0000;oo`0000?o
0000ooooooooool0POooool00ol0003oooooooooo`05ooooo`00;oooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A0kooooo00?o^[Zjob4Q8Oooool01oooool00ol0003oooooooooo`03ooooo`[o0000
0_oo00000ol0003oooooooooo`21ooooo`03o`000?oooooooooo00Gooooo000_ooooo`06okZj^_lQ
8B7ogMgMomgMgOlQ8B7o^[Zj3oooool00omEEEGo<S8bomgMg@06ooooo`03o`000?oooooooooo00Wo
oooo0ol00003ool00003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool0033ooooo
00CoV9RHo`000?l0003oV9RH4Oooool01?nHV9So8B4Qo`000?lQ8B44ooooo`03o`000?oooooooooo
00Wooooo0ol00003ool00003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool004go
oooo0_l0000:ooooo`?o00000ooo00000ol0003oooooooooo`20ooooo`;o00001oooool004gooooo
00?o0000ooooooooool02Oooool2o`0000Coo`0000?o0000ooooooooool0POooool00ol0003ooooo
ooooo`05ooooo`00COooool00ol0003oooooooooo`09ooooo`;o00001?oo00000ol0003ooooooooo
o`21ooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oooooooooo00Wooooo0_l00004
ool00003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool004gooooo00?o0000oooo
ooooool02?ooool3o`0000Coo`0000?o0000ooooooooool0POooool00ol0003oooooooooo`05oooo
o`00COooool00ol0003oooooooooo`08ooooo`;o00001Ooo00000ol0003oooooooooo`21ooooo`03
o`000?oooooooooo00Gooooo001=ooooo`03o`000?oooooooooo00Sooooo0_l00005ool00003o`00
0?oooooooooo087ooooo00?o0000ooooooooool01Oooool004gooooo0_l00008ooooo`?o00001Ooo
00000ol0003oooooooooo`20ooooo`;o00001oooool004gooooo00?o0000ooooooooool01oooool3
o`0000Goo`0000?o0000ooooooooool0POooool00ol0003oooooooooo`05ooooo`00COooool00ol0
003oooooooooo`07ooooo`?o00001Ooo00000ol0003oooooooooo`21ooooo`03o`000?oooooooooo
00Gooooo001=ooooo`03o`000?oooooooooo00Kooooo1?l00005ool00003o`000?oooooooooo087o
oooo00?o0000ooooooooool01Oooool004gooooo00?o0000ooooooooool01_ooool2o`000003oooo
ool0003oo`0000Coo`0000?o0000ooooooooool0POooool00ol0003oooooooooo`05ooooo`00COoo
ool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?oo00001?oo00000ol0003ooooooooo
o`21ooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oooooooooo00Gooooo0ol00000
0ooooooo0000ool00004ool00003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool0
04gooooo0_l00006ooooo`;o00000_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
083ooooo0_l00007ooooo`00COooool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003o
o`00ool00003ool00003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool004gooooo
00?o0000ooooooooool01Oooool2o`0000;ooooo00?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`21ooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oooooooooo00Cooooo0ol0
0002ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0POooool00ol0003ooooooooo
o`05ooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Kooooo00Ko
k^k^oeEEEOl0003o0000oeEEEOo^k^h4ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0POooool00ol0003oooooooooo`05ooooo`00
;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`06oeEEEOmgMgOooooo
oooooomgMgOoEEEE1?ooool00ol0003oooooooooo`04ooooo`;o00000oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool002oooooo00KoA4A4
oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0POooool00ol0003oooooooooo`05ooooo`00;ooo
ool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`;o00001?ooool2o`0000Cooooo00?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`20ooooo`;o00001oooool002oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0<ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE1?ooool00ol0003oooooooooo`03oooo
o`;o00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo087ooooo00?o0000oooo
ooooool01Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03
omgMgOl0003o000000;o000000?ogMgMooooooooool00_ooool00ol0003oooooooooo`02ooooo`?o
00001?ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo087ooooo00?o0000oooooooo
ool01Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`06oc8b<_mVIVKok^k^
onk^k_mVIVKo<S8b1?ooool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003oo`00ool0
0003ool00003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool002oooooo00KoA4A4
oiRHV?oooooooooooiRHV?m4A4@>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003oo`00ool00003ool00003o`00
0?oooooooooo087ooooo00?o0000ooooooooool01Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgM
ob4Q8Onj^[X>ooooo`06oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b1?ooool00ol0003oooooooooo`02
ooooo`;o00001Oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo087ooooo00?o0000
ooooooooool01Oooool0033ooooo00CoV9RHo`000?l0003oV9RH3oooool01_o^k^koA4A4o`000?l0
003oA4A4onk^kPCooooo00Co0000oooooooooooooooo0ol00005ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0POooool00ol0003oooooooooo`05ooooo`00COooool01?l0003ooooo
ooooooooool2o`0000Kooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`21ooooo`03
o`000?oooooooooo00Gooooo001=ooooo`;o00000_ooool2o`0000Kooooo00?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`20ooooo`;o00001oooool004gooooo00Co0000oooooooooooooooo
0_l00006ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0POooool00ol0003ooooo
ooooo`05ooooo`00COooool00ol0003oooooooooo`03o`0000Kooooo00?o0000ool00?oo00000ooo
00000ol0003oooooooooo`21ooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oooooo
oooo00;o00001oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo087ooooo00?o0000
ooooooooool01Oooool004gooooo00?o0000ooooooooool00_l00007ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0POooool00ol0003oooooooooo`05ooooo`00COooool00ol0003o
ooooooooo`02o`0000Oooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`21ooooo`03
o`000?oooooooooo00Gooooo001=ooooo`03o`000?oooooooooo00;o00001oooool00ol0003oo`00
ool00003ool00003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool004gooooo1Ol0
0007ooooo`Oo0000P_ooool2o`0000Oooooo001=ooooo`04o`000?oooooo0000o`0009;ooooo00?o
0000ooooooooool01Oooool004gooooo00Co0000ooooool0003o0000T_ooool00ol0003ooooooooo
o`05ooooo`00COooool01?l0003oooooo`000?l0002Booooo`03o`000?oooooooooo00Gooooo001=
ooooo`Co0000T_ooool00ol0003oooooooooo`05ooooo`00COooool3o`0009?ooooo00?o0000oooo
ooooool01Oooool004gooooo0ol0002Cooooo`03o`000?oooooooooo00Gooooo001=ooooo`?o0000
T_ooool2o`0000Oooooo001=ooooo`?o0000Toooool00ol0003oooooooooo`05ooooo`00COooool2
o`0009Cooooo00?o0000ooooooooool01Oooool004gooooo0_l0002Dooooo`03o`000?oooooooooo
00Gooooo0012ooooo`Co000000?o410@ooooooooool01?ooool2o`0009Cooooo00?o0000oooooooo
ool01Oooool004Cooooo00?o0000ooooooooool01_ooool2o`0009Cooooo00?o0000ooooooooool0
1Oooool004Cooooo00?o0000ooooooooool01_ooool2o`0009Cooooo00?o0000ooooooooool01Ooo
ool004Cooooo00?o0000ooooooooool01_ooool2o`0009?ooooo0_l00007ooooo`00A?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool01Oooool004Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo00Go
oooo0014ooooo`03o`000?oooooooooo00KoooooUol00007ooooo`00A?ooool00ol0003ooooooooo
o`2Tooooo`00@_ooool00ol0003oA4A4o`00002Vooooo`00@_ooool00oo<c<coEEEEo`00002Voooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-2.60043, -0.435759, 0.03345, \
0.00702449}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The plot below shows the density of the primes between the ",
  Cell[BoxData[
      \(TraditionalForm\`10\^12 + 
        1  st\ and\ the\ 10\^12 + \(10\^4\) th\ \(\(primes\)\(.\)\)\)]],
  " It is clear that the density of primes is fairly uniform over this range \
(which is consistent with the fact that the function 1/ln(x) does not change \
much over this range).  Note that the drop-off in the last bar of the \
histogram occurs because of the way the intervals are defined (i.e. the last \
interval extends well beyond the last prime number in the list)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n = 10000;\)\), "\n", 
    \(\(P2 = Table[Prime[10^12 + i] - Prime[10^12], {i, 1, n}];\)\), "\n", 
    \(\(int = 
        Table[P2[\([1]\)] + i*\((P2[\([n]\)] - P2[\([1]\)])\)/25, {i, 0, 
            25}];\)\), "\[IndentingNewLine]", 
    \(P2DHist = 
      Histogram[P2, HistogramCategories \[Rule] int, 
        HistogramScale \[Rule] n, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, 
        FrameLabel \[Rule] {\*"\"\<p-\!\(p\_\(\_\(10\^12\)\)\)\>\"", \
"\<\[Rho](p)\>"}, RotateLabel \[Rule] False]\)}], "Input"],

Cell[BoxData[
    \(Histogram::"rtail1" \(\(:\)\(\ \)\) 
      "Warning: One point from the right tail of the data, greater than or \
equal to \!\(314316\), is not included in histogram."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-5.72705e-05 3.18169e-06 0.0147151 17.5752 [
[.15903 -0.0125 -25.9062 -18 ]
[.15903 -0.0125 25.9062 0 ]
[.31811 -0.0125 -30.6875 -18 ]
[.31811 -0.0125 30.6875 0 ]
[.4772 -0.0125 -30.6875 -18 ]
[.4772 -0.0125 30.6875 0 ]
[.63628 -0.0125 -30.6875 -18 ]
[.63628 -0.0125 30.6875 0 ]
[.79537 -0.0125 -30.6875 -18 ]
[.79537 -0.0125 30.6875 0 ]
[.95445 -0.0125 -30.6875 -18 ]
[.95445 -0.0125 30.6875 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26.25 -37.3125 ]
[.5 -0.0125 26.25 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .10259 -51.8125 -9 ]
[-0.0125 .10259 0 9 ]
[-0.0125 .19047 -42.25 -9 ]
[-0.0125 .19047 0 9 ]
[-0.0125 .27834 -51.8125 -9 ]
[-0.0125 .27834 0 9 ]
[-0.0125 .36622 -42.25 -9 ]
[-0.0125 .36622 0 9 ]
[-0.0125 .45409 -51.8125 -9 ]
[-0.0125 .45409 0 9 ]
[-0.0125 .54197 -42.25 -9 ]
[-0.0125 .54197 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -94.0625 -9 ]
[-0.01875 .30902 -51.8125 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15903 0 m
.15903 .00625 L
s
gsave
.15903 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50000) show
1.000 setlinewidth
grestore
.31811 0 m
.31811 .00625 L
s
gsave
.31811 -0.0125 -91.6875 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100000) show
1.000 setlinewidth
grestore
.4772 0 m
.4772 .00625 L
s
gsave
.4772 -0.0125 -91.6875 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150000) show
1.000 setlinewidth
grestore
.63628 0 m
.63628 .00625 L
s
gsave
.63628 -0.0125 -91.6875 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200000) show
1.000 setlinewidth
grestore
.79537 0 m
.79537 .00625 L
s
gsave
.79537 -0.0125 -91.6875 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(250000) show
1.000 setlinewidth
grestore
.95445 0 m
.95445 .00625 L
s
gsave
.95445 -0.0125 -91.6875 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300000) show
1.000 setlinewidth
grestore
.125 Mabswid
.03176 0 m
.03176 .00375 L
s
.06358 0 m
.06358 .00375 L
s
.09539 0 m
.09539 .00375 L
s
.12721 0 m
.12721 .00375 L
s
.19084 0 m
.19084 .00375 L
s
.22266 0 m
.22266 .00375 L
s
.25448 0 m
.25448 .00375 L
s
.2863 0 m
.2863 .00375 L
s
.34993 0 m
.34993 .00375 L
s
.38175 0 m
.38175 .00375 L
s
.41356 0 m
.41356 .00375 L
s
.44538 0 m
.44538 .00375 L
s
.50901 0 m
.50901 .00375 L
s
.54083 0 m
.54083 .00375 L
s
.57265 0 m
.57265 .00375 L
s
.60446 0 m
.60446 .00375 L
s
.6681 0 m
.6681 .00375 L
s
.69992 0 m
.69992 .00375 L
s
.73173 0 m
.73173 .00375 L
s
.76355 0 m
.76355 .00375 L
s
.82718 0 m
.82718 .00375 L
s
.859 0 m
.859 .00375 L
s
.89082 0 m
.89082 .00375 L
s
.92263 0 m
.92263 .00375 L
s
.98627 0 m
.98627 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87.25 -41.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
72.562 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
82.125 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
91.688 19.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 11.375 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
91.688 22.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.062 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
101.188 19.312 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 5.750 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
111.500 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .10259 m
.00625 .10259 L
s
gsave
-0.0125 .10259 -112.812 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.005) show
1.000 setlinewidth
grestore
0 .19047 m
.00625 .19047 L
s
gsave
-0.0125 .19047 -103.25 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
1.000 setlinewidth
grestore
0 .27834 m
.00625 .27834 L
s
gsave
-0.0125 .27834 -112.812 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.015) show
1.000 setlinewidth
grestore
0 .36622 m
.00625 .36622 L
s
gsave
-0.0125 .36622 -103.25 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
1.000 setlinewidth
grestore
0 .45409 m
.00625 .45409 L
s
gsave
-0.0125 .45409 -112.812 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.025) show
1.000 setlinewidth
grestore
0 .54197 m
.00625 .54197 L
s
gsave
-0.0125 .54197 -103.25 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.03) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03229 m
.00375 .03229 L
s
0 .04987 m
.00375 .04987 L
s
0 .06744 m
.00375 .06744 L
s
0 .08502 m
.00375 .08502 L
s
0 .12017 m
.00375 .12017 L
s
0 .13774 m
.00375 .13774 L
s
0 .15532 m
.00375 .15532 L
s
0 .17289 m
.00375 .17289 L
s
0 .20804 m
.00375 .20804 L
s
0 .22562 m
.00375 .22562 L
s
0 .24319 m
.00375 .24319 L
s
0 .26077 m
.00375 .26077 L
s
0 .29592 m
.00375 .29592 L
s
0 .31349 m
.00375 .31349 L
s
0 .33107 m
.00375 .33107 L
s
0 .34864 m
.00375 .34864 L
s
0 .38379 m
.00375 .38379 L
s
0 .40137 m
.00375 .40137 L
s
0 .41894 m
.00375 .41894 L
s
0 .43652 m
.00375 .43652 L
s
0 .47167 m
.00375 .47167 L
s
0 .48924 m
.00375 .48924 L
s
0 .50682 m
.00375 .50682 L
s
0 .52439 m
.00375 .52439 L
s
0 .55954 m
.00375 .55954 L
s
0 .57712 m
.00375 .57712 L
s
0 .5947 m
.00375 .5947 L
s
0 .61227 m
.00375 .61227 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -155.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15903 .61178 m
.15903 .61803 L
s
.31811 .61178 m
.31811 .61803 L
s
.4772 .61178 m
.4772 .61803 L
s
.63628 .61178 m
.63628 .61803 L
s
.79537 .61178 m
.79537 .61803 L
s
.95445 .61178 m
.95445 .61803 L
s
.125 Mabswid
.03176 .61428 m
.03176 .61803 L
s
.06358 .61428 m
.06358 .61803 L
s
.09539 .61428 m
.09539 .61803 L
s
.12721 .61428 m
.12721 .61803 L
s
.19084 .61428 m
.19084 .61803 L
s
.22266 .61428 m
.22266 .61803 L
s
.25448 .61428 m
.25448 .61803 L
s
.2863 .61428 m
.2863 .61803 L
s
.34993 .61428 m
.34993 .61803 L
s
.38175 .61428 m
.38175 .61803 L
s
.41356 .61428 m
.41356 .61803 L
s
.44538 .61428 m
.44538 .61803 L
s
.50901 .61428 m
.50901 .61803 L
s
.54083 .61428 m
.54083 .61803 L
s
.57265 .61428 m
.57265 .61803 L
s
.60446 .61428 m
.60446 .61803 L
s
.6681 .61428 m
.6681 .61803 L
s
.69992 .61428 m
.69992 .61803 L
s
.73173 .61428 m
.73173 .61803 L
s
.76355 .61428 m
.76355 .61803 L
s
.82718 .61428 m
.82718 .61803 L
s
.859 .61428 m
.859 .61803 L
s
.89082 .61428 m
.89082 .61803 L
s
.92263 .61428 m
.92263 .61803 L
s
.98627 .61428 m
.98627 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10259 m
1 .10259 L
s
.99375 .19047 m
1 .19047 L
s
.99375 .27834 m
1 .27834 L
s
.99375 .36622 m
1 .36622 L
s
.99375 .45409 m
1 .45409 L
s
.99375 .54197 m
1 .54197 L
s
.125 Mabswid
.99625 .03229 m
1 .03229 L
s
.99625 .04987 m
1 .04987 L
s
.99625 .06744 m
1 .06744 L
s
.99625 .08502 m
1 .08502 L
s
.99625 .12017 m
1 .12017 L
s
.99625 .13774 m
1 .13774 L
s
.99625 .15532 m
1 .15532 L
s
.99625 .17289 m
1 .17289 L
s
.99625 .20804 m
1 .20804 L
s
.99625 .22562 m
1 .22562 L
s
.99625 .24319 m
1 .24319 L
s
.99625 .26077 m
1 .26077 L
s
.99625 .29592 m
1 .29592 L
s
.99625 .31349 m
1 .31349 L
s
.99625 .33107 m
1 .33107 L
s
.99625 .34864 m
1 .34864 L
s
.99625 .38379 m
1 .38379 L
s
.99625 .40137 m
1 .40137 L
s
.99625 .41894 m
1 .41894 L
s
.99625 .43652 m
1 .43652 L
s
.99625 .47167 m
1 .47167 L
s
.99625 .48924 m
1 .48924 L
s
.99625 .50682 m
1 .50682 L
s
.99625 .52439 m
1 .52439 L
s
.99625 .55954 m
1 .55954 L
s
.99625 .57712 m
1 .57712 L
s
.99625 .5947 m
1 .5947 L
s
.99625 .61227 m
1 .61227 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .55299 L
.04 .55299 L
.04 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .55299 L
.04 .55299 L
.04 .01472 L
0 .01472 L
s
1 0 0 r
.04 .01472 m
.04 .59074 L
.08 .59074 L
.08 .01472 L
F
0 g
.04 .01472 m
.04 .59074 L
.08 .59074 L
.08 .01472 L
.04 .01472 L
s
1 0 0 r
.08 .01472 m
.08 .58794 L
.12 .58794 L
.12 .01472 L
F
0 g
.08 .01472 m
.08 .58794 L
.12 .58794 L
.12 .01472 L
.08 .01472 L
s
1 0 0 r
.12 .01472 m
.12 .56138 L
.16 .56138 L
.16 .01472 L
F
0 g
.12 .01472 m
.12 .56138 L
.16 .56138 L
.16 .01472 L
.12 .01472 L
s
1 0 0 r
.16 .01472 m
.16 .56837 L
.2 .56837 L
.2 .01472 L
F
0 g
.16 .01472 m
.16 .56837 L
.2 .56837 L
.2 .01472 L
.16 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .58514 L
.24 .58514 L
.24 .01472 L
F
0 g
.2 .01472 m
.2 .58514 L
.24 .58514 L
.24 .01472 L
.2 .01472 L
s
1 0 0 r
.24 .01472 m
.24 .55858 L
.28 .55858 L
.28 .01472 L
F
0 g
.24 .01472 m
.24 .55858 L
.28 .55858 L
.28 .01472 L
.24 .01472 L
s
1 0 0 r
.28 .01472 m
.28 .60332 L
.32 .60332 L
.32 .01472 L
F
0 g
.28 .01472 m
.28 .60332 L
.32 .60332 L
.32 .01472 L
.28 .01472 L
s
1 0 0 r
.32 .01472 m
.32 .58934 L
.36 .58934 L
.36 .01472 L
F
0 g
.32 .01472 m
.32 .58934 L
.36 .58934 L
.36 .01472 L
.32 .01472 L
s
1 0 0 r
.36 .01472 m
.36 .5432 L
.4 .5432 L
.4 .01472 L
F
0 g
.36 .01472 m
.36 .5432 L
.4 .5432 L
.4 .01472 L
.36 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .56976 L
.44 .56976 L
.44 .01472 L
F
0 g
.4 .01472 m
.4 .56976 L
.44 .56976 L
.44 .01472 L
.4 .01472 L
s
1 0 0 r
.44 .01472 m
.44 .59353 L
.48 .59353 L
.48 .01472 L
F
0 g
.44 .01472 m
.44 .59353 L
.48 .59353 L
.48 .01472 L
.44 .01472 L
s
1 0 0 r
.48 .01472 m
.48 .56837 L
.52 .56837 L
.52 .01472 L
F
0 g
.48 .01472 m
.48 .56837 L
.52 .56837 L
.52 .01472 L
.48 .01472 L
s
1 0 0 r
.52 .01472 m
.52 .59213 L
.56 .59213 L
.56 .01472 L
F
0 g
.52 .01472 m
.52 .59213 L
.56 .59213 L
.56 .01472 L
.52 .01472 L
s
1 0 0 r
.56 .01472 m
.56 .51664 L
.6 .51664 L
.6 .01472 L
F
0 g
.56 .01472 m
.56 .51664 L
.6 .51664 L
.6 .01472 L
.56 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .58095 L
.64 .58095 L
.64 .01472 L
F
0 g
.6 .01472 m
.6 .58095 L
.64 .58095 L
.64 .01472 L
.6 .01472 L
s
1 0 0 r
.64 .01472 m
.64 .56277 L
.68 .56277 L
.68 .01472 L
F
0 g
.64 .01472 m
.64 .56277 L
.68 .56277 L
.68 .01472 L
.64 .01472 L
s
1 0 0 r
.68 .01472 m
.68 .58095 L
.72 .58095 L
.72 .01472 L
F
0 g
.68 .01472 m
.68 .58095 L
.72 .58095 L
.72 .01472 L
.68 .01472 L
s
1 0 0 r
.72 .01472 m
.72 .58934 L
.76 .58934 L
.76 .01472 L
F
0 g
.72 .01472 m
.72 .58934 L
.76 .58934 L
.76 .01472 L
.72 .01472 L
s
1 0 0 r
.76 .01472 m
.76 .56697 L
.8 .56697 L
.8 .01472 L
F
0 g
.76 .01472 m
.76 .56697 L
.8 .56697 L
.8 .01472 L
.76 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .59074 L
.84 .59074 L
.84 .01472 L
F
0 g
.8 .01472 m
.8 .59074 L
.84 .59074 L
.84 .01472 L
.8 .01472 L
s
1 0 0 r
.84 .01472 m
.84 .55858 L
.88 .55858 L
.88 .01472 L
F
0 g
.84 .01472 m
.84 .55858 L
.88 .55858 L
.88 .01472 L
.84 .01472 L
s
1 0 0 r
.88 .01472 m
.88 .58514 L
.92 .58514 L
.92 .01472 L
F
0 g
.88 .01472 m
.88 .58514 L
.92 .58514 L
.92 .01472 L
.88 .01472 L
s
1 0 0 r
.92 .01472 m
.92 .60332 L
.96 .60332 L
.96 .01472 L
F
0 g
.92 .01472 m
.92 .60332 L
.96 .60332 L
.96 .01472 L
.92 .01472 L
s
1 0 0 r
.96 .01472 m
.96 .54739 L
1 .54739 L
1 .01472 L
F
0 g
.96 .01472 m
.96 .54739 L
1 .54739 L
1 .01472 L
.96 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo002Mooooo`?o00000oooool00ol0003oooooooooo`15
ooooo`00W_ooool01ol0003ooooooooooooooooo0000ooooool00000A_ooool009kooooo00Oo0000
ooooooooooooooooo`000?oooooo000004Kooooo0021ooooo`04oa0@4?l0003o0000o`0000oooooo
00Co410@o`000?l0003o00001_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool5
o`0003oooooo0022ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool2o`00
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000010ooooo`00P_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00Co0000oooooooooooo0000?oooool008;o
oooo00Ko0000ohN7Qol@413o0000oa0@4?mgMgL=ooooo`06o`000?n7QhOo410@o`000?l@413oMgMg
3?ooool2o`000003ooooool0003o000003oooooo0022ooooo`07o`000?lQ8B7oc<c<ooooooo<c<co
8B4QogMgM`0<ooooo`07o`000?lQ8B7oc<c<ooooooo<c<co8B4QogMgM`1?ooooo`00P_ooool00ol0
003oc<c<ooooo`02ooooo`03olc<c?l@413ooooo00_ooooo00?o0000olc<c?ooool00_ooool00oo<
c<co410@ooooo`1>ooooo`00P_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Ko
00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04gooooo0022ooooo`03o`00
0?o<c<cooooo00;ooooo00?oc<c<oa0@4?ooool02oooool00ol0003oc<c<ooooo`02ooooo`03olc<
c?l@413ooooo04kooooo0022ooooo`07o`000?lQ8B7oc<c<oooooonj^[[o8B4QojVYZ@0<ooooo`07
o`000?lQ8B7oc<c<oooooonj^[[o8B4QojVYZ@1?ooooo`00POooool01ol@413o0000ohN7Qol@413o
0000oa0@4?nYZJT03?ooool01ol@413o0000ohN7Qol@413o0000oa0@4?nYZJT0D?ooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00G?ooool01OnHV9So410@o`000?l0003oIVIV00Kooooo00?oV9RHo`000?l00000
0ol000001Ol@413oooooooooooooooooV9RH00;o000000CoV9RHo`000?l0003oV9RH0oooool6o`00
0005oiRHV?oooooooooooooooonHV9P03ol000000onHV9SooooooiRHV002o`000003oiRHV?l0003o
000000Oo000000?oV9RHo`000?l000000_nHV9P00ol@413o0000o`000002o`000004oiRHV?l0003o
0000oa@D50Ko000000CoV9RHooooooooooooV9RH1_l000001?nHV9SooooooooooonHV9P4o`000003
oiRHV?oooooooooo00;ooooo00?oV9RHo`000?l000000_l000000onHV9Soooooooooo`02ooooo`04
oiRHV?l0003o0000oiRHV0Kooooo00CoV9RHo`000?l0003oV9RH1?ooool005cooooo00Ko410@ohN7
QoooooooooooogMgMomVIVH4ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o00001?ooool0BOnj^[[o
8B4QomgMgOnRXZ;o8B4Qoj6QXOoMgMgo8B4QokZj^_oooooo^[Zjob4Q8OoMgMgo0000ob4Q8OnQXJ7o
gMgMob4Q8Onj^[[ooooookZj^_l20P;oMGEeoj:RX_lQ8B7oBd];oeQHF?lC4a?o0000omgMgOoooooo
^[Zjo`820_nQXJ7o71`LoadM7OnRXZ;o8B4QokZj^_lQ8B7ogMgMoj6QXOlQ8B7oMWIfoa`L7?lA4A7o
0000oa`L7?nj^[[o8B4Qo`h>3_nQXJ7o8B4Qoj:RX_oMgMgo8B4Qo``<3?n7QhOo^[Zjob4Q8OmWIfOo
@410ob4Q8OnRXZ;o3Ph>oaXJ6_nj^[[o8B4Qod];Bol;2`_o7AdMoj:RX_lQ8B400_nj^[X02?lQ8B7o
XJ6Qoa`L7?lE5AGo51@DoadM7OnRXZ;o8B4Q0_nj^[X01olQ8B7oXJ6Qoa`L7?lM7AgoXZ:Rob4Q8Onj
^[X00_ooool02?nj^[[o8B4Qoj6QXOlL71co7AdMoj:RX_lQ8B7o^[Zj0_ooool01_nj^[[o8B4QomgM
gOoMgMgo8B4QokZj^PCooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X3ooooo`00HOooool00ol0
003oooooooooo`02ooooo`06odA4A?nHV9SooooooooooonHV9So00001?ooool08_m4A4CoV9RHoooo
oom4A4CoV9RHodA4A?ooooooV9RHodA4A?ooooooA4A4oiRHV?oooooo0000oiRHV?m4A4CooooooiRH
V?m4A4CoooooodA4A?nHV9SoooooodA4A?nHV9SoA4A4o`000?nHV9So92@Tob4Q8Oo^k^koA4A4oiRH
V?m4A4@2oiRHV008odA4A?nHV9SoA4A4oiRHV?ooooooA4A4oiRHV?m4A4@2oiRHV00Kob@T9?lD51Co
?clooiRHV?ooooooA4A4oiRHV?m4A4CooooooiRHV?m4A4CoooooodA4A?nHV9Soooooo`000?nHV9So
A4A4oooooonHV9SoA4A4oiRHV?m4A4Co0000oiRHV?m4A4CoV9RH00;oA4A400?oV9RHodA4A?nHV9P0
0_lX:2P00onHV9SoA4A4oiRHV002odA4A007oiRHV?m4A4CoV9RHoiRHV?m4A4CoV9RHodA4A002oooo
o`03odA4A?nHV9SoA4A400;oV9RH00?oA4A4oiRHV?m4A4@00_ooool01_m4A4CoV9RHoooooooooooo
V9RHodA4A0Cooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@3ooooo`00H?ooool00oo^k^ko0000
ooooo`03ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool06Ol0003ok^k^ooooool0003o
k^k^o`000?ooooook^k^o`000?oooooo0000onk^k_oooooo0000onk^k_l0003oooooonk^k_l0003o
ooooo`000?o^k^koooooo`000?o^k^h00_l000001oo^k^ko0000ojVYZOlQ8B7o0000onk^k_l00000
0_o^k^h02?l0003ok^k^o`000?o^k^koooooo`000?o^k^ko00000_o^k^h03Ol0003oWYjNo`000?o^
k^koooooo`000?o^k^ko0000ooooooo^k^ko0000ooooool000000_o^k^h01ol0003ok^k^o`000?oo
ooook^k^o`000?o^k^h00_l000000oo^k^ko0000onk^kP02o`000003onk^k_l0003ok^k^00;o0000
00?ok^k^o`000?o^k^h00_l000001oo^k^ko0000onk^k_o^k^ko0000onk^k_l000000_ooool00ol0
003ok^k^o`000002onk^kP03o`000?o^k^ko000000;ooooo00Ko0000onk^k_ooooooooooonk^k_l0
0004ooooo`06o`000?o^k^koooooooooooo^k^ko00000oooool005cooooo00Ko410@oiRHV?oooooo
ooooogMgMomVIVH4ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01_l0
003oooooooooool0003oooooo`0000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`00
0002ooooo`0@o`000?oooooo0000oa0@4?nHV9So0000ooooool0003oIVIVooooool0003ooooooiRH
V?l0003oooooo`0000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`08
o`000?oooooo0000oc8b<_oooooo0000ooooool00002ooooo`08o`000?nHV9So0000oooooomgMgOo
0000ooooool00002ooooo`07o`000?oooooo0000odA4A?oooooo0000ooooo`02o`000003ooooool0
003ooooo00;o000000?oooooo`000?ooool00_l000001ooooooo0000oooooooooooo0000ooooool0
00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00Oooool005cooooo00Go0000ob4Q8Ol0003o0000ofIVIP05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000
ooooool000000_ooool00ol0003oooooo`000002ooooo`05o`000?oooooo0000o`000?lQ8B400ol0
0002ooooo`06o`000?ooooooooooo`000?mgMgOo00000_ooool00ol0003oooooo`000002ooooo`03
o`000?oooooo000000;ooooo00So0000ooooool0003oA4A4ogMgMol0003oooooo`0000;ooooo00So
0000ob4Q8Ol0003o0000ofIVI_l0003oooooo`0000;ooooo0ol000001?oMgMgoooooo`000?ooool2
o`000003ooooool0003ooooo00;o000000?oooooo`000?ooool00_l000001ooooooo0000oooooooo
oooo0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00Oooool005cooooo00?o0000ooooooooool01oooool01_l0003ok^k^oooo
ooooooook^k^o`0000Cooooo01Co0000onk^k_oooooo0000onk^k_l0003oooooonk^k_l0003ooooo
o`000?o^k^koooooo`000?o^k^ko0000ooooooo^k^ko0000ooooo`;o000000Ooooooo`000?o^k^ko
0000ooooooo^k^ko000000;ooooo00?o0000o`l?3ol000000_o^k^h02?l0003ok^k^o`000?o^k^ko
ooooo`000?o^k^ko00000_o^k^h06ol0003ok^k^o`000?o>c/ko410@o`000?o^k^ko0000ooooooo^
k^ko0000ooooool0003ok^k^ooooool0003ok^k^o`000?ooooook^k^o`000?o^k^ko0000obl_;oo^
k^ko0000onk^kP02o`000003onk^k_l0003ok^k^00;o000000?ok^k^o`000?o^k^h00_l000001oo^
k^ko0000onk^k_o^k^ko0000onk^k_l000000_ooool00ol0003ok^k^o`000002onk^kP03o`000?o^
k^ko000000;ooooo00Ko0000onk^k_ooooooooooonk^k_l00004ooooo`06o`000?o^k^kooooooooo
ooo^k^ko00000oooool005cooooo00?o0000ooooooooool01oooool01_m4A4CoV9RHoooooooooooo
V9RHo`0000Cooooo01goA4A4oiRHV?ooooooA4A4oiRHV?m4A4CooooooiRHV?m4A4CoooooodA4A?nH
V9Soooooo`000?nHV9SoA4A4oooooonHV9SoA4A4oooooom4A4Co0000oooooom4A4CoV9RHodA4A?oo
ooooV9RHodA4A002ooooo`03odA4A?l0003oA4A400;oV9RH00SoA4A4oiRHV?m4A4CoV9RHoooooom4
A4CoV9RHodA4A0;oV9RH01_oA4A4oiRHV?m4A4CoV9RHo`000?m4A4CoV9RHodA4A?ooooooV9RHo`00
0?ooooooA4A4oiRHV?ooooooA4A4oiRHV?m4A4CooooooiRHV?m4A4CoV9RHodA4A?l0003oV9RHodA4
A?nHV9P00_m4A4@00onHV9SoA4A4oiRHV002obPX:003oiRHV?m4A4CoV9RH00;oA4A400OoV9RHodA4
A?nHV9SoV9RHodA4A?nHV9SoA4A400;ooooo00?oA4A4oiRHV?m4A4@00_nHV9P00om4A4CoV9RHodA4
A002ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41?ooool01_m4A4CoV9RHooooooooooooV9RH
odA4A0?ooooo001Looooo`03o`000?oooooooooo00Oooooo00Ko^[Zjob4Q8OoMgMgo0000o`P82?l0
0004ooooo`19okZj^_lQ8B7ogMgMoj:RX_lQ8B7oXJ6QomgMgOlQ8B7o^[Zjoooooonj^[[o0000ocXj
>_l0003o8B4Qoj6QXOoMgMgo8B4QokZj^_oooooo^[Zjo`000?oMgMgoXZ:Rob4Q8OnQXJ7ogMgMo`00
0?mSHf?ok^k^oooooom_Kfoo2`/;oj6QXOlL71co7AdMoj:RX_lQ8B7o^[Zjob4Q8OoMgMgoXJ6Qob4Q
8OmfMWKo71`Lo`000?mFEUKo7QhNokZj^_lC4a?oBDU9oj6QXOlQ8B7oXZ:RomgMgOlQ8B7o0000oooo
oonj^[[o8B4QomgMgOnQXJ7o8B4Qoj:RX_lM7Ago61PHokZj^_lQ8B7o@410o`D51OlM7AgoXZ:Rob4Q
8@02okZj^P08ob4Q8OnQXJ7o71`LoaDE5OlD51Co7AdMoj:RX_lQ8B42okZj^P07ob4Q8OnQXJ7o71`L
oadM7OnRXZ;o8B4QokZj^P02ooooo`08okZj^_lQ8B7oXJ6Qoa`L7?lM7AgoXZ:Rob4Q8Onj^[X2oooo
o`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^P?o
oooo001Looooo`Go00001_ooool01OnHV9So0000o`000?lb<S;o000000Gooooo00CoV9RHo`000?l0
003oV9RH0_l000001OnHV9SoooooooooooooooooNGUi00;o000000CoV9RHo`000?l0003oV9RH0ooo
ool6o`000006ofEUIOlb<S;o0000o`000?mEEEGoSHf=1?l000000onHV9SooooooiRHV002o`000003
oiRHV?l0003o000000Co000000Co<S8bo`000?l0003oV9RH0_l000000onHV9So0000o`000004o`00
0004oiRHV?l0003o0000obPX:0Ko000000CoV9RHooooooooooooV9RH1_l000001?nHV9Sooooooooo
oonHV9P4o`000003oiRHV?oooooooooo00;ooooo00?oV9RHo`000?l000000_l000000onHV9Sooooo
ooooo`02ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00CoV9RHo`000?l0003oV9RH1?ooool00>_o
oooo003[ooooo`00E_ooool01?nHV9So0000o`000?nHV9RAooooo`00EOooool01_nj^[[o8B4QomgM
gOoMgMgo8B4QokZj^PGoooooLOl0000Jooooo`00EOooool01_m4A4CoV9RHooooooooooooV9RHodA4
A0Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`00EOooool01_l0003o
k^k^ooooooooooook^k^o`0000GoooooLOl0000Jooooo`00EOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`00EOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`00EOooool01_l0003ok^k^oooo
ooooooook^k^o`0000Gooooo00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`00EOooool01_m4A4CoV9RHoooooooooooo
V9RHodA4A0Gooooo00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oooooooooo`0Hooooo`00EOooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj
^PGooooo00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oooooooooo`0Hooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0
003oEEEE00Oooooo00CoV9RHo`000?l0003oV9RH1_ooool01?nHV9So0000o`000?nHV9P4ooooo`03
oiRHV?l0003o000000;o000000?oIVIVooooooooool00_ooool01Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooooooo01Sooooo000_oooo
o`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo00Ko^[Zjob4Q8OoMgMgogMgM
ob4Q8Onj^[X4ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_l@413oQhN7oooooooo
ooooMgMgofIVIP?ooooo00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oooooooooo`0Hooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RH
odA4A0Gooooo00?oEEEEo`000?mEEED01_ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo
00KoA4A4oiRHV?oooooooooooiRHV?m4A4@9ooooo`05o`000?ooooooooooooooool000000ooo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003ooooooooo
o`0Hooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00Ko0000onk^k_oooooo
ooooonk^k_l00004ooooo`06o`000?o^k^koooooooooooo^k^ko00002?ooool00oo^k^ko0000oooo
o`02ooooo`05o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ooooooooool06?ooool002oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH3oooo
o`05o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ooooooooool06?ooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Go0000ob4Q8Ol0003o0000ofIVIP04ooooo`05o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000oooooooo
ool06?ooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`06o`000?o^k^kooooo
ooooooo^k^ko00001?ooool01_l0003ok^k^ooooooooooook^k^o`0000Cooooo00?o0000oooooooo
ool01_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oooooooooo01Sooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A43_oo
ool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@4
ooooo`03o`000?oooooooooo00Kooooo00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`00;oooool01_nj^[[o8B4QomgM
gOoMgMgo8B4QokZj^Pkooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`06okZj^_lQ8B7o
gMgMomgMgOlQ8B7o^[Zj1?ooool00ol0003oooooooooo`06ooooo`05o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool06?ooool0033o
oooo00CoV9RHo`000?l0003oV9RH4?ooool01?nHV9So0000o`000?nHV9P6ooooo`04oiRHV?l0003o
0000oiRHV0Gooooo1Ol00004ooooo`05o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ooooooooool06?ooool003Wooooo00CoV9RHo`000?l0003o
V9RH1_ooool00omEEEGo0000oeEEE@07ooooo`04oiRHV?l0003o0000oiRHV0Gooooo1?l000000ol@
413oooooooooo`03ooooo`05o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ooooooooool06?ooool003Sooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q
8Onj^[X5ooooo`?o00001_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PKooooo00?o0000oooo
ooooool01Oooool01Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oooooooooo01Sooooo000hooooo`06odA4A?nHV9SooooooooooonHV9SoA4A4
1Oooool00omEEEGo0000oeEEE@06ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41_ooool00ol0
003oooooooooo`05ooooo`05o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ooooooooool06?ooool003Sooooo00Ko0000onk^k_ooooooooooonk^
k_l0000>ooooo`06o`000?o^k^koooooooooooo^k^ko00001_ooool00ol0003oooooooooo`05oooo
o`05o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ooooooooool06?ooool003Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`05o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ooooooooool06?ooool003Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`05o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ooooooooool06?ooool003Sooooo00Ko0000onk^k_ooooooooooonk^k_l0000>oooo
o`06o`000?o^k^koooooooooooo^k^ko00001_ooool00ol0003oooooooooo`05ooooo`05o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000oooooooo
ool06?ooool003Sooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@>ooooo`06odA4A?nHV9Sooooo
oooooonHV9SoA4A41_ooool00ol0003oooooooooo`05ooooo`05o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool06?ooool003Sooooo
00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X>ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?oo
ool00ol0003oA4A4o`000007ooooo`05o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ooooooooool06?ooool003Wooooo00CoV9RHo`000?l0003o
V9RH4?ooool01?nHV9So0000o`000?nHV9P5ooooo`03olc<c?mEEEGo000000Oooooo00Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003ooooooooo
o`0Hooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Oooooo00Co
V9RHo`000?l0003oV9RH1Oooool4o`000003oa0@4?oooooooooo00?ooooo00GoV9RHoa0@4?l0003o
0000ofIVIP04ooooo`05o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ooooooooool06?ooool0013ooooo00?o^[Zjoc8b<_ooool00oooool01?l@
413o0000o`000?l00007ooooo`03oc8b<_nj^[[ooooo00_ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q
8Onj^[X5ooooo`?o00001_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PKooooo00?o0000oooo
ooooool01Oooool01_l@413oQhN7ooooooooooooMgMgofIVIP?ooooo00Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`00
0oooool00ol0003oooooooooo`0:ooooo`03oc8b<_nj^[[ooooo00Cooooo00?o0000ooooooooool0
1oooool00onj^[[o<S8booooo`0;ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omE
EEGo0000oeEEE@06ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41_ooool00ol0003ooooooooo
o`0:ooooo`05o`000?ooooooooooooooool000000ooo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`000oooool00olb<S;o^[Zj
ooooo`09ooooo`03olc<c?lb<S;ooooo00Gooooo00?o0000ooooooooool02?ooool00olb<S;oc<c<
ooooo`0:ooooo`06o`000?o^k^koooooooooooo^k^ko00003_ooool01_l0003ok^k^oooooooooooo
k^k^o`0000Kooooo00?o0000ooooooooool02Oooool00oo^k^ko0000ooooo`02ooooo`05o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000oooooooo
ool06?ooool000?ooooo00?oMgMgohN7QomgMgL00_l000000om4A4Coc<c<ooooo`04ooooo`03ofIV
I_nYZJWooooo00Gooooo00Ko0000ohN7Qol@413o0000oa0@4?mgMgL5ooooo`03oiRHV?mVIVKooooo
00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`06oa0@4?nHV9Sooooo
oooooomgMgOoIVIV0oooool01Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oooooooooo01Sooooo0003ooooo`08oiRHV?l@413oQhN7onk^k_oo
ooooV9RHoa0@4?o<c<`4ooooo`03oc8b<_oooooooooo00Gooooo00Oo0000ob4Q8Oo<c<coooooolc<
c?lQ8B7oMgMg00Cooooo00?ok^k^oc8b<_ooool02_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ob4Q8Ol0003o0000ofIVIP04ooooo`05o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool06?ooool0
00?ooooo00?o^[Zjoc8b<_ooool00oooool00onHV9SoA4A4ooooo`03ooooo`03oc8b<_oooooooooo
00Gooooo00?o0000olc<c?ooool00_ooool00oo<c<co410@ooooo`04ooooo`03o`000?oooooooooo
00Wooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`06o`000?o^k^koooooooooooo^k^ko
00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`0H
ooooo`001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o<S8boooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0kooooo00KoA4A4oiRHV?oooooooooo
oiRHV?m4A4@6ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
0ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooo
oooo01Sooooo0004ooooo`03odA4A?nHV9Sooooo00;ooooo00?ok^k^o`000?ooool00oooool00olQ
8B7oooooooooo`05ooooo`03o`000?o<c<cooooo00;ooooo00?oc<c<oa0@4?ooool01?ooool00ol0
003oooooooooo`09ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool01_nj^[[o8B4QomgM
gOoMgMgo8B4QokZj^PCooooo00?o0000odA4A?l000001oooool00ol0003oooooooooo`06ooooo`05
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ooooooooool06?ooool000Cooooo00Oo^[Zjo`000?nj^[[oooooonk^k_mVIVKoEEEE00Cooooo00?o
<S8bonk^k_ooool01Oooool01ol0003o8B4Qolc<c?oooooo^[Zjob4Q8OnYZJT01?ooool00ooMgMgo
<S8booooo`0;ooooo`04oiRHV?l0003o0000oiRHV13ooooo00CoV9RHo`000?l0003oV9RH1Oooool0
0oo<c<coEEEEo`000007ooooo`Go00001?ooool01Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oooooooooo01Sooooo0005ooooo`06ojVYZOlQ
8B7o0000o`000?mEEEGok^k^1?ooool00omVIVKoV9RHooooo`04ooooo`07oa0@4?l0003oQhN7oa0@
4?l0003o410@ojVYZ@05ooooo`03oiRHV?mVIVKooooo01Cooooo00CoV9RHo`000?l0003oV9RH1_oo
ool00omEEEGo0000oeEEE@07ooooo`04oiRHV?l0003o0000oiRHV0Cooooo1_l00005ooooo`05o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000oooo
ooooool06?ooool000oooooo00?ogMgMob4Q8Oooool04?ooool00ol@413oc<c<ooooo`0Cooooo`06
okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q
8Onj^[X3ooooo`03oiRHV?l0003ogMgM00;ooooo00?o410@ooooooooool00oooool01Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooooooo
01Sooooo000@ooooo`03oc8b<_nj^[[ooooo00kooooo00?o^[Zjoc8b<_ooool05?ooool01_m4A4Co
V9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A0Cooooo00?oQhN7ob4Q8Oo^k^h01oooool01Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooooooo01Sooooo000@ooooo`03
okZj^_lb<S;ooooo00kooooo00?o<S8bokZj^_ooool05?ooool01_l0003ok^k^ooooooooooook^k^
o`0000kooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooo`03ojVYZOlQ8B7ok^k^00Kooooo
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oooooooooo`0Hooooo`00>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03oiRHV?lb<S;ooooo00Go
oooo00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oooooooooo`0Hooooo`00>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03odA4A?mgMgOooooo
00Cooooo00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oooooooooo`0Hooooo`00>?ooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo
00Ko0000onk^k_ooooooooooonk^k_l00007ooooo`03omgMgOl@413ooooo00Cooooo00Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003ooooooooo
o`0Hooooo`00>?ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0kooooo00KoA4A4oiRHV?oooooo
oooooiRHV?m4A4@8ooooo`03o`000?oooooooooo00?ooooo00Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`00>?ooool0
1_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X3oooo
o`06o`000?n7QhOok^k^oooooonHV9SoEEEE1Oooool01Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooooooo01Sooooo000iooooo`04oiRH
V?l0003o0000oiRHV13ooooo00CoV9RHo`000?l0003oV9RH1?ooool01_nYZJWo<S8bo`000?l0003o
EEEEonk^kPGooooo00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oooooooooo`0Hooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03
oeEEEOl0003oEEEE00Oooooo00CoV9RHo`000?l0003oV9RH1?ooool6o`0000Gooooo00GoV9RHoa0@
4?l0003o0000ofIVIP04ooooo`05o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool0
0?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`00
0004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ooooooooool06?ooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgM
ob4Q8Onj^[X5ooooo`?o00001_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^P?ooooo00?oV9RH
o`000?oMgMd00_ooool00ol@413oooooooooo`03ooooo`06oa0@4?n7QhOooooooooooomgMgOoIVIV
0oooool01Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oooooooooo01Sooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool0
0omEEEGo0000oeEEE@06ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41?ooool00on7QhOo8B4Q
onk^kP0<ooooo`05o`000?ooooooooooooooool000000ooo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`0Hooooo`00;oooool01_l0003o
k^k^ooooooooooook^k^o`0000kooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooo`03ojVY
ZOlQ8B7ok^k^00[ooooo00?ok^k^o`000?ooool00_ooool01Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool0
0?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooooooo01Sooooo000_ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?oV9RHoc8b<_ooool01Oooool01_l@413oV9RHooooooooooooMgMg
ofIVIP?ooooo00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003o
o`00ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oooooooooo`0Hooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03odA4A?mg
MgOooooo00Cooooo00Go0000ob4Q8Ol0003o0000ofIVIP04ooooo`05o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool06?ooool002oo
oooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`06o`000?o^k^koooooooooooo^k^ko0000
1oooool00ooMgMgo410@ooooo`04ooooo`03o`000?oooooooooo00Kooooo00Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oooooooooo`0Hoooo
o`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0kooooo00KoA4A4oiRHV?oooooooooooiRH
V?m4A4@8ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool01Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000000ooo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooooooo
01Sooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool01_nj^[[o8B4QomgMgOoM
gMgo8B4QokZj^P?ooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED5ooooo`03o`000?oooooooooo
00Kooooo00Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005
o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000
ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00
ool00?oo003o000000?oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oooooooooo`0Hooooo`00<?ooool01?nHV9So0000o`000?nHV9P@ooooo`04oiRHV?l0
003o0000oiRHV0Cooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h5ooooo`Go00001?ooool01Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo
003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00000ooo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
oooooooo01Sooooo000iooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01ooo
ool01?nHV9So0000o`000?nHV9P5ooooo`05ojVYZOlQ8B7o0000o`000?mVIVH01Oooool01Ol0003o
o`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003o
o`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003o
o`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`001Ol00004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooooooo01Sooooo000hooooo`06
okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q
8Onj^[X4ooooo`06oa0@4?o<c<cooooooooooomgMgOoIVIV1?ooool01Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l00000
1?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool0
0005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go
0000ooooooooooooooooo`000004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oooooooooo01Sooooo000h
ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`06odA4
A?nHV9SooooooooooonHV9SoA4A42Oooool00ol0003oooooooooo`02ooooo`05o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00
o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo
00001Ol0003ooooooooooooooooo000000Coo`0000Go0000ool00?oo003oo`00o`000003ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00
ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ooooooooool06?oo
ool003Sooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`06o`000?o^k^koooooooooooo^
k^ko00002Oooool00ol0003oooooooooo`02ooooo`05o`000?oo003oo`00ool00?l000001?oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`00
0?oo003oo`00ool00?l000001?oo00001?l0003oo`00ool00?oo0006o`0000?oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ooooooooooooooooo`00
0004ool00005o`000?oo003oo`00ool00?l000000ooo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Co0000ool0
0?oo003oo`001_l0000Jooooo`00>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03ojVYZOm4A4Cooooo
00?ooooo1Ol00004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000Go0000ool00?oo003oo`00o`000004ool00005o`000?oo003oo`00ool00?l0
00001?ooool01Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo003oo`00o`000004
ool00005o`000?ooooooooooooooool000001?oo00001Ol0003oo`00ool00?oo003o000000?oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?ooool00ol0003oooooooooo`0H
ooooo`00>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`04ob4Q8Ol0003o0000omgMg@Cooooo00Go0000
ooooooooooooooooo`000004ool00004o`000?oo003oo`00ool000Ko00000ooo00000ol0003oo`00
ool00002ool000Go00001?oo00001Ol0003oo`00ool00?oo003o000000Cooooo00Go0000ool00?oo
003oo`00o`000004ool00005o`000?oo003oo`00ool00?l000001?oo00001Ol0003ooooooooooooo
oooo000000Coo`001Ol00003ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool000Go00001?oo00001Ol0003oo`00ool00?oo003o000000Cooooo00?o0000oooooooo
ool06?ooool003Sooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`06o`000?o^k^kooooo
ooooooo^k^ko00002?ooool00onYZJWo<S8booooo`03ooooo`05o`000?ooooooooooooooool00000
1?oo00001Ol0003oo`00ool00?oo003o000000Cooooo1Ol00004ool00005o`000?oooooooooooooo
ool000001?oo00001Ol0003oo`00ool00?oo003o000000Cooooo1Ol00004ool000Go00001?oo0000
1Ol0003ooooooooooooooooo000000Coo`0000Go0000ooooooooooooooooo`000003ool00003o`00
0?oo003oo`0000;oo`001Ol00004ool00005o`000?ooooooooooooooool000001?oo00001Ol0003o
o`00ool00?oo003o000000Cooooo00?o0000ooooooooool06?ooool003Sooooo00KoA4A4oiRHV?oo
oooooooooiRHV?m4A4@>ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A42Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001?oo00001Ol0003oo`00ool00?oo003o0000
00Sooooo00?o0000ool00?oo00000_oo00001Ol0003ooooooooooooooooo000000Coo`0000Go0000
ool00?oo003oo`00o`000008ooooo`03o`000?oo003oo`0000;oo`0000Go0000oooooooooooooooo
o`000004ool00004o`000?ooooooooooooooo`Ko00000oooool5o`0000Coo`0000Go0000oooooooo
ooooooooo`000004ool00005o`000?ooooooooooooooool000001?oo00001Ol0003oo`00ool00?oo
003o000000Cooooo00?o0000ooooooooool06?ooool003Sooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q
8Onj^[X>ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_lQ8B7o^[Zjoooooooooooo
IVIVoc8b<PCooooo00Co0000oooooooooooooooo2_l00008ooooo`Ko00000oooool00ol0003oo`00
ool00002ool000Go00002?ooool00ol0003oo`00ool00002ool00004o`000?ooooooooooooooo`Ko
00004?ooool6o`0000?ooooo1_l00003ooooo`Ko00000ooo00000ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Sooooo000iooooo`04oiRHV?l0003o0000oiRHV13ooooo00CoV9RHo`000?l0
003oV9RH1Oooool01_nj^[[oA4A4o`000?l0003oA4A4onk^kPCooooo00?o0000ooooooooool07?oo
ool00ol0003oo`00ool00002ool00003o`000?oooooooooo00[ooooo1_l0000`ooooo`05o`000?oo
003oo`00ool00?l000001?ooool00ol0003oooooooooo`0Hooooo`00H?ooool00ol0003ooooooooo
o`0Looooo`Ko0000@_ooool5o`0000Cooooo00?o0000ooooooooool06?ooool0063oooooLOl0000J
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-269233, -0.0522516, 2799.8, \
0.000506856}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Since the density of primes between the ",
  Cell[BoxData[
      \(TraditionalForm\`10\^12 + 
        1  st\ and\ the\ 10\^12 + \(10\^4\) th\ primes\)]],
  "is roughly uniform, we do not need to unfold this sequence of primes in \
order to calculate the spacing statistics.  The code below generates a \
histogram of the spacings between consecutive primes in this range, without \
unfolding (but still scaled so that the mean spacing is 1)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n = 10000;\)\), "\n", 
    \(\(P3 = Table[Prime[10^12 + i], {i, 1, n + 1}];\)\), "\n", 
    \(\(P3Spacing = 
        Table[P3[\([i + 1]\)] - P3[\([i]\)], {i, 1, n}];\)\), "\n", 
    \(\(P3SpacingNorm = P3Spacing/Mean[P3Spacing];\)\), "\n", 
    \(\(int\  = \ Table[0 + i/5, {i, 0, 25}];\)\), "\n", 
    \(P3Hist = 
      Histogram[P3SpacingNorm, HistogramCategories \[Rule] int, 
        HistogramScale \[Rule] 1, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<s\>", "\<P(s)\>"}, 
        RotateLabel \[Rule] False]\)}], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(P3Hist\\)\\\" is similar to existing symbol \
\\\"\\!\\(PHist\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(Histogram::"rtail" \(\(:\)\(\ \)\) 
      "Warning: \!\(39\) points from the right tail of the data, greater than \
or equal to \!\(5\), are not included in histogram."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.2 0.0147151 0.700488 [
[.2 -0.0125 -6.78125 -18 ]
[.2 -0.0125 6.78125 0 ]
[.4 -0.0125 -6.78125 -18 ]
[.4 -0.0125 6.78125 0 ]
[.6 -0.0125 -6.78125 -18 ]
[.6 -0.0125 6.78125 0 ]
[.8 -0.0125 -6.78125 -18 ]
[.8 -0.0125 6.78125 0 ]
[1 -0.0125 -6.78125 -18 ]
[1 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .15481 -32.6875 -9 ]
[-0.0125 .15481 0 9 ]
[-0.0125 .29491 -32.6875 -9 ]
[-0.0125 .29491 0 9 ]
[-0.0125 .43501 -32.6875 -9 ]
[-0.0125 .43501 0 9 ]
[-0.0125 .57511 -32.6875 -9 ]
[-0.0125 .57511 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -74.9375 -9 ]
[-0.01875 .30902 -32.6875 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
gsave
.2 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.4 0 m
.4 .00625 L
s
gsave
.4 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.6 0 m
.6 .00625 L
s
gsave
.6 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.8 0 m
.8 .00625 L
s
gsave
.8 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .15481 m
.00625 .15481 L
s
gsave
-0.0125 .15481 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .29491 m
.00625 .29491 L
s
gsave
-0.0125 .29491 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .43501 m
.00625 .43501 L
s
gsave
-0.0125 .43501 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .57511 m
.00625 .57511 L
s
gsave
-0.0125 .57511 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04974 m
.00375 .04974 L
s
0 .08476 m
.00375 .08476 L
s
0 .11979 m
.00375 .11979 L
s
0 .18984 m
.00375 .18984 L
s
0 .22486 m
.00375 .22486 L
s
0 .25989 m
.00375 .25989 L
s
0 .32993 m
.00375 .32993 L
s
0 .36496 m
.00375 .36496 L
s
0 .39998 m
.00375 .39998 L
s
0 .47003 m
.00375 .47003 L
s
0 .50506 m
.00375 .50506 L
s
0 .54008 m
.00375 .54008 L
s
0 .61013 m
.00375 .61013 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.04 .61428 m
.04 .61803 L
s
.08 .61428 m
.08 .61803 L
s
.12 .61428 m
.12 .61803 L
s
.16 .61428 m
.16 .61803 L
s
.24 .61428 m
.24 .61803 L
s
.28 .61428 m
.28 .61803 L
s
.32 .61428 m
.32 .61803 L
s
.36 .61428 m
.36 .61803 L
s
.44 .61428 m
.44 .61803 L
s
.48 .61428 m
.48 .61803 L
s
.52 .61428 m
.52 .61803 L
s
.56 .61428 m
.56 .61803 L
s
.64 .61428 m
.64 .61803 L
s
.68 .61428 m
.68 .61803 L
s
.72 .61428 m
.72 .61803 L
s
.76 .61428 m
.76 .61803 L
s
.84 .61428 m
.84 .61803 L
s
.88 .61428 m
.88 .61803 L
s
.92 .61428 m
.92 .61803 L
s
.96 .61428 m
.96 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .15481 m
1 .15481 L
s
.99375 .29491 m
1 .29491 L
s
.99375 .43501 m
1 .43501 L
s
.99375 .57511 m
1 .57511 L
s
.125 Mabswid
.99625 .04974 m
1 .04974 L
s
.99625 .08476 m
1 .08476 L
s
.99625 .11979 m
1 .11979 L
s
.99625 .18984 m
1 .18984 L
s
.99625 .22486 m
1 .22486 L
s
.99625 .25989 m
1 .25989 L
s
.99625 .32993 m
1 .32993 L
s
.99625 .36496 m
1 .36496 L
s
.99625 .39998 m
1 .39998 L
s
.99625 .47003 m
1 .47003 L
s
.99625 .50506 m
1 .50506 L
s
.99625 .54008 m
1 .54008 L
s
.99625 .61013 m
1 .61013 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .60332 L
.04 .60332 L
.04 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .60332 L
.04 .60332 L
.04 .01472 L
0 .01472 L
s
1 0 0 r
.04 .01472 m
.04 .54284 L
.08 .54284 L
.08 .01472 L
F
0 g
.04 .01472 m
.04 .54284 L
.08 .54284 L
.08 .01472 L
.04 .01472 L
s
1 0 0 r
.08 .01472 m
.08 .42575 L
.12 .42575 L
.12 .01472 L
F
0 g
.08 .01472 m
.08 .42575 L
.12 .42575 L
.12 .01472 L
.08 .01472 L
s
1 0 0 r
.12 .01472 m
.12 .39376 L
.16 .39376 L
.16 .01472 L
F
0 g
.12 .01472 m
.12 .39376 L
.16 .39376 L
.16 .01472 L
.12 .01472 L
s
1 0 0 r
.16 .01472 m
.16 .34383 L
.2 .34383 L
.2 .01472 L
F
0 g
.16 .01472 m
.16 .34383 L
.2 .34383 L
.2 .01472 L
.16 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .23518 L
.24 .23518 L
.24 .01472 L
F
0 g
.2 .01472 m
.2 .23518 L
.24 .23518 L
.24 .01472 L
.2 .01472 L
s
1 0 0 r
.24 .01472 m
.24 .25874 L
.28 .25874 L
.28 .01472 L
F
0 g
.24 .01472 m
.24 .25874 L
.28 .25874 L
.28 .01472 L
.24 .01472 L
s
1 0 0 r
.28 .01472 m
.28 .15466 L
.32 .15466 L
.32 .01472 L
F
0 g
.28 .01472 m
.28 .15466 L
.32 .15466 L
.32 .01472 L
.28 .01472 L
s
1 0 0 r
.32 .01472 m
.32 .14376 L
.36 .14376 L
.36 .01472 L
F
0 g
.32 .01472 m
.32 .14376 L
.36 .14376 L
.36 .01472 L
.32 .01472 L
s
1 0 0 r
.36 .01472 m
.36 .11774 L
.4 .11774 L
.4 .01472 L
F
0 g
.36 .01472 m
.36 .11774 L
.4 .11774 L
.4 .01472 L
.36 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .09383 L
.44 .09383 L
.44 .01472 L
F
0 g
.4 .01472 m
.4 .09383 L
.44 .09383 L
.44 .01472 L
.4 .01472 L
s
1 0 0 r
.44 .01472 m
.44 .08785 L
.48 .08785 L
.48 .01472 L
F
0 g
.44 .01472 m
.44 .08785 L
.48 .08785 L
.48 .01472 L
.44 .01472 L
s
1 0 0 r
.48 .01472 m
.48 .0657 L
.52 .0657 L
.52 .01472 L
F
0 g
.48 .01472 m
.48 .0657 L
.52 .0657 L
.52 .01472 L
.48 .01472 L
s
1 0 0 r
.52 .01472 m
.52 .07238 L
.56 .07238 L
.56 .01472 L
F
0 g
.52 .01472 m
.52 .07238 L
.56 .07238 L
.56 .01472 L
.52 .01472 L
s
1 0 0 r
.56 .01472 m
.56 .05339 L
.6 .05339 L
.6 .01472 L
F
0 g
.56 .01472 m
.56 .05339 L
.6 .05339 L
.6 .01472 L
.56 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .04038 L
.64 .04038 L
.64 .01472 L
F
0 g
.6 .01472 m
.6 .04038 L
.64 .04038 L
.64 .01472 L
.6 .01472 L
s
1 0 0 r
.64 .01472 m
.64 .04038 L
.68 .04038 L
.68 .01472 L
F
0 g
.64 .01472 m
.64 .04038 L
.68 .04038 L
.68 .01472 L
.64 .01472 L
s
1 0 0 r
.68 .01472 m
.68 .03652 L
.72 .03652 L
.72 .01472 L
F
0 g
.68 .01472 m
.68 .03652 L
.72 .03652 L
.72 .01472 L
.68 .01472 L
s
1 0 0 r
.72 .01472 m
.72 .02737 L
.76 .02737 L
.76 .01472 L
F
0 g
.72 .01472 m
.72 .02737 L
.76 .02737 L
.76 .01472 L
.72 .01472 L
s
1 0 0 r
.76 .01472 m
.76 .02456 L
.8 .02456 L
.8 .01472 L
F
0 g
.76 .01472 m
.76 .02456 L
.8 .02456 L
.8 .01472 L
.76 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .02737 L
.84 .02737 L
.84 .01472 L
F
0 g
.8 .01472 m
.8 .02737 L
.84 .02737 L
.84 .01472 L
.8 .01472 L
s
1 0 0 r
.84 .01472 m
.84 .02069 L
.88 .02069 L
.88 .01472 L
F
0 g
.84 .01472 m
.84 .02069 L
.88 .02069 L
.88 .01472 L
.84 .01472 L
s
1 0 0 r
.88 .01472 m
.88 .0221 L
.92 .0221 L
.92 .01472 L
F
0 g
.88 .01472 m
.88 .0221 L
.92 .0221 L
.92 .01472 L
.88 .01472 L
s
1 0 0 r
.92 .01472 m
.92 .01964 L
.96 .01964 L
.96 .01472 L
F
0 g
.92 .01472 m
.92 .01964 L
.96 .01964 L
.96 .01472 L
.92 .01472 L
s
1 0 0 r
.96 .01472 m
.96 .01858 L
1 .01858 L
1 .01472 L
F
0 g
.96 .01472 m
.96 .01858 L
1 .01858 L
1 .01472 L
.96 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00U?ooool00ol@413o<S8boa0@4002o`000003
odA4A?o<c<cooooo04oooooo002Dooooo`03o`000?nHV9Sok^k^00;ooooo00?oQhN7oa0@4?ooool0
Coooool009Wooooo00?o^[Zjo`000?ooool0Coooool009Cooooo00?oc<c<odA4A?l000000ol00000
0onHV9Soooooooooo`1>ooooo`00U?ooool01Ol0003oQhN7okZj^_nj^[[oc<c<05;ooooo002Doooo
o`03o`000?nHV9Sooooo00;ooooo00?oc<c<oa0@4?ooool0Coooool009Cooooo00Ooc<c<odA4A?l0
003o0000oa0@4?lb<S;o0000053ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool006Sooooo1?l000000ol@413o
ooooooooo`0Fooooo`Ko00006Oooool01OnYZJWo8B4Qo`000?l0003oIVIV01cooooo0_l000000ol@
413oooooooooo`0Fooooo`05oiRHV?l@413o0000o`000?mVIVH01_ooool006[ooooo00?o0000oooo
ooooool06?ooool00onHV9So0000omgMg@02ooooo`03oa0@4?oooooooooo01Oooooo00Ko410@olc<
c?ooooooooooogMgMomVIVHLooooo`03o`000?oooooooooo01Oooooo00Ko410@ohN7Qooooooooooo
ogMgMomVIVH5ooooo`00J_ooool00ol0003oooooooooo`0Iooooo`03ohN7QolQ8B7ok^k^023ooooo
00?o0000ooooooooool05_ooool6o`0001gooooo00?o0000ooooooooool00oooool006[ooooo00?o
0000ooooooooool06_ooool00onYZJWo8B4Qonk^kP0Oooooo`03o`000?oooooooooo01Kooooo00Go
A4A4okZj^_ooooooooooo`00000Mooooo`03onk^k_l0003ooooo00Cooooo001Zooooo`03o`000?oo
oooooooo01_ooooo00?oV9RHoc8b<_ooool07Oooool00onYZJWoA4A4ooooo`0Gooooo`05omgMgOlQ
8B7oooooooooool000006Oooool01_l@413oV9RHooooooooooooMgMgofIVIPGooooo001Zooooo`03
o`000?oooooooooo01cooooo00?oA4A4ogMgMoooool06_ooool01?lQ8B7o0000o`000?oMgMdIoooo
o`04ogMgMonHV9Soooooo`0001Wooooo00Go0000ob4Q8Ol0003o0000ofIVIP06ooooo`00J_ooool0
0ol0003oooooooooo`0Looooo`03omgMgOl@413ooooo01cooooo00?oZJVYoc8b<_ooool06?ooool0
1?o^k^ko8B4Qooooool0000Iooooo`03o`000?oooooooooo00Sooooo001Zooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Hooooo`03ogMgMonHV9So
000001Wooooo00?o0000ooooooooool02?ooool006Sooooo00?o0000odA4A?l000006_ooool01_l0
003oQhN7onk^k_ooooooV9RHoeEEEAWooooo00Ko8B4QokZj^_ooooooooooofIVI_lb<S8Jooooo`03
onk^k_lb<S;o000001Wooooo00?o0000ooooooooool02?ooool006Sooooo00?oc<c<oeEEEOl00000
6_ooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kQWooooo00Ko^[ZjodA4A?l0003o0000odA4A?o^
k^hKooooo`03oiRHV?l@413ooooo01Sooooo1Ol00006ooooo`00joooool00>_ooooo003[ooooo`00
@oooool01?nHV9So0000o`000?nHV9RTooooo`00@_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj
^PGoooooUol00007ooooo`00@_ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`00@_ooool01_l0003ok^k^oooooooooooo
k^k^o`0000GoooooUol00007ooooo`00@_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`006Ol00007ooooo`00@_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`004ol0000Gooooo`03o`000?oooooooooo00Gooooo0012ooooo`06o`000?o^k^kooooooooo
ooo^k^ko00001Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001ol0000Y
ooooo`03o`000?oooooooooo00Gooooo0012ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Ooo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
000=o`0002oooooo00?o0000ooooooooool01Oooool004;ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q
8Onj^[X5ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oooooooooo03Sooooo0_l00007ooooo`00@oooool01?nHV9So0000o`00
0?nHV9P6ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0007o`0003_ooooo
00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo03oooooo00?o0000ooooooooool01Oooool004gooooo00?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001ol00005
ool00003o`000?oooooooooo03oooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool00oooool7o`00047ooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Boooool00ol0003oooooooooo`05ooooo`00COooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`001ol0001<ooooo`;o00001oooool004gooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
0007o`0005?ooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0Eoooool00ol0003oooooooooo`05ooooo`00COooool00ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo05Oooooo00?o0000ooooooooool01Oooool004gooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
1ol0001Hooooo`;o00001oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0GOooool00ol0003ooooooooo
o`05ooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Gooooo1_l0
0005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo05gooooo00?o0000ooooooooool01Oooool002oooooo00Ko^[Zj
ob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001Oooool00onHV9So0000omgMg@02ooooo`03oa0@
4?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000Oo0000
Goooool00ol0003oooooooooo`05ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Go
oooo00?oEEEEo`000?mEEED01_ooool00on7QhOo8B4Qonk^kP07ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00Go
oooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00003oooool00onYZJWo8B4Qonk^kP06oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`001ol0001Tooooo`;o00001oooool002oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0>ooooo`03oiRHV?lb<S;ooooo00Gooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Gooooo000_ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03oooool00om4A4CoMgMgooooo`04ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0JOooool00ol0003oooooooooo`05ooooo`00;ooo
ool01_l0003ok^k^ooooooooooook^k^o`00017ooooo00?ogMgMoa0@4?ooool01?ooool00ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo06Wooooo00?o0000ooooooooool01Oooool002oooooo
00KoA4A4oiRHV?oooooooooooiRHV?m4A4@Booooo`03o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Gooooo000_ooooo`06
okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3Oooool01_l0003oQhN7onk^k_ooooooV9RHoeEEE@Gooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Xooooo`;o00001oooool0033ooooo00Co
V9RHo`000?l0003oV9RH3_ooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kPGooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Gooooo001=ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0JOooool00ol0003oooooooooo`05ooooo`00
COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo06Wooooo00?o0000ooooooooool0
1Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Yooooo`03o`000?oo
oooooooo00Gooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0JOooool0
0ol0003oooooooooo`05ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
06Sooooo0_l00007ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`001ol00005ool00003o`000?oooooooooo06Wooooo00?o0000ooooooooool01Oooool004gooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Gooooo
001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0JOooool00ol0003ooooooooo
o`05ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oooooooooo06Wooooo00?o0000
ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo00?ooooo1ol0001Zooooo`;o00001oooool0013ooooo00?o^[Zjoc8b<_oo
ool03_ooool00olb<S;o^[Zjooooo`0Yooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`1eooooo`03o`000?oooooooooo00Gooooo000@ooooo`03oc8b
<_nj^[[ooooo00kooooo00?o^[Zjoc8b<_ooool03?ooool01?nHV9So0000o`000?nHV9P6ooooo`03
oeEEEOl0003oEEEE00Wooooo0_l000000ol@413oooooooooo`02ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1eooooo`03o`000?oooooooooo00Go
oooo000?ooooo`03olc<c?lb<S;ooooo013ooooo00?o<S8bolc<c?ooool02_ooool01_nj^[[o8B4Q
omgMgOoMgMgo8B4QokZj^PGooooo0ol0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo07Gooooo00?o0000oooo
ooooool01Oooool000;ooooo00Go410@o`000?l0003o0000oa0@4008ooooo`03ofIVI_nYZJWooooo
00Cooooo00?o410@oc8b<_l@41000_l000000om4A4Coc<c<ooooo`04ooooo`03oiRHV?mVIVKooooo
00[ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo1_l0
0004ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo00Gooooo0004ooooo`03o`000?oooooooooo00Sooooo00?o<S8b
ooooooooool01?ooool00ol0003oV9RHonk^kP02ooooo`03ohN7Qol@413ooooo00Cooooo00?ok^k^
oc8b<_ooool02_ooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00GoA4A4okZj^_oooooo
ooooo`000005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`1dooooo`;o00001oooool000Cooooo00?o0000ooooooooool02?ooool00olb<S;ooooo
ooooo`09ooooo`03okZj^_l0003ooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00cooooo00GogMgMob4Q8Oooooooooooo`000005ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1eooooo`03
o`000?oooooooooo00Gooooo0004ooooo`?o000000?o410@ogMgMoo^k^h01Oooool00olb<S;ooooo
ooooo`04ooooo`03olc<c?m4A4Co000000?o000000?oV9RHooooooooool01?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01?mgMgOoV9RH
ooooool00005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`1eooooo`03o`000?oooooooooo00Gooooo0004ooooo`06o`000?ooooooooooonk^k_mg
MgOoEEEE1Oooool00olQ8B7oooooooooo`04ooooo`05o`000?n7QhOo^[ZjokZj^_o<c<`02?ooool0
0ol0003oooooooooo`09ooooo`06o`000?o^k^koooooooooooo^k^ko00003oooool01?o^k^ko8B4Q
ooooool00005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`1eooooo`03o`000?oooooooooo00Gooooo0004ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00olb<S;ok^k^ooooo`04ooooo`03o`000?nHV9Sooooo00;ooooo
00?oc<c<oa0@4?ooool01?ooool00ooMgMgo<S8booooo`0:ooooo`06odA4A?nHV9SooooooooooonH
V9SoA4A44?ooool00omgMgOoV9RHo`000005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`1eooooo`03o`000?oooooooooo00Gooooo0004ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00omVIVKoV9RHooooo`04ooooo`07
olc<c?m4A4Co0000o`000?l@413o<S8bo`000005ooooo`03oiRHV?mVIVKooooo00[ooooo00Ko^[Zj
ob4Q8OoMgMgogMgMob4Q8Onj^[X@ooooo`03onk^k_lb<S;o000000Gooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo07Cooooo0_l00007ooooo`001?oo
ool01_l0003oooooooooooo^k^koMgMgoeEEE@Gooooo00?ogMgMob4Q8Oooool04?ooool00ol@413o
c<c<ooooo`0;ooooo`04oiRHV?l0003o0000oiRHV1;ooooo00?oV9RHoa0@4?ooool01?ooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0MOooool00ol0
003oooooooooo`05ooooo`000_ooool00ol@413o0000o`000002o`000003oa0@4?mgMgOok^k^00Ko
oooo00?o<S8bokZj^_ooool03_ooool00onj^[[o<S8booooo`0Yooooo`03o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`001ol0001gooooo`03o`000?oooooooooo00Gooooo000@ooooo`03okZj^_lb<S;ooooo00kooooo
00?o<S8bokZj^_ooool0:Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo07_ooooo
00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`1kooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0Noooool00ol0003oooooooooo`05ooooo`00COooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo07[ooooo0_l00007ooooo`00COooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo07_ooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0Noooool00ol0003oooooooooo`05ooooo`00COooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0007
o`0007gooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0P?ooool2o`00
00Oooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo087ooooo00?o0000ooooooooool01Oooool0033ooooo
00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@06ooooo`06onk^k_mEEEGo0000o`00
0?mEEEGok^k^1?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`21ooooo`03o`000?oooooooooo00Gooooo000_oooo
o`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo0_mgMgL2ooooo`03ogMgMomE
EEGooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0POooool00ol0003oooooooooo`05ooooo`00;oooool0
1_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool00olQ8B7ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool000Oo0000Poooool00ol0003oooooooooo`05ooooo`00;oooool01_l0003ok^k^oooo
ooooooook^k^o`0000kooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`26ooooo`;o
00001oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`06o`00
0?mEEEGok^k^oooooomgMgOoEEEE1?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0Qoooool00ol0003oooooooooo`05ooooo`00;oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^h4
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`27
ooooo`03o`000?oooooooooo00Gooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00003_oo
ool00om4A4CoV9RHooooo`07ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`27ooooo`03o`000?oooooooooo00Gooooo000_ooooo`06odA4A?nHV9So
oooooooooonHV9SoA4A43_ooool00onj^[[o8B4Qooooo`07ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`27ooooo`03o`000?oooooooooo00Gooooo
000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3oooool00omEEEGo<S8bomgMg@06ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`26ooooo`;o
00001oooool0033ooooo00CoV9RHo`000?l0003oV9RH4Oooool01?nHV9So8B4Qo`000?lQ8B44oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`27oooo
o`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`27ooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`27ooooo`03o`00
0?oooooooooo00Gooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`27ooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`26ooooo`;o00001oooool0
04gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
08Oooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo08Oooooo00?o0000ooooooooool01Oooool004gooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo08Oooooo
00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo08Oooooo00?o0000ooooooooool01Oooool004gooooo00?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo08Oooooo00?o0000
ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo0007o`0008Sooooo0_l00007oooo
o`00COooool00ol0003oo`00ool00003ool00003o`000?oooooooooo08gooooo00?o0000oooooooo
ool01Oooool0033ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@06ooooo`06
onk^k_mEEEGo0000o`000?mEEEGok^k^1?ooool00ol0003oo`00ool00003ool00003o`000?oooooo
oooo08gooooo00?o0000ooooooooool01Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj
^[X5ooooo`?o00001_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Cooooo00?o0000ool00?oo
00000ooo00000ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Gooooo000_ooooo`06odA4
A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oooooooooo
08gooooo00?o0000ooooooooool01Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oooooooooo08cooooo0_l00007ooooo`00;oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00cooooo00KoEEEEogMgMoooooooooooogMgMomEEED4ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0SOooool00ol0003oooooooooo`05ooooo`00;oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?ogMgMo`000?l000000_l00000
0ooMgMgoooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000ooooooooool0SOooool0
0ol0003oooooooooo`05ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00Ko
<S8bofIVI_o^k^kok^k^ofIVI_lb<S84ooooo`03o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0SOooool00ol0003oooooooooo`05ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4
A0kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`Oo0000Soooool00ol0
003oooooooooo`05ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00Ko<S8b
ofIVI_o^k^kok^k^ofIVI_lb<S84ooooo`;o00007?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Jooooo`;o0000
1oooool0033ooooo00CoV9RHo`000?l0003oV9RH3oooool01_o^k^koA4A4o`000?l0003oA4A4onk^
kPCoooooUol00007ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-2.60043, -0.865759, 0.03345, \
0.00955047}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Finally we show a comparison of the Poisson distribution to the histogram \
of prime spacings near the ",
  Cell[BoxData[
      \(TraditionalForm\`\(10\^12\) th\ \(\(prime\)\(.\)\)\)]],
  " We see that the agreement is very good in this case (although there is \
still a small shortage of small spacings)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[P3Hist, Poisson, AspectRatio \[Rule] 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.2 0.0238095 0.952381 [
[.2 -0.0125 -6.78125 -18 ]
[.2 -0.0125 6.78125 0 ]
[.4 -0.0125 -6.78125 -18 ]
[.4 -0.0125 6.78125 0 ]
[.6 -0.0125 -6.78125 -18 ]
[.6 -0.0125 6.78125 0 ]
[.8 -0.0125 -6.78125 -18 ]
[.8 -0.0125 6.78125 0 ]
[1 -0.0125 -6.78125 -18 ]
[1 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .02381 -13.5625 -9 ]
[-0.0125 .02381 0 9 ]
[-0.0125 .21429 -32.6875 -9 ]
[-0.0125 .21429 0 9 ]
[-0.0125 .40476 -32.6875 -9 ]
[-0.0125 .40476 0 9 ]
[-0.0125 .59524 -32.6875 -9 ]
[-0.0125 .59524 0 9 ]
[-0.0125 .78571 -32.6875 -9 ]
[-0.0125 .78571 0 9 ]
[-0.0125 .97619 -13.5625 -9 ]
[-0.0125 .97619 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -74.9375 -9 ]
[-0.01875 .5 -32.6875 9 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
gsave
.2 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.4 0 m
.4 .00625 L
s
gsave
.4 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.6 0 m
.6 .00625 L
s
gsave
.6 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.8 0 m
.8 .00625 L
s
gsave
.8 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02381 m
.00625 .02381 L
s
gsave
-0.0125 .02381 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .21429 m
.00625 .21429 L
s
gsave
-0.0125 .21429 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .40476 m
.00625 .40476 L
s
gsave
-0.0125 .40476 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .59524 m
.00625 .59524 L
s
gsave
-0.0125 .59524 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .78571 m
.00625 .78571 L
s
gsave
-0.0125 .78571 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .97619 m
.00625 .97619 L
s
gsave
-0.0125 .97619 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07143 m
.00375 .07143 L
s
0 .11905 m
.00375 .11905 L
s
0 .16667 m
.00375 .16667 L
s
0 .2619 m
.00375 .2619 L
s
0 .30952 m
.00375 .30952 L
s
0 .35714 m
.00375 .35714 L
s
0 .45238 m
.00375 .45238 L
s
0 .5 m
.00375 .5 L
s
0 .54762 m
.00375 .54762 L
s
0 .64286 m
.00375 .64286 L
s
0 .69048 m
.00375 .69048 L
s
0 .7381 m
.00375 .7381 L
s
0 .83333 m
.00375 .83333 L
s
0 .88095 m
.00375 .88095 L
s
0 .92857 m
.00375 .92857 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.2 .99375 m
.2 1 L
s
.4 .99375 m
.4 1 L
s
.6 .99375 m
.6 1 L
s
.8 .99375 m
.8 1 L
s
.125 Mabswid
.04 .99625 m
.04 1 L
s
.08 .99625 m
.08 1 L
s
.12 .99625 m
.12 1 L
s
.16 .99625 m
.16 1 L
s
.24 .99625 m
.24 1 L
s
.28 .99625 m
.28 1 L
s
.32 .99625 m
.32 1 L
s
.36 .99625 m
.36 1 L
s
.44 .99625 m
.44 1 L
s
.48 .99625 m
.48 1 L
s
.52 .99625 m
.52 1 L
s
.56 .99625 m
.56 1 L
s
.64 .99625 m
.64 1 L
s
.68 .99625 m
.68 1 L
s
.72 .99625 m
.72 1 L
s
.76 .99625 m
.76 1 L
s
.84 .99625 m
.84 1 L
s
.88 .99625 m
.88 1 L
s
.92 .99625 m
.92 1 L
s
.96 .99625 m
.96 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .21429 m
1 .21429 L
s
.99375 .40476 m
1 .40476 L
s
.99375 .59524 m
1 .59524 L
s
.99375 .78571 m
1 .78571 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .07143 m
1 .07143 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .30952 m
1 .30952 L
s
.99625 .35714 m
1 .35714 L
s
.99625 .45238 m
1 .45238 L
s
.99625 .5 m
1 .5 L
s
.99625 .54762 m
1 .54762 L
s
.99625 .64286 m
1 .64286 L
s
.99625 .69048 m
1 .69048 L
s
.99625 .7381 m
1 .7381 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .88095 m
1 .88095 L
s
.99625 .92857 m
1 .92857 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .02381 m
1 .02381 L
s
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
0 .02381 m
0 .82407 L
.04 .82407 L
.04 .02381 L
F
0 g
.5 Mabswid
0 .02381 m
0 .82407 L
.04 .82407 L
.04 .02381 L
0 .02381 L
s
1 0 0 r
.04 .02381 m
.04 .74185 L
.08 .74185 L
.08 .02381 L
F
0 g
.04 .02381 m
.04 .74185 L
.08 .74185 L
.08 .02381 L
.04 .02381 L
s
1 0 0 r
.08 .02381 m
.08 .58266 L
.12 .58266 L
.12 .02381 L
F
0 g
.08 .02381 m
.08 .58266 L
.12 .58266 L
.12 .02381 L
.08 .02381 L
s
1 0 0 r
.12 .02381 m
.12 .53915 L
.16 .53915 L
.16 .02381 L
F
0 g
.12 .02381 m
.12 .53915 L
.16 .53915 L
.16 .02381 L
.12 .02381 L
s
1 0 0 r
.16 .02381 m
.16 .47127 L
.2 .47127 L
.2 .02381 L
F
0 g
.16 .02381 m
.16 .47127 L
.2 .47127 L
.2 .02381 L
.16 .02381 L
s
1 0 0 r
.2 .02381 m
.2 .32355 L
.24 .32355 L
.24 .02381 L
F
0 g
.2 .02381 m
.2 .32355 L
.24 .32355 L
.24 .02381 L
.2 .02381 L
s
1 0 0 r
.24 .02381 m
.24 .35558 L
.28 .35558 L
.28 .02381 L
F
0 g
.24 .02381 m
.24 .35558 L
.28 .35558 L
.28 .02381 L
.24 .02381 L
s
1 0 0 r
.28 .02381 m
.28 .21408 L
.32 .21408 L
.32 .02381 L
F
0 g
.28 .02381 m
.28 .21408 L
.32 .21408 L
.32 .02381 L
.28 .02381 L
s
1 0 0 r
.32 .02381 m
.32 .19926 L
.36 .19926 L
.36 .02381 L
F
0 g
.32 .02381 m
.32 .19926 L
.36 .19926 L
.36 .02381 L
.32 .02381 L
s
1 0 0 r
.36 .02381 m
.36 .16388 L
.4 .16388 L
.4 .02381 L
F
0 g
.36 .02381 m
.36 .16388 L
.4 .16388 L
.4 .02381 L
.36 .02381 L
s
1 0 0 r
.4 .02381 m
.4 .13137 L
.44 .13137 L
.44 .02381 L
F
0 g
.4 .02381 m
.4 .13137 L
.44 .13137 L
.44 .02381 L
.4 .02381 L
s
1 0 0 r
.44 .02381 m
.44 .12324 L
.48 .12324 L
.48 .02381 L
F
0 g
.44 .02381 m
.44 .12324 L
.48 .12324 L
.48 .02381 L
.44 .02381 L
s
1 0 0 r
.48 .02381 m
.48 .09313 L
.52 .09313 L
.52 .02381 L
F
0 g
.48 .02381 m
.48 .09313 L
.52 .09313 L
.52 .02381 L
.48 .02381 L
s
1 0 0 r
.52 .02381 m
.52 .10221 L
.56 .10221 L
.56 .02381 L
F
0 g
.52 .02381 m
.52 .10221 L
.56 .10221 L
.56 .02381 L
.52 .02381 L
s
1 0 0 r
.56 .02381 m
.56 .0764 L
.6 .0764 L
.6 .02381 L
F
0 g
.56 .02381 m
.56 .0764 L
.6 .0764 L
.6 .02381 L
.56 .02381 L
s
1 0 0 r
.6 .02381 m
.6 .05871 L
.64 .05871 L
.64 .02381 L
F
0 g
.6 .02381 m
.6 .05871 L
.64 .05871 L
.64 .02381 L
.6 .02381 L
s
1 0 0 r
.64 .02381 m
.64 .05871 L
.68 .05871 L
.68 .02381 L
F
0 g
.64 .02381 m
.64 .05871 L
.68 .05871 L
.68 .02381 L
.64 .02381 L
s
1 0 0 r
.68 .02381 m
.68 .05345 L
.72 .05345 L
.72 .02381 L
F
0 g
.68 .02381 m
.68 .05345 L
.72 .05345 L
.72 .02381 L
.68 .02381 L
s
1 0 0 r
.72 .02381 m
.72 .04102 L
.76 .04102 L
.76 .02381 L
F
0 g
.72 .02381 m
.72 .04102 L
.76 .04102 L
.76 .02381 L
.72 .02381 L
s
1 0 0 r
.76 .02381 m
.76 .0372 L
.8 .0372 L
.8 .02381 L
F
0 g
.76 .02381 m
.76 .0372 L
.8 .0372 L
.8 .02381 L
.76 .02381 L
s
1 0 0 r
.8 .02381 m
.8 .04102 L
.84 .04102 L
.84 .02381 L
F
0 g
.8 .02381 m
.8 .04102 L
.84 .04102 L
.84 .02381 L
.8 .02381 L
s
1 0 0 r
.84 .02381 m
.84 .03194 L
.88 .03194 L
.88 .02381 L
F
0 g
.84 .02381 m
.84 .03194 L
.88 .03194 L
.88 .02381 L
.84 .02381 L
s
1 0 0 r
.88 .02381 m
.88 .03385 L
.92 .03385 L
.92 .02381 L
F
0 g
.88 .02381 m
.88 .03385 L
.92 .03385 L
.92 .02381 L
.88 .02381 L
s
1 0 0 r
.92 .02381 m
.92 .0305 L
.96 .0305 L
.96 .02381 L
F
0 g
.92 .02381 m
.92 .0305 L
.96 .0305 L
.96 .02381 L
.92 .02381 L
s
1 0 0 r
.96 .02381 m
.96 .02907 L
1 .02907 L
1 .02381 L
F
0 g
.96 .02381 m
.96 .02907 L
1 .02907 L
1 .02381 L
.96 .02381 L
s
.015 w
0 .97619 m
.04057 .80135 L
.08481 .64704 L
.12636 .53013 L
.16632 .43843 L
.20885 .359 L
.2498 .29695 L
.29331 .24354 L
.33524 .20198 L
.37557 .16944 L
.41848 .14132 L
.4598 .11939 L
.49953 .10217 L
.54183 .08723 L
.58254 .07555 L
.62583 .06548 L
.66752 .05764 L
.70762 .05149 L
.7503 .04617 L
.79139 .04202 L
.83505 .03845 L
.87712 .03567 L
.9176 .0335 L
.96065 .03162 L
1 .03023 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00U?ooool00ol@413o<S8boa0@4002o`000003odA4A?o<c<cooooo04oooooo002Dooooo`03o`00
0?nHV9Sok^k^00;ooooo00?oQhN7oa0@4?ooool0Coooool009Wooooo00?o^[Zjo`000?ooool0Cooo
ool009Cooooo00?oc<c<odA4A?l000000ol000000onHV9Soooooooooo`1>ooooo`00U?ooool01Ol0
003oQhN7okZj^_nj^[[oc<c<05;ooooo002Dooooo`03o`000?nHV9Sooooo00;ooooo00?oc<c<oa0@
4?ooool0Coooool009Cooooo00Ooc<c<odA4A?l0003o0000oa0@4?lb<S;o0000053ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool006Sooooo1?l000000ol@413oooooooooo`0Fooooo`Ko00006Oooool01OnYZJWo
8B4Qo`000?l0003oIVIV01cooooo0_l000000ol@413oooooooooo`0Fooooo`05oiRHV?l@413o0000
o`000?mVIVH01_ooool006[ooooo00?o0000ooooooooool06?ooool00onHV9So0000omgMg@02oooo
o`03oa0@4?oooooooooo01Oooooo00Ko410@olc<c?ooooooooooogMgMomVIVHLooooo`03o`000?oo
oooooooo01Oooooo00Ko410@ohN7QoooooooooooogMgMomVIVH5ooooo`00J_ooool00ol0003ooooo
ooooo`0Iooooo`03ohN7QolQ8B7ok^k^023ooooo00?o0000ooooooooool05_ooool6o`0001gooooo
00?o0000ooooooooool00oooool006[ooooo00?o0000ooooooooool06_ooool00onYZJWo8B4Qonk^
kP0Oooooo`03o`000?oooooooooo01Kooooo00GoA4A4okZj^_ooooooooooo`00000Mooooo`03onk^
k_l0003ooooo00Cooooo001Zooooo`03o`000?oooooooooo01_ooooo00?oV9RHoc8b<_ooool07Ooo
ool00onYZJWoA4A4ooooo`0Gooooo`05omgMgOlQ8B7oooooooooool000006Oooool01_l@413oV9RH
ooooooooooooMgMgofIVIPGooooo001Zooooo`03o`000?oooooooooo01cooooo00?oA4A4ogMgMooo
ool06_ooool01?lQ8B7o0000o`000?oMgMdIooooo`04ogMgMonHV9Soooooo`0001Wooooo00Go0000
ob4Q8Ol0003o0000ofIVIP06ooooo`00J_ooool00ol0003oooooooooo`0Looooo`03omgMgOl@413o
oooo01cooooo00?oZJVYoc8b<_ooool06?ooool01?o^k^ko8B4Qooooool0000Iooooo`03o`000?oo
oooooooo00Sooooo001Zooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Hooooo`03ogMgMonHV9So000001Wooooo00?o0000ooooooooool02?ooool0
06Sooooo00?o0000odA4A?l000006_ooool01_l0003oQhN7onk^k_ooooooV9RHoeEEEAWooooo00Ko
8B4QokZj^_ooooooooooofIVI_lb<S8Jooooo`03onk^k_lb<S;o000001Wooooo00?o0000oooooooo
ool02?ooool006Sooooo00?oc<c<oeEEEOl000006_ooool01_nYZJWo<S8bo`000?l0003oEEEEonk^
kQWooooo00Ko^[ZjodA4A?l0003o0000odA4A?o^k^hKooooo`03oiRHV?l@413ooooo01Sooooo1Ol0
0006ooooo`00joooool00>_ooooo003[ooooo`00joooool004goooooUol00007ooooo`00@oooool0
1?nHV9So0000o`000?nHV9P6ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool004;ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`03o`000?oooooooooo09?ooooo
00?o0000ooooooooool01Oooool004;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03
o`000?oooooooooo09?ooooo00?o0000ooooooooool01Oooool004;ooooo00Ko0000onk^k_oooooo
ooooonk^k_l00005oooooiOo00001oooool004;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool001Wo00001oooool004;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool002Oo00000oooool00ol0003oooooooooo`05ooooo`00@_ooool01_l0003ok^k^oooo
ooooooook^k^o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`005?l0000Fooooo`03o`000?oooooooooo00Gooooo0012ooooo`06odA4
A?nHV9SooooooooooonHV9SoA4A41Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`003_l0000Rooooo`03o`000?oooooooooo00Gooooo0012ooooo`06okZj^_lQ8B7ogMgMomgM
gOlQ8B7o^[Zj1Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo000Co`0002Wooooo00?o0000ooooooooool01Oooool004?ooooo00CoV9RHo`00
0?l0003oV9RH1_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo000=o`0002oooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool000go0000=?ooool2o`0000Oooooo001=ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000Co0000ool00?oo003oo`002Ol0000kooooo`03o`000?oooooooooo
00Gooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`002?l00010ooooo`03o`000?oooooooooo00Go
oooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool000_o000000?oo`00o`000?ooool0@?ooool00ol0003oooooooooo`05ooooo`00COoo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
000=o`00047ooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`001_l00019ooooo`03o`000?oooooo
oooo00Gooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00005o`0004cooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool000Oo0000C?ooool2o`0000Oooooo001=ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0005o`00053ooooo00?o0000ooooooooool0
1Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo0008o`0005;ooooo00?o0000ooooooooool01Ooo
ool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo0006o`0005Cooooo00?o0000ooooooooool01Oooool0
04gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo0005o`0005Kooooo00?o0000ooooooooool01Oooool004go
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000Co0000ool00?oo003oo`001?l0001Hooooo`03o`000?oooooooooo00Gooooo001=ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000Oo
0000FOooool00ol0003oooooooooo`05ooooo`00COooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0005o`0005[ooooo0_l00007ooooo`00COoo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
0004o`0005gooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00004o`000?oo003oo`00ool000?o0000Goooool00ol0003ooooooooo
o`05ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?l0001Oooooo`03o`000?oooooooooo00Gooooo000`ooooo`04oiRHV?l0003o0000
oiRHV0Kooooo00?oEEEEo`000?mEEED01Oooool6o`0000Gooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003o000000;o000000?oo`00o`000?ooool0G_ooool0
0ol0003oooooooooo`05ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol0
0005ooooo`03oiRHV?l0003ogMgM00;ooooo00?o410@ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`001ol0001Oooooo`03o`000?oooooooooo00Gooooo000_
ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`03ohN7
QolQ8B7ok^k^00Oooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000?o0000
Hoooool00ol0003oooooooooo`05ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000oo
oooo00?oZJVYob4Q8Oo^k^h01_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000So0000Hoooool2o`0000Oo
oooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00onHV9So<S8b
ooooo`05ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000oooooooooooooooo0ol0001Uooooo`03
o`000?oooooooooo00Gooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3oooool00om4A4CoMgMgooooo`04ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
0ol0001Vooooo`03o`000?oooooooooo00Gooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko
00004Oooool00ooMgMgo410@ooooo`04ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooool0
00000_l0001Wooooo`03o`000?oooooooooo00Gooooo000_ooooo`06odA4A?nHV9SooooooooooonH
V9SoA4A44_ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001?l0001Xoooo
o`03o`000?oooooooooo00Gooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3Oooool0
1_l0003oQhN7onk^k_ooooooV9RHoeEEE@Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0003o`0006Wooooo
00?o0000ooooooooool01Oooool0033ooooo00CoV9RHo`000?l0003oV9RH3_ooool01_nYZJWo<S8b
o`000?l0003oEEEEonk^kPGooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0003o`0006Wooooo00?o0000oooo
ooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0003o`0006Wooooo0_l00007ooooo`00
COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00001?l0003oo`00ool00?oo0003o`0006_ooooo00?o0000ooooooooool01Oooool004gooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00Co0000ool00?oo003oo`000ol0001[ooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Co0000Joooool00ol0003oooooooooo`05ooooo`00COooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00o`00
0002o`000003ool00?l0003ooooo06[ooooo00?o0000ooooooooool01Oooool004gooooo00?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001?l00002
ool00003o`000?oooooooooo06Wooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000ol00003ool0
0003o`000?oooooooooo06Wooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000ol00003ool00003
o`000?oooooooooo06Sooooo0_l00007ooooo`00COooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0003o`0000Coo`0000?o0000ooooooooool0
JOooool00ol0003oooooooooo`05ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`001ol00005ool00003o`000?oooooooooo06Wooooo00?o0000ooooooooool01Ooo
ool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?oooooo
ooooooooo`?o00001Ooo00000ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Gooooo001=
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`04
o`0000Goo`0000?o0000ooooooooool0JOooool00ol0003oooooooooo`05ooooo`00COooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooool000000_l000000ooo
oooo0000ool00004ool00003o`000?oooooooooo06Wooooo00?o0000ooooooooool01Oooool004go
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?oooooo0000o`00
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Yooooo`03o`000?oooooooooo
00Gooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0004o`0000;o
oooo1ol0001Zooooo`;o00001oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool000?o0000MOooool00ol0003oooooooooo`05ooooo`00COooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`000_l0001fooooo`03o`000?oooooooooo00Gooooo001=
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0003o`0007Kooooo00?o0000
ooooooooool01Oooool0033ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@09
ooooo`;o000000?o410@ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`000_l0001gooooo`03o`000?oooooooooo00Gooooo000_ooooo`06okZj^_lQ8B7ogMgM
omgMgOlQ8B7o^[Zj1Oooool3o`0000[ooooo00?o0000ooooooooool00oooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00004o`000?oo003oo`00ool000?o0000Moooool00ol0003oooooooooo`05ooooo`00;ooo
ool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool6o`0000Co
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00001?l0003oo`00ool00?oo0003o`0007Oooooo00?o0000oooo
ooooool01Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`05odA4A?nj^[[o
ooooooooool000001Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co0000M_oo
ool2o`0000Oooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool0
1OoMgMgo8B4Qoooooooooooo000000Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002o`000003ool00?l0003ooooo07Kooooo00?o0000ooooooooool01Oooool002oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`04ogMgMonHV9Soooooo`0000Gooooo00?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00o`000002o`000003ool00?l0003ooooo07Kooooo00?o
0000ooooooooool01Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000?ooooo`04onk^
k_lQ8B7oooooo`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003oo`00o`000?l00002ool0
0003o`000?oooooooooo07Gooooo00?o0000ooooooooool01Oooool002oooooo00KoA4A4oiRHV?oo
oooooooooiRHV?m4A4@@ooooo`03ogMgMonHV9So000000Gooooo00?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0004
o`0000;oo`0000?o0000ooooooooool0MOooool00ol0003oooooooooo`05ooooo`00;oooool01_nj
^[[o8B4QomgMgOoMgMgo8B4QokZj^Q3ooooo00?ok^k^oc8b<_l000001Oooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool000?o00000ooo00000ol0003oooooooooo`1eooooo`03o`000?oooooooooo00Gooooo000`
ooooo`04oiRHV?l0003o0000oiRHV1;ooooo00?oV9RHoa0@4?ooool01?ooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool000?o00000ooo00000ol0003oooooooooo`1eooooo`03o`000?oooooooooo00Gooooo001=
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`000_l00004ool00003o`000?oooooooooo07Gooooo00?o0000
ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0003o`0000Coo`0000?o0000oooo
ooooool0M?ooool2o`0000Oooooo000@ooooo`03okZj^_lb<S;ooooo00kooooo00?o<S8bokZj^_oo
ool0:Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool000;o00001Ooo00000ol0003oooooooooo`1eooooo`03
o`000?oooooooooo00Gooooo000@ooooo`03oc8b<_nj^[[ooooo00kooooo00?o^[Zjoc8b<_ooool0
:Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00001?l0003oo`00ool00?oo0009o`0007Oooooo00?o0000ooooooooool01Oooool000oooooo
00?oc<c<oc8b<_ooool04?ooool00olb<S;oc<c<ooooo`0Xooooo`03o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?oo003oo`00ool000?o
0000OOooool00ol0003oooooooooo`05ooooo`000_ooool01Ol@413o0000o`000?l0003o410@00So
oooo00?oIVIVojVYZOooool01?ooool00ol@413o<S8boa0@4002o`000003odA4A?o<c<cooooo00Co
oooo00?oV9RHofIVI_ooool0:?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004o`0007gooooo00?o0000oooooooo
ool01Oooool000Cooooo00?o0000ooooooooool02?ooool00olb<S;oooooooooo`04ooooo`03o`00
0?nHV9Sok^k^00;ooooo00?oQhN7oa0@4?ooool01?ooool00oo^k^ko<S8booooo`0Xooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;o000000?oo`00o`000?ooool0O?ooool00ol0003oooooooooo`05ooooo`001?oo
ool00ol0003oooooooooo`08ooooo`03oc8b<_oooooooooo00Wooooo00?o^[Zjo`000?ooool01Ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o000000?oo`00o`000?ooool0O?oo
ool00ol0003oooooooooo`05ooooo`001?ooool3o`000003oa0@4?mgMgOok^k^00Gooooo00?o<S8b
ooooooooool01?ooool00oo<c<coA4A4o`000003o`000003oiRHV?oooooooooo00Cooooo00?o0000
ooooooooool09oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00o`000002o`000003ool00?l0003ooooo07_ooooo0_l00007
ooooo`001?ooool01_l0003oooooooooooo^k^koMgMgoeEEE@Gooooo00?o8B4Qooooooooool01?oo
ool01Ol0003oQhN7okZj^_nj^[[oc<c<00Sooooo00?o0000ooooooooool09oooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003oo`00
o`000?l00002ool00003o`000?oooooooooo07_ooooo00?o0000ooooooooool01Oooool000Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03oc8b<_o^k^kooooo00Cooooo
00?o0000oiRHV?ooool00_ooool00oo<c<co410@ooooo`04ooooo`03omgMgOlb<S;ooooo02Sooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
1?l00002ool00003o`000?oooooooooo07_ooooo00?o0000ooooooooool01Oooool000Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03ofIVI_nHV9Sooooo00Cooooo00Oo
c<c<odA4A?l0003o0000oa0@4?lb<S;o000000Gooooo00?oV9RHofIVI_ooool0:?ooool00ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0003o`0000?o
o`0000?o0000ooooooooool0Noooool00ol0003oooooooooo`05ooooo`001?ooool01_l0003ooooo
ooooooo^k^koMgMgoeEEE@Gooooo00?ogMgMob4Q8Oooool04?ooool00ol@413oc<c<ooooo`0Xoooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
00?o00000ooo00000ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Gooooo0002ooooo`03
oa0@4?l0003o000000;o000000?o410@ogMgMoo^k^h01_ooool00olb<S;o^[Zjooooo`0>ooooo`03
okZj^_lb<S;ooooo02Wooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`000_l00004ool00003o`000?oooooooooo07_ooooo00?o0000oooooooo
ool01Oooool0013ooooo00?o^[Zjoc8b<_ooool03_ooool00olb<S;o^[Zjooooo`0Yooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool000So0000
OOooool00ol0003oooooooooo`05ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo0002o`0008;ooooo0_l00007ooooo`00COooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0002
o`0008?ooooo00?o0000ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00004o`000?oo003oo`00ool000?o0000Poooool00ol0003oooooooooo`05
ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000ool0
0?oo003oo`000ol00023ooooo`03o`000?oooooooooo00Gooooo000`ooooo`04oiRHV?l0003o0000
oiRHV0Kooooo00?oEEEEo`000?mEEED01_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPCooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?oo003oo`00ool000?o
0000Poooool00ol0003oooooooooo`05ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj
^PGooooo0ol00006ooooo`;oMgMg0_ooool00omgMgOoEEEEooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo0007o`0008?ooooo00?o0000ooooooooool01Oooool002oo
oooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?o8B4Q
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`02o`0008Gooooo00?o0000ooooooooool01Oooool0
02oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`03o`000?o^k^kooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ooooooooool00_l00024ooooo`;o00001oooool002oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0<ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE1?ooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooool000000_l00025ooooo`03o`00
0?oooooooooo00Gooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?oo
ool01_l0003oMgMgo`000?l0003oEEEEonk^kPCooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00004o`000?oooooo0000o`0008Kooooo00?o0000ooooooooool01Oooool002oo
oooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`03odA4A?nHV9Sooooo00Oooooo00?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?oooooo0000o`0008Kooooo00?o
0000ooooooooool01Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@>ooooo`03okZj
^_lQ8B7ooooo00Oooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000Co0000
Q_ooool00ol0003oooooooooo`05ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Poo
oooo00?oEEEEoc8b<_oMgMd01_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`000ol00027ooooo`03o`000?oooooooooo00Gooooo000`ooooo`04oiRHV?l0003o0000oiRHV17o
oooo00CoV9RHob4Q8Ol0003o8B4Q1?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`000ol00027ooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo0003o`0008Kooooo0_l00007ooooo`00COooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`000_l00028ooooo`03o`000?oooooooooo00Gooooo
001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0002o`0008Sooooo00?o
0000ooooooooool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool000;o0000R?ooool00ol0003oooooooooo`05ooooo`00COooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`000ol00028ooooo`03o`000?oooooooooo00Gooooo001=ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0002o`0008Wooooo00?o0000oooooooo
ool01Oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool000;o0000
ROooool00ol0003oooooooooo`05ooooo`00COooool00ol0003oo`00ool00003ool00004o`000?oo
003oo`00ool000?o0000R?ooool2o`0000Oooooo001=ooooo`03o`000?oo003oo`0000?oo`0000Co
0000ool00?oo003oo`000ol00029ooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oo
003oo`0000?oo`0000Co0000ool00?oo003oo`000ol00029ooooo`03o`000?oooooooooo00Gooooo
001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?l00029ooooo`03o`000?oo
oooooooo00Gooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_l00000
0ooo003o0000ooooo`28ooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_l000000ooo003o0000ooooo`28ooooo`03o`000?oooooooooo
00Gooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?l000000_l000000ooo003o
0000ooooo`28ooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`000?oo003oo`0000?oo`00
00Co0000ool00?l0003o00000_oo00000ol0003oooooooooo`26ooooo`;o00001oooool004gooooo
00?o0000ool00?oo00000ooo0007o`0008Wooooo00?o0000ooooooooool01Oooool004gooooo00?o
0000ool00?oo00000ooo00001?l0003oooooo`000?l0002<ooooo`03o`000?oooooooooo00Gooooo
001=ooooo`03o`000?oo003oo`0000?oo`001?l0002<ooooo`03o`000?oooooooooo00Gooooo000`
ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01_ooool01_o^k^koEEEEo`00
0?l0003oEEEEonk^kPCooooo00?o0000ool00?oo00000ooo0003o`0008gooooo00?o0000oooooooo
ool01Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001_ooool01_mE
EEGoMgMgooooooooooooMgMgoeEEE@Cooooo00?o0000ool00?oo00000ooo0003o`0008gooooo00?o
0000ooooooooool01Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEE
EOl0003oEEEE00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`000ol0002=ooooo`03o`000?oooooooooo00Gooooo000_ooooo`06o`000?o^
k^koooooooooooo^k^ko00003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ool00?oo00000ooo0002o`0008gooooo0_l00007ooooo`00;oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00cooooo00KoEEEEogMgMoooooooooooogMgMomEEED4oooo
o`03o`000?oo003oo`0000?oo`000_l0002>ooooo`03o`000?oooooooooo00Gooooo000_ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ooMgMgo0000o`000002o`000003
omgMgOoooooooooo00;ooooo00?o0000ool00?oo00000_oo0003o`0008kooooo00?o0000oooooooo
ool01Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`06oc8b<_mVIVKok^k^
onk^k_mVIVKo<S8b1?ooool00ol0003oo`00ool00002ool000;o0000Soooool00ol0003ooooooooo
o`05ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000;oo`000_l0002?ooooo`03o`00
0?oooooooooo00Gooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool01_lb<S;o
IVIVonk^k_o^k^koIVIVoc8b<PCooooo00?o0000ool00?oo00000_oo0002o`0008oooooo00?o0000
ooooooooool01Oooool0033ooooo00CoV9RHo`000?l0003oV9RH3oooool01_o^k^koA4A4o`000?l0
003oA4A4onk^kPCooooo1ol0002?ooooo`03o`000?oooooooooo00Gooooo001=ooooo`04o`000?oo
ooooooooooooo`;o0000T?ooool00ol0003oooooooooo`05ooooo`00COooool2o`0000;ooooo0_l0
002?ooooo`;o00001oooool004gooooo00Co0000oooooooooooooooo0_l0002@ooooo`03o`000?oo
oooooooo00Gooooo001=ooooo`03o`000?oooooooooo00?o0000T?ooool00ol0003oooooooooo`05
ooooo`00COooool00ol0003oooooooooo`02o`00097ooooo00?o0000ooooooooool01Oooool004go
oooo00?o0000ooooooooool00_l0002Aooooo`03o`000?oooooooooo00Gooooo001=ooooo`03o`00
0?oooooooooo00;o0000TOooool00ol0003oooooooooo`05ooooo`00COooool00ol0003ooooooooo
o`02o`00097ooooo00?o0000ooooooooool01Oooool004gooooo1Ol0002@ooooo`;o00001oooool0
04gooooo00Co0000ooooool0003o0000T_ooool00ol0003oooooooooo`05ooooo`00COooool01?l0
003oooooo`000?l0002Booooo`03o`000?oooooooooo00Gooooo001=ooooo`04o`000?oooooo0000
o`0009;ooooo00?o0000ooooooooool01Oooool004gooooo1?l0002Booooo`03o`000?oooooooooo
00Gooooo001=ooooo`?o0000Toooool00ol0003oooooooooo`05ooooo`00COooool3o`0009?ooooo
00?o0000ooooooooool01Oooool004gooooo0ol0002Booooo`;o00001oooool004gooooo0ol0002C
ooooo`03o`000?oooooooooo00Gooooo001=ooooo`;o0000U?ooool00ol0003oooooooooo`05oooo
o`00COooool2o`0009Cooooo00?o0000ooooooooool01Oooool004;ooooo1?l000000ol@413ooooo
ooooo`04ooooo`;o0000U?ooool00ol0003oooooooooo`05ooooo`00A?ooool00ol0003ooooooooo
o`06ooooo`;o0000U?ooool00ol0003oooooooooo`05ooooo`00A?ooool00ol0003oooooooooo`06
ooooo`;o0000U?ooool00ol0003oooooooooo`05ooooo`00A?ooool00ol0003oooooooooo`06oooo
o`;o0000Toooool2o`0000Oooooo0014ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Toooool00ol0003oooooooooo`05ooooo`00A?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo09?ooooo00?o0000ooooooooool01Oooool004Cooooo00?o0000ooooooooool01_oo
oonGo`0000Oooooo0014ooooo`03o`000?oooooooooo0:Cooooo0012ooooo`03o`000?m4A4Co0000
0:Kooooo0012ooooo`03olc<c?mEEEGo00000:Kooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00001\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-2.60043, -0.435759, 0.03345, \
0.00702449}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Zeros of Riemann Zeta Function", "Section"],

Cell[TextData[{
  "In this section we will compute the level spacing distrubution for the \
imaginary parts of the nontrivial zeros of the Riemann zeta function (which I \
will refer to as \"zeta zeros\" from here on).  Values of the zeta zeros have \
been computed by Andrew Odlyzko and generously made available on his website \
(http://www.dtc.umn.edu/~odlyzko/zeta_tables/).  To use this data, go to \
Odlyzko's website and download the text files containing the zeta zeros.  \
Name the files according to the names given on the website (zeros1, zeros3, \
etc.).  You will need to cut out the explanations of the data given at the \
beginning of each file, so that what remains is just a list of numbers that \
can be read into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  Put the files into a convenient directory (such as the directory where \
this notebook is located) and then set the current directory to that \
directory using a command such as the one shown below (which will obviously \
need to be modified)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetDirectory["\</Users/timbertk/Documents/Research/RandomMatrix/\>"]\)],\
 "Input"],

Cell[BoxData[
    \("/Users/timbertk/Documents/Research/RandomMatrix"\)], "Output"]
}, Open  ]],

Cell["\<\
We'll need to load the Graphics package if that has not already \
been done.\
\>", "Text"],

Cell[BoxData[
    \(<< Graphics`\)], "Input"],

Cell["\<\
The zeta zeros are not uniformly distributed, on average. The code \
below creates a histogram of the density of the first 100,000 zeta \
zeros.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ZetaZero1 = ReadList["\<zeros1\>", Real];\)\), "\n", 
    \(\(L1 = Length[ZetaZero1];\)\), "\[IndentingNewLine]", 
    \(\(int = 
        Table[ZetaZero1[\([1]\)] + 
            i*\((ZetaZero1[\([L1]\)] - ZetaZero1[\([1]\)])\)/25, {i, 0, 
            25}];\)\), "\[IndentingNewLine]", 
    \(ZHist1 = 
      Histogram[ZetaZero1, HistogramCategories \[Rule] int, 
        HistogramScale \[Rule] L1, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<\[Gamma]\>", "\<\[Rho](\[Gamma])\>"}, 
        RotateLabel \[Rule] False]\)}], "Input"],

Cell[BoxData[
    \(Histogram::"rtail1" \(\(:\)\(\ \)\) 
      "Warning: One point from the right tail of the data, greater than or \
equal to \!\(74920.827498994`\), is not included in histogram."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.000188698 1.33499e-05 0.0147151 0.394894 [
[.13331 -0.0125 -25.9062 -18 ]
[.13331 -0.0125 25.9062 0 ]
[.26681 -0.0125 -25.9062 -18 ]
[.26681 -0.0125 25.9062 0 ]
[.40031 -0.0125 -25.9062 -18 ]
[.40031 -0.0125 25.9062 0 ]
[.53381 -0.0125 -25.9062 -18 ]
[.53381 -0.0125 25.9062 0 ]
[.66731 -0.0125 -25.9062 -18 ]
[.66731 -0.0125 25.9062 0 ]
[.80081 -0.0125 -25.9062 -18 ]
[.80081 -0.0125 25.9062 0 ]
[.93431 -0.0125 -25.9062 -18 ]
[.93431 -0.0125 25.9062 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .09369 -32.6875 -9 ]
[-0.0125 .09369 0 9 ]
[-0.0125 .17267 -32.6875 -9 ]
[-0.0125 .17267 0 9 ]
[-0.0125 .25165 -32.6875 -9 ]
[-0.0125 .25165 0 9 ]
[-0.0125 .33063 -32.6875 -9 ]
[-0.0125 .33063 0 9 ]
[-0.0125 .40961 -13.5625 -9 ]
[-0.0125 .40961 0 9 ]
[-0.0125 .48859 -32.6875 -9 ]
[-0.0125 .48859 0 9 ]
[-0.0125 .56757 -32.6875 -9 ]
[-0.0125 .56757 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -74.9375 -9 ]
[-0.01875 .30902 -32.6875 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13331 0 m
.13331 .00625 L
s
gsave
.13331 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10000) show
1.000 setlinewidth
grestore
.26681 0 m
.26681 .00625 L
s
gsave
.26681 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20000) show
1.000 setlinewidth
grestore
.40031 0 m
.40031 .00625 L
s
gsave
.40031 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30000) show
1.000 setlinewidth
grestore
.53381 0 m
.53381 .00625 L
s
gsave
.53381 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40000) show
1.000 setlinewidth
grestore
.66731 0 m
.66731 .00625 L
s
gsave
.66731 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50000) show
1.000 setlinewidth
grestore
.80081 0 m
.80081 .00625 L
s
gsave
.80081 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60000) show
1.000 setlinewidth
grestore
.93431 0 m
.93431 .00625 L
s
gsave
.93431 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70000) show
1.000 setlinewidth
grestore
.125 Mabswid
.02651 0 m
.02651 .00375 L
s
.05321 0 m
.05321 .00375 L
s
.07991 0 m
.07991 .00375 L
s
.10661 0 m
.10661 .00375 L
s
.16001 0 m
.16001 .00375 L
s
.18671 0 m
.18671 .00375 L
s
.21341 0 m
.21341 .00375 L
s
.24011 0 m
.24011 .00375 L
s
.29351 0 m
.29351 .00375 L
s
.32021 0 m
.32021 .00375 L
s
.34691 0 m
.34691 .00375 L
s
.37361 0 m
.37361 .00375 L
s
.42701 0 m
.42701 .00375 L
s
.45371 0 m
.45371 .00375 L
s
.48041 0 m
.48041 .00375 L
s
.50711 0 m
.50711 .00375 L
s
.56051 0 m
.56051 .00375 L
s
.58721 0 m
.58721 .00375 L
s
.61391 0 m
.61391 .00375 L
s
.64061 0 m
.64061 .00375 L
s
.69401 0 m
.69401 .00375 L
s
.72071 0 m
.72071 .00375 L
s
.74741 0 m
.74741 .00375 L
s
.77411 0 m
.77411 .00375 L
s
.82751 0 m
.82751 .00375 L
s
.85421 0 m
.85421 .00375 L
s
.88091 0 m
.88091 .00375 L
s
.90761 0 m
.90761 .00375 L
s
.96101 0 m
.96101 .00375 L
s
.98771 0 m
.98771 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
72.562 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .09369 m
.00625 .09369 L
s
gsave
-0.0125 .09369 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .17267 m
.00625 .17267 L
s
gsave
-0.0125 .17267 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .25165 m
.00625 .25165 L
s
gsave
-0.0125 .25165 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .33063 m
.00625 .33063 L
s
gsave
-0.0125 .33063 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .40961 m
.00625 .40961 L
s
gsave
-0.0125 .40961 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .48859 m
.00625 .48859 L
s
gsave
-0.0125 .48859 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .56757 m
.00625 .56757 L
s
gsave
-0.0125 .56757 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03446 m
.00375 .03446 L
s
0 .0542 m
.00375 .0542 L
s
0 .07395 m
.00375 .07395 L
s
0 .11344 m
.00375 .11344 L
s
0 .13318 m
.00375 .13318 L
s
0 .15293 m
.00375 .15293 L
s
0 .19242 m
.00375 .19242 L
s
0 .21216 m
.00375 .21216 L
s
0 .23191 m
.00375 .23191 L
s
0 .2714 m
.00375 .2714 L
s
0 .29114 m
.00375 .29114 L
s
0 .31089 m
.00375 .31089 L
s
0 .35038 m
.00375 .35038 L
s
0 .37012 m
.00375 .37012 L
s
0 .38986 m
.00375 .38986 L
s
0 .42935 m
.00375 .42935 L
s
0 .4491 m
.00375 .4491 L
s
0 .46884 m
.00375 .46884 L
s
0 .50833 m
.00375 .50833 L
s
0 .52808 m
.00375 .52808 L
s
0 .54782 m
.00375 .54782 L
s
0 .58731 m
.00375 .58731 L
s
0 .60706 m
.00375 .60706 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.13331 .61178 m
.13331 .61803 L
s
.26681 .61178 m
.26681 .61803 L
s
.40031 .61178 m
.40031 .61803 L
s
.53381 .61178 m
.53381 .61803 L
s
.66731 .61178 m
.66731 .61803 L
s
.80081 .61178 m
.80081 .61803 L
s
.93431 .61178 m
.93431 .61803 L
s
.125 Mabswid
.02651 .61428 m
.02651 .61803 L
s
.05321 .61428 m
.05321 .61803 L
s
.07991 .61428 m
.07991 .61803 L
s
.10661 .61428 m
.10661 .61803 L
s
.16001 .61428 m
.16001 .61803 L
s
.18671 .61428 m
.18671 .61803 L
s
.21341 .61428 m
.21341 .61803 L
s
.24011 .61428 m
.24011 .61803 L
s
.29351 .61428 m
.29351 .61803 L
s
.32021 .61428 m
.32021 .61803 L
s
.34691 .61428 m
.34691 .61803 L
s
.37361 .61428 m
.37361 .61803 L
s
.42701 .61428 m
.42701 .61803 L
s
.45371 .61428 m
.45371 .61803 L
s
.48041 .61428 m
.48041 .61803 L
s
.50711 .61428 m
.50711 .61803 L
s
.56051 .61428 m
.56051 .61803 L
s
.58721 .61428 m
.58721 .61803 L
s
.61391 .61428 m
.61391 .61803 L
s
.64061 .61428 m
.64061 .61803 L
s
.69401 .61428 m
.69401 .61803 L
s
.72071 .61428 m
.72071 .61803 L
s
.74741 .61428 m
.74741 .61803 L
s
.77411 .61428 m
.77411 .61803 L
s
.82751 .61428 m
.82751 .61803 L
s
.85421 .61428 m
.85421 .61803 L
s
.88091 .61428 m
.88091 .61803 L
s
.90761 .61428 m
.90761 .61803 L
s
.96101 .61428 m
.96101 .61803 L
s
.98771 .61428 m
.98771 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09369 m
1 .09369 L
s
.99375 .17267 m
1 .17267 L
s
.99375 .25165 m
1 .25165 L
s
.99375 .33063 m
1 .33063 L
s
.99375 .40961 m
1 .40961 L
s
.99375 .48859 m
1 .48859 L
s
.99375 .56757 m
1 .56757 L
s
.125 Mabswid
.99625 .03446 m
1 .03446 L
s
.99625 .0542 m
1 .0542 L
s
.99625 .07395 m
1 .07395 L
s
.99625 .11344 m
1 .11344 L
s
.99625 .13318 m
1 .13318 L
s
.99625 .15293 m
1 .15293 L
s
.99625 .19242 m
1 .19242 L
s
.99625 .21216 m
1 .21216 L
s
.99625 .23191 m
1 .23191 L
s
.99625 .2714 m
1 .2714 L
s
.99625 .29114 m
1 .29114 L
s
.99625 .31089 m
1 .31089 L
s
.99625 .35038 m
1 .35038 L
s
.99625 .37012 m
1 .37012 L
s
.99625 .38986 m
1 .38986 L
s
.99625 .42935 m
1 .42935 L
s
.99625 .4491 m
1 .4491 L
s
.99625 .46884 m
1 .46884 L
s
.99625 .50833 m
1 .50833 L
s
.99625 .52808 m
1 .52808 L
s
.99625 .54782 m
1 .54782 L
s
.99625 .58731 m
1 .58731 L
s
.99625 .60706 m
1 .60706 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .34131 L
.04 .34131 L
.04 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .34131 L
.04 .34131 L
.04 .01472 L
0 .01472 L
s
1 0 0 r
.04 .01472 m
.04 .42684 L
.08 .42684 L
.08 .01472 L
F
0 g
.04 .01472 m
.04 .42684 L
.08 .42684 L
.08 .01472 L
.04 .01472 L
s
1 0 0 r
.08 .01472 m
.08 .45966 L
.12 .45966 L
.12 .01472 L
F
0 g
.08 .01472 m
.08 .45966 L
.12 .45966 L
.12 .01472 L
.08 .01472 L
s
1 0 0 r
.12 .01472 m
.12 .48101 L
.16 .48101 L
.16 .01472 L
F
0 g
.12 .01472 m
.12 .48101 L
.16 .48101 L
.16 .01472 L
.12 .01472 L
s
1 0 0 r
.16 .01472 m
.16 .4967 L
.2 .4967 L
.2 .01472 L
F
0 g
.16 .01472 m
.16 .4967 L
.2 .4967 L
.2 .01472 L
.16 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .50948 L
.24 .50948 L
.24 .01472 L
F
0 g
.2 .01472 m
.2 .50948 L
.24 .50948 L
.24 .01472 L
.2 .01472 L
s
1 0 0 r
.24 .01472 m
.24 .52002 L
.28 .52002 L
.28 .01472 L
F
0 g
.24 .01472 m
.24 .52002 L
.28 .52002 L
.28 .01472 L
.24 .01472 L
s
1 0 0 r
.28 .01472 m
.28 .52899 L
.32 .52899 L
.32 .01472 L
F
0 g
.28 .01472 m
.28 .52899 L
.32 .52899 L
.32 .01472 L
.28 .01472 L
s
1 0 0 r
.32 .01472 m
.32 .53676 L
.36 .53676 L
.36 .01472 L
F
0 g
.32 .01472 m
.32 .53676 L
.36 .53676 L
.36 .01472 L
.32 .01472 L
s
1 0 0 r
.36 .01472 m
.36 .54375 L
.4 .54375 L
.4 .01472 L
F
0 g
.36 .01472 m
.36 .54375 L
.4 .54375 L
.4 .01472 L
.36 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .5502 L
.44 .5502 L
.44 .01472 L
F
0 g
.4 .01472 m
.4 .5502 L
.44 .5502 L
.44 .01472 L
.4 .01472 L
s
1 0 0 r
.44 .01472 m
.44 .55574 L
.48 .55574 L
.48 .01472 L
F
0 g
.44 .01472 m
.44 .55574 L
.48 .55574 L
.48 .01472 L
.44 .01472 L
s
1 0 0 r
.48 .01472 m
.48 .56114 L
.52 .56114 L
.52 .01472 L
F
0 g
.48 .01472 m
.48 .56114 L
.52 .56114 L
.52 .01472 L
.48 .01472 L
s
1 0 0 r
.52 .01472 m
.52 .56589 L
.56 .56589 L
.56 .01472 L
F
0 g
.52 .01472 m
.52 .56589 L
.56 .56589 L
.56 .01472 L
.52 .01472 L
s
1 0 0 r
.56 .01472 m
.56 .5705 L
.6 .5705 L
.6 .01472 L
F
0 g
.56 .01472 m
.56 .5705 L
.6 .5705 L
.6 .01472 L
.56 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .57446 L
.64 .57446 L
.64 .01472 L
F
0 g
.6 .01472 m
.6 .57446 L
.64 .57446 L
.64 .01472 L
.6 .01472 L
s
1 0 0 r
.64 .01472 m
.64 .57867 L
.68 .57867 L
.68 .01472 L
F
0 g
.64 .01472 m
.64 .57867 L
.68 .57867 L
.68 .01472 L
.64 .01472 L
s
1 0 0 r
.68 .01472 m
.68 .5821 L
.72 .5821 L
.72 .01472 L
F
0 g
.68 .01472 m
.68 .5821 L
.72 .5821 L
.72 .01472 L
.68 .01472 L
s
1 0 0 r
.72 .01472 m
.72 .58579 L
.76 .58579 L
.76 .01472 L
F
0 g
.72 .01472 m
.72 .58579 L
.76 .58579 L
.76 .01472 L
.72 .01472 L
s
1 0 0 r
.76 .01472 m
.76 .58895 L
.8 .58895 L
.8 .01472 L
F
0 g
.76 .01472 m
.76 .58895 L
.8 .58895 L
.8 .01472 L
.76 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .59225 L
.84 .59225 L
.84 .01472 L
F
0 g
.8 .01472 m
.8 .59225 L
.84 .59225 L
.84 .01472 L
.8 .01472 L
s
1 0 0 r
.84 .01472 m
.84 .59502 L
.88 .59502 L
.88 .01472 L
F
0 g
.84 .01472 m
.84 .59502 L
.88 .59502 L
.88 .01472 L
.84 .01472 L
s
1 0 0 r
.88 .01472 m
.88 .59805 L
.92 .59805 L
.92 .01472 L
F
0 g
.88 .01472 m
.88 .59805 L
.92 .59805 L
.92 .01472 L
.88 .01472 L
s
1 0 0 r
.92 .01472 m
.92 .60081 L
.96 .60081 L
.96 .01472 L
F
0 g
.92 .01472 m
.92 .60081 L
.96 .60081 L
.96 .01472 L
.92 .01472 L
s
1 0 0 r
.96 .01472 m
.96 .60332 L
1 .60332 L
1 .01472 L
F
0 g
.96 .01472 m
.96 .60332 L
1 .60332 L
1 .01472 L
.96 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0097ooooo00?o8B4Qo`000?o<c<`0
Eoooool0097ooooo00?o0000okZj^_lQ8B40Eoooool0097ooooo00?oA4A4olc<c?l00000Eoooool0
097ooooo00?oV9RHogMgMol00000Eoooool009;ooooo00?o<S8bodA4A?ooool0E_ooool009;ooooo
00?o8B4Qoc8b<_o<c<`0E_ooool0097ooooo00GoIVIVojVYZOo^k^ko8B4Qonk^kP1Eooooo`00Sooo
ool00oo^k^koIVIVoiRHV002ooooo`03olc<c?lb<S;ok^k^05Cooooo002>ooooo`;oIVIV00?oc<c<
ooooooooool00_ooool00oo<c<coEEEEooooo`1Cooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo001:ooooo`Co
000000?o410@ooooooooool01?ooool01?nHV9So0000o`000?nHV9P2ooooo`Oo000000?oV9RHoooo
ooooool00_ooool00onHV9So0000o`000002o`000005oiRHV?ooooooooooojVYZOlQ8B401Ol00000
1OnHV9SoooooooooooooooooV9RH00?o000000?oV9RHooooooooool00oooool01OnHV9So0000o`00
0?l0003oV9RH00Cooooo00GoV9RHo`000?l0003o0000oiRHV002ooooo`03oiRHV?l@413o000000Co
000000GoV9RHoooooooooooooooooiRHV004o`000005oiRHV?ooooooooooonk^k_mEEED01Ol00000
1OnHV9SoooooooooooooooooV9RH00?o000000?oV9RHooooooooool00oooool4o`000003oiRHV?oo
oooooooo00;ooooo00GoV9RHo`000?l0003o0000oiRHV005ooooo`05oiRHV?l0003o0000o`000?nH
V9P01Oooool01?nHV9So0000o`000?nHV9P6ooooo`04oiRHV?l0003o0000oiRHV0Cooooo001<oooo
o`03o`000?oooooooooo00Gooooo013o^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[[ooooooiRHV?l0003o
gMgMokZj^_lQ8B7o3Ph>omgMgOlQ8B7o^[Zj0_ooool06_nj^[[o8B4Qoj6QXOlL71co7AdMoj:RX_lQ
8B7o^[Zjooooool@413oU9BDob4Q8OnQXJ7o3@d=o`/;2onRXZ;o8B4QokZj^_oooooo^[ZjoaPH6?lL
71cogMgMoadM7OlH61So^[Zj0oooool01onj^[[o61PHoa`L7?l0003o7AdMoaPH6?nj^[X00_ooool0
;?nj^[[o61PHoa`L7?oMgMgo7AdMoaPH6?nj^[[ooooooa0@4?n7QhOo^[ZjoaPH6?l=3@goF5QHoadM
7OlH61So^[Zjoooooonj^[[o8B4Qoj6QXOlL71co7AdMoj:RX_lQ8B7o^[ZjoooooomgMgOoEUIFob4Q
8OnQXJ7o3@d=o`T92OnRXZ;o8B4QokZj^_oooooo^[ZjoaPH6?lL71cogMgMoadM7OlH61So^[Zj0ooo
ool01onj^[[o20P8o`T92OoMgMgo7AdMoaPH6?nj^[X00_ooool01onj^[[o61PHoa`L7?oMgMgo7AdM
oaPH6?nj^[X00oooool01onj^[[o61PHoa`L7?oMgMgo7AdMoaPH6?nj^[X00oooool01_nj^[[o8B4Q
omgMgOoMgMgo8B4QokZj^PCooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X3ooooo`00C?ooool0
0ol0003oooooooooo`05ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A40_ooool01?n7QhOo8B4Q
oclo?onHV9P2ooooo`07oiRHV?m4A4Cooooooooooom4A4CoV9RHodA4A002oiRHV003odA4A?nHV9So
A4A400;ooooo013oA4A4oiRHV?m4A4CoV9RHo`000?m4A4CoV9RHodA4A?ooooooA4A4obPX:?nHV9So
oooooiRHV?lX:2SoA4A40_ooool6o`00000;obPX:?m4A4Cooooooooooom4A4Co:2PXoiRHV?oooooo
V9RHobPX:?m4A4@00oooool02om4A4Co:2PXoiRHV?l0003oV9RHobPX:?m4A4CoooooodA4A?nHV9So
A4A400;oV9RH01GoA4A4oiRHV?m4A4Coooooob4Q8Om4A4CoV9RHodA4A?nHV9So0000odA4A?nHV9So
A4A4oooooom4A4Co:2PXoiRHV?ooooooV9RHobPX:?m4A4@00oooool01om4A4Co6QXJo`000?oooooo
V9RHobPX:?m4A4@00_ooool01om4A4Co:2PXoiRHV?ooooooV9RHobPX:?m4A4@00oooool01om4A4Co
:2PXoiRHV?ooooooV9RHobPX:?m4A4@00oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo
00KoA4A4oiRHV?oooooooooooiRHV?m4A4@3ooooo`00C?ooool00ol0003oooooooooo`05ooooo`06
o`000?o^k^koooooooooooo^k^ko00000oooool00onYZJWo0000onk^kP02ooooo`07onk^k_l0003o
ooooooooool0003ok^k^o`000002onk^kP03o`000?o^k^ko000000;ooooo00Co0000onk^k_l0003o
k^k^0_l000000oo^k^ko0000ooooo`02o`000003onk^k_ooooook^k^00;o00000_ooool01_m4A4Co
0000o`000?o^k^ko0000onk^kP;o00000_ooool2o`000003onk^k_ooooook^k^00;o00000oooool2
o`000003onk^k_l0003ok^k^00;o000000Coooooo`000?o^k^ko00000_o^k^h01?l0003ok^k^o`00
0?ooool2o`000003onk^k_l0003ok^k^00;o000000?ok^k^o`000?ooool00_l000000oo^k^kooooo
onk^kP02o`0000?ooooo0ol000001?o<c<cok^k^o`000?l00002ooooo`;o000000?ok^k^ooooooo^
k^h00_l00003ooooo`;o000000?ok^k^ooooooo^k^h00_l00003ooooo`06o`000?o^k^kooooooooo
ooo^k^ko00001?ooool01_l0003ok^k^ooooooooooook^k^o`0000?ooooo001<ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?lb
<S;ooooo00;ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooo000000;o
oooo00Wo0000ooooool0003oZJVYodA4A?l0003oooooo`000?ooool00_l00003ooooo`;o00000_oo
ool01_oMgMgo0000o`000?oooooo0000ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo
410@oiRHV002o`000003ogMgMomVIVKooooo00;o000000Coooooo`000?oooooo00000_ooool01?l0
003oooooo`000?ooool2o`000008onk^k_l0003oMgMgoeEEEOl0003oooooo`000?ooool2o`0000?o
oooo0_l00003ooooo`;o000000?oEEEEofIVI_ooool00_l00002ooooo`;o00000oooool2o`0000?o
oooo0_l00003ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`01ooooo`00C?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oA4A4
ogMgM`02ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooo`000002oooo
o`09o`000?lQ8B7o0000o`000?oMgMgo0000ooooool0003ooooo00;o00000oooool2o`0000?ooooo
0_l000000ooooooo0000ooooo`02o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?lQ8B40
0_l000000omVIVKoooooooooo`02o`000004ooooool0003oooooo`0000;ooooo00Co0000ooooool0
003ooooo1?l000001_mEEEGok^k^o`000?oooooo0000ooooo`;o00000oooool2o`0000?ooooo0_l0
00000onYZJWo410@ooooo`02o`0000;ooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l0
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo007ooooo001<ooooo`03o`000?oooooooooo00Gooooo00Ko0000
onk^k_ooooooooooonk^k_l00004ooooo`06o`000?o>c/ko410@ooooooo^k^ko00000_ooool00ol0
003ok^k^o`000002onk^kP03o`000?o^k^ko000000;ooooo00Wo0000onk^k_l0003oWYjNobl_;ol0
003ok^k^o`000?ooool00_l000000oo^k^koooooonk^kP02o`0000?ooooo0_l000000oo^k^ko0000
onk^kP02o`0000;ooooo0_l000000oo^k^koooooonk^kP02o`000003ooooool0003ooooo00;o0000
00?ok^k^ooooooo^k^h00_l000001?oooooo0000onk^k_l00002onk^kP08o`000?o^k^ko0000oooo
oom4A4Co0000onk^k_l00002onk^kP04o`000?o^k^ko0000ooooo`;o000000?ok^k^ooooooo^k^h0
0_l00003ooooo`;o000000?ok^k^o`000?o>c/h00_l00002ooooo`;o000000?ok^k^ooooooo^k^h0
0_l00003ooooo`;o000000?ok^k^ooooooo^k^h00_l00003ooooo`06o`000?o^k^koooooooooooo^
k^ko00001?ooool01_l0003ok^k^ooooooooooook^k^o`0000?ooooo001<ooooo`03o`000?oooooo
oooo00Gooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@4ooooo`06odA4A?nHV9So0000oooooonH
V9SoA4A40_ooool00om4A4CoV9RHodA4A002oiRHV003odA4A?nHV9SoA4A400;ooooo013oA4A4oiRH
V?m4A4CoV9RHo`000?m4A4CoV9RHodA4A?ooooooA4A4obPX:?nHV9SooooooiRHV?lX:2SoA4A40ooo
ool01om4A4Co4Q8BoiRHV?l0003oV9RHobPX:?m4A4@00_ooool05Om4A4Co:2PXoiRHV?ooooooV9RH
obPX:?m4A4Coooooo`000?ooooooA4A4obPX:?nHV9SooooooiRHV?lX:2SoA4A4oooooom4A4CoV9RH
odA4A002oiRHV008odA4A?nHV9SoA4A4oooooonj^[[o2@T9oiRHV?m4A4@2oiRHV00;odA4A?nHV9So
A4A4oooooom4A4Co:2PXoiRHV?ooooooV9RHobPX:?m4A4@00oooool01om4A4Co:2PXoiRHV?mEEEGo
DE5AobPX:?m4A4@00_ooool01om4A4Co:2PXoiRHV?ooooooV9RHobPX:?m4A4@00oooool01om4A4Co
:2PXoiRHV?ooooooV9RHobPX:?m4A4@00oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo
00KoA4A4oiRHV?oooooooooooiRHV?m4A4@3ooooo`00B_ooool00ol0003oA4A4o`000007ooooo`0@
okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zjooooool0003oQhN7onk^k_nj^[[o4a<CodU9BOoMgMgo8B4Q
okZj^P;ooooo01[o^[Zjob4Q8OnQXJ7o71`LoadM7OnRXZ;o8B4QokZj^_oooooo8B4QokZj^_lQ8B7o
XJ6Qo`/;2ol51@GoXZ:Rob4Q8Onj^[[ooooookZj^_lH61So71`LomgMgOlM7Ago61PHokZj^P?ooooo
00Oo^[ZjoaHF5_l51@Go0000oadM7OlH61So^[Zj00;ooooo01[o^[ZjoaPH6?lL71cogMgMoadM7OlH
61So^[Zjooooool0003ooooookZj^_lH61So71`LomgMgOlM7Ago61PHokZj^_oooooo^[Zjob4Q8OnQ
XJ7o71`LoadM7OnRXZ;o8B4QokZj^P;ooooo013o?Shno`H61_n;Rh_o71`LoadM7OnRXZ;o8B4QokZj
^_oooooo^[ZjoaPH6?lL71cogMgMoadM7OlH61So^[Zj0_ooool02?l@413o^[ZjoaPH6?lL71coTi>C
o`D51OlH61So^[Zj0_ooool01onj^[[o61PHoa`L7?oMgMgo7AdMoaPH6?nj^[X00oooool01onj^[[o
61PHoa`L7?oMgMgo7AdMoaPH6?nj^[X00oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PCooooo
00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X3ooooo`00B_ooool00oo<c<coEEEEo`000008ooooo`04
oiRHV?l0003o0000oiRHV0;ooooo00GoZJVYoc8b<_l0003o0000oc8b<P02o`000003oiRHV?oooooo
oooo00;ooooo00?oV9RHo`000?l000000_l000001OnHV9Sooooooooooonj^[[oA4A400Go000000Go
V9RHoooooooooooooooooiRHV003o`000003oiRHV?oooooooooo00?ooooo00GoV9RHo`000?l0003o
0000oiRHV004ooooo`05oiRHV?l0003o0000o`000?nHV9P00_ooool7o`000005oiRHV?oooooooooo
oooooonHV9P01?l000000onHV9Soooooooooo`02ooooo`03oiRHV?l0003o000000;o000000GoV9RH
oooooooooooooooooiRHV003o`000004oiRHV?ooooooooooooooo`Ko000000?oV9RHooooooooool0
0_ooool01OnHV9So0000o`000?l0003oV9RH00Gooooo00GoV9RHo`000?l0003o0000oiRHV005oooo
o`04oiRHV?l0003o0000oiRHV0Kooooo00CoV9RHo`000?l0003oV9RH1?ooool00>_ooooo003[oooo
o`00joooool004?ooooo00CoV9RHo`000?l0003oV9RHY?ooool004;ooooo00Ko^[Zjob4Q8OoMgMgo
gMgMob4Q8Onj^[X5ooooohgo00004Oooool004;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`00000Aooooo`00@_ooool01_l0
003ok^k^ooooooooooook^k^o`0000GoooooSOl0000Aooooo`00@_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?
ooooo`00@_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`0?ooooo`00@_ooool01_l0003ok^k^ooooooooooook^k^
o`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00@_ooool01_m4
A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`0?ooooo`00@_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`0?ooooo`00@oooool01?nHV9So0000o`000?nHV9P6ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool03oooool004gooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`0?ooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0
003oEEEE00Gooooo1_l00005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03ooo
ool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001Oooool00onHV9So0000
omgMg@02ooooo`03oa0@4?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`0?ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mE
EED01_ooool00on7QhOo8B4Qonk^kP07ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool03oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000?ooooo`03ojVYZOlQ8B7ok^k^
00Kooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00;oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?oV9RHoc8b<_ooool01Oooool00ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo00oooooo000_ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03oooool00om4A4CoMgMgooooo`04ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ooooooooool03oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000Aooooo`03
omgMgOl@413ooooo00Cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00
;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A1;ooooo00?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo00oooooo000_ooooo`06okZj^_lQ8B7ogMgMomgM
gOlQ8B7o^[Zj3Oooool01_l0003oQhN7onk^k_ooooooV9RHoeEEE@Gooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`0?ooooo`00<?ooool01?nHV9So0000o`000?nHV9P>ooooo`06ojVY
ZOlb<S;o0000o`000?mEEEGok^k^1Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
00oooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool0033ooooo
00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@09ooooo`;o000000?o410@oooooooo
ool00_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo000_ooooo`06okZj
^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000[ooooo00?o0000ooooooooool00oooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo00oooooo000_ooooo`06odA4A?nHV9Sooooooooo
oonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`Ko00001?ooool00ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo00oooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00003_oo
ool01Om4A4Co^[Zjoooooooooooo000000Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`0?ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Go
gMgMob4Q8Oooooooooooo`000005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
3oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`04ogMgMonH
V9Soooooo`0000Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00;ooo
ool01_l0003ok^k^ooooooooooook^k^o`0000oooooo00Cok^k^ob4Q8Ooooooo00001Oooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo00oooooo000_ooooo`06odA4A?nHV9Sooooooooo
oonHV9SoA4A44?ooool00omgMgOoV9RHo`000005ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool03oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X@ooooo`03onk^k_lb
<S;o000000Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00<?ooool0
1?nHV9So0000o`000?nHV9PBooooo`03oiRHV?l@413ooooo00Cooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`0?ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooo
oooo00oooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01_ooool0
1_o^k^koEEEEo`000?l0003oEEEEonk^kPCooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`0?ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`;o
MgMg0_ooool00omgMgOoEEEEooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool03oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE
00Kooooo00?o8B4Qooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ooooooooool03oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>
ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo00oooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03?ooool01_l0003oEEEEonk^k_ooooooMgMgoeEEE@Cooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`0?ooooo`004?ooool00onj^[[o<S8booooo`0>ooooo`03oc8b<_nj^[[o
oooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`06o`000?mgMgOo
0000o`000?mEEEGok^k^1?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo
0003ooooo`03o`000?oooooooooo00[ooooo00?o<S8bokZj^_ooool01Oooool00olQ8B7o0000olc<
c006ooooo`03okZj^_lb<S;ooooo00_ooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`03
odA4A?nHV9Sooooo00Oooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00
0oooool00olb<S;o^[Zjooooo`09ooooo`03olc<c?lb<S;ooooo00Kooooo00?o0000okZj^_lQ8B40
1oooool00olb<S;oc<c<ooooo`0:ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A43_ooool00onj
^[[o8B4Qooooo`07ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool000?o
oooo00?oMgMgohN7QomgMgL00_l000000om4A4Coc<c<ooooo`04ooooo`03ofIVI_nYZJWooooo00Ko
oooo00?oA4A4olc<c?l000001oooool00onHV9SoIVIVooooo`0:ooooo`06okZj^_lQ8B7ogMgMomgM
gOlQ8B7o^[Zj3oooool00omEEEGo<S8bomgMg@06ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool03oooool000?ooooo00SoV9RHoa0@4?n7QhOok^k^oooooonHV9So410@olc<c0Cooooo
00?o<S8booooooooool01_ooool00onHV9SoMgMgo`000007ooooo`03onk^k_lb<S;ooooo00_ooooo
00CoV9RHo`000?l0003oV9RH4Oooool01?nHV9So8B4Qo`000?lQ8B44ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ooooooooool03oooool000?ooooo00?o^[Zjoc8b<_ooool00oooool00onHV9So
A4A4ooooo`03ooooo`03oc8b<_oooooooooo00Oooooo00?o<S8bodA4A?ooool01oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool000Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03oc8b<_oooooooooo00Oooooo
00?o8B4Qoc8b<_o<c<`01oooool00ol0003oooooooooo`0:ooooo`04oiRHV?l0003o0000oiRHV0Ko
oooo00?oEEEEo`000?mEEED01_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPCooooo00?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`001?ooool00om4A4CoV9RHooooo`02oooo
o`03onk^k_l0003ooooo00?ooooo00?o8B4Qooooooooool01_ooool01OmVIVKoZJVYonk^k_lQ8B7o
k^k^00Kooooo00?o0000ooooooooool02Oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo
0ol00006ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE1?ooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo00oooooo0004ooooo`07okZj^_l0003o^[Zjooooooo^k^koIVIVoeEEE@04
ooooo`03oc8b<_o^k^kooooo00Cooooo00?ok^k^ofIVI_nHV9P00_ooool00oo<c<co<S8bonk^kP04
ooooo`03omgMgOlb<S;ooooo00[ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEE
EOl0003oEEEE00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool03oooool000Gooooo00KoZJVYob4Q8Ol0003o0000
oeEEEOo^k^h4ooooo`03ofIVI_nHV9Sooooo00?ooooo0_mVIVH00oo<c<coooooooooo`02ooooo`03
olc<c?mEEEGooooo00?ooooo00?oV9RHofIVI_ooool02_ooool01_l0003ok^k^ooooooooooook^k^
o`0000kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ooooooooool03oooool000oooooo00?ogMgMob4Q8Oooool04?ooool00ol@
413oc<c<ooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01_mE
EEGoMgMgooooooooooooMgMgoeEEE@Cooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`0?ooooo`004?ooool00olb<S;o^[Zjooooo`0>ooooo`03okZj^_lb<S;ooooo00_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03omgMgOl0003o000000;o000000?ogMgM
ooooooooool00_ooool7o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo00oooooo000@ooooo`03okZj^_lb<S;ooooo00kooooo00?o<S8bokZj
^_ooool02oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00Ko<S8bofIVI_o^k^kok^k^
ofIVI_lb<S84ooooo`;o00001?ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00;oooool01_m4A4CoV9RH
ooooooooooooV9RHodA4A0kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool002oooooo00Ko^[Zjob4Q8OoM
gMgogMgMob4Q8Onj^[X>ooooo`06oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b1?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oooooooooo00oooooo000`ooooo`04oiRHV?l0003o0000oiRHV0oooooo
00Kok^k^odA4A?l0003o0000odA4A?o^k^h4ooooo`;o00001?ooool00ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?oooo
o`00COooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo0012ooooo`Co0000
00?o410@ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo
0014ooooo`03o`000?oooooooooo00Kooooo0_l00004ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo0014
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?
ooooo`00A?ooool00ol0003oooooooooo`06ooooo`;o00001?ooool00ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?oooo
o`00A?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool03oooool004Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo00oooooo0014ooooo`03o`000?oooooooooo00Kooooo0_l00004ooooo`Ko00001Ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo0014ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ooooooooool03oooool004;ooooo00?o0000odA4A?l000002?ooool00ol0
003oooooooooo`08ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`0?ooooo`00@_ooool00oo<c<coEEEEo`000008ooooo`;o00002Oooool00ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool004gooooo
00?o0000ooooooooool02?ooool7o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool002oooooo1?l0
00000ol@413oooooooooo`04ooooo`03oeEEEOl0003oEEEE00Gooooo1_l00005ooooo`03o`000?oo
oooooooo00kooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00<Oooool0
0ol0003oooooooooo`06ooooo`?o00001Oooool00onHV9So0000omgMg@02ooooo`03oa0@4?oooooo
oooo00?ooooo0_l0000?ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool0
037ooooo00?o0000ooooooooool01_ooool00omEEEGo0000oeEEE@06ooooo`03ohN7QolQ8B7ok^k^
00Oooooo00?o0000ooooooooool03_ooool6o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo00oooooo000aooooo`03o`000?oooooooooo013o
oooo00?oZJVYob4Q8Oo^k^h01_ooool2o`0001Cooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool0037ooooo
00?o0000ooooooooool04Oooool00onHV9So<S8booooo`05ooooo`03o`000?oooooooooo01?ooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ooooooooool03oooool0037ooooo00?o0000ooooooooool04_ooool00om4A4CoMgMgoooo
o`04ooooo`03o`000?oooooooooo01?ooooo1ol00005ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ooooooooool03oooool0037ooooo00?o0000ooooooooool04_ooool00ooMgMgo410@ooooo`04
ooooo`;o00006_ooool7o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool0037ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`0?ooooo`00;oooool00ol0003oA4A4o`00000@ooooo`06
o`000?n7QhOok^k^oooooonHV9SoEEEE1Oooool00ol0003oooooooooo`0Oooooo`Ko00001Ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool0
02oooooo00?oc<c<oeEEEOl000004?ooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kPGooooo0_l0
000Uooooo`Oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo001=
ooooo`03o`000?oooooooooo02[ooooo1_l00005ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo001=oooo
o`03o`000?oooooooooo02oooooo1ol00005ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`0?ooooo`00;oooool4o`000003oa0@4?oooooooooo00Co
oooo00?oEEEEo`000?mEEED02Oooool2o`000003oa0@4?oooooooooo00;ooooo0_l0000fooooo`Oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo000aooooo`03o`00
0?oooooooooo00Kooooo0ol0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
>oooool6o`0000Goo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool03oooool0037ooooo00?o0000ooooooooool01_oo
ool00omEEEGo0000oeEEE@06ooooo`Ko00001?ooool00ol0003oooooooooo`10ooooo`co00001Ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo000aooooo`03o`000?oooooo
oooo00oooooo00GoA4A4okZj^_ooooooooooo`000005ooooo`;o0000C?ooool<o`0000Goo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo000a
ooooo`03o`000?oooooooooo00oooooo00GogMgMob4Q8Oooooooooooo`000005ooooo`03o`000?oo
oooooooo05Kooooo1ol00005ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03ooo
ool0037ooooo00?o0000ooooooooool04?ooool01?mgMgOoV9RHooooool00005ooooo`;o0000GOoo
ool<o`0000Goo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
oooooooo00oooooo000aooooo`03o`000?oooooooooo013ooooo00Cok^k^ob4Q8Ooooooo00001Ooo
ool00ol0003oooooooooo`1Woooooa;o00001Ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ooooooooool03oooool0037ooooo00?o0000ooooooooool04Oooool0
0omgMgOoV9RHo`000005ooooo`03o`000?oooooooooo07Sooooo3?l00005ool00003o`000?oooooo
oooo00oooooo000_ooooo`03o`000?m4A4Co000001?ooooo00?ok^k^oc8b<_l000001Oooool2o`00
08Cooooo1ol0000Aooooo`00;oooool00oo<c<coEEEEo`00000Dooooo`03oiRHV?l@413ooooo00Co
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo0000017ooooo001=ooooohgo0000
4Oooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-41568.3, -1.69979, 536.148, \
0.0181252}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Number theory tells us that if ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\_n\)]],
  " is the nth zeta zero, then the average density of zeta zeros near ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\_n\)]],
  " is ln(",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\_n\)]],
  "/(2\[Pi]))/(2\[Pi]).  Below is a plot of the function ln(x/(2\[Pi]))/(2\
\[Pi])."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ZD = 
      Plot[Log[x/\((2*Pi)\)]/\((2*Pi)\), {x, 7, 80000}, 
        PlotStyle \[Rule] {Thickness[0.015]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 1.19048e-05 0.0147151 0.391276 [
[.2619 .00222 -15 -9 ]
[.2619 .00222 15 0 ]
[.5 .00222 -15 -9 ]
[.5 .00222 15 0 ]
[.7381 .00222 -15 -9 ]
[.7381 .00222 15 0 ]
[.97619 .00222 -15 -9 ]
[.97619 .00222 15 0 ]
[.01131 .09297 -18 -4.5 ]
[.01131 .09297 0 4.5 ]
[.01131 .17123 -18 -4.5 ]
[.01131 .17123 0 4.5 ]
[.01131 .24948 -18 -4.5 ]
[.01131 .24948 0 4.5 ]
[.01131 .32774 -18 -4.5 ]
[.01131 .32774 0 4.5 ]
[.01131 .40599 -6 -4.5 ]
[.01131 .40599 0 4.5 ]
[.01131 .48425 -18 -4.5 ]
[.01131 .48425 0 4.5 ]
[.01131 .5625 -18 -4.5 ]
[.01131 .5625 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(20000)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(40000)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(60000)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(80000)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.08333 .01472 m
.08333 .01847 L
s
.14286 .01472 m
.14286 .01847 L
s
.20238 .01472 m
.20238 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.44048 .01472 m
.44048 .01847 L
s
.55952 .01472 m
.55952 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.67857 .01472 m
.67857 .01847 L
s
.79762 .01472 m
.79762 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09297 m
.03006 .09297 L
s
[(0.2)] .01131 .09297 1 0 Mshowa
.02381 .17123 m
.03006 .17123 L
s
[(0.4)] .01131 .17123 1 0 Mshowa
.02381 .24948 m
.03006 .24948 L
s
[(0.6)] .01131 .24948 1 0 Mshowa
.02381 .32774 m
.03006 .32774 L
s
[(0.8)] .01131 .32774 1 0 Mshowa
.02381 .40599 m
.03006 .40599 L
s
[(1)] .01131 .40599 1 0 Mshowa
.02381 .48425 m
.03006 .48425 L
s
[(1.2)] .01131 .48425 1 0 Mshowa
.02381 .5625 m
.03006 .5625 L
s
[(1.4)] .01131 .5625 1 0 Mshowa
.125 Mabswid
.02381 .03428 m
.02756 .03428 L
s
.02381 .05384 m
.02756 .05384 L
s
.02381 .07341 m
.02756 .07341 L
s
.02381 .11253 m
.02756 .11253 L
s
.02381 .1321 m
.02756 .1321 L
s
.02381 .15166 m
.02756 .15166 L
s
.02381 .19079 m
.02756 .19079 L
s
.02381 .21035 m
.02756 .21035 L
s
.02381 .22992 m
.02756 .22992 L
s
.02381 .26904 m
.02756 .26904 L
s
.02381 .28861 m
.02756 .28861 L
s
.02381 .30817 m
.02756 .30817 L
s
.02381 .3473 m
.02756 .3473 L
s
.02381 .36686 m
.02756 .36686 L
s
.02381 .38643 m
.02756 .38643 L
s
.02381 .42556 m
.02756 .42556 L
s
.02381 .44512 m
.02756 .44512 L
s
.02381 .46468 m
.02756 .46468 L
s
.02381 .50381 m
.02756 .50381 L
s
.02381 .52337 m
.02756 .52337 L
s
.02381 .54294 m
.02756 .54294 L
s
.02381 .58207 m
.02756 .58207 L
s
.02381 .60163 m
.02756 .60163 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.015 w
.02389 .02147 m
.02507 .19052 L
.02614 .22882 L
.02737 .25531 L
.02854 .27295 L
.03062 .29561 L
.03287 .31342 L
.03535 .3285 L
.03798 .34128 L
.0427 .35918 L
.05213 .38441 L
.0575 .39521 L
.06252 .40387 L
.08282 .43012 L
.09422 .44112 L
.10466 .44973 L
.14436 .47461 L
.18255 .49174 L
.22319 .50594 L
.26232 .5171 L
.3039 .5271 L
.34396 .53543 L
.38251 .54251 L
.42351 .54925 L
.46299 .55512 L
.50096 .56028 L
.54138 .56534 L
.58029 .56986 L
.62164 .57432 L
.66149 .57834 L
.69981 .58197 L
.74059 .58562 L
.77985 .58894 L
.8176 .59198 L
.8578 .59505 L
.89648 .59788 L
.93762 .60074 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo000gooooo`Go00000oooool2
o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0001Oooooo0ol00003ooooo`;o00001?ooool2
o`0000Cooooo0_l00004ooooo`;o00005oooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2
o`0000Cooooo0_l0000Gooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2
o`0000?ooooo000hooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00005oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool04oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00005Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool003Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
000Dooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Eooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Eooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00>_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool04_ooool01?l0003o
ooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Gooooo1?l00003ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0001Kooooo0ol00003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo000gooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000Eooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00005Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Go
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo000gooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Fooooo`;o00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Fooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00005Oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Sooooo0ol00004oooo
o`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00006?ooool00ol0003oooooooooo`02oooo
o`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00006?ooool2o`0000Cooooo0_l00004oooo
o`;o00001?ooool2o`0000Cooooo0_l0000Gooooo`?o00001?ooool2o`0000Cooooo0_l00004oooo
o`;o00001?ooool2o`0000?ooooo000Dooooo`03o`000?oooooooooo0=Cooooo000Dooooo`03o`00
0?oooooooooo0=Cooooo000Dooooo`03o`000?oooooooooo0=Cooooo000?ooooom7o00002oooool0
01?ooooo0ol0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo000Cooooo`?o0000<?ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0=ooooo`004oooool3o`000=Gooooo000Cooooo`?o0000eOooool001?ooooo0ol0003E
ooooo`004oooool3o`000=Gooooo000Cooooo`?o0000eOooool001?ooooo0ol0003Eooooo`004ooo
ool3o`000=Gooooo000Cooooo`?o0000eOooool001?ooooo0ol0003Eooooo`004oooool3o`000=Go
oooo000Cooooo`?o0000eOooool000;ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go0000
0_ooool3o`000=Gooooo00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo
00000_ooool3o`000=Gooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o0000oooooooo
ool00_ooool3o`000=Gooooo00001Ooooooo0000oooooooooooo000000[ooooo00Co0000oooooooo
oooooooo0ol0003Eooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000000_ooool3o`000=Gooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000002ooooo`?o0000eOooool000;ooooo0_l00009ooooo`?o00000oooool3
o`000=Gooooo000Cooooo`?o0000eOooool001?ooooo0ol0003Eooooo`004oooool3o`000=Gooooo
000Cooooo`?o0000eOooool001?ooooo0ol0003Eooooo`004oooool3o`000=Gooooo000Cooooo`?o
0000eOooool001?ooooo0ol0003Eooooo`004oooool3o`000=Gooooo000Cooooo`?o0000eOooool0
00;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00002ooooo`?o0000eOooool00005
ooooool0003oooooooooool000002_ooool01?l0003oooooooooooooool3o`000=Gooooo00001Ooo
oooo0000oooooooooooo000000Oooooo1Ol00002ooooo`?o0000eOooool00005ooooool0003ooooo
ooooool000001oooool01?l0003oooooooooool00003ooooo`?o0000eOooool00005ooooool0003o
ooooooooool000002?ooool00ol0003oooooo`000003ooooo`?o0000eOooool00005ooooool0003o
ooooooooool000002Oooool2o`0000?ooooo0ol0003Eooooo`000_ooool2o`0000_ooooo00Co0000
oooooooooooooooo0ol0003Eooooo`004oooool3o`000=Gooooo000Cooooo`?o0000eOooool001?o
oooo0ol0003Eooooo`004oooool4o`000=Cooooo000Cooooo`Co0000e?ooool001Cooooo0ol0003D
ooooo`005?ooool3o`000=Cooooo000Dooooo`?o0000e?ooool001Cooooo0ol0003Dooooo`000_oo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0ol0003Dooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000000oooool3o`000=Cooooo
00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000003ooooo`?o
0000e?ooool00005ooooool0003oooooooooool000001oooool4o`0000Cooooo0ol0003Dooooo`00
00Goooooo`000?ooooooooooo`000007ooooo`03o`000?oooooooooo00Gooooo0ol0003Dooooo`00
00Goooooo`000?ooooooooooo`000008ooooo`03o`000?oooooooooo00Cooooo0ol0003Dooooo`00
0_ooool2o`0000[ooooo0_l00004ooooo`?o0000e?ooool001Cooooo0ol0003Dooooo`005?ooool3
o`000=Cooooo000Dooooo`Co0000doooool001Cooooo1?l0003Cooooo`005?ooool4o`000=?ooooo
000Dooooo`Co0000doooool001Cooooo1?l0003Cooooo`005?ooool4o`000=?ooooo000Dooooo`Co
0000doooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`Co0000
doooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000?o
oooo1Ol0003Booooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000000oooool5o`000=;ooooo00001Ooooooo0000oooooooooooo000000Sooooo0ol00004oooo
o`Go0000d_ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooool000000_l0003Booooo`0000Goooooo`000?ooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002o`000=;ooooo0002
ooooo`;o00002Oooool3o`0000Cooooo00?o0000ooooool000000_l0003Booooo`005?ooool6o`00
0=7ooooo000Dooooo`03o`000?oooooo000000?o0000dOooool001Cooooo00?o0000ooooooooool0
0ol0003Aooooo`005?ooool00ol0003oooooooooo`04o`000=3ooooo000Dooooo`;o000000?ooooo
o`000?l000000_l0003@ooooo`005?ooool01?l0003oooooooooooooool3o`000=3ooooo000Doooo
o`04o`000?ooooooooooooooo`Co0000coooool001Cooooo00Co0000oooooooooooooooo1?l0003?
ooooo`005?ooool2o`0000?ooooo1?l0003>ooooo`003Oooool3o`0000Cooooo00?o0000oooooooo
ool00_ooool4o`000<kooooo000>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool3o`000<kooooo000>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool4o`000<gooooo000>ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`Co0000cOooool0
00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`Co0000c?ooool000go
oooo0_l00005ooooo`03o`000?oooooooooo00Cooooo1Ol0003;ooooo`003_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo1Ol0003:ooooo`005?ooool2o`0000Oooooo1_l0
0038ooooo`005?ooool00ol0003oooooooooo`07ooooo`Ko0000aoooool001Cooooo00?o0000oooo
ooooool02?ooool6o`000<Kooooo000Dooooo`03o`000?oooooooooo00[ooooo1Ol00035ooooo`00
5?ooool2o`0000cooooo1_l00033ooooo`005?ooool00ol0003oooooooooo`0<ooooo`Ko0000`_oo
ool001Cooooo00?o0000ooooooooool03Oooool7o`000<3ooooo000Dooooo`03o`000?oooooooooo
00oooooo1ol0002nooooo`005?ooool2o`00017ooooo1ol0002mooooo`005?ooool00ol0003ooooo
ooooo`0Booooo`Oo0000^oooool00004ooooool0003o0000o`0000Cooooo00Co0000oooooooooooo
oooo1Ol00003ooooo`03o`000?oooooooooo01Cooooo1ol0002iooooo`000_ooool00ol0003ooooo
ooooo`08ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool05Oooool8o`000;Oo
oooo0002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool2o`0001Sooooo
2?l0002eooooo`000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool06Oooool9o`000;;ooooo0002ooooo`03o`000?oooooooooo00Oooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01_ooooo2_l0002_ooooo`0000?ooooo
o`000?l000002Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool07Ooo
ool;o`000:cooooo0002ooooo`03o`000?oooooooooo00Sooooo0ol00004ooooo`;o00008Oooool;
o`000:Wooooo000Dooooo`03o`000?oooooooooo02?ooooo3?l0002Uooooo`005?ooool00ol0003o
ooooooooo`0Vooooo`go0000XOooool001Cooooo00?o0000ooooooooool0:Oooool>o`0009gooooo
000Dooooo`;o0000;_ooool>o`0009Wooooo000Dooooo`03o`000?oooooooooo037ooooo3ol0002D
ooooo`005?ooool00ol0003oooooooooo`0eoooooa7o0000S_ooool001Cooooo00?o0000oooooooo
ool0>OoooolCo`0008Sooooo000Dooooo`;o0000?ooooolBo`0008Cooooo000Dooooo`03o`000?oo
oooooooo04Cooooo4ol0001mooooo`0000Coooooo`000?l0003o00001?ooool00ol0003ooooooooo
o`03ooooo`?o00000oooool00ol0003oooooooooo`1:oooooaGo0000MOooool000;ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04kooooo6Ol0001]
ooooo`000_ooool00ol0003oooooooooo`07ooooo`Go00000oooool00ol0003oooooooooo`1Eoooo
oa[o0000IOooool000;ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool00004oooo
o`;o0000G_oooolKo`0005cooooo0002ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool0
00001?ooool00ol0003oooooooooo`1Uoooooa_o0000E?ooool00003ooooool0003o000000_ooooo
0_l00004ooooo`03o`000?oooooooooo06gooooo6ol0001<ooooo`000_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M_oooolSo`0003_ooooo000D
ooooo`;o0000OooooolSo`0003?ooooo000Dooooo`03o`000?oooooooooo08Kooooo:ol0000Soooo
o`005?ooool00ol0003oooooooooo`2Gooooob;o00006oooool001Cooooo00?o0000ooooooooool0
WooooolWo`0000kooooo000Dooooo`;o0000/?oooolGo`0000kooooo000Dooooo`03o`000?oooooo
oooo0;Oooooo3ol0000>ooooo`005?ooool00ol0003oooooooooo`3Dooooo`005?ooool00ol0003o
ooooooooo`3Dooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-8308.61, -0.735655, 403.236, \
0.0122687}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The plot below compares the computed density of the zeta zeros to \
the theoretical prediction.  The agreement is nearly perfect.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[ZHist1, ZD, AspectRatio \[Rule] 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.000188698 1.33499e-05 0.0238095 0.633098 [
[.13331 -0.0125 -25.9062 -18 ]
[.13331 -0.0125 25.9062 0 ]
[.26681 -0.0125 -25.9062 -18 ]
[.26681 -0.0125 25.9062 0 ]
[.40031 -0.0125 -25.9062 -18 ]
[.40031 -0.0125 25.9062 0 ]
[.53381 -0.0125 -25.9062 -18 ]
[.53381 -0.0125 25.9062 0 ]
[.66731 -0.0125 -25.9062 -18 ]
[.66731 -0.0125 25.9062 0 ]
[.80081 -0.0125 -25.9062 -18 ]
[.80081 -0.0125 25.9062 0 ]
[.93431 -0.0125 -25.9062 -18 ]
[.93431 -0.0125 25.9062 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .02381 -13.5625 -9 ]
[-0.0125 .02381 0 9 ]
[-0.0125 .15043 -32.6875 -9 ]
[-0.0125 .15043 0 9 ]
[-0.0125 .27705 -32.6875 -9 ]
[-0.0125 .27705 0 9 ]
[-0.0125 .40367 -32.6875 -9 ]
[-0.0125 .40367 0 9 ]
[-0.0125 .53029 -32.6875 -9 ]
[-0.0125 .53029 0 9 ]
[-0.0125 .65691 -13.5625 -9 ]
[-0.0125 .65691 0 9 ]
[-0.0125 .78353 -32.6875 -9 ]
[-0.0125 .78353 0 9 ]
[-0.0125 .91015 -32.6875 -9 ]
[-0.0125 .91015 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -74.9375 -9 ]
[-0.01875 .5 -32.6875 9 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13331 0 m
.13331 .00625 L
s
gsave
.13331 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10000) show
1.000 setlinewidth
grestore
.26681 0 m
.26681 .00625 L
s
gsave
.26681 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20000) show
1.000 setlinewidth
grestore
.40031 0 m
.40031 .00625 L
s
gsave
.40031 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30000) show
1.000 setlinewidth
grestore
.53381 0 m
.53381 .00625 L
s
gsave
.53381 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40000) show
1.000 setlinewidth
grestore
.66731 0 m
.66731 .00625 L
s
gsave
.66731 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50000) show
1.000 setlinewidth
grestore
.80081 0 m
.80081 .00625 L
s
gsave
.80081 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60000) show
1.000 setlinewidth
grestore
.93431 0 m
.93431 .00625 L
s
gsave
.93431 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70000) show
1.000 setlinewidth
grestore
.125 Mabswid
.02651 0 m
.02651 .00375 L
s
.05321 0 m
.05321 .00375 L
s
.07991 0 m
.07991 .00375 L
s
.10661 0 m
.10661 .00375 L
s
.16001 0 m
.16001 .00375 L
s
.18671 0 m
.18671 .00375 L
s
.21341 0 m
.21341 .00375 L
s
.24011 0 m
.24011 .00375 L
s
.29351 0 m
.29351 .00375 L
s
.32021 0 m
.32021 .00375 L
s
.34691 0 m
.34691 .00375 L
s
.37361 0 m
.37361 .00375 L
s
.42701 0 m
.42701 .00375 L
s
.45371 0 m
.45371 .00375 L
s
.48041 0 m
.48041 .00375 L
s
.50711 0 m
.50711 .00375 L
s
.56051 0 m
.56051 .00375 L
s
.58721 0 m
.58721 .00375 L
s
.61391 0 m
.61391 .00375 L
s
.64061 0 m
.64061 .00375 L
s
.69401 0 m
.69401 .00375 L
s
.72071 0 m
.72071 .00375 L
s
.74741 0 m
.74741 .00375 L
s
.77411 0 m
.77411 .00375 L
s
.82751 0 m
.82751 .00375 L
s
.85421 0 m
.85421 .00375 L
s
.88091 0 m
.88091 .00375 L
s
.90761 0 m
.90761 .00375 L
s
.96101 0 m
.96101 .00375 L
s
.98771 0 m
.98771 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
72.562 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02381 m
.00625 .02381 L
s
gsave
-0.0125 .02381 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .15043 m
.00625 .15043 L
s
gsave
-0.0125 .15043 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .27705 m
.00625 .27705 L
s
gsave
-0.0125 .27705 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .40367 m
.00625 .40367 L
s
gsave
-0.0125 .40367 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .53029 m
.00625 .53029 L
s
gsave
-0.0125 .53029 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .65691 m
.00625 .65691 L
s
gsave
-0.0125 .65691 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .78353 m
.00625 .78353 L
s
gsave
-0.0125 .78353 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .91015 m
.00625 .91015 L
s
gsave
-0.0125 .91015 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05546 m
.00375 .05546 L
s
0 .08712 m
.00375 .08712 L
s
0 .11877 m
.00375 .11877 L
s
0 .18208 m
.00375 .18208 L
s
0 .21374 m
.00375 .21374 L
s
0 .24539 m
.00375 .24539 L
s
0 .3087 m
.00375 .3087 L
s
0 .34036 m
.00375 .34036 L
s
0 .37201 m
.00375 .37201 L
s
0 .43532 m
.00375 .43532 L
s
0 .46698 m
.00375 .46698 L
s
0 .49863 m
.00375 .49863 L
s
0 .56194 m
.00375 .56194 L
s
0 .5936 m
.00375 .5936 L
s
0 .62525 m
.00375 .62525 L
s
0 .68856 m
.00375 .68856 L
s
0 .72022 m
.00375 .72022 L
s
0 .75187 m
.00375 .75187 L
s
0 .81518 m
.00375 .81518 L
s
0 .84684 m
.00375 .84684 L
s
0 .87849 m
.00375 .87849 L
s
0 .9418 m
.00375 .9418 L
s
0 .97346 m
.00375 .97346 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.13331 .99375 m
.13331 1 L
s
.26681 .99375 m
.26681 1 L
s
.40031 .99375 m
.40031 1 L
s
.53381 .99375 m
.53381 1 L
s
.66731 .99375 m
.66731 1 L
s
.80081 .99375 m
.80081 1 L
s
.93431 .99375 m
.93431 1 L
s
.125 Mabswid
.02651 .99625 m
.02651 1 L
s
.05321 .99625 m
.05321 1 L
s
.07991 .99625 m
.07991 1 L
s
.10661 .99625 m
.10661 1 L
s
.16001 .99625 m
.16001 1 L
s
.18671 .99625 m
.18671 1 L
s
.21341 .99625 m
.21341 1 L
s
.24011 .99625 m
.24011 1 L
s
.29351 .99625 m
.29351 1 L
s
.32021 .99625 m
.32021 1 L
s
.34691 .99625 m
.34691 1 L
s
.37361 .99625 m
.37361 1 L
s
.42701 .99625 m
.42701 1 L
s
.45371 .99625 m
.45371 1 L
s
.48041 .99625 m
.48041 1 L
s
.50711 .99625 m
.50711 1 L
s
.56051 .99625 m
.56051 1 L
s
.58721 .99625 m
.58721 1 L
s
.61391 .99625 m
.61391 1 L
s
.64061 .99625 m
.64061 1 L
s
.69401 .99625 m
.69401 1 L
s
.72071 .99625 m
.72071 1 L
s
.74741 .99625 m
.74741 1 L
s
.77411 .99625 m
.77411 1 L
s
.82751 .99625 m
.82751 1 L
s
.85421 .99625 m
.85421 1 L
s
.88091 .99625 m
.88091 1 L
s
.90761 .99625 m
.90761 1 L
s
.96101 .99625 m
.96101 1 L
s
.98771 .99625 m
.98771 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .15043 m
1 .15043 L
s
.99375 .27705 m
1 .27705 L
s
.99375 .40367 m
1 .40367 L
s
.99375 .53029 m
1 .53029 L
s
.99375 .65691 m
1 .65691 L
s
.99375 .78353 m
1 .78353 L
s
.99375 .91015 m
1 .91015 L
s
.125 Mabswid
.99625 .05546 m
1 .05546 L
s
.99625 .08712 m
1 .08712 L
s
.99625 .11877 m
1 .11877 L
s
.99625 .18208 m
1 .18208 L
s
.99625 .21374 m
1 .21374 L
s
.99625 .24539 m
1 .24539 L
s
.99625 .3087 m
1 .3087 L
s
.99625 .34036 m
1 .34036 L
s
.99625 .37201 m
1 .37201 L
s
.99625 .43532 m
1 .43532 L
s
.99625 .46698 m
1 .46698 L
s
.99625 .49863 m
1 .49863 L
s
.99625 .56194 m
1 .56194 L
s
.99625 .5936 m
1 .5936 L
s
.99625 .62525 m
1 .62525 L
s
.99625 .68856 m
1 .68856 L
s
.99625 .72022 m
1 .72022 L
s
.99625 .75187 m
1 .75187 L
s
.99625 .81518 m
1 .81518 L
s
.99625 .84684 m
1 .84684 L
s
.99625 .87849 m
1 .87849 L
s
.99625 .9418 m
1 .9418 L
s
.99625 .97346 m
1 .97346 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .02381 m
1 .02381 L
s
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
0 .02381 m
0 .54741 L
.04 .54741 L
.04 .02381 L
F
0 g
.5 Mabswid
0 .02381 m
0 .54741 L
.04 .54741 L
.04 .02381 L
0 .02381 L
s
1 0 0 r
.04 .02381 m
.04 .68454 L
.08 .68454 L
.08 .02381 L
F
0 g
.04 .02381 m
.04 .68454 L
.08 .68454 L
.08 .02381 L
.04 .02381 L
s
1 0 0 r
.08 .02381 m
.08 .73715 L
.12 .73715 L
.12 .02381 L
F
0 g
.08 .02381 m
.08 .73715 L
.12 .73715 L
.12 .02381 L
.08 .02381 L
s
1 0 0 r
.12 .02381 m
.12 .77138 L
.16 .77138 L
.16 .02381 L
F
0 g
.12 .02381 m
.12 .77138 L
.16 .77138 L
.16 .02381 L
.12 .02381 L
s
1 0 0 r
.16 .02381 m
.16 .79653 L
.2 .79653 L
.2 .02381 L
F
0 g
.16 .02381 m
.16 .79653 L
.2 .79653 L
.2 .02381 L
.16 .02381 L
s
1 0 0 r
.2 .02381 m
.2 .81702 L
.24 .81702 L
.24 .02381 L
F
0 g
.2 .02381 m
.2 .81702 L
.24 .81702 L
.24 .02381 L
.2 .02381 L
s
1 0 0 r
.24 .02381 m
.24 .83393 L
.28 .83393 L
.28 .02381 L
F
0 g
.24 .02381 m
.24 .83393 L
.28 .83393 L
.28 .02381 L
.24 .02381 L
s
1 0 0 r
.28 .02381 m
.28 .84829 L
.32 .84829 L
.32 .02381 L
F
0 g
.28 .02381 m
.28 .84829 L
.32 .84829 L
.32 .02381 L
.28 .02381 L
s
1 0 0 r
.32 .02381 m
.32 .86076 L
.36 .86076 L
.36 .02381 L
F
0 g
.32 .02381 m
.32 .86076 L
.36 .86076 L
.36 .02381 L
.32 .02381 L
s
1 0 0 r
.36 .02381 m
.36 .87196 L
.4 .87196 L
.4 .02381 L
F
0 g
.36 .02381 m
.36 .87196 L
.4 .87196 L
.4 .02381 L
.36 .02381 L
s
1 0 0 r
.4 .02381 m
.4 .88231 L
.44 .88231 L
.44 .02381 L
F
0 g
.4 .02381 m
.4 .88231 L
.44 .88231 L
.44 .02381 L
.4 .02381 L
s
1 0 0 r
.44 .02381 m
.44 .89119 L
.48 .89119 L
.48 .02381 L
F
0 g
.44 .02381 m
.44 .89119 L
.48 .89119 L
.48 .02381 L
.44 .02381 L
s
1 0 0 r
.48 .02381 m
.48 .89985 L
.52 .89985 L
.52 .02381 L
F
0 g
.48 .02381 m
.48 .89985 L
.52 .89985 L
.52 .02381 L
.48 .02381 L
s
1 0 0 r
.52 .02381 m
.52 .90746 L
.56 .90746 L
.56 .02381 L
F
0 g
.52 .02381 m
.52 .90746 L
.56 .90746 L
.56 .02381 L
.52 .02381 L
s
1 0 0 r
.56 .02381 m
.56 .91485 L
.6 .91485 L
.6 .02381 L
F
0 g
.56 .02381 m
.56 .91485 L
.6 .91485 L
.6 .02381 L
.56 .02381 L
s
1 0 0 r
.6 .02381 m
.6 .92119 L
.64 .92119 L
.64 .02381 L
F
0 g
.6 .02381 m
.6 .92119 L
.64 .92119 L
.64 .02381 L
.6 .02381 L
s
1 0 0 r
.64 .02381 m
.64 .92795 L
.68 .92795 L
.68 .02381 L
F
0 g
.64 .02381 m
.64 .92795 L
.68 .92795 L
.68 .02381 L
.64 .02381 L
s
1 0 0 r
.68 .02381 m
.68 .93345 L
.72 .93345 L
.72 .02381 L
F
0 g
.68 .02381 m
.68 .93345 L
.72 .93345 L
.72 .02381 L
.68 .02381 L
s
1 0 0 r
.72 .02381 m
.72 .93936 L
.76 .93936 L
.76 .02381 L
F
0 g
.72 .02381 m
.72 .93936 L
.76 .93936 L
.76 .02381 L
.72 .02381 L
s
1 0 0 r
.76 .02381 m
.76 .94443 L
.8 .94443 L
.8 .02381 L
F
0 g
.76 .02381 m
.76 .94443 L
.8 .94443 L
.8 .02381 L
.76 .02381 L
s
1 0 0 r
.8 .02381 m
.8 .94972 L
.84 .94972 L
.84 .02381 L
F
0 g
.8 .02381 m
.8 .94972 L
.84 .94972 L
.84 .02381 L
.8 .02381 L
s
1 0 0 r
.84 .02381 m
.84 .95415 L
.88 .95415 L
.88 .02381 L
F
0 g
.84 .02381 m
.84 .95415 L
.88 .95415 L
.88 .02381 L
.84 .02381 L
s
1 0 0 r
.88 .02381 m
.88 .95901 L
.92 .95901 L
.92 .02381 L
F
0 g
.88 .02381 m
.88 .95901 L
.92 .95901 L
.92 .02381 L
.88 .02381 L
s
1 0 0 r
.92 .02381 m
.92 .96345 L
.96 .96345 L
.96 .02381 L
F
0 g
.92 .02381 m
.92 .96345 L
.96 .96345 L
.96 .02381 L
.92 .02381 L
s
1 0 0 r
.96 .02381 m
.96 .96747 L
1 .96747 L
1 .02381 L
F
0 g
.96 .02381 m
.96 .96747 L
1 .96747 L
1 .02381 L
.96 .02381 L
s
.015 w
0 .0545 m
.00122 .30827 L
.00242 .37024 L
.00381 .4131 L
.00512 .44165 L
.00744 .47831 L
.00997 .50712 L
.01275 .53152 L
.0157 .55221 L
.02099 .58117 L
.03157 .62199 L
.03759 .63947 L
.04323 .65348 L
.06599 .69595 L
.07877 .71375 L
.09047 .72767 L
.135 .76793 L
.17782 .79566 L
.2234 .81863 L
.26727 .83668 L
.3139 .85287 L
.35883 .86634 L
.40205 .8778 L
.44803 .8887 L
.49231 .8982 L
.53489 .90655 L
.58021 .91474 L
.62384 .92205 L
.67022 .92927 L
.7149 .93577 L
.75788 .94165 L
.80361 .94755 L
.84763 .95293 L
.88996 .95784 L
.93504 .96282 L
.97842 .96738 L
s
.97842 .96738 m
1 .96955 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00TOooool00olQ8B7o0000
olc<c01Gooooo`00TOooool00ol0003o^[Zjob4Q8@1Gooooo`00TOooool00om4A4Coc<c<o`00001G
ooooo`00TOooool00onHV9SoMgMgo`00001Gooooo`00T_ooool00olb<S;oA4A4ooooo`1Fooooo`00
T_ooool00olQ8B7o<S8bolc<c01Fooooo`00TOooool01OmVIVKoZJVYonk^k_lQ8B7ok^k^05Gooooo
002?ooooo`03onk^k_mVIVKoV9RH00;ooooo00?oc<c<oc8b<_o^k^h0E?ooool008kooooo0_mVIVH0
0oo<c<coooooooooo`02ooooo`03olc<c?mEEEGooooo05?ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool004[o
oooo1?l000000ol@413oooooooooo`04ooooo`04oiRHV?l0003o0000oiRHV0;ooooo1ol000000onH
V9Soooooooooo`02ooooo`03oiRHV?l0003o000000;o000000GoV9RHooooooooooooZJVYob4Q8@05
o`000005oiRHV?oooooooooooooooonHV9P00ol000000onHV9Soooooooooo`03ooooo`05oiRHV?l0
003o0000o`000?nHV9P01?ooool01OnHV9So0000o`000?l0003oV9RH00;ooooo00?oV9RHoa0@4?l0
00001?l000001OnHV9SoooooooooooooooooV9RH00Co000000GoV9RHooooooooooook^k^oeEEE@05
o`000005oiRHV?oooooooooooooooonHV9P00ol000000onHV9Soooooooooo`03ooooo`Co000000?o
V9RHooooooooool00_ooool01OnHV9So0000o`000?l0003oV9RH00Gooooo00GoV9RHo`000?l0003o
0000oiRHV005ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00CoV9RHo`000?l0003oV9RH1?ooool0
04cooooo00?o0000ooooooooool01Oooool04?nj^[[o8B4QomgMgOoMgMgo8B4QokZj^_ooooooV9RH
o`000?oMgMgo^[Zjob4Q8Ol>3PkogMgMob4Q8Onj^[X2ooooo`0JokZj^_lQ8B7oXJ6Qoa`L7?lM7Ago
XZ:Rob4Q8Onj^[[ooooooa0@4?nDU9Co8B4Qoj6QXOl=3@go2`/;oj:RX_lQ8B7o^[Zjoooooonj^[[o
61PHoa`L7?oMgMgo7AdMoaPH6?nj^[X3ooooo`07okZj^_lH61So71`Lo`000?lM7Ago61PHokZj^P02
ooooo`0/okZj^_lH61So71`LomgMgOlM7Ago61PHokZj^_oooooo410@ohN7Qonj^[[o61PHo`d=3OmH
F5So7AdMoaPH6?nj^[[ooooookZj^_lQ8B7oXJ6Qoa`L7?lM7AgoXZ:Rob4Q8Onj^[[oooooogMgMomF
EUKo8B4Qoj6QXOl=3@go2@T9oj:RX_lQ8B7o^[Zjoooooonj^[[o61PHoa`L7?oMgMgo7AdMoaPH6?nj
^[X3ooooo`07okZj^_l820So2@T9omgMgOlM7Ago61PHokZj^P02ooooo`07okZj^_lH61So71`LomgM
gOlM7Ago61PHokZj^P03ooooo`07okZj^_lH61So71`LomgMgOlM7Ago61PHokZj^P03ooooo`06okZj
^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^P?ooooo001<
ooooo`03o`000?oooooooooo00Gooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@2ooooo`04ohN7
QolQ8B7o?clooiRHV0;ooooo00OoV9RHodA4A?ooooooooooodA4A?nHV9SoA4A400;oV9RH00?oA4A4
oiRHV?m4A4@00_ooool04?m4A4CoV9RHodA4A?nHV9So0000odA4A?nHV9SoA4A4oooooom4A4Co:2PX
oiRHV?ooooooV9RHobPX:?m4A4@2ooooo`Ko000000_o:2PXodA4A?ooooooooooodA4A?lX:2SoV9RH
oooooonHV9So:2PXodA4A003ooooo`0;odA4A?lX:2SoV9RHo`000?nHV9So:2PXodA4A?ooooooA4A4
oiRHV?m4A4@00_nHV9P05Om4A4CoV9RHodA4A?oooooo8B4QodA4A?nHV9SoA4A4oiRHV?l0003oA4A4
oiRHV?m4A4CoooooodA4A?lX:2SoV9RHoooooonHV9So:2PXodA4A003ooooo`07odA4A?lJ6Q[o0000
oooooonHV9So:2PXodA4A002ooooo`07odA4A?lX:2SoV9RHoooooonHV9So:2PXodA4A003ooooo`07
odA4A?lX:2SoV9RHoooooonHV9So:2PXodA4A003ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A4
1?ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0?ooooo001<ooooo`03o`000?oooooooooo00Go
oooo00Ko0000onk^k_ooooooooooonk^k_l00003ooooo`03ojVYZOl0003ok^k^00;ooooo00Ook^k^
o`000?ooooooooooo`000?o^k^ko000000;ok^k^00?o0000onk^k_l000000_ooool01?l0003ok^k^
o`000?o^k^h2o`000003onk^k_l0003ooooo00;o000000?ok^k^ooooooo^k^h00_l00002ooooo`06
odA4A?l0003o0000onk^k_l0003ok^k^0_l00002ooooo`;o000000?ok^k^ooooooo^k^h00_l00003
ooooo`;o000000?ok^k^o`000?o^k^h00_l000001?oooooo0000onk^k_l00002onk^kP04o`000?o^
k^ko0000ooooo`;o000000?ok^k^o`000?o^k^h00_l000000oo^k^ko0000ooooo`02o`000003onk^
k_ooooook^k^00;o00000oooool3o`000004olc<c?o^k^ko0000o`0000;ooooo0_l000000oo^k^ko
ooooonk^kP02o`0000?ooooo0_l000000oo^k^koooooonk^kP02o`0000?ooooo00Ko0000onk^k_oo
ooooooooonk^k_l00004ooooo`06o`000?o^k^koooooooooooo^k^ko00000oooool004cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000oc8b<_ooool00_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooool0
00000_ooool02Ol0003oooooo`000?nYZJWoA4A4o`000?oooooo0000ooooo`02o`0000?ooooo0_l0
0002ooooo`06omgMgOl0003o0000ooooool0003ooooo0_l00002ooooo`;o00000oooool2o`000003
ooooool@413oV9RH00;o000000?oMgMgofIVI_ooool00_l000001?oooooo0000ooooool00002oooo
o`04o`000?oooooo0000ooooo`;o000000Sok^k^o`000?mgMgOoEEEEo`000?oooooo0000ooooo`;o
00000oooool2o`0000?ooooo0_l000000omEEEGoIVIVooooo`02o`0000;ooooo0_l00003ooooo`;o
00000oooool2o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo007ooooo001<ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?m4A4CoMgMg00;ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooo0000
00;ooooo00Wo0000ob4Q8Ol0003o0000omgMgOl0003oooooo`000?ooool00_l00003ooooo`;o0000
0oooool2o`000003ooooool0003ooooo00;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000
ob4Q8@02o`000003ofIVI_oooooooooo00;o000000Coooooo`000?oooooo00000_ooool01?l0003o
ooooo`000?ooool4o`000006oeEEEOo^k^ko0000ooooool0003ooooo0_l00003ooooo`;o00000ooo
ool2o`000003ojVYZOl@413ooooo00;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o00000ooo
ool2o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00Oooool004cooooo00?o0000ooooooooool01Oooool0
1_l0003ok^k^ooooooooooook^k^o`0000Cooooo00Ko0000olk>c_l@413oooooonk^k_l00002oooo
o`03o`000?o^k^ko000000;ok^k^00?o0000onk^k_l000000_ooool02Ol0003ok^k^o`000?nNWYko
;bl_o`000?o^k^ko0000ooooo`02o`000003onk^k_ooooook^k^00;o00000oooool2o`000003onk^
k_l0003ok^k^00;o00000_ooool2o`000003onk^k_ooooook^k^00;o000000?oooooo`000?ooool0
0_l000000oo^k^koooooonk^kP02o`000004ooooool0003ok^k^o`0000;ok^k^00So0000onk^k_l0
003oooooodA4A?l0003ok^k^o`0000;ok^k^00Co0000onk^k_l0003ooooo0_l000000oo^k^kooooo
onk^kP02o`0000?ooooo0_l000000oo^k^ko0000olk>cP02o`0000;ooooo0_l000000oo^k^kooooo
onk^kP02o`0000?ooooo0_l000000oo^k^koooooonk^kP02o`0000?ooooo00Ko0000onk^k_oooooo
ooooonk^k_l00004ooooo`06o`000?o^k^koooooooooooo^k^ko00000oooool004cooooo00?o0000
ooooooooool01Oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo00KoA4A4oiRHV?l0003o
oooooiRHV?m4A4@2ooooo`03odA4A?nHV9SoA4A400;oV9RH00?oA4A4oiRHV?m4A4@00_ooool04?m4
A4CoV9RHodA4A?nHV9So0000odA4A?nHV9SoA4A4oooooom4A4Co:2PXoiRHV?ooooooV9RHobPX:?m4
A4@3ooooo`07odA4A?lB4Q;oV9RHo`000?nHV9So:2PXodA4A002ooooo`0EodA4A?lX:2SoV9RHoooo
oonHV9So:2PXodA4A?oooooo0000oooooom4A4Co:2PXoiRHV?ooooooV9RHobPX:?m4A4CoooooodA4
A?nHV9SoA4A400;oV9RH00SoA4A4oiRHV?m4A4CooooookZj^_l92@WoV9RHodA4A0;oV9RH00_oA4A4
oiRHV?m4A4CoooooodA4A?lX:2SoV9RHoooooonHV9So:2PXodA4A003ooooo`07odA4A?lX:2SoV9RH
oeEEEOmADE7o:2PXodA4A002ooooo`07odA4A?lX:2SoV9RHoooooonHV9So:2PXodA4A003ooooo`07
odA4A?lX:2SoV9RHoooooonHV9So:2PXodA4A003ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A4
1?ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0?ooooo001:ooooo`03o`000?m4A4Co000000Oo
oooo013o^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[[oooooo`000?n7QhOok^k^okZj^_lC4a?oBDU9omgM
gOlQ8B7o^[Zj0_ooool06_nj^[[o8B4Qoj6QXOlL71co7AdMoj:RX_lQ8B7o^[ZjoooooolQ8B7o^[Zj
ob4Q8OnQXJ7o2`/;o`D51OnRXZ;o8B4QokZj^_oooooo^[ZjoaPH6?lL71cogMgMoadM7OlH61So^[Zj
0oooool01onj^[[o5QHFo`D51Ol0003o7AdMoaPH6?nj^[X00_ooool06_nj^[[o61PHoa`L7?oMgMgo
7AdMoaPH6?nj^[[oooooo`000?oooooo^[ZjoaPH6?lL71cogMgMoadM7OlH61So^[Zjoooooonj^[[o
8B4Qoj6QXOlL71co7AdMoj:RX_lQ8B7o^[Zj0_ooool04?ln?Sko1PH6oh^;RolL71co7AdMoj:RX_lQ
8B7o^[Zjoooooonj^[[o61PHoa`L7?oMgMgo7AdMoaPH6?nj^[X2ooooo`08oa0@4?nj^[[o61PHoa`L
7?nCTi?o1@D5oaPH6?nj^[X2ooooo`07okZj^_lH61So71`LomgMgOlM7Ago61PHokZj^P03ooooo`07
okZj^_lH61So71`LomgMgOlM7Ago61PHokZj^P03ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj
1?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^P?ooooo001:ooooo`03olc<c?mEEEGo000000So
oooo00CoV9RHo`000?l0003oV9RH0_ooool01OnYZJWo<S8bo`000?l0003o<S8b00;o000000?oV9RH
ooooooooool00_ooool00onHV9So0000o`000002o`000005oiRHV?oooooooooookZj^_m4A4@01Ol0
00001OnHV9SoooooooooooooooooV9RH00?o000000?oV9RHooooooooool00oooool01OnHV9So0000
o`000?l0003oV9RH00Cooooo00GoV9RHo`000?l0003o0000oiRHV002ooooo`Oo000000GoV9RHoooo
oooooooooooooiRHV004o`000003oiRHV?oooooooooo00;ooooo00?oV9RHo`000?l000000_l00000
1OnHV9SoooooooooooooooooV9RH00?o000000CoV9RHoooooooooooooooo1_l000000onHV9Sooooo
ooooo`02ooooo`05oiRHV?l0003o0000o`000?nHV9P01Oooool01OnHV9So0000o`000?l0003oV9RH
00Gooooo00CoV9RHo`000?l0003oV9RH1_ooool01?nHV9So0000o`000?nHV9P4ooooo`00joooool0
0>_ooooo003[ooooo`00joooool004?ooooo00CoV9RHo`000?l0003oV9RH1_oooon=o`00017ooooo
0012ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool00ol0003oooooooooo`29ooooo`03
o`000?oooooooooo00oooooo0012ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00ol0
003oooooooooo`29ooooo`03o`000?oooooooooo00oooooo0012ooooo`06o`000?o^k^kooooooooo
ooo^k^ko00001Ooooon=o`00017ooooo0012ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo0012ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo00oooooo0012ooooo`06o`000?o^k^koooooooooooo^k^ko00001Oooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo00oooooo0012ooooo`06odA4A?nHV9Sooooooooo
oonHV9SoA4A41Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo0012oooo
o`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool00ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
oooooooo00oooooo0013ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`0?ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooo
oooo00oooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool004go
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00COooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oooooooooo00oooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ooooooooool03oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?
ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo001=ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool0033ooooo00CoV9RHo`000?l0003o
V9RH1_ooool00omEEEGo0000oeEEE@05ooooo`Ko00001Oooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo00oooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`00
00Gooooo00?oV9RHo`000?oMgMd00_ooool00ol@413oooooooooo`03ooooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ooooooooool03oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5
ooooo`03oeEEEOl0003oEEEE00Kooooo00?oQhN7ob4Q8Oo^k^h01oooool00ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo00oooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00003ooo
ool00onYZJWo8B4Qonk^kP06ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03ooo
ool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03oiRHV?lb<S;o
oooo00Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00;oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?oA4A4ogMgMoooool01?ooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo00oooooo000_ooooo`06o`000?o^k^kooooooooo
ooo^k^ko00004Oooool00ooMgMgo410@ooooo`04ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool03oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@Booooo`03o`000?oo
oooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00;oooool0
1_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pgooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED5oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool0033ooooo00CoV9RHo`000?l0
003oV9RH3_ooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kPGooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`0?ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooo
oooo00oooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool004go
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00COooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oooooooooo00oooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ooooooooool03oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?
ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo000`ooooo`04
oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED02Oooool2o`000003oa0@4?oooooooooo
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00;oooool01_nj^[[o
8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00;oooool01_m4A4CoV9RHoooooooooooo
V9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool6o`0000Cooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`0?ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo
00GoA4A4okZj^_ooooooooooo`000005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool03oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`05omgM
gOlQ8B7oooooooooool000001Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oo
oooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01?mgMgOoV9RH
ooooool00005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool002oooooo
00Ko0000onk^k_ooooooooooonk^k_l0000?ooooo`04onk^k_lQ8B7oooooo`0000Gooooo00?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00;oooool01_m4A4CoV9RHoooooooooooo
V9RHodA4A13ooooo00?oMgMgoiRHV?l000001Oooool00ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
oooooooo00oooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj4?ooool00oo^k^ko<S8b
o`000005ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool0033ooooo00Co
V9RHo`000?l0003oV9RH4_ooool00onHV9So410@ooooo`04ooooo`03o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ooooooooool03oooool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`0?ooooo`00COooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo001=oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool004gooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`0?ooooo`00COooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo00oooooo001=ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03ooo
ool004gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00COooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo00oooooo000`ooooo`04oiRHV?l0003o0000oiRH
V0Kooooo00?oEEEEo`000?mEEED01_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPCooooo00?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00;oooool01_nj^[[o8B4QomgMgOoM
gMgo8B4QokZj^PGooooo0ol00006ooooo`;oMgMg0_ooool00omgMgOoEEEEooooo`03ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool03oooool002oooooo00KoA4A4oiRHV?oooooooooo
oiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?o8B4Qooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`;o00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00;oooool01_l0003ok^k^
ooooooooooook^k^o`0000kooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`02oooo
o`;o00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`0?ooooo`00;oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00cooooo00Ko0000oeEEEOo^k^koooooogMgMomEEED4ooooo`;o00001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`0?ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00cooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^h4ooooo`;o00001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`0?ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00?oA4A4oiRHV?ooool0
1oooool2o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool03oooool002oooooo00KoA4A4oiRHV?oooooooooo
oiRHV?m4A4@>ooooo`03okZj^_lQ8B7ooooo00Oooooo0_l00004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oo
oooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3oooool00omEEEGo<S8bomgMg@06oooo
o`;o00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`0?ooooo`00<?ooool01?nHV9So0000o`000?nHV9PAoooo
o`04oiRHV?lQ8B7o0000ob4Q8@Cooooo0_l00004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo000@oooo
o`03okZj^_lb<S;ooooo00kooooo00?o<S8bokZj^_ooool0:Oooool2o`0000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool03oooool000?ooooo00?o0000ooooooooool02_ooool00olb<S;o^[Zjooooo`05ooooo`03
ob4Q8Ol0003oc<c<00Kooooo00?o^[Zjoc8b<_ooool0:Oooool2o`0000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool03oooool000?ooooo00?o<S8bokZj^_ooool02Oooool00oo<c<co<S8booooo`06ooooo`03o`00
0?nj^[[o8B4Q00Oooooo00?o<S8bolc<c?ooool0:?ooool2o`0000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0
3oooool000?ooooo00?oMgMgohN7QomgMgL00_l000000om4A4Coc<c<ooooo`04ooooo`03ofIVI_nY
ZJWooooo00Kooooo00?oA4A4olc<c?l000001oooool00onHV9SoIVIVooooo`0Xooooo`;o00001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`0?ooooo`000oooool02?nHV9So410@ohN7Qoo^k^kooooooiRHV?l@413o
c<c<1?ooool00olb<S;oooooooooo`06ooooo`03oiRHV?mgMgOo000000Oooooo00?ok^k^oc8b<_oo
ool0:?ooool2o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool000?ooooo00?o^[Zjoc8b<_ooool0
0oooool00onHV9SoA4A4ooooo`03ooooo`03oc8b<_oooooooooo00Oooooo00?o<S8bodA4A?ooool0
1oooool00ol0003oooooooooo`0Wooooo`;o00001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`001?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o<S8booooooooool01ooo
ool00olQ8B7o<S8bolc<c007ooooo`03o`000?oooooooooo02Oooooo0_l00004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
oooooooo00oooooo0004ooooo`03odA4A?nHV9Sooooo00;ooooo00?ok^k^o`000?ooool00oooool0
0olQ8B7oooooooooo`06ooooo`05ofIVI_nYZJWok^k^ob4Q8Oo^k^h01_ooool00ol0003ooooooooo
o`0Wooooo`;o00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`001?ooool01onj^[[o0000okZj^_oo
ooook^k^ofIVI_mEEED01?ooool00olb<S;ok^k^ooooo`04ooooo`03onk^k_mVIVKoV9RH00;ooooo
00?oc<c<oc8b<_o^k^h01?ooool00ooMgMgo<S8booooo`0;ooooo`04oiRHV?l0003o0000oiRHV0Ko
oooo00?oEEEEo`000?mEEED01_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPCooooo0_l00004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo00oooooo0005ooooo`06ojVYZOlQ8B7o0000o`000?mEEEGok^k^1?oo
ool00omVIVKoV9RHooooo`03ooooo`;oIVIV00?oc<c<ooooooooool00_ooool00oo<c<coEEEEoooo
o`03ooooo`03oiRHV?mVIVKooooo00[ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o
00001_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Cooooo0_l00004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooo
oooo00oooooo000?ooooo`03omgMgOlQ8B7ooooo013ooooo00?o410@olc<c?ooool02_ooool01_m4
A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo0ol00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo000@
ooooo`03oc8b<_nj^[[ooooo00kooooo00?o^[Zjoc8b<_ooool02oooool01_l0003ok^k^oooooooo
ooook^k^o`0000kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`?o0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`0?ooooo`004?ooool00onj^[[o<S8booooo`0>ooooo`03oc8b<_nj
^[[ooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`06oeEEEOmg
MgOooooooooooomgMgOoEEEE1?ooool3o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool002oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03omgMgOl0003o000000;o0000
00?ogMgMooooooooool00_ooool7o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oooooooooo00oooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko
00003_ooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<PCooooo0ol00003ooooo`03o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooo
oooo00oooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A43_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo000_
ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b
<PCooooo0ol00003ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo00oooooo000`ooooo`04oiRHV?l0003o0000oiRH
V0oooooo00Kok^k^odA4A?l0003o0000odA4A?o^k^h4ooooo`Co00000_ooool00ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`0?ooooo`00COooool01?l0003oooooo`000?l00002ooooo`03o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo001=
ooooo`Co00000_ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00COooool01?l0003oooooo`000?l00002
ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooo000000;o000000?oooooo`00
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool03oooool004gooooo00?o0000ooooooooool00_l000000ooooooo0000ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00
COooool00ol0003oooooooooo`02o`000003ooooool0003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo001=ooooo`;o000000Go
ooooo`000?l0003oooooo`000004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`0?ooooo`00@_ooool4o`000003oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool01?l00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`0?ooooo`00A?ooool00ol0003oooooooooo`06ooooo`04o`000?oooooo
ooooooooo`?o00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ooooooooool03oooool004Cooooo00?o0000ooooooooool01_ooool01?l0003ooooooooooooo
ool3o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
oooooooo00oooooo0014ooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`?o00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool0
04Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`;o00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool004Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`?o00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool004Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`;o00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool004Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`Ko00001Ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo00oooooo0012ooooo`03o`000?m4A4Co000000Sooooo0_l00005
ooooo`;o00000_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool03oooool004;ooooo00?oc<c<oeEEEOl000002?ooool00ol0003oooooooooo`04oooo
o`?o000000?oooooo`000?oo00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
00oooooo001=ooooo`03o`000?oooooooooo00Gooooo1?l00005ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ooooooooool03oooool004gooooo00?o0000ooooooooool01_ooool3o`0000Goo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00COooool2o`0000Sooooo0ol0
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool004gooooo00?o0000
ooooooooool02?ooool3o`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?
ooooo`00COooool00ol0003oooooooooo`08ooooo`Co00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo00Sooooo1ol00004ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo00_ooooo1?l00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo00oooooo001=ooooo`;o00003Oooool3o`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03ooo
ool002oooooo1?l000000ol@413oooooooooo`04ooooo`03oeEEEOl0003oEEEE00Gooooo1_l00005
ooooo`03o`000?oooooooooo00gooooo0ol00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo000aoooo
o`03o`000?oooooooooo00Kooooo0ol00005ooooo`03oiRHV?l0003ogMgM00;ooooo00?o410@oooo
ooooool00oooool00ol0003oooooooooo`0>ooooo`Ko00001Ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool0037ooooo00?o0000oooooooo
ool01_ooool00omEEEGo0000oeEEE@06ooooo`03ohN7QolQ8B7ok^k^00Oooooo00?o0000oooooooo
ool03oooool5o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo00oooooo000aooooo`03o`000?oooooooooo013ooooo00?oZJVYob4Q8Oo^k^h0
1_ooool2o`0001;ooooo1?l00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`0?ooooo`00<Oooool00ol0003oooooooooo`0Aooooo`03oiRHV?lb
<S;ooooo00Gooooo00?o0000ooooooooool04_ooool4o`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo000aooooo`03o`000?oooooo
oooo01;ooooo00?oA4A4ogMgMoooool01?ooool00ol0003oooooooooo`0Cooooo`Oo00001Ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oooooooooo00oooooo000aooooo`03o`000?oooooooooo
01;ooooo00?ogMgMoa0@4?ooool01?ooool00ol0003oooooooooo`0Eooooo`Go00001Ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo00oooooo000aooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool00oooool2o`0001Sooooo1Ol00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o
o`0000?o0000ooooooooool03oooool002oooooo00?o0000odA4A?l000004?ooool01_l0003oQhN7
onk^k_ooooooV9RHoeEEE@Gooooo00?o0000ooooooooool06Oooool7o`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool03oooool002oooooo00?oc<c<oeEEEOl000004?ooool01_nYZJWo<S8bo`000?l0003oEEEE
onk^kPGooooo00?o0000ooooooooool06oooool7o`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool0
04gooooo00?o0000ooooooooool07_ooool7o`0000Goo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo027o
oooo1_l00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`0?ooooo`00COooool2o`0002Cooooo2?l00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ooooooooool03oooool004gooooo00?o0000ooooooooool09_ooool6o`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`0X
ooooo`So00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`0[oooo
o`_o00001Ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool03oooool004gooooo0_l0000_ooooo`[o00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000?oo`0000?o0000ooooooooool03oooool004gooooo00?o0000ooooooooool0
<_ooool:o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00;ooo
ool4o`000003oa0@4?oooooooooo00Cooooo00?oEEEEo`000?mEEED02Oooool2o`000003oa0@4?oo
oooooooo00;ooooo00?o0000ooooooooool0=oooool:o`0000Goo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool03ooo
ool0037ooooo00?o0000ooooooooool01_ooool3o`0000[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0jooooo`go00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000?oo`0000?o0000ooooooooool03oooool0037ooooo00?o0000ooooooooool01_ooool00omE
EEGo0000oeEEE@06ooooo`Ko00001?ooool00ol0003oooooooooo`0oooooo`go00001Ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo00oooooo000aooooo`03o`000?oooooooooo00oo
oooo00GoA4A4okZj^_ooooooooooo`000005ooooo`;o0000A_ooool=o`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool03oooool0037ooooo00?o0000ooooooooool03oooool01OoMgMgo8B4Qoooooooooooo0000
00Gooooo00?o0000ooooooooool0Boooool>o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo00oooooo000aooooo`03o`000?oooooooooo013o
oooo00CoMgMgoiRHV?oooooo00001Oooool00ol0003oooooooooo`1Aooooo`ko00000ooo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo00oooooo000aooooo`03o`000?oooooooooo013o
oooo00Cok^k^ob4Q8Ooooooo00001Oooool00ol0003oooooooooo`1Hooooo`go00000_oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`0?ooooo`00<Oooool00ol0003oooooooooo`0Aooooo`03ogMgMonHV9So000000Go
oooo0_l0001Ooooooa3o00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00oo
oooo000_ooooo`03o`000?m4A4Co000001?ooooo00?ok^k^oc8b<_l000001Oooool00ol0003ooooo
ooooo`1Tooooo`oo00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00;oooool00oo<c<coEEEEo`00
000Dooooo`03oiRHV?l@413ooooo00Cooooo00?o0000ooooooooool0J_oooolEo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`1`
oooooaCo00001Ooo00000ol0003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`1moooo
o`go00004Oooool004gooooo0_l00024ooooo`Oo00004Oooool004gooooo00?o0000ooooooooool0
ROooool00ol0003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool03oooool004goooooSOl0000Aooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00001\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-41568.3, -0.783963, 536.148, \
0.0113056}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The unfolded zeta zeros are given by \
\>", "Text"],

Cell[BoxData[
    \(e = \[Gamma]\ \((ln \((\[Gamma]/\((2  \[Pi]\ )\))\) - 
              1)\)/\(\((2  \[Pi])\)\(.\)\)\)], "DisplayFormula"],

Cell["\<\
The code below creates a histogram showing the density of the \
unfolded zeta zeros.  We see that the density is uniform.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ZNorm = 
        Table[ZetaZero1[\([i]\)]*\((Log[ZetaZero1[\([i]\)]/\((2*Pi)\)] - 
                  1)\)/\((2*Pi)\), {i, 2, 
            100000}];\)\), "\[IndentingNewLine]", 
    \(\(LN = Length[ZNorm];\)\), "\[IndentingNewLine]", 
    \(\(int = 
        Table[ZNorm[\([1]\)] + 
            i*\((ZNorm[\([LN]\)] - ZNorm[\([1]\)])\)/25, {i, 0, 
            25}];\)\), "\n", 
    \(ZHist1 = 
      Histogram[ZNorm, HistogramCategories \[Rule] int, 
        HistogramScale \[Rule] L1, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<e\>", "\<\[Rho](e)\>"}, 
        RotateLabel \[Rule] False]\)}], "Input"],

Cell[BoxData[
    \(Histogram::"rtail1" \(\(:\)\(\ \)\) 
      "Warning: One point from the right tail of the data, greater than or \
equal to \!\(99998.53008849114`\), is not included in histogram."\)], \
"Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-6.94911e-06 1.00002e-05 0.0147151 0.588432 [
[.2 -0.0125 -25.9062 -18 ]
[.2 -0.0125 25.9062 0 ]
[.4 -0.0125 -25.9062 -18 ]
[.4 -0.0125 25.9062 0 ]
[.60001 -0.0125 -25.9062 -18 ]
[.60001 -0.0125 25.9062 0 ]
[.80001 -0.0125 -25.9062 -18 ]
[.80001 -0.0125 25.9062 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .1324 -32.6875 -9 ]
[-0.0125 .1324 0 9 ]
[-0.0125 .25009 -32.6875 -9 ]
[-0.0125 .25009 0 9 ]
[-0.0125 .36777 -32.6875 -9 ]
[-0.0125 .36777 0 9 ]
[-0.0125 .48546 -32.6875 -9 ]
[-0.0125 .48546 0 9 ]
[-0.0125 .60315 -13.5625 -9 ]
[-0.0125 .60315 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -74.9375 -9 ]
[-0.01875 .30902 -32.6875 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
gsave
.2 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20000) show
1.000 setlinewidth
grestore
.4 0 m
.4 .00625 L
s
gsave
.4 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40000) show
1.000 setlinewidth
grestore
.60001 0 m
.60001 .00625 L
s
gsave
.60001 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60000) show
1.000 setlinewidth
grestore
.80001 0 m
.80001 .00625 L
s
gsave
.80001 -0.0125 -86.9062 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80000) show
1.000 setlinewidth
grestore
.125 Mabswid
.04999 0 m
.04999 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65001 0 m
.65001 .00375 L
s
.70001 0 m
.70001 .00375 L
s
.75001 0 m
.75001 .00375 L
s
.85001 0 m
.85001 .00375 L
s
.90001 0 m
.90001 .00375 L
s
.95001 0 m
.95001 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .1324 m
.00625 .1324 L
s
gsave
-0.0125 .1324 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .25009 m
.00625 .25009 L
s
gsave
-0.0125 .25009 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .36777 m
.00625 .36777 L
s
gsave
-0.0125 .36777 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .48546 m
.00625 .48546 L
s
gsave
-0.0125 .48546 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .60315 m
.00625 .60315 L
s
gsave
-0.0125 .60315 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04414 m
.00375 .04414 L
s
0 .07356 m
.00375 .07356 L
s
0 .10298 m
.00375 .10298 L
s
0 .16182 m
.00375 .16182 L
s
0 .19124 m
.00375 .19124 L
s
0 .22067 m
.00375 .22067 L
s
0 .27951 m
.00375 .27951 L
s
0 .30893 m
.00375 .30893 L
s
0 .33835 m
.00375 .33835 L
s
0 .3972 m
.00375 .3972 L
s
0 .42662 m
.00375 .42662 L
s
0 .45604 m
.00375 .45604 L
s
0 .51488 m
.00375 .51488 L
s
0 .5443 m
.00375 .5443 L
s
0 .57373 m
.00375 .57373 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.60001 .61178 m
.60001 .61803 L
s
.80001 .61178 m
.80001 .61803 L
s
.125 Mabswid
.04999 .61428 m
.04999 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65001 .61428 m
.65001 .61803 L
s
.70001 .61428 m
.70001 .61803 L
s
.75001 .61428 m
.75001 .61803 L
s
.85001 .61428 m
.85001 .61803 L
s
.90001 .61428 m
.90001 .61803 L
s
.95001 .61428 m
.95001 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1324 m
1 .1324 L
s
.99375 .25009 m
1 .25009 L
s
.99375 .36777 m
1 .36777 L
s
.99375 .48546 m
1 .48546 L
s
.99375 .60315 m
1 .60315 L
s
.125 Mabswid
.99625 .04414 m
1 .04414 L
s
.99625 .07356 m
1 .07356 L
s
.99625 .10298 m
1 .10298 L
s
.99625 .16182 m
1 .16182 L
s
.99625 .19124 m
1 .19124 L
s
.99625 .22067 m
1 .22067 L
s
.99625 .27951 m
1 .27951 L
s
.99625 .30893 m
1 .30893 L
s
.99625 .33835 m
1 .33835 L
s
.99625 .3972 m
1 .3972 L
s
.99625 .42662 m
1 .42662 L
s
.99625 .45604 m
1 .45604 L
s
.99625 .51488 m
1 .51488 L
s
.99625 .5443 m
1 .5443 L
s
.99625 .57373 m
1 .57373 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .60317 L
.04 .60317 L
.04 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .60317 L
.04 .60317 L
.04 .01472 L
0 .01472 L
s
1 0 0 r
.04 .01472 m
.04 .60317 L
.08 .60317 L
.08 .01472 L
F
0 g
.04 .01472 m
.04 .60317 L
.08 .60317 L
.08 .01472 L
.04 .01472 L
s
1 0 0 r
.08 .01472 m
.08 .60317 L
.12 .60317 L
.12 .01472 L
F
0 g
.08 .01472 m
.08 .60317 L
.12 .60317 L
.12 .01472 L
.08 .01472 L
s
1 0 0 r
.12 .01472 m
.12 .60317 L
.16 .60317 L
.16 .01472 L
F
0 g
.12 .01472 m
.12 .60317 L
.16 .60317 L
.16 .01472 L
.12 .01472 L
s
1 0 0 r
.16 .01472 m
.16 .60317 L
.2 .60317 L
.2 .01472 L
F
0 g
.16 .01472 m
.16 .60317 L
.2 .60317 L
.2 .01472 L
.16 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .60317 L
.24 .60317 L
.24 .01472 L
F
0 g
.2 .01472 m
.2 .60317 L
.24 .60317 L
.24 .01472 L
.2 .01472 L
s
1 0 0 r
.24 .01472 m
.24 .60302 L
.28 .60302 L
.28 .01472 L
F
0 g
.24 .01472 m
.24 .60302 L
.28 .60302 L
.28 .01472 L
.24 .01472 L
s
1 0 0 r
.28 .01472 m
.28 .60332 L
.32 .60332 L
.32 .01472 L
F
0 g
.28 .01472 m
.28 .60332 L
.32 .60332 L
.32 .01472 L
.28 .01472 L
s
1 0 0 r
.32 .01472 m
.32 .60317 L
.36 .60317 L
.36 .01472 L
F
0 g
.32 .01472 m
.32 .60317 L
.36 .60317 L
.36 .01472 L
.32 .01472 L
s
1 0 0 r
.36 .01472 m
.36 .60317 L
.4 .60317 L
.4 .01472 L
F
0 g
.36 .01472 m
.36 .60317 L
.4 .60317 L
.4 .01472 L
.36 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .60302 L
.44 .60302 L
.44 .01472 L
F
0 g
.4 .01472 m
.4 .60302 L
.44 .60302 L
.44 .01472 L
.4 .01472 L
s
1 0 0 r
.44 .01472 m
.44 .60317 L
.48 .60317 L
.48 .01472 L
F
0 g
.44 .01472 m
.44 .60317 L
.48 .60317 L
.48 .01472 L
.44 .01472 L
s
1 0 0 r
.48 .01472 m
.48 .60317 L
.52 .60317 L
.52 .01472 L
F
0 g
.48 .01472 m
.48 .60317 L
.52 .60317 L
.52 .01472 L
.48 .01472 L
s
1 0 0 r
.52 .01472 m
.52 .60317 L
.56 .60317 L
.56 .01472 L
F
0 g
.52 .01472 m
.52 .60317 L
.56 .60317 L
.56 .01472 L
.52 .01472 L
s
1 0 0 r
.56 .01472 m
.56 .60317 L
.6 .60317 L
.6 .01472 L
F
0 g
.56 .01472 m
.56 .60317 L
.6 .60317 L
.6 .01472 L
.56 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .60317 L
.64 .60317 L
.64 .01472 L
F
0 g
.6 .01472 m
.6 .60317 L
.64 .60317 L
.64 .01472 L
.6 .01472 L
s
1 0 0 r
.64 .01472 m
.64 .60332 L
.68 .60332 L
.68 .01472 L
F
0 g
.64 .01472 m
.64 .60332 L
.68 .60332 L
.68 .01472 L
.64 .01472 L
s
1 0 0 r
.68 .01472 m
.68 .60302 L
.72 .60302 L
.72 .01472 L
F
0 g
.68 .01472 m
.68 .60302 L
.72 .60302 L
.72 .01472 L
.68 .01472 L
s
1 0 0 r
.72 .01472 m
.72 .60317 L
.76 .60317 L
.76 .01472 L
F
0 g
.72 .01472 m
.72 .60317 L
.76 .60317 L
.76 .01472 L
.72 .01472 L
s
1 0 0 r
.76 .01472 m
.76 .60317 L
.8 .60317 L
.8 .01472 L
F
0 g
.76 .01472 m
.76 .60317 L
.8 .60317 L
.8 .01472 L
.76 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .60317 L
.84 .60317 L
.84 .01472 L
F
0 g
.8 .01472 m
.8 .60317 L
.84 .60317 L
.84 .01472 L
.8 .01472 L
s
1 0 0 r
.84 .01472 m
.84 .60317 L
.88 .60317 L
.88 .01472 L
F
0 g
.84 .01472 m
.84 .60317 L
.88 .60317 L
.88 .01472 L
.84 .01472 L
s
1 0 0 r
.88 .01472 m
.88 .60317 L
.92 .60317 L
.92 .01472 L
F
0 g
.88 .01472 m
.88 .60317 L
.92 .60317 L
.92 .01472 L
.88 .01472 L
s
1 0 0 r
.92 .01472 m
.92 .60317 L
.96 .60317 L
.96 .01472 L
F
0 g
.92 .01472 m
.92 .60317 L
.96 .60317 L
.96 .01472 L
.92 .01472 L
s
1 0 0 r
.96 .01472 m
.96 .60302 L
1 .60302 L
1 .01472 L
F
0 g
.96 .01472 m
.96 .60302 L
1 .60302 L
1 .01472 L
.96 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo002Iooooo`06ogMgMol@413o0000oa0@4?mEEEGogMgMC?ooool009Sooooo00OoMgMgodA4A?oM
gMgoooooomgMgOn7QhOo8B4Q04cooooo002Hooooo`03oa0@4?o^k^kooooo053ooooo002Hooooo`Oo
0000C?ooool009Sooooo00?o410@omgMgOooool00_ooool00ooMgMgo0000ooooo`1;ooooo`00V?oo
ool01on7QhOo8B4QokZj^_oooooogMgMob4Q8OmgMgL0C?ooool009Wooooo00GoQhN7oa0@4?l0003o
410@ogMgM`1=ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo001Fooooo`Ko00001_ooool01?nHV9So0000o`00
0?nHV9P6ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oV9RHo`000?l000000_l000000ol@413o
ooooooooo`02ooooo`05oiRHV?l0003o0000o`000?nHV9P01_ooool01?nHV9So0000o`000?nHV9P6
ooooo`06ohf=SOl0003o0000o`000?mEEEGok^k^1?ooool01OnHV9So0000o`000?l0003oV9RH00Ko
oooo00CoV9RHo`000?l0003oV9RH1_ooool01_n=SHgo0000o`000?l0003oEEEEonk^kPCooooo00Go
V9RHo`000?l0003o0000oiRHV006ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00CoV9RHo`000?l0
003oV9RH1_ooool01?nHV9So0000o`000?nHV9P:ooooo`00E_ooool00onHV9So0000omgMg@02oooo
o`03oa0@4?oooooooooo00?ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`06okZj^_lQ
8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4Qo`0000Cooooo00Oo^[Zj
oaPH6?lM7AgogMgMoa`L7?lH61So^[Zj00Cooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4oooo
o`07okZj^_l?3`ooIfMWomgMgOlQ8B7oEUIFoeEEE@03ooooo`07okZj^_lH61So7AdMomgMgOlL71co
61PHokZj^P04ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01onj^[[o2`/;ofMWIooM
gMgo8B4QoeIFE_mEEED00oooool01onj^[[o61PHoadM7OoMgMgo71`LoaPH6?nj^[X01?ooool01_nj
^[[o8B4QomgMgOoMgMgo8B4QokZj^PCooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`06
okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj2Oooool005Oooooo00?oQhN7ob4Q8Oo^k^h01oooool01_m4
A4CoV9RHooooooooooooV9RHodA4A0Cooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@4ooooo`03
odA4A?l0003o000000Co00000oooool01om4A4Co:2PXoiRHV?ooooooV9RHobPX:?m4A4@01?ooool0
1_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo00OoA4A4oa@D5?oooooooooooiRHV?m4A4Co0000
00?ooooo00OoA4A4obPX:?nHV9SooooooiRHV?lX:2SoA4A400Cooooo00KoA4A4oiRHV?oooooooooo
oiRHV?m4A4@4ooooo`07odA4A?l0003ooooooooooonHV9SoA4A4o`000003ooooo`07odA4A?lX:2So
V9RHoooooonHV9So:2PXodA4A004ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41?ooool01_m4
A4CoV9RHooooooooooooV9RHodA4A0Cooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@9ooooo`00
F?ooool00onYZJWo8B4Qonk^kP06ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool01_l0
003ok^k^ooooooooooook^k^o`0000Cooooo00Ko0000oclo?onj^[[oooooonk^k_l00004ooooo`;o
000000?ok^k^ooooooo^k^h00_l00004ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool2
o`000003onk^k_ooooook^k^00;o00000oooool2o`000003onk^k_ooooook^k^00;o00001?ooool0
1_l0003ok^k^ooooooooooook^k^o`0000Cooooo0_l00002ooooo`03onk^k_l0003o000000?ooooo
0_l000000oo^k^koooooonk^kP02o`0000Cooooo00Ko0000onk^k_ooooooooooonk^k_l00004oooo
o`06o`000?o^k^koooooooooooo^k^ko00001?ooool01_l0003ok^k^ooooooooooook^k^o`0000Wo
oooo001Iooooo`03oiRHV?lb<S;ooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ogMgM
ob4Q8@02ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l000001OmEEEGok^k^ooooool0003oEEEE00?o
oooo0_l00003ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000oeEEEOmgMgL00_ooool00ol0003oEEEEooooo`02ooooo`;o00000oooool2o`0000Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo001Jooooo`03odA4A?mgMgOooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01_l0003ooooo
ogMgMonHV9Soooooo`0000Cooooo0_l00003ooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo0_l000001OmgMgOo0000o`000?l0003ok^k^00?ooooo0_l00003
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
omgMgOl000000ol000001?oMgMgoooooooooooooool2o`0000?ooooo0_l00004ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`00F_ooool0
0ooMgMgo410@ooooo`04ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool01_l0003ok^k^
ooooooooooook^k^o`0000Cooooo00Ko0000onk^k_o^k^ko8B4Qonk^k_l00004ooooo`;o000000?o
k^k^ooooooo^k^h00_l00004ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool01_l0003o
?clooiRHV?ooooook^k^o`0000Cooooo0_l000000oo^k^koooooonk^kP02o`0000Cooooo00Ko0000
onk^k_ooooooooooonk^k_l00004ooooo`03o`000?l_;booIVIV00;ok^k^00?o0000oc8b<_ooool0
0_ooool2o`000003onk^k_ooooook^k^00;o00001?ooool01_l0003ok^k^ooooooooooook^k^o`00
00Cooooo00Ko0000onk^k_ooooooooooonk^k_l00004ooooo`06o`000?o^k^koooooooooooo^k^ko
00002Oooool005_ooooo00?o0000ooooooooool00oooool01_m4A4CoV9RHooooooooooooV9RHodA4
A0Cooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@4ooooo`06odA4A?nHV9SoooooogMgMonHV9So
00001?ooool01om4A4Co:2PXoiRHV?ooooooV9RHobPX:?m4A4@01?ooool01_m4A4CoV9RHoooooooo
ooooV9RHodA4A0Cooooo00KoA4A4ofm_KolQ8B7ooooooiRHV?m4A4@4ooooo`07odA4A?lX:2SoV9RH
oooooonHV9So:2PXodA4A004ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41?ooool01om4A4Co
0000ooooooooooooV9RHodA4A?l000000oooool01om4A4Co:2PXoiRHV?ooooooV9RHobPX:?m4A4@0
1?ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo00KoA4A4oiRHV?oooooooooooiRHV?m4
A4@4ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A42Oooool005Kooooo00Ko0000ohN7Qoo^k^ko
oooooiRHV?mEEED5ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_nj^[[o8B4QomgM
gOoMgMgo8B4QokZj^PCooooo00Ko^[Zjob4Q8OoMgMgoc/k>o`H61_l00004ooooo`07okZj^_lH61So
7AdMomgMgOlL71co61PHokZj^P04ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_nj
^[[o8B4QodU9BOl/;2co71`LokZj^PCooooo00Oo^[ZjoaPH6?lM7AgogMgMoa`L7?lH61So^[Zj00Co
oooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`07okZj^_l61PKoF5QHolk>c_lN7QkoBTY:
oc8b<P03ooooo`07okZj^_lH61So7AdMomgMgOlL71co61PHokZj^P04ooooo`06okZj^_lQ8B7ogMgM
omgMgOlQ8B7o^[Zj1?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PCooooo00Ko^[Zjob4Q8OoM
gMgogMgMob4Q8Onj^[X9ooooo`00E_ooool01_nYZJWo<S8bo`000?l0003oEEEEonk^kPKooooo00Co
V9RHo`000?l0003oV9RH1_ooool01?nHV9So0000o`000?nHV9P6ooooo`05oiRHV?l0003o0000oiRH
V?l@41001Oooool01OnHV9So0000o`000?l0003oV9RH00Kooooo00CoV9RHo`000?l0003oV9RH1_oo
ool01_nHV9So0000o`000?lD51Co0000ob4Q8@Cooooo00GoV9RHo`000?l0003o0000oiRHV006oooo
o`04oiRHV?l0003o0000oiRHV0Kooooo00KoSHf=o`000?l0003o0000odA4A?o^k^h4ooooo`05oiRH
V?l0003o0000o`000?nHV9P01_ooool01?nHV9So0000o`000?nHV9P6ooooo`04oiRHV?l0003o0000
oiRHV0Kooooo00CoV9RHo`000?l0003oV9RH2_ooool00>_ooooo003[ooooo`00joooool004?ooooo
00CoV9RHo`000?l0003oV9RHY?ooool004;ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5oooo
oigo00000Oooool004;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool1o`00007ooooo0012ooooo`06o`000?o^k^kooooo
ooooooo^k^ko00001OoooonMo`00007ooooo0012ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool0007o00000Oooool004;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000Ol00001oooo
o`00@_ooool01_l0003ok^k^ooooooooooook^k^o`0000Gooooo00?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0001
o`00007ooooo0012ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool0007o00000Oooool004;ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`03o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`000Ol00001ooooo`00@oooool01?nHV9So0000o`000?nHV9P6ooooo`03o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`000Ol00001ooooo`00COooool00ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0007o00000Ooo
ool004gooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo0001o`00007ooooo001=ooooo`03o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`000Ol00001ooooo`00COooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0007o00000Oooool004gooooo
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo0001o`00007ooooo001=ooooo`03o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000Ol0
0001ooooo`00COooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool0007o00000Oooool004gooooo00?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo0001o`00007ooooo001=ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000Ol00001ooooo`00
<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Gooooo1_l00005ooooo`03
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`000Ol00001ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj
^PGooooo0ol00005ooooo`03oiRHV?l0003ogMgM00;ooooo00?o410@ooooooooool00oooool00ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool0007o00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5
ooooo`03oeEEEOl0003oEEEE00Kooooo00?oQhN7ob4Q8Oo^k^h01oooool00ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool0007o00000Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000?ooooo`03ojVYZOlQ
8B7ok^k^00Kooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo0001o`00007ooooo000_ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03_ooool00onHV9So<S8booooo`05ooooo`03o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`000Ol00001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00oooooo00?oA4A4ogMgMoooool01?ooool00ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0007o00000Oooool002oo
oooo00Ko0000onk^k_ooooooooooonk^k_l0000Aooooo`03omgMgOl@413ooooo00Cooooo00?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo0001o`00007ooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A44_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000Ol00001ooooo`00;oooool0
1_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pgooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED5oooo
o`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`000Ol00001ooooo`00<?ooool01?nHV9So0000o`000?nHV9P>oooo
o`06ojVYZOlb<S;o0000o`000?mEEEGok^k^1Oooool00ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0007o00000Ooo
ool004gooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo0001o`00007ooooo001=ooooo`03o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`000Ol00001ooooo`00COooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0007o00000Oooool004gooooo
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo0001o`00007ooooo001=ooooo`03o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000Ol0
0001ooooo`00COooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool0007o00000Oooool004gooooo00?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo0001o`00007ooooo001=ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000Ol00001ooooo`00
<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Wooooo0_l000000ol@413o
ooooooooo`02ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`000Ol00001ooooo`00;oooool01_nj^[[o8B4Q
omgMgOoMgMgo8B4QokZj^PGooooo0ol0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo0001o`00007ooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool0
0omEEEGo0000oeEEE@06ooooo`Ko00001?ooool00ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0007o00000Oooool0
02oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`05odA4A?nj^[[oooooooooool00000
1Oooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool0007o00000Oooool002oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0<ooooo`05omgMgOlQ8B7oooooooooool000001Oooool00ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool0007o00000Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0=ooooo`04ogMgMonHV9Soooooo`0000Gooooo00?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0001o`00007ooooo
000@ooooo`03okZj^_lb<S;ooooo00kooooo00?o<S8bokZj^_ooool02oooool01_l0003ok^k^oooo
ooooooook^k^o`0000oooooo00Cok^k^ob4Q8Ooooooo00001Oooool00ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
007o00000Oooool000?ooooo00?o0000ooooooooool02_ooool00olb<S;o^[Zjooooo`0>ooooo`03
okZj^_lb<S;ooooo00_ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@@ooooo`03ogMgMonHV9So
000000Gooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo0001o`00007ooooo0003ooooo`03oc8b<_nj^[[ooooo
00Wooooo00?oc<c<oc8b<_ooool04?ooool00olb<S;oc<c<ooooo`0:ooooo`06okZj^_lQ8B7ogMgM
omgMgOlQ8B7o^[Zj4?ooool00oo^k^ko<S8bo`000005ooooo`03o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000Ol0
0001ooooo`000oooool00omgMgOoQhN7ogMgM`02o`000003odA4A?o<c<cooooo00Cooooo00?oIVIV
ojVYZOooool01Oooool01_mgMgOo410@o`000?l@413oEEEEomgMg@Gooooo00?oV9RHofIVI_ooool0
2oooool01?nHV9So0000o`000?nHV9PBooooo`03oiRHV?l@413ooooo00Cooooo00?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo0001o`00007ooooo0003ooooo`08oiRHV?l@413oQhN7onk^k_ooooooV9RHoa0@4?o<c<`4
ooooo`03oc8b<_oooooooooo00Cooooo00OoMgMgodA4A?oMgMgoooooomgMgOn7QhOo8B4Q00Gooooo
00?ok^k^oc8b<_ooool0:?ooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0007o00000Oooool000?ooooo00?o
^[Zjoc8b<_ooool00oooool00onHV9SoA4A4ooooo`03ooooo`03oc8b<_oooooooooo00Cooooo00?o
410@onk^k_ooool02_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000Ol0
0001ooooo`001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o<S8b
ooooooooool01?ooool7o`0000Kooooo00?o0000ooooooooool09oooool00ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool0007o00000Oooool000Cooooo00?oA4A4oiRHV?ooool00_ooool00oo^k^ko0000ooooo`03oooo
o`03ob4Q8Ooooooooooo00Cooooo00?o410@omgMgOooool00_ooool00ooMgMgo0000ooooo`05oooo
o`03o`000?oooooooooo02Oooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0001o`00007ooooo0004ooooo`07
okZj^_l0003o^[Zjooooooo^k^koIVIVoeEEE@04ooooo`03oc8b<_o^k^kooooo00Cooooo00OoQhN7
ob4Q8Onj^[[oooooomgMgOlQ8B7oMgMg00Gooooo00?ogMgMoc8b<_ooool0:?ooool00ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool0007o00000Oooool000Gooooo00KoZJVYob4Q8Ol0003o0000oeEEEOo^k^h4ooooo`03
ofIVI_nHV9Sooooo00Gooooo00GoQhN7oa0@4?l0003o410@ogMgM`06ooooo`03oiRHV?mVIVKooooo
02Sooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo0001o`00007ooooo000?ooooo`03omgMgOlQ8B7ooooo013o
oooo00?o410@olc<c?ooool0:?ooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0007o00000Oooool0013ooooo
00?o<S8bokZj^_ooool03_ooool00onj^[[o<S8booooo`0Yooooo`03o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
0Ol00001ooooo`004?ooool00onj^[[o<S8booooo`0>ooooo`03oc8b<_nj^[[ooooo00cooooo00Co
V9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@06ooooo`06onk^k_mEEEGo0000o`000?mE
EEGok^k^1?ooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool0007o00000Oooool002oooooo00Ko^[Zjob4Q8OoM
gMgogMgMob4Q8Onj^[X5ooooo`?o00001_ooool2ogMgM`;ooooo00?oMgMgoeEEEOooool00oooool0
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool0007o00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4
A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo00?o8B4Qooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`000Ol00001ooooo`00;oooool01_l0003ok^k^oooooooo
ooook^k^o`0000kooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`000Ol00001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00cooooo00Ko0000oeEEEOo^k^koooooogMgMomEEED4ooooo`03o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`000Ol00001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo
00Ko0000ogMgMol0003o0000oeEEEOo^k^h4ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000Ol00001oooo
o`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00?oA4A4oiRHV?ooool01oooool0
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool0007o00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4
A4@>ooooo`03okZj^_lQ8B7ooooo00Oooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0001o`00007ooooo000_
ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3oooool00omEEEGo<S8bomgMg@06ooooo`03o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`000Ol00001ooooo`00<?ooool01?nHV9So0000o`000?nHV9PAooooo`04oiRH
V?lQ8B7o0000ob4Q8@Cooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0001o`00007ooooo001=ooooo`03o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`000Ol00001ooooo`00COooool00ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0007o00000Ooo
ool004gooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo0001o`00007ooooo001=ooooo`03o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`000Ol00001ooooo`00COooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0007o00000Oooool004gooooo
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo0001o`00007ooooo001=ooooo`03o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000Ol0
0001ooooo`00COooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool0007o00000Oooool004gooooo00?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo0001o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`00
0?mEEED01_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPCooooo00?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
0001o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo
00KoEEEEogMgMoooooooooooogMgMomEEED4ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000Ol00001oooo
o`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0001
o`00007ooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00003_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0001o`00007ooooo000_
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01_mEEEGoMgMgoooooooo
ooooMgMgoeEEE@Cooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0001o`00007ooooo000_ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03?ooool00ooMgMgo0000o`000002o`000003omgMgOoo
oooooooo00;ooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo0001o`00007ooooo000_ooooo`06o`000?o^k^ko
ooooooooooo^k^ko00003_ooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<PCooooo00?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo0001o`00007ooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A43_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0001
o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool01_lb<S;oIVIVonk^
k_o^k^koIVIVoc8b<PCooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0001o`00007ooooo000`ooooo`04oiRH
V?l0003o0000oiRHV0oooooo00Kok^k^odA4A?l0003o0000odA4A?o^k^h4ooooo`03o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`000Ol00001ooooo`00COooool00ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0007o00000Oooool004go
oooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo0001o`00007ooooo001=ooooo`03o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
0Ol00001ooooo`00COooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0007o00000Oooool004gooooo00?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo0001o`00007ooooo001=ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000Ol00001oooo
o`00COooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool0007o00000Oooool004gooooo00?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo0001o`00007ooooo0012ooooo`Co000000?o410@ooooooooool01?ooool00ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool0007o00000Oooool004Cooooo00?o0000ooooooooool01_ooool00ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool0007o00000Oooool004Cooooo00?o0000ooooooooool01_ooool00ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
007o00000Oooool004Cooooo00?o0000ooooooooool01_oooonMo`00007ooooo0014ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`7o0000
0Oooool004Cooooo00?o0000ooooooooool01_oooonMo`00007ooooo0014ooooo`03o`000?oooooo
oooo0:Cooooo0014ooooo`03o`000?oooooooooo0:Cooooo0012ooooo`03o`000?m4A4Co00000:Ko
oooo0012ooooo`03olc<c?mEEEGo00000:Kooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-49907.4, -0.944665, 640.969, \
0.010893}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The code below creates the level spacing histogram for the first \
100,000 unfolded zeta zeros.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ZSpacing1 = 
        Table[ZNorm[\([i + 1]\)] - ZNorm[\([i]\)], {i, 1, 
            L1 - 2}];\)\), "\n", 
    \(\(int\  = \ Table[0 + i/8, {i, 0, 40}];\)\), "\n", 
    \(ZHist1 = 
      Histogram[ZSpacing1, HistogramCategories \[Rule] int, 
        HistogramScale \[Rule] 1, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<s\>", "\<P(s)\>"}, 
        RotateLabel \[Rule] False]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.38778e-17 0.347826 0.0147151 0.585827 [
[.17391 -0.0125 -16.3438 -18 ]
[.17391 -0.0125 16.3438 0 ]
[.34783 -0.0125 -6.78125 -18 ]
[.34783 -0.0125 6.78125 0 ]
[.52174 -0.0125 -16.3438 -18 ]
[.52174 -0.0125 16.3438 0 ]
[.69565 -0.0125 -6.78125 -18 ]
[.69565 -0.0125 6.78125 0 ]
[.86957 -0.0125 -16.3438 -18 ]
[.86957 -0.0125 16.3438 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .13188 -32.6875 -9 ]
[-0.0125 .13188 0 9 ]
[-0.0125 .24905 -32.6875 -9 ]
[-0.0125 .24905 0 9 ]
[-0.0125 .36621 -32.6875 -9 ]
[-0.0125 .36621 0 9 ]
[-0.0125 .48338 -32.6875 -9 ]
[-0.0125 .48338 0 9 ]
[-0.0125 .60054 -13.5625 -9 ]
[-0.0125 .60054 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -74.9375 -9 ]
[-0.01875 .30902 -32.6875 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17391 0 m
.17391 .00625 L
s
gsave
.17391 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.34783 0 m
.34783 .00625 L
s
gsave
.34783 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.52174 0 m
.52174 .00625 L
s
gsave
.52174 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.69565 0 m
.69565 .00625 L
s
gsave
.69565 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.86957 0 m
.86957 .00625 L
s
gsave
.86957 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.03478 0 m
.03478 .00375 L
s
.06957 0 m
.06957 .00375 L
s
.10435 0 m
.10435 .00375 L
s
.13913 0 m
.13913 .00375 L
s
.2087 0 m
.2087 .00375 L
s
.24348 0 m
.24348 .00375 L
s
.27826 0 m
.27826 .00375 L
s
.31304 0 m
.31304 .00375 L
s
.38261 0 m
.38261 .00375 L
s
.41739 0 m
.41739 .00375 L
s
.45217 0 m
.45217 .00375 L
s
.48696 0 m
.48696 .00375 L
s
.55652 0 m
.55652 .00375 L
s
.5913 0 m
.5913 .00375 L
s
.62609 0 m
.62609 .00375 L
s
.66087 0 m
.66087 .00375 L
s
.73043 0 m
.73043 .00375 L
s
.76522 0 m
.76522 .00375 L
s
.8 0 m
.8 .00375 L
s
.83478 0 m
.83478 .00375 L
s
.90435 0 m
.90435 .00375 L
s
.93913 0 m
.93913 .00375 L
s
.97391 0 m
.97391 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13188 m
.00625 .13188 L
s
gsave
-0.0125 .13188 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .24905 m
.00625 .24905 L
s
gsave
-0.0125 .24905 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .36621 m
.00625 .36621 L
s
gsave
-0.0125 .36621 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .48338 m
.00625 .48338 L
s
gsave
-0.0125 .48338 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .60054 m
.00625 .60054 L
s
gsave
-0.0125 .60054 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04401 m
.00375 .04401 L
s
0 .0733 m
.00375 .0733 L
s
0 .10259 m
.00375 .10259 L
s
0 .16117 m
.00375 .16117 L
s
0 .19046 m
.00375 .19046 L
s
0 .21975 m
.00375 .21975 L
s
0 .27834 m
.00375 .27834 L
s
0 .30763 m
.00375 .30763 L
s
0 .33692 m
.00375 .33692 L
s
0 .3955 m
.00375 .3955 L
s
0 .42479 m
.00375 .42479 L
s
0 .45409 m
.00375 .45409 L
s
0 .51267 m
.00375 .51267 L
s
0 .54196 m
.00375 .54196 L
s
0 .57125 m
.00375 .57125 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.17391 .61178 m
.17391 .61803 L
s
.34783 .61178 m
.34783 .61803 L
s
.52174 .61178 m
.52174 .61803 L
s
.69565 .61178 m
.69565 .61803 L
s
.86957 .61178 m
.86957 .61803 L
s
.125 Mabswid
.03478 .61428 m
.03478 .61803 L
s
.06957 .61428 m
.06957 .61803 L
s
.10435 .61428 m
.10435 .61803 L
s
.13913 .61428 m
.13913 .61803 L
s
.2087 .61428 m
.2087 .61803 L
s
.24348 .61428 m
.24348 .61803 L
s
.27826 .61428 m
.27826 .61803 L
s
.31304 .61428 m
.31304 .61803 L
s
.38261 .61428 m
.38261 .61803 L
s
.41739 .61428 m
.41739 .61803 L
s
.45217 .61428 m
.45217 .61803 L
s
.48696 .61428 m
.48696 .61803 L
s
.55652 .61428 m
.55652 .61803 L
s
.5913 .61428 m
.5913 .61803 L
s
.62609 .61428 m
.62609 .61803 L
s
.66087 .61428 m
.66087 .61803 L
s
.73043 .61428 m
.73043 .61803 L
s
.76522 .61428 m
.76522 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.83478 .61428 m
.83478 .61803 L
s
.90435 .61428 m
.90435 .61803 L
s
.93913 .61428 m
.93913 .61803 L
s
.97391 .61428 m
.97391 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13188 m
1 .13188 L
s
.99375 .24905 m
1 .24905 L
s
.99375 .36621 m
1 .36621 L
s
.99375 .48338 m
1 .48338 L
s
.99375 .60054 m
1 .60054 L
s
.125 Mabswid
.99625 .04401 m
1 .04401 L
s
.99625 .0733 m
1 .0733 L
s
.99625 .10259 m
1 .10259 L
s
.99625 .16117 m
1 .16117 L
s
.99625 .19046 m
1 .19046 L
s
.99625 .21975 m
1 .21975 L
s
.99625 .27834 m
1 .27834 L
s
.99625 .30763 m
1 .30763 L
s
.99625 .33692 m
1 .33692 L
s
.99625 .3955 m
1 .3955 L
s
.99625 .42479 m
1 .42479 L
s
.99625 .45409 m
1 .45409 L
s
.99625 .51267 m
1 .51267 L
s
.99625 .54196 m
1 .54196 L
s
.99625 .57125 m
1 .57125 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .02207 L
.04348 .02207 L
.04348 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02207 L
.04348 .02207 L
.04348 .01472 L
0 .01472 L
s
1 0 0 r
.04348 .01472 m
.04348 .06378 L
.08696 .06378 L
.08696 .01472 L
F
0 g
.04348 .01472 m
.04348 .06378 L
.08696 .06378 L
.08696 .01472 L
.04348 .01472 L
s
1 0 0 r
.08696 .01472 m
.08696 .15058 L
.13043 .15058 L
.13043 .01472 L
F
0 g
.08696 .01472 m
.08696 .15058 L
.13043 .15058 L
.13043 .01472 L
.08696 .01472 L
s
1 0 0 r
.13043 .01472 m
.13043 .27159 L
.17391 .27159 L
.17391 .01472 L
F
0 g
.13043 .01472 m
.13043 .27159 L
.17391 .27159 L
.17391 .01472 L
.13043 .01472 L
s
1 0 0 r
.17391 .01472 m
.17391 .40165 L
.21739 .40165 L
.21739 .01472 L
F
0 g
.17391 .01472 m
.17391 .40165 L
.21739 .40165 L
.21739 .01472 L
.17391 .01472 L
s
1 0 0 r
.21739 .01472 m
.21739 .51797 L
.26087 .51797 L
.26087 .01472 L
F
0 g
.21739 .01472 m
.21739 .51797 L
.26087 .51797 L
.26087 .01472 L
.21739 .01472 L
s
1 0 0 r
.26087 .01472 m
.26087 .58945 L
.30435 .58945 L
.30435 .01472 L
F
0 g
.26087 .01472 m
.26087 .58945 L
.30435 .58945 L
.30435 .01472 L
.26087 .01472 L
s
1 0 0 r
.30435 .01472 m
.30435 .60332 L
.34783 .60332 L
.34783 .01472 L
F
0 g
.30435 .01472 m
.30435 .60332 L
.34783 .60332 L
.34783 .01472 L
.30435 .01472 L
s
1 0 0 r
.34783 .01472 m
.34783 .55734 L
.3913 .55734 L
.3913 .01472 L
F
0 g
.34783 .01472 m
.34783 .55734 L
.3913 .55734 L
.3913 .01472 L
.34783 .01472 L
s
1 0 0 r
.3913 .01472 m
.3913 .47542 L
.43478 .47542 L
.43478 .01472 L
F
0 g
.3913 .01472 m
.3913 .47542 L
.43478 .47542 L
.43478 .01472 L
.3913 .01472 L
s
1 0 0 r
.43478 .01472 m
.43478 .38375 L
.47826 .38375 L
.47826 .01472 L
F
0 g
.43478 .01472 m
.43478 .38375 L
.47826 .38375 L
.47826 .01472 L
.43478 .01472 L
s
1 0 0 r
.47826 .01472 m
.47826 .29287 L
.52174 .29287 L
.52174 .01472 L
F
0 g
.47826 .01472 m
.47826 .29287 L
.52174 .29287 L
.52174 .01472 L
.47826 .01472 L
s
1 0 0 r
.52174 .01472 m
.52174 .20996 L
.56522 .20996 L
.56522 .01472 L
F
0 g
.52174 .01472 m
.52174 .20996 L
.56522 .20996 L
.56522 .01472 L
.52174 .01472 L
s
1 0 0 r
.56522 .01472 m
.56522 .1474 L
.6087 .1474 L
.6087 .01472 L
F
0 g
.56522 .01472 m
.56522 .1474 L
.6087 .1474 L
.6087 .01472 L
.56522 .01472 L
s
1 0 0 r
.6087 .01472 m
.6087 .10273 L
.65217 .10273 L
.65217 .01472 L
F
0 g
.6087 .01472 m
.6087 .10273 L
.65217 .10273 L
.65217 .01472 L
.6087 .01472 L
s
1 0 0 r
.65217 .01472 m
.65217 .06538 L
.69565 .06538 L
.69565 .01472 L
F
0 g
.65217 .01472 m
.65217 .06538 L
.69565 .06538 L
.69565 .01472 L
.65217 .01472 L
s
1 0 0 r
.69565 .01472 m
.69565 .04663 L
.73913 .04663 L
.73913 .01472 L
F
0 g
.69565 .01472 m
.69565 .04663 L
.73913 .04663 L
.73913 .01472 L
.69565 .01472 L
s
1 0 0 r
.73913 .01472 m
.73913 .03299 L
.78261 .03299 L
.78261 .01472 L
F
0 g
.73913 .01472 m
.73913 .03299 L
.78261 .03299 L
.78261 .01472 L
.73913 .01472 L
s
1 0 0 r
.78261 .01472 m
.78261 .0239 L
.82609 .0239 L
.82609 .01472 L
F
0 g
.78261 .01472 m
.78261 .0239 L
.82609 .0239 L
.82609 .01472 L
.78261 .01472 L
s
1 0 0 r
.82609 .01472 m
.82609 .01931 L
.86957 .01931 L
.86957 .01472 L
F
0 g
.82609 .01472 m
.82609 .01931 L
.86957 .01931 L
.86957 .01472 L
.82609 .01472 L
s
1 0 0 r
.86957 .01472 m
.86957 .01664 L
.91304 .01664 L
.91304 .01472 L
F
0 g
.86957 .01472 m
.86957 .01664 L
.91304 .01664 L
.91304 .01472 L
.86957 .01472 L
s
1 0 0 r
.91304 .01472 m
.91304 .01551 L
.95652 .01551 L
.95652 .01472 L
F
0 g
.91304 .01472 m
.91304 .01551 L
.95652 .01551 L
.95652 .01472 L
.91304 .01472 L
s
1 0 0 r
.95652 .01472 m
.95652 .01481 L
1 .01481 L
1 .01472 L
F
0 g
.95652 .01472 m
.95652 .01481 L
1 .01481 L
1 .01472 L
.95652 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo002Hooooo`03oa0@4?lb<S;o410@00;o000000?oA4A4olc<c?ooool0Boooool009Sooooo00?o
0000oiRHV?o^k^h00_ooool00on7QhOo410@ooooo`1;ooooo`00WOooool00onj^[[o0000ooooo`1;
ooooo`00V?ooool00oo<c<coA4A4o`000003o`000003oiRHV?oooooooooo04[ooooo002Hooooo`05
o`000?n7QhOo^[ZjokZj^_o<c<`0C_ooool009Sooooo00?o0000oiRHV?ooool00_ooool00oo<c<co
410@ooooo`1;ooooo`00V?ooool01oo<c<coA4A4o`000?l0003o410@oc8b<_l00000C?ooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00GOooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Ko
oooo00GoV9RHoa0@4?l0003o0000ofIVIP0<ooooo`Co000000?o410@ooooooooool02_ooool4o`00
0003oa0@4?oooooooooo00Cooooo00?oEEEEo`000?mEEED01_ooool01OnHV9So410@o`000?l0003o
IVIV00_ooooo1_l0000<ooooo`Ko00001_ooool00omEEEGo0000oeEEE@06ooooo`05oiRHV?l@413o
0000o`000?mVIVH02Oooool005cooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o0000
1_ooool01_l@413oQhN7ooooooooooooMgMgofIVIPgooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`06ooooo`?o00001_ooool01_l@413oQhN7ooooooooooooMgMgofIVIP[ooooo00?o
V9RHo`000?oMgMd00_ooool00ol@413oooooooooo`0:ooooo`03oiRHV?l0003ogMgM00;ooooo00?o
410@ooooooooool01?ooool3o`0000Kooooo00Ko410@ohN7QoooooooooooogMgMomVIVH8ooooo`00
G?ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00omE
EEGo0000oeEEE@0;ooooo`03o`000?oooooooooo00Wooooo00?oQhN7ob4Q8Oo^k^h03oooool00on7
QhOo8B4Qonk^kP08ooooo`03oeEEEOl0003oEEEE00_ooooo00?o0000ooooooooool01_ooool005co
oooo00Ko0000onk^k_ooooooooooonk^k_l0000Booooo`03onk^k_l0003ooooo00cooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`03onk^k_l0003ooooo00_ooooo00?oZJVY
ob4Q8Oo^k^h03oooool00onYZJWo8B4Qonk^kP0Dooooo`03onk^k_l0003ooooo00Oooooo001Loooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01_l@413oV9RHoooooooooooo
MgMgofIVIPgooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`06oa0@4?nH
V9SooooooooooomgMgOoIVIV3Oooool00onHV9So<S8booooo`0?ooooo`03oiRHV?lb<S;ooooo00oo
oooo00Ko410@oiRHV?ooooooooooogMgMomVIVH8ooooo`00G?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00cooooo00Go0000ob4Q8Ol0003o0000ofIVIP0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool01Ol0003o8B4Qo`000?l0003oIVIV00oooooo00?o
A4A4ogMgMoooool03oooool00om4A4CoMgMgooooo`0>ooooo`05o`000?lQ8B7o0000o`000?mVIVH0
2Oooool005cooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017o
oooo00?ogMgMoa0@4?ooool03oooool00ooMgMgo410@ooooo`0>ooooo`03o`000?oooooooooo00_o
oooo001Looooo`06odA4A?nHV9SooooooooooonHV9SoA4A43_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;oooo
o`00G?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00?o0000ooooooooool03_ooool0
0ol0003oA4A4o`00000>ooooo`03o`000?m4A4Co0000017ooooo00?o0000ooooooooool03Oooool0
1_l0003oQhN7onk^k_ooooooV9RHoeEEE@cooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED?oooo
o`03o`000?oooooooooo00_ooooo001Mooooo`04oiRHV?l0003o0000oiRHV0oooooo1Ol0000<oooo
o`03olc<c?mEEEGo000000kooooo00?oc<c<oeEEEOl000004Oooool5o`0000_ooooo00KoZJVYoc8b
<_l0003o0000oeEEEOo^k^h<ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^3oooool5o`0000Wo
oooo003[ooooo`00joooool00>_ooooo0013ooooo`04oiRHV?l0003o0000oiRHV:Cooooo0012oooo
o`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1OoooonMo`00007ooooo0012ooooo`06odA4A?nHV9So
oooooooooonHV9SoA4A41Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000Oooool004;ooooo00Ko0000onk^k_ooooooooooonk^k_l00005oooooigo00000Oooool004;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`005_l00005ooooo`7o00000Oooool004;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`So00001_oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool000So00006_ooool1o`00007ooooo
0012ooooo`06o`000?o^k^koooooooooooo^k^ko00001Oooool00ol0003oooooooooo`04ooooo`03
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000Coo`001ol0000Qooooo`7o00000Oooool004;ooooo00KoA4A4oiRHV?oooooo
oooooiRHV?m4A4@5ooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?oo00001?oo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0
003oooooooooo`0Uooooo`7o00000Oooool004;ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5
ooooo`;o00001Oooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00001?oo0008o`0002Oooooo0Ol00001ooooo`00@oooool01?nHV9So0000o`000?nHV9P6
ooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000Coo`0000?o0000ooooooooool0;?ooool1o`00007ooooo001=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000Coo`0000?o0000ooooooooool0;?ooool1o`00007ooooo001=ooooo`03
o`000?oooooooooo00Cooooo2?l00006ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool000So0000;_ooool1o`00007ooooo001=ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oooooooooo`0cooooo`7o0000
0Oooool004gooooo0_l0000<ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ooooooooool0<ooo
ool1o`00007ooooo001=ooooo`03o`000?oooooooooo00_ooooo00?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0000
0ol0003oooooooooo`0cooooo`7o00000Oooool004gooooo00?o0000ooooooooool02oooool00ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004ool00003o`000?oooooooooo03?ooooo0Ol00001ooooo`00COooool00ol0003o
ooooooooo`0;ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ooooooooool0<oooool1o`00007o
oooo001=ooooo`;o00003?ooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo0008o`0003Gooooo0Ol00001ooooo`00COooool00ol0003ooooooooo
o`0;ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo03[ooooo0Ol00001ooooo`00<?ooool01?nHV9So0000o`000?nH
V9P6ooooo`03oeEEEOl0003oEEEE00Gooooo1_l00005ooooo`03o`000?oooooooooo00_ooooo00?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0>_ooool1o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj
1Oooool3o`0000Gooooo00?oV9RHo`000?oMgMd00_ooool00ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0>_ooool1o`00007ooooo000_ooooo`06odA4A?nH
V9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`03ohN7QolQ8B7ok^k^00Oo
oooo00?o0000ooooooooool02oooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0jooooo`7o00000Oooool002oooooo
00Ko0000onk^k_ooooooooooonk^k_l0000?ooooo`03ojVYZOlQ8B7ok^k^00Kooooo0_l0000<oooo
o`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo03Wooooo0_l00001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00kooooo00?oV9RHoc8b<_ooool01Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo03[ooooo0Ol00001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00oooooo00?oA4A4ogMgMoooool01?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo0007o`0003cooooo0Ol00001ooooo`00;ooo
ool01_l0003ok^k^ooooooooooook^k^o`00017ooooo00?ogMgMoa0@4?ooool01?ooool00ol0003o
ooooooooo`0;ooooo`So00001Ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00001?oo00000ol0003oooooooooo`10ooooo`7o00000Oooool002oooooo
00KoA4A4oiRHV?oooooooooooiRHV?m4A4@Booooo`03o`000?oooooooooo00?ooooo0_l0000Coooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000Coo`0000?o0000ooooooooool0@?ooool1o`00007ooooo000_ooooo`06
okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3Oooool01_l0003oQhN7onk^k_ooooooV9RHoeEEE@Gooooo
00?o0000ooooooooool04_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oooooooooo043ooooo
0Ol00001ooooo`00<?ooool01?nHV9So0000o`000?nHV9P>ooooo`06ojVYZOlb<S;o0000o`000?mE
EEGok^k^1Oooool00ol0003oooooooooo`0Booooo`03o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000oooo
ooooool0@?ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo01;ooooo00?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00001?oo00000ol0003oooooooooo`10ooooo`7o00000Oooool004gooooo00?o0000ooooooooool0
4_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00004ool00003o`000?oooooooooo043ooooo0Ol00001ooooo`00COoo
ool2o`0001?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oooooooooo`10ooooo`7o00000Ooo
ool004gooooo00?o0000ooooooooool04_ooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oooooo
oooo043ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Booooo`03o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00Coo`0000?o0000ooooooooool0@?ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo01;o
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Co
o`002?l00012ooooo`7o00000Oooool004gooooo0_l0000Cooooo`03o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oooooooooo04Oooooo
0Ol00001ooooo`00COooool00ol0003oooooooooo`0Booooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oooooooooo04Oooooo0Ol0
0001ooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Wooooo0_l0
00000ol@413oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ool00?oo00000ooo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ooooooooool0Aooo
ool1o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oooooooooo04Oooooo
0Ol00001ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mE
EED01_ooool6o`0000Cooooo00?o0000ooooooooool04_ooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oooooooooo`17ooooo`7o
00000Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`05odA4A?nj^[[ooooo
ooooool000001Oooool2o`0001?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000Coo`0000?o0000ooooooooool0A_ooool2o`00007ooooo000_oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01OoMgMgo8B4Qoooooooooooo
000000Gooooo00?o0000ooooooooool04_ooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oooooooooo`17ooooo`7o00000Oooool0
02oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`04ogMgMonHV9Sooooo
o`0000Gooooo00?o0000ooooooooool04_ooool00ol0003oo`00ool00003ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003o
o`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oooooooooo`17ooooo`7o00000Oooool0
013ooooo00?o^[Zjoc8b<_ooool03_ooool00olb<S;o^[Zjooooo`0;ooooo`06o`000?o^k^kooooo
ooooooo^k^ko00003oooool01?o^k^ko8B4Qooooool00005ooooo`03o`000?oooooooooo01;ooooo
1ol00006ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ooooooooool0Aoooool1o`00007ooooo
000@ooooo`03oc8b<_nj^[[ooooo00kooooo00?o^[Zjoc8b<_ooool02oooool01_m4A4CoV9RHoooo
ooooooooV9RHodA4A13ooooo00?oMgMgoiRHV?l000001Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003
o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oooooooooo`17ooooo`7o
00000Oooool000oooooo00?oc<c<oc8b<_ooool04?ooool00olb<S;oc<c<ooooo`0:ooooo`06okZj
^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj4?ooool00oo^k^ko<S8bo`000005ooooo`;o00006Oooool00ol0
003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ooooooooool0Aoooool1o`00
007ooooo0002ooooo`05oa0@4?l0003o0000o`000?l@41002?ooool00omVIVKoZJVYooooo`04oooo
o`03oa0@4?lb<S;o410@00;o000000?oA4A4olc<c?ooool01?ooool00onHV9SoIVIVooooo`0;oooo
o`04oiRHV?l0003o0000oiRHV1;ooooo00?oV9RHoa0@4?ooool01?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004
ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oooooooooo`17
ooooo`7o00000Oooool000Cooooo00?o0000ooooooooool02?ooool00olb<S;oooooooooo`04oooo
o`03o`000?nHV9Sok^k^00;ooooo00?oQhN7oa0@4?ooool01?ooool00oo^k^ko<S8booooo`0Xoooo
o`03o`000?oooooooooo01Sooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo0008o`0004Wooooo0Ol00001oooo
o`001?ooool00ol0003oooooooooo`08ooooo`03oc8b<_oooooooooo00Wooooo00?o^[Zjo`000?oo
ool01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Sooooo00?o0000ool00?oo
00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00001?oo00000ol0003oooooooooo`1>ooooo`7o00000Oooool000Cooooo0ol000000ol@413oMgMg
onk^kP05ooooo`03oc8b<_oooooooooo00Cooooo00?oc<c<odA4A?l000000ol000000onHV9Sooooo
ooooo`04ooooo`03o`000?oooooooooo02Oooooo0_l0000Iooooo`03o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`00
00?o0000ooooooooool0C_ooool1o`00007ooooo0004ooooo`06o`000?ooooooooooonk^k_mgMgOo
EEEE1Oooool00olQ8B7oooooooooo`04ooooo`05o`000?n7QhOo^[ZjokZj^_o<c<`02?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01Sooooo00?o0000ool00?oo00001?oo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0
003oooooooooo`1>ooooo`7o00000Oooool000Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03oc8b<_o^k^kooooo00Cooooo00?o0000oiRHV?ooool00_ooool00oo<c<co
410@ooooo`04ooooo`03omgMgOlb<S;ooooo02Sooooo00?o0000ooooooooool06?ooool00ol0003o
o`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00004ool00003o`000?oooooooooo04kooooo0Ol00001ooooo`001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?oIVIVoiRHV?ooool01?ooool01oo<c<coA4A4
o`000?l0003o410@oc8b<_l000001Oooool00onHV9SoIVIVooooo`0Xooooo`03o`000?oooooooooo
01Sooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00001?oo00000ol0003oooooooooo`1>ooooo`7o00000Oooool000Co
oooo00Ko0000ooooooooooook^k^ogMgMomEEED5ooooo`03omgMgOlQ8B7ooooo013ooooo00?o410@
olc<c?ooool0:?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000
ooooooooool0C_ooool1o`00007ooooo0002ooooo`03oa0@4?l0003o000000;o000000?o410@ogMg
Moo^k^h01_ooool00olb<S;o^[Zjooooo`0>ooooo`03okZj^_lb<S;ooooo02Wooooo0_l0000Ioooo
o`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool0
0003o`000?oo003oo`0000Coo`0000?o0000ooooooooool0C_ooool1o`00007ooooo000@ooooo`03
okZj^_lb<S;ooooo00kooooo00?o<S8bokZj^_ooool03?ooool01?nHV9So0000o`000?nHV9P6oooo
o`03oeEEEOl0003oEEEE00Kooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h4ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oooooooooo`1>ooooo`7o00000Ooo
ool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001_ooool2ogMgM`;ooooo
00?oMgMgoeEEEOooool00oooool00ol0003oooooooooo`0Hooooo`03o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`00
00?o0000ooooooooool0C_ooool1o`00007ooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9So
A4A41Oooool00omEEEGo0000oeEEE@06ooooo`03ob4Q8Ooooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000oooooooo
ool0C_ooool1o`00007ooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00003_ooool00ol0
003ok^k^ooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l0000Iooooo`03o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00Coo`0000?o0000ooooooooool0COooool2o`00007ooooo000_ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03?ooool01_l0003oEEEEonk^k_ooooooMgMgoeEEE@Cooooo00?o0000
ooooooooool06?ooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oooooooooo04kooooo0Ol00001
ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Ko0000ogMg
Mol0003o0000oeEEEOo^k^h4ooooo`03o`000?oooooooooo01Sooooo00?o0000ool00?oo00001?oo
00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo
00000ol0003oooooooooo`1>ooooo`7o00000Oooool002oooooo00Ko0000onk^k_ooooooooooonk^
k_l0000>ooooo`03odA4A?nHV9Sooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003oo`00
ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo0008o`00053ooooo
0Ol00001ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0kooooo00?o^[Zjob4Q8Ooo
ool01oooool00ol0003oooooooooo`0Hooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oooooooooo05Gooooo0Ol00001ooooo`00
;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Poooooo00?oEEEEoc8b<_oMgMd01_ooool2o`00
01Wooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`00
00Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00Coo`0000?o0000ooooooooool0EOooool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRH
V17ooooo00CoV9RHob4Q8Ol0003o8B4Q1?ooool00ol0003oooooooooo`0Hooooo`So00001_oo0000
0ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00004ool00003o`000?oooooooooo05Gooooo0Ol00001ooooo`00COooool00ol0
003oooooooooo`0Oooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0
003oooooooooo`1Eooooo`7o00000Oooool004gooooo00?o0000ooooooooool07oooool00ol0003o
o`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000ooooooooool0EOooool1o`00007o
oooo001=ooooo`;o00008?ooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`00
00?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`00
00?o0000ooooooooool0EOooool1o`00007ooooo001=ooooo`03o`000?oooooooooo01oooooo00?o
0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`000?oooooooooo05Gooooo0Ol0
0001ooooo`00COooool00ol0003oooooooooo`0Oooooo`03o`000?oo003oo`0000Coo`0000?o0000
ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00001?oo00000ol0003oooooooooo`1Eooooo`7o00000Oooool004gooooo00?o0000oooo
ooooool07oooool00ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Coo`0000?o0000oooo
ooooool0EOooool1o`00007ooooo001=ooooo`03o`000?oooooooooo01oooooo00?o0000ool00?oo
00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00004ool00003o`000?oooooooooo05Gooooo0Ol00001ooooo`00
COooool2o`00023ooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`00
0?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00004ool00003o`00
0?oooooooooo05Gooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Oooooo`03o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00001?oo00000ol0003oooooooooo`1Eooooo`7o00000Ooo
ool0033ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@06ooooo`06onk^k_mE
EEGo0000o`000?mEEEGok^k^1?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo003oo`0000Co
o`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00001?oo00000ol0003oooooooooo`1Eooooo`7o00000Oooool002oooooo
00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001_ooool01_mEEEGoMgMgoooooooooooo
MgMgoeEEE@Cooooo00?o0000ooooooooool07oooool00ol0003oo`00ool00004ool00003o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003ool000So0000Eooo
ool1o`00007ooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000
oeEEE@06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0G?ooool1o`00007ooooo
000_ooooo`06o`000?o^k^koooooooooooo^k^ko00003_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo0_l0000Pooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo
00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0Foooool2o`00007ooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3?ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Cooooo00?o0000ooooooooool07oooool00ol0
003oo`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo05cooooo0Ol00001ooooo`00;oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?ogMgMo`000?l000000_l000000ooMgMgo
ooooooooo`02ooooo`03o`000?oooooooooo01oooooo00?o0000ool00?oo00001?oo00000ol0003o
o`00ool00004ool00003o`000?oo003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
ooooooooo`1Looooo`7o00000Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>oooo
o`06oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b1?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0G?ooool1o`00007ooooo000_ooooo`06odA4A?nHV9So
oooooooooonHV9SoA4A43_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
0_l0000Pooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0G?ooool1o`00007ooooo
000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool01_lb<S;oIVIVonk^k_o^k^koIVIV
oc8b<PCooooo00?o0000ooooooooool07oooool8o`0000Koo`0000?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oooooooooo05cooooo0Ol00001ooooo`00<?ooool01?nH
V9So0000o`000?nHV9P?ooooo`06onk^k_m4A4Co0000o`000?m4A4Cok^k^1?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oooooooooo05cooooo0Ol00001ooooo`00COooool00ol0003ooooooooo
o`0Vooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo05cooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0V
ooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo05cooooo0Ol00001ooooo`00COooool2o`0002Oooooo00?o0000ool0
0?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0G?ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo02Kooooo00?o0000ool00?oo
00001?oo00000ol0003oo`00ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0G?ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo02Kooooo00?o0000ool00?oo0000
1?oo00000ol0003oo`00ool00004ool000Oo0000G_ooool1o`00007ooooo001=ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003o`000?oo
oooooooo06;ooooo0Ol00001ooooo`00COooool2o`0002Oooooo00?o0000ool00?oo00001?oo0000
0ol0003oo`00ool00004ool00003o`000?oooooooooo06;ooooo0Ol00001ooooo`00COooool00ol0
003oooooooooo`0Vooooo`03o`000?oo003oo`0000Coo`0000?o0000ool00?oo00001?oo00000ol0
003oooooooooo`1Rooooo`7o00000Oooool004;ooooo1?l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo02Kooooo00?o0000ool00?oo00001?oo00000ol0003oo`00ool00004ool00003
o`000?oooooooooo06;ooooo0Ol00001ooooo`00A?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02Kooooo2?l00006ool00003o`000?oooooooooo06;ooooo0Ol00001ooooo`00A?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000ool00?oo00001?oo
00000ol0003oooooooooo`1Rooooo`7o00000Oooool004Cooooo00?o0000ooooooooool01_ooool2
o`0002kooooo2?l0001Sooooo`;o00000Oooool004Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`2Iooooo`7o00000Oooool004Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000Oooool004Cooooo00?o0000oooooooo
ool01_oooonMo`00007ooooo0014ooooo`03o`000?oooooooooo0:Cooooo0012ooooo`03o`000?m4
A4Co00000:Kooooo0012ooooo`03olc<c?mEEEGo00000:Kooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-1.43489, -0.951093, 0.0184282, \
0.0109415}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The plot below compares the level spacing hisotgram for the first \
100,000 zeta zeros to the theoretical GUE distribution.  The fit is not \
perfect, but it is good, but not perfect.  In particular, there seems to be \
an excess of spacings near the peak of the distribution.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[ZHist1, GUE, AspectRatio \[Rule] 1, 
      PlotRange \[Rule] {{0, 3.5}, {0, 1.1}}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-17 0.285714 0 0.909091 [
[.14286 -0.0125 -16.3438 -18 ]
[.14286 -0.0125 16.3438 0 ]
[.28571 -0.0125 -6.78125 -18 ]
[.28571 -0.0125 6.78125 0 ]
[.42857 -0.0125 -16.3438 -18 ]
[.42857 -0.0125 16.3438 0 ]
[.57143 -0.0125 -6.78125 -18 ]
[.57143 -0.0125 6.78125 0 ]
[.71429 -0.0125 -16.3438 -18 ]
[.71429 -0.0125 16.3438 0 ]
[.85714 -0.0125 -6.78125 -18 ]
[.85714 -0.0125 6.78125 0 ]
[1 -0.0125 -16.3438 -18 ]
[1 -0.0125 16.3438 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .18182 -32.6875 -9 ]
[-0.0125 .18182 0 9 ]
[-0.0125 .36364 -32.6875 -9 ]
[-0.0125 .36364 0 9 ]
[-0.0125 .54545 -32.6875 -9 ]
[-0.0125 .54545 0 9 ]
[-0.0125 .72727 -32.6875 -9 ]
[-0.0125 .72727 0 9 ]
[-0.0125 .90909 -13.5625 -9 ]
[-0.0125 .90909 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -74.9375 -9 ]
[-0.01875 .5 -32.6875 9 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .00625 L
s
gsave
.14286 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.28571 0 m
.28571 .00625 L
s
gsave
.28571 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.42857 0 m
.42857 .00625 L
s
gsave
.42857 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.57143 0 m
.57143 .00625 L
s
gsave
.57143 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.71429 0 m
.71429 .00625 L
s
gsave
.71429 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.85714 0 m
.85714 .00625 L
s
gsave
.85714 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .18182 m
.00625 .18182 L
s
gsave
-0.0125 .18182 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .36364 m
.00625 .36364 L
s
gsave
-0.0125 .36364 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .54545 m
.00625 .54545 L
s
gsave
-0.0125 .54545 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .72727 m
.00625 .72727 L
s
gsave
-0.0125 .72727 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .90909 m
.00625 .90909 L
s
gsave
-0.0125 .90909 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04545 m
.00375 .04545 L
s
0 .09091 m
.00375 .09091 L
s
0 .13636 m
.00375 .13636 L
s
0 .22727 m
.00375 .22727 L
s
0 .27273 m
.00375 .27273 L
s
0 .31818 m
.00375 .31818 L
s
0 .40909 m
.00375 .40909 L
s
0 .45455 m
.00375 .45455 L
s
0 .5 m
.00375 .5 L
s
0 .59091 m
.00375 .59091 L
s
0 .63636 m
.00375 .63636 L
s
0 .68182 m
.00375 .68182 L
s
0 .77273 m
.00375 .77273 L
s
0 .81818 m
.00375 .81818 L
s
0 .86364 m
.00375 .86364 L
s
0 .95455 m
.00375 .95455 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .18182 m
1 .18182 L
s
.99375 .36364 m
1 .36364 L
s
.99375 .54545 m
1 .54545 L
s
.99375 .72727 m
1 .72727 L
s
.99375 .90909 m
1 .90909 L
s
.125 Mabswid
.99625 .04545 m
1 .04545 L
s
.99625 .09091 m
1 .09091 L
s
.99625 .13636 m
1 .13636 L
s
.99625 .22727 m
1 .22727 L
s
.99625 .27273 m
1 .27273 L
s
.99625 .31818 m
1 .31818 L
s
.99625 .40909 m
1 .40909 L
s
.99625 .45455 m
1 .45455 L
s
.99625 .5 m
1 .5 L
s
.99625 .59091 m
1 .59091 L
s
.99625 .63636 m
1 .63636 L
s
.99625 .68182 m
1 .68182 L
s
.99625 .77273 m
1 .77273 L
s
.99625 .81818 m
1 .81818 L
s
.99625 .86364 m
1 .86364 L
s
.99625 .95455 m
1 .95455 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
0 0 m
0 .01142 L
.03571 .01142 L
.03571 0 L
F
0 g
.5 Mabswid
0 0 m
0 .01142 L
.03571 .01142 L
.03571 0 L
0 0 L
s
1 0 0 r
.03571 0 m
.03571 .07615 L
.07143 .07615 L
.07143 0 L
F
0 g
.03571 0 m
.03571 .07615 L
.07143 .07615 L
.07143 0 L
.03571 0 L
s
1 0 0 r
.07143 0 m
.07143 .21084 L
.10714 .21084 L
.10714 0 L
F
0 g
.07143 0 m
.07143 .21084 L
.10714 .21084 L
.10714 0 L
.07143 0 L
s
1 0 0 r
.10714 0 m
.10714 .39863 L
.14286 .39863 L
.14286 0 L
F
0 g
.10714 0 m
.10714 .39863 L
.14286 .39863 L
.14286 0 L
.10714 0 L
s
1 0 0 r
.14286 0 m
.14286 .60045 L
.17857 .60045 L
.17857 0 L
F
0 g
.14286 0 m
.14286 .60045 L
.17857 .60045 L
.17857 0 L
.14286 0 L
s
1 0 0 r
.17857 0 m
.17857 .78096 L
.21429 .78096 L
.21429 0 L
F
0 g
.17857 0 m
.17857 .78096 L
.21429 .78096 L
.21429 0 L
.17857 0 L
s
1 0 0 r
.21429 0 m
.21429 .89187 L
.25 .89187 L
.25 0 L
F
0 g
.21429 0 m
.21429 .89187 L
.25 .89187 L
.25 0 L
.21429 0 L
s
1 0 0 r
.25 0 m
.25 .9134 L
.28571 .9134 L
.28571 0 L
F
0 g
.25 0 m
.25 .9134 L
.28571 .9134 L
.28571 0 L
.25 0 L
s
1 0 0 r
.28571 0 m
.28571 .84205 L
.32143 .84205 L
.32143 0 L
F
0 g
.28571 0 m
.28571 .84205 L
.32143 .84205 L
.32143 0 L
.28571 0 L
s
1 0 0 r
.32143 0 m
.32143 .71492 L
.35714 .71492 L
.35714 0 L
F
0 g
.32143 0 m
.32143 .71492 L
.35714 .71492 L
.35714 0 L
.32143 0 L
s
1 0 0 r
.35714 0 m
.35714 .57267 L
.39286 .57267 L
.39286 0 L
F
0 g
.35714 0 m
.35714 .57267 L
.39286 .57267 L
.39286 0 L
.35714 0 L
s
1 0 0 r
.39286 0 m
.39286 .43164 L
.42857 .43164 L
.42857 0 L
F
0 g
.39286 0 m
.39286 .43164 L
.42857 .43164 L
.42857 0 L
.39286 0 L
s
1 0 0 r
.42857 0 m
.42857 .30299 L
.46429 .30299 L
.46429 0 L
F
0 g
.42857 0 m
.42857 .30299 L
.46429 .30299 L
.46429 0 L
.42857 0 L
s
1 0 0 r
.46429 0 m
.46429 .2059 L
.5 .2059 L
.5 0 L
F
0 g
.46429 0 m
.46429 .2059 L
.5 .2059 L
.5 0 L
.46429 0 L
s
1 0 0 r
.5 0 m
.5 .13658 L
.53571 .13658 L
.53571 0 L
F
0 g
.5 0 m
.5 .13658 L
.53571 .13658 L
.53571 0 L
.5 0 L
s
1 0 0 r
.53571 0 m
.53571 .07862 L
.57143 .07862 L
.57143 0 L
F
0 g
.53571 0 m
.53571 .07862 L
.57143 .07862 L
.57143 0 L
.53571 0 L
s
1 0 0 r
.57143 0 m
.57143 .04953 L
.60714 .04953 L
.60714 0 L
F
0 g
.57143 0 m
.57143 .04953 L
.60714 .04953 L
.60714 0 L
.57143 0 L
s
1 0 0 r
.60714 0 m
.60714 .02836 L
.64286 .02836 L
.64286 0 L
F
0 g
.60714 0 m
.60714 .02836 L
.64286 .02836 L
.64286 0 L
.60714 0 L
s
1 0 0 r
.64286 0 m
.64286 .01425 L
.67857 .01425 L
.67857 0 L
F
0 g
.64286 0 m
.64286 .01425 L
.67857 .01425 L
.67857 0 L
.64286 0 L
s
1 0 0 r
.67857 0 m
.67857 .00713 L
.71429 .00713 L
.71429 0 L
F
0 g
.67857 0 m
.67857 .00713 L
.71429 .00713 L
.71429 0 L
.67857 0 L
s
1 0 0 r
.71429 0 m
.71429 .00298 L
.75 .00298 L
.75 0 L
F
0 g
.71429 0 m
.71429 .00298 L
.75 .00298 L
.75 0 L
.71429 0 L
s
1 0 0 r
.75 0 m
.75 .00124 L
.78571 .00124 L
.78571 0 L
F
0 g
.75 0 m
.75 .00124 L
.78571 .00124 L
.78571 0 L
.75 0 L
s
1 0 0 r
.78571 0 m
.78571 .00015 L
.82143 .00015 L
.82143 0 L
F
0 g
.78571 0 m
.78571 .00015 L
.82143 .00015 L
.82143 0 L
.78571 0 L
s
.015 w
0 0 m
.00176 .00011 L
.00337 .00041 L
.00522 .00098 L
.00697 .00175 L
.01008 .00367 L
.01346 .00653 L
.01719 .01062 L
.02113 .01601 L
.02821 .02838 L
.04236 .06301 L
.05795 .11508 L
.09059 .26069 L
.12116 .42155 L
.14896 .56681 L
.17931 .7031 L
.19575 .7611 L
.21101 .80279 L
.21853 .8187 L
.2256 .83084 L
.22952 .83636 L
.23376 .84137 L
.23732 .84481 L
.24115 .84772 L
.24313 .8489 L
.24501 .84983 L
.24669 .8505 L
.24852 .85105 L
.25026 .8514 L
.2521 .8516 L
.25367 .85163 L
.25541 .85151 L
.25639 .85137 L
.25743 .85116 L
.25929 .85066 L
.26129 .84992 L
.26348 .84887 L
.26741 .84639 L
.27106 .8434 L
.27906 .83461 L
.28633 .82409 L
.30265 .79252 L
.33143 .715 L
.36263 .61062 L
.42401 .39314 L
.45454 .29732 L
.48311 .22117 L
.51226 .15814 L
.53994 .11155 L
.57037 .07349 L
Mistroke
.59818 .0487 L
.6126 .0389 L
.62795 .03037 L
.65555 .01905 L
.67101 .01449 L
.68772 .01068 L
.7035 .00794 L
.718 .006 L
.73264 .00448 L
.74629 .00339 L
.76127 .00248 L
.77731 .00176 L
.79261 .00126 L
.80923 .00087 L
.82492 .0006 L
.83943 .00043 L
.8539 .0003 L
.86748 .00022 L
.88237 .00015 L
.89074 .00012 L
.8984 .0001 L
.90554 8e-05 L
.91315 7e-05 L
.92685 5e-05 L
.93523 4e-05 L
.94314 3e-05 L
.95018 2e-05 L
.95792 2e-05 L
.97254 1e-05 L
.98053 1e-05 L
.988 1e-05 L
Mfstroke
.988 1e-05 m
1 1e-05 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo002?
ooooo`03oa0@4?lb<S;o410@00;o000000?oA4A4olc<c?ooool0E?ooool008oooooo00?o0000oiRH
V?o^k^h00_ooool00on7QhOo410@ooooo`1Dooooo`00U?ooool00onj^[[o0000ooooo`1Dooooo`00
Soooool00oo<c<coA4A4o`000003o`000003oiRHV?oooooooooo05?ooooo002?ooooo`05o`000?n7
QhOo^[ZjokZj^_o<c<`0Eoooool008oooooo00?o0000oiRHV?ooool00_ooool00oo<c<co410@oooo
o`1Dooooo`00Soooool01oo<c<coA4A4o`000?l0003o410@oc8b<_l00000EOooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00E_ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Kooooo00Go
V9RHoa0@4?l0003o0000ofIVIP04ooooo`Co000000?o410@ooooooooool01?ooool4o`000003oa0@
4?oooooooooo00Cooooo00?oEEEEo`000?mEEED01_ooool01OnHV9So410@o`000?l0003oIVIV00?o
oooo1_l00005ooooo`Ko00001_ooool00omEEEGo0000oeEEE@06ooooo`05oiRHV?l@413o0000o`00
0?mVIVH01?ooool01OnYZJWo8B4Qo`000?l0003oIVIV00Kooooo00GoZJVYob4Q8Ol0003o0000ofIV
IP06ooooo`03oeEEEOl0003oEEEE00Kooooo00GoV9RHoa0@4?l0003o0000ofIVIP05ooooo`00EOoo
ool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`06oa0@4?n7QhOooooooooo
oomgMgOoIVIV1Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo0ol00006
ooooo`06oa0@4?n7QhOooooooooooomgMgOoIVIV0_ooool00onHV9So0000omgMg@02ooooo`03oa0@
4?oooooooooo00?ooooo00?oV9RHo`000?oMgMd00_ooool00ol@413oooooooooo`04ooooo`?o0000
1_ooool01_l@413oQhN7ooooooooooooMgMgofIVIP?ooooo00Ko410@olc<c?ooooooooooogMgMomV
IVH5ooooo`06oa0@4?o<c<cooooooooooomgMgOoIVIV1Oooool3o`0000Kooooo00Ko410@ohN7Qooo
ooooooooogMgMomVIVH4ooooo`00EOooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?o
EEEEo`000?mEEED02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01_ooool00omEEEGo0000oeEEE@0;ooooo`07o`000?oooooooooooooooon7QhOo
8B4Qonk^kP08ooooo`03ohN7QolQ8B7ok^k^00Sooooo00?oEEEEo`000?mEEED02oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00omEEEGo
0000oeEEE@0;ooooo`03o`000?oooooooooo00;ooooo001Eooooo`06o`000?o^k^koooooooooooo^
k^ko00004_ooool00oo^k^ko0000ooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04oooool00oo^k^ko0000ooooo`03ooooo`03ojVYZOlQ8B7ok^k^00Sooooo00?oZJVYob4Q
8Oo^k^h05?ooool00oo^k^ko0000ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool04?ooool00oo^k^ko0000ooooo`03ooooo`00EOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00cooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH5ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03oooool01_l@413oV9RHooooooooooooMgMgofIVIPGooooo
00?oV9RHoc8b<_ooool02?ooool00onHV9So<S8booooo`0?ooooo`06oa0@4?nHV9Sooooooooooomg
MgOoIVIV1oooool00onYZJWoA4A4ooooo`08ooooo`03ojVYZOm4A4Cooooo00gooooo00Ko410@oiRH
V?ooooooooooogMgMomVIVH4ooooo`00EOooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00cooooo00Go0000ob4Q8Ol0003o0000ofIVIP06ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool03oooool01Ol0003o8B4Qo`000?l0003oIVIV00Oooooo00?oA4A4ogMgMoooool0
2?ooool00om4A4CoMgMgooooo`0>ooooo`05o`000?lQ8B7o0000o`000?mVIVH01_ooool01?lQ8B7o
0000o`000?oMgMd7ooooo`04ob4Q8Ol0003o0000omgMg@kooooo00Go0000ob4Q8Ol0003o0000ofIV
IP05ooooo`00EOooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
2Oooool00ooMgMgo410@ooooo`08ooooo`03omgMgOl@413ooooo00kooooo00?o0000ooooooooool0
2_ooool00onYZJWo<S8booooo`08ooooo`03ojVYZOlb<S;ooooo00gooooo00?o0000ooooooooool0
1oooool005Gooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@>ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oo
oooo001Eooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool00ol0003oooooooooo`06oooo
o`03o`000?m4A4Co000000Sooooo00?o0000odA4A?l000004Oooool00ol0003oooooooooo`05oooo
o`06o`000?n7QhOok^k^oooooonHV9SoEEEE1Oooool01_l0003oQhN7onk^k_ooooooV9RHoeEEE@oo
oooo00?o0000ooooooooool01_ooool01_lQ8B7o^[ZjooooooooooooIVIVoc8b<PGooooo00Ko8B4Q
okZj^_ooooooooooofIVI_lb<S8>ooooo`03o`000?oooooooooo00Oooooo001Fooooo`04oiRHV?l0
003o0000oiRHV0oooooo1Ol00004ooooo`03olc<c?mEEEGo000000Sooooo00?oc<c<oeEEEOl00000
4Oooool5o`0000?ooooo00KoZJVYoc8b<_l0003o0000oeEEEOo^k^h5ooooo`06ojVYZOlb<S;o0000
o`000?mEEEGok^k^3oooool5o`0000Cooooo00Ko^[ZjodA4A?l0003o0000odA4A?o^k^h5ooooo`06
okZj^_m4A4Co0000o`000?m4A4Cok^k^3_ooool5o`0000Gooooo003[ooooo`00joooool00>_ooooo
001=ooooohgo00004Oooool004gooooo0ol00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool002ko00004Oooool004gooooo1_l00004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`005_l0000Looooo`03o`000?oooooooooo00oooooo001=ooooo`Co
000000?oooooo`000?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000So0000:_ooool00ol0003o
ooooooooo`0?ooooo`00COooool00ol0003oooooo`000003o`0000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`002?l0000_ooooo`03o`00
0?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo00?o00001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0006o`00037ooooo00?o
0000ooooooooool03oooool004gooooo00?o0000ooooooooool00ol00004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001?l0003oo`00ool00?oo0005o`0003?ooooo00?o
0000ooooooooool03oooool004gooooo0_l00002ooooo`;o00001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`001ol0000eooooo`03o`000?oooooooooo00oooooo001=oooo
o`04o`000?ooooooooooooooo`;o00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ooooool000000_l0000gooooo`03o`000?oooooooooo00oooooo001=oooo
o`04o`000?ooooooooooooooo`?o00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`001?l0000hooooo`03o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo
00;ooooo0_l00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0003o`00
03Wooooo00?o0000ooooooooool03oooool004gooooo00?o0000ooooooooool00_ooool6o`0000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`001ol0000jooooo`03o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo00;ooooo
0ol00002ooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Co0000oooooooooooooooo0_l0000kooooo`03
o`000?oooooooooo00oooooo001=ooooo`;o00001?ooool2o`0000;ooooo00?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`03o`0003_ooooo00?o0000ooooooooool03oooool004gooooo00?o
0000ooooooooool00oooool2o`0000;ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oooooo`00
0002o`0003cooooo00?o0000ooooooooool03oooool004gooooo00?o0000ooooooooool00oooool3
o`000003ooooool0003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`001?l0000mooooo`03o`000?oooooooooo00oooooo001=oooo
o`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000?o0000?_ooool00ol0
003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?oo
00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo0002o`0003oooooo00?o0000ooooooooool03oooool004gooooo00?o0000ooooooooool0
1?ooool2o`000003ooooool0003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00004o`000?oo003oo`00ool000?o0000?oooool00ol0003oooooooooo`0?ooooo`00
COooool2o`0000Gooooo1?l00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo0006o`00043ooooo00?o0000ooooooooool03oooool004gooooo00?o0000ooooooooool01Ooo
ool3o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
oooooooo00;o0000@Oooool00ol0003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`05
ooooo`?o00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ooooool000000_l00011ooooo`03o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo
00Gooooo0ol00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0004o`00
04;ooooo00?o0000ooooooooool03oooool0033ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omE
EEGo0000oeEEE@05ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`?o00001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`000ol00013ooooo`03o`000?oooooooooo
00oooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Gooooo00?oV9RH
o`000?oMgMd00_ooool00ol@413oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo0_l00004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0003o`0004?ooooo00?o0000
ooooooooool03oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0
003oEEEE00Kooooo00?oQhN7ob4Q8Oo^k^h01oooool00ol0003oooooooooo`06ooooo`;o00001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`000_l00014ooooo`03o`000?oo
oooooooo00oooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00003oooool00onYZJWo8B4Q
onk^kP06ooooo`;o00001oooool2o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001?l0003oo`00
ool00?oo0003o`0004?ooooo0_l0000Aooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00kooooo00?oV9RHoc8b<_ooool01Oooool00ol0003oooooooooo`06ooooo`?o0000
0ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00004o`000?oo003oo`00ool000;o0000AOooool00ol0003o
ooooooooo`0?ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo
00?oA4A4ogMgMoooool01?ooool00ol0003oooooooooo`07ooooo`;o00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00004o`000?oo003oo`00ool000;o0000AOooool00ol0003oooooooooo`0?ooooo`00
;oooool01_l0003ok^k^ooooooooooook^k^o`00017ooooo00?ogMgMoa0@4?ooool01?ooool00ol0
003oooooooooo`07ooooo`;o00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000Ko0000AOooool00ol0
003oooooooooo`0?ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A1;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`Ko00001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`02
o`0004Kooooo00?o0000ooooooooool03oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj
^[X=ooooo`06o`000?n7QhOok^k^oooooonHV9SoEEEE1Oooool00ol0003oooooooooo`07ooooo`;o
00000oooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oooooo000000;o0000A_ooool00ol0003o
ooooooooo`0?ooooo`00<?ooool01?nHV9So0000o`000?nHV9P>ooooo`06ojVYZOlb<S;o0000o`00
0?mEEEGok^k^1Oooool2o`0000Sooooo0ol00002ooooo`03o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Co0000
ooooool0003o0000Aoooool00ol0003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`08
ooooo`;o00000_ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool000Co0000Aoooool00ol0003oooooooooo`0?
ooooo`00COooool00ol0003oooooooooo`08ooooo`;o00000_ooool00ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
00?o0000B?ooool00ol0003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`08ooooo`;o
00000_ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool000?o0000B?ooool00ol0003oooooooooo`0?ooooo`00
COooool00ol0003oooooooooo`08ooooo`?o000000?oooooo`000?oo00000ooo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0003o`0004Sooooo
00?o0000ooooooooool03oooool004gooooo00?o0000ooooooooool02Oooool2o`000003ooooool0
003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`000_l00019ooooo`03o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooo
oooo00Wooooo0_l000000ooooooo0000ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool000;o0000BOooool00ol0003oooooooooo`0?
ooooo`00COooool2o`0000[ooooo0_l000000ooooooo0000ool00003ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001?l0003oo`00ool00?oo0003o`0004Wooooo00?o0000
ooooooooool03oooool004gooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003oo`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00004o`000?oo003oo`00
ool000;o0000B_ooool00ol0003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`09oooo
o`Co00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Co0000ool0
0?oo003oo`000_l0001:ooooo`03o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo
00[ooooo0ol00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00003o`0004[ooooo00?o0000ooooooooool03oooool004gooooo00?o0000oooooooo
ool02_ooool3o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000Ko
0000B_ooool00ol0003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`0:ooooo`?o0000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ooooool00000
0_l0001;ooooo`03o`000?oooooooooo00oooooo001=ooooo`;o00002oooool3o`0000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00004o`000?oooooo0000o`0004cooooo
00?o0000ooooooooool03oooool004gooooo00?o0000ooooooooool02_ooool3o`0000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00004o`000?oooooo0000o`0004cooooo
00?o0000ooooooooool03oooool004gooooo00?o0000ooooooooool02oooool2o`0000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000Co0000C?ooool00ol0003ooooooooo
o`0?ooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003oEEEE00Wooooo0_l0
00000ol@413oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo0_l00004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo0003o`0004gooooo00?o0000ooooooooool03ooo
ool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00002_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00_ooooo0_l00004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo0003o`0004gooooo00?o0000ooooooooool03oooool002oooooo00Ko
A4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo1_l00004ooooo`03
o`000?oooooooooo00_ooooo0_l00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo0002o`0004kooooo00?o0000ooooooooool03oooool002oooooo00Ko0000onk^k_oooooo
ooooonk^k_l0000>ooooo`05odA4A?nj^[[oooooooooool000001Oooool2o`0000cooooo0_l00004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0002o`0004gooooo0_l0000A
ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00GogMgMob4Q
8Oooooooooooo`000005ooooo`03o`000?oooooooooo00_ooooo0ol00003ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Co0000ool00?oo003oo`000ol0001>ooooo`03o`000?oooooooooo00oooooo000_
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01?mgMgOoV9RHooooool0
0005ooooo`03o`000?oooooooooo00cooooo0_l00003ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Co
0000ool00?oo003oo`000_l0001?ooooo`03o`000?oooooooooo00oooooo000_ooooo`06o`000?o^
k^koooooooooooo^k^ko00003oooool01?o^k^ko8B4Qooooool00005ooooo`03o`000?oooooooooo
00cooooo0_l00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Co0000ool00?oo003oo`000_l0001?
ooooo`03o`000?oooooooooo00oooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A44?oo
ool00omgMgOoV9RHo`000005ooooo`03o`000?oooooooooo00cooooo0_l00003ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000ol0001?ooooo`03o`000?oooooooooo00oooooo000_
ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj4?ooool00oo^k^ko<S8bo`000005ooooo`03o`00
0?oooooooooo00cooooo1_l00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o0000Coooool00ol0003ooooo
ooooo`0?ooooo`00<?ooool01?nHV9So0000o`000?nHV9PBooooo`03oiRHV?l@413ooooo00Cooooo
00?o0000ooooooooool03?ooool3o`0000;ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00003o`0004oooooo00?o0000ooooooooool03oooool004gooooo0_l0000>ooooo`;o00000_oo
ool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003o000000?o0000Coooool00ol0003ooooooooo
o`0?ooooo`00COooool00ol0003oooooooooo`0=ooooo`;o00000_ooool00ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00006o`000?oo003o0000o`000?oo003o0000Coooool00ol0003oooooooooo`0?ooooo`00COoo
ool00ol0003oooooooooo`0=ooooo`;o00000_ooool00ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00006o`000?oo
003o0000o`000?oo003o0000Coooool00ol0003oooooooooo`0?ooooo`00COooool00ol0003ooooo
ooooo`0=ooooo`;o00000_ooool00ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000Ko0000Coooool00ol0003ooooo
ooooo`0?ooooo`00COooool00ol0003oooooooooo`0=ooooo`;o00000_ooool00ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool000Co0000DOooool00ol0003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`0=
ooooo`?o000000?oooooo`000?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo0003o`0005;ooooo00?o0000ooooooooool03oooool0
013ooooo00?o^[Zjoc8b<_ooool03_ooool00olb<S;o^[Zjooooo`0Yooooo`;o00003oooool2o`00
0003ooooool0003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`000ol0001Booooo`03o`000?oooooooooo00oooooo000@ooooo`03
oc8b<_nj^[[ooooo00kooooo00?o^[Zjoc8b<_ooool0:Oooool00ol0003oooooooooo`0>ooooo`;o
000000?oooooo`000?oo00000ooo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo0003o`0005;ooooo00?o0000ooooooooool03oooool000oooooo
00?oc<c<oc8b<_ooool04?ooool00olb<S;oc<c<ooooo`0Xooooo`03o`000?oooooooooo00kooooo
0_l000000ooooooo0000ool00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool000?o0000D_ooool00ol0003oooooooooo`0?ooooo`000_oo
ool01Ol@413o0000o`000?l0003o410@00Sooooo00?oIVIVojVYZOooool01?ooool00ol@413o<S8b
oa0@4002o`000003odA4A?o<c<cooooo00Cooooo00?oV9RHofIVI_ooool0:?ooool00ol0003ooooo
ooooo`0>ooooo`;o000000?oooooo`000?oo00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0002o`0005?ooooo00?o0000ooooooooool0
3oooool000Cooooo00?o0000ooooooooool02?ooool00olb<S;oooooooooo`04ooooo`03o`000?nH
V9Sok^k^00;ooooo00?oQhN7oa0@4?ooool01?ooool00oo^k^ko<S8booooo`0Xooooo`03o`000?oo
oooooooo00kooooo1?l00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool000;o0000Doooool00ol0003oooooooooo`0?ooooo`001?ooool0
0ol0003oooooooooo`08ooooo`03oc8b<_oooooooooo00Wooooo00?o^[Zjo`000?ooool01Oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00oooooo0ol00004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000;o0000Doooool0
0ol0003oooooooooo`0?ooooo`001?ooool3o`000003oa0@4?mgMgOok^k^00Gooooo00?o<S8boooo
ooooool01?ooool00oo<c<coA4A4o`000003o`000003oiRHV?oooooooooo00Cooooo00?o0000oooo
ooooool09oooool2o`00013ooooo0ol00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001?l0003oo`00ool00?oo0003o`0005?ooooo00?o0000ooooooooool03oooool0
00Cooooo00Ko0000ooooooooooook^k^ogMgMomEEED5ooooo`03ob4Q8Ooooooooooo00Cooooo00Go
0000ohN7Qonj^[[o^[Zjolc<c008ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
3oooool3o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00004o`00
0?oo003oo`00ool000;o0000E?ooool00ol0003oooooooooo`0?ooooo`001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o<S8bonk^k_ooool01?ooool00ol0003oV9RH
ooooo`02ooooo`03olc<c?l@413ooooo00Cooooo00?ogMgMoc8b<_ooool0:?ooool00ol0003ooooo
ooooo`0?ooooo`?o00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Co0000ool00?oo003oo`000_l0001Dooooo`03o`000?oooooooooo00oooooo0004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00omVIVKoV9RHooooo`04ooooo`07olc<
c?m4A4Co0000o`000?l@413o<S8bo`000005ooooo`03oiRHV?mVIVKooooo02Sooooo00?o0000oooo
ooooool03oooool3o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?o0000E?ooool00ol0003oooooooooo`0?ooooo`001?ooool01_l0003o
ooooooooooo^k^koMgMgoeEEE@Gooooo00?ogMgMob4Q8Oooool04?ooool00ol@413oc<c<ooooo`0;
ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01_ooool01_o^k^koEEEEo`00
0?l0003oEEEEonk^kPCooooo00?o0000ooooooooool04?ooool2o`0000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o0000E?ooool00ol0003o
ooooooooo`0?ooooo`000_ooool00ol@413o0000o`000002o`000003oa0@4?mgMgOok^k^00Kooooo
00?o<S8bokZj^_ooool03_ooool00onj^[[o<S8booooo`0;ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ
8B7o^[Zj1Oooool3o`0000Kooooo0_mgMgL2ooooo`03ogMgMomEEEGooooo00?ooooo00?o0000oooo
ooooool04?ooool2o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000?o0000E?ooool00ol0003oooooooooo`0?ooooo`004?ooool00onj^[[o
<S8booooo`0>ooooo`03oc8b<_nj^[[ooooo00_ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5
ooooo`03oeEEEOl0003oEEEE00Kooooo00?o8B4Qooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo013ooooo0_l00004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00003o`0005Cooooo00?o0000ooooooooool03oooool0
02oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`03o`000?o^k^kooooo00;ooooo00?o
0000ooooooooool00_ooool2o`00017ooooo0_l00004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00o`000003o`0005?ooooo0_l0000Aooooo`00;oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Ko0000oeEEEOo^k^koooooogMg
MomEEED4ooooo`03o`000?oooooooooo013ooooo0ol00003ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001_l0003oo`00o`000?l0003oo`00o`0005Cooooo00?o0000oooo
ooooool03oooool002oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`06
o`000?mgMgOo0000o`000?mEEEGok^k^1?ooool00ol0003oooooooooo`0Aooooo`;o00000ooo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Ko0000ool00?l0003o0000ool0
0?l0001Dooooo`03o`000?oooooooooo00oooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko
00003_ooool00om4A4CoV9RHooooo`07ooooo`03o`000?oooooooooo017ooooo0_l00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001_l0003oo`00o`000?l0003oo`00
o`0005Cooooo00?o0000ooooooooool03oooool002oooooo00KoA4A4oiRHV?oooooooooooiRHV?m4
A4@>ooooo`03okZj^_lQ8B7ooooo00Oooooo00?o0000ooooooooool04Oooool2o`0000?oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000Ko0000E?ooool00ol0003ooooooooo
o`0?ooooo`00;oooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Poooooo00?oEEEEoc8b<_oMgMd0
1_ooool00ol0003oooooooooo`0Aooooo`;o00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`000ol0001Gooooo`03o`000?oooooooooo00oooooo000`ooooo`04oiRHV?l0
003o0000oiRHV17ooooo00CoV9RHob4Q8Ol0003o8B4Q1?ooool2o`0001;ooooo0ol00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0003o`0005Oooooo00?o0000oooooooo
ool03oooool004gooooo00?o0000ooooooooool04Oooool6o`0000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo0003o`0005Oooooo00?o0000ooooooooool03oooool004gooooo00?o0000ooooooooool04_oo
ool2o`0000;ooooo00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000?o0000Eooo
ool00ol0003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`0Booooo`;o00000_ooool0
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`000_l0001Hooooo`03o`000?oooooo
oooo00oooooo001=ooooo`03o`000?oooooooooo01;ooooo0_l00002ooooo`03o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo0002o`0005Sooooo00?o0000ooooooooool03oooool004go
oooo00?o0000ooooooooool04_ooool3o`000003ooooool0003oo`0000?oo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Co0000ool00?oo
003oo`000ol0001Hooooo`03o`000?oooooooooo00oooooo001=ooooo`;o00005?ooool2o`000003
ooooool0003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Co0000ool00?oo003oo`000_l0001Iooooo`03o`000?oooooooooo
00oooooo001=ooooo`03o`000?oooooooooo01?ooooo0_l000000ooooooo0000ool00003ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00004
o`000?oo003oo`00ool000;o0000FOooool00ol0003oooooooooo`0?ooooo`00COooool00ol0003o
ooooooooo`0Cooooo`;o000000?oooooo`000?oo00000ooo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00003o`0005Wo
oooo00?o0000ooooooooool03oooool004gooooo00?o0000ooooooooool04oooool2o`000003oooo
ool0003oo`0000?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000ol0001Iooooo`03o`000?oooooooooo00oooooo
001=ooooo`03o`000?oooooooooo01?ooooo1?l00004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000?o0000FOoo
ool00ol0003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`0Dooooo`?o00001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00o`000003o`0005Wooooo00?o0000ooooooooool03oooool004gooooo00?o0000oooo
ooooool05?ooool3o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Ko0000ool00?l0003o0000ool00?l0001Iooooo`03o`000?oo
oooooooo00oooooo001=ooooo`;o00005Oooool3o`0000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Ko0000ool00?l0003o0000ool0
0?l0001Iooooo`03o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo01Cooooo0ol0
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool000Co000000?oo`00o`000?ooool0F?ooool00ol0003oooooooooo`0?ooooo`00COooool0
0ol0003oooooooooo`0Dooooo`?o00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo0003o`0000;oo`0000?o0000ooooooooool0Eoooool0
0ol0003oooooooooo`0?ooooo`00<?ooool01?nHV9So0000o`000?nHV9P6ooooo`03oeEEEOl0003o
EEEE00Kooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h4ooooo`03o`000?oooooooooo01Gooooo
0_l00004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool000?o00000_oo00000ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00oooooo
000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo00KoEEEEogMgMooo
ooooooooogMgMomEEED4ooooo`03o`000?oooooooooo01Gooooo0_l00004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool000Ko0000FOooool0
0ol0003oooooooooo`0?ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?o
EEEEo`000?mEEED01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05Oooool2o`0000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`000_l0001Mooooo`03o`000?oooooooooo00oooooo000_
ooooo`06o`000?o^k^koooooooooooo^k^ko00003_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo0_l0000Fooooo`?o00000ooo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Co0000ool00?oo003oo`000ol0001Looooo`;o00004Oooool002oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`06oeEEEOmgMgOooooooooooomg
MgOoEEEE1?ooool00ol0003oooooooooo`0Fooooo`;o00000ooo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Co0000ool00?oo003oo`000_l0001Nooooo`03o`000?oooooo
oooo00oooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ooM
gMgo0000o`000002o`000003omgMgOoooooooooo00;ooooo00?o0000ooooooooool05_ooool2o`00
00?oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00004o`000?oo003oo`00
ool000;o0000G_ooool00ol0003oooooooooo`0?ooooo`00;oooool01_l0003ok^k^oooooooooooo
k^k^o`0000kooooo00Ko<S8bofIVI_o^k^kok^k^ofIVI_lb<S84ooooo`03o`000?oooooooooo01Ko
oooo0_l00003ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00003o`0005kooooo00?o0000ooooooooool03oooool002oooooo00KoA4A4oiRHV?oooooo
oooooiRHV?m4A4@>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Fooooo`?o00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000ol0001Nooooo`03o`000?oooooooooo00oooooo000_ooooo`06
okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_ooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<PCooooo
00?o0000ooooooooool05_ooool3o`0000;oo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000?o0000G_ooool00ol0003oooooooooo`0?ooooo`00<?oo
ool01?nHV9So0000o`000?nHV9P?ooooo`06onk^k_m4A4Co0000o`000?m4A4Cok^k^1?ooool00ol0
003oooooooooo`0Fooooo`?o00000_oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?l000000ol0001Nooooo`03o`000?oooooooooo00oooooo001=ooooo`;o
00005oooool4o`000003ool00?l0003oo`0000?oo`0000?o0000ool00?oo00000_oo00001_l0003o
o`00o`000?l0003oo`00o`0005kooooo00?o0000ooooooooool03oooool004gooooo00?o0000oooo
ooooool05_ooool6o`0000Coo`0000?o0000ool00?oo00000_oo00001_l0003oo`00o`000?l0003o
o`00o`0005kooooo00?o0000ooooooooool03oooool004gooooo00?o0000ooooooooool06?ooool4
o`0000Coo`0000?o0000ool00?oo00000_oo0004o`000003ool00?l0003ooooo05gooooo00?o0000
ooooooooool03oooool004gooooo00?o0000ooooooooool06Oooool3o`0000Coo`0000?o0000ool0
0?oo00000_oo0003o`0000;oo`0000?o0000ooooooooool0G?ooool00ol0003oooooooooo`0?oooo
o`00COooool00ol0003oooooooooo`0Iooooo`?o00001?oo00000ol0003oo`00ool00002ool000?o
00000_oo00000ol0003oooooooooo`1Looooo`03o`000?oooooooooo00oooooo001=ooooo`03o`00
0?oooooooooo01[ooooo0_l00004ool00003o`000?oo003oo`0000;oo`000_l00003ool00003o`00
0?oooooooooo05cooooo00?o0000ooooooooool03oooool004gooooo0_l0000Kooooo`?o00000ooo
00000ol0003oo`00ool00002ool000;o00000ooo00000ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo00oooooo001=ooooo`03o`000?oooooooooo01_ooooo0_l00003ool00004o`000?oo003o
o`00ool000?o00000ooo00000ol0003oooooooooo`1Looooo`03o`000?oooooooooo00oooooo001=
ooooo`03o`000?oooooooooo01_ooooo0ol00002ool00003o`000?oo003oo`0000?o00001?oo0000
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo
01_ooooo1?l000000ooo003o0000ool00009o`0005kooooo00?o0000ooooooooool03oooool004go
oooo00?o0000ooooooooool06oooool00ol0003oo`00o`000006o`000003ool00?l0003ooooo06;o
oooo00?o0000ooooooooool03oooool004gooooo00?o0000ooooooooool06oooool00ol0003oo`00
o`000006o`000003ool00?l0003ooooo06;ooooo00?o0000ooooooooool03oooool004gooooo0_l0
000Looooo`04o`000?oo003oo`00ool000?o00000ooo00000ol0003oooooooooo`1Qooooo`03o`00
0?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo01_ooooo00?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00003o`000?oooooooooo067ooooo00?o0000ooooooooool03ooo
ool004gooooo00?o0000ooooooooool06oooool00ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000?o0000ooooooooool0HOooool00ol0003oooooooooo`0?ooooo`00COooool00ol0
003oooooooooo`0Kooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00000ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo00oooooo0012ooooo`Co000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`0Kooooo`Ko00001?oo00000ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo00oooooo0014ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
8?ooool00ol0003oo`00ool00002ool00003o`000?oooooooooo067ooooo00?o0000ooooooooool0
3oooool004Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0HOooool00ol0003oooooooooo`0?ooooo`00A?ooool0
0ol0003oooooooooo`06ooooo`;o00008Oooool6o`0006;ooooo0_l0000Aooooo`00A?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool03oooool004Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo00oo
oooo0014ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ROooool00ol0003ooooo
ooooo`0?ooooo`00A?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08Wooooo00?o
0000ooooooooool03oooool004;ooooo00?o0000odA4A?l000002?ooool00ol0003oooooooooo`29
ooooo`03o`000?oooooooooo00oooooo0012ooooo`03olc<c?mEEEGo000000Sooooo0_l0002:oooo
o`03o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo08Wooooo00?o0000oooooooo
ool03oooool004gooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0?ooooo`00COoo
ool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooo
oooo08Wooooo00?o0000ooooooooool03oooool004gooooo00?o0000ooooooooool0ROooool00ol0
003oooooooooo`0?ooooo`00COoooon=o`00017ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-1.93787, -0.516903, 0.0249839, \
0.00785206}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Odlyzko's website also provides tables of zeta zeros that are far up the \
critical line.  For example, the data file titled \"zeros5\" contains the ",
  Cell[BoxData[
      \(TraditionalForm\`zeta\ zeros\ 10\^22\)]],
  "+1 to ",
  Cell[BoxData[
      \(TraditionalForm\`10\^22\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`10\^4\)]],
  ".  Because these numbers are so large the density of zeta zeros in this \
range is approximately uniform and we could avoid the unfolding altogether \
and simply rescale the average spacing to 1.  The code below generates a \
histogram showing the density of the zeta zeros in this range.  It is clear \
that the density is roughly uniform for this range of values.  Note that the \
numbers listed in Odlyzko's table (file \"zeros5\" on his website) are \
actually the values of the zeta zeros minus ",
  "1370919909931995300000."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ZetaZero5 = ReadList["\<zeros5\>", Real];\)\), "\n", 
    \(\(L5 = Length[ZetaZero5];\)\), "\[IndentingNewLine]", 
    \(\(int = 
        Table[ZetaZero5[\([1]\)] + 
            i*\((ZetaZero5[\([L5]\)] - ZetaZero5[\([1]\)])\)/25, {i, 0, 
            25}];\)\), "\[IndentingNewLine]", 
    \(ZHist1 = 
      Histogram[ZetaZero5, HistogramCategories \[Rule] int, 
        HistogramScale \[Rule] L5, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, 
        FrameLabel \[Rule] {"\<\[Gamma]-1370919909931995300000\>", "\<\[Rho](\
\[Gamma])\>"}, RotateLabel \[Rule] False]\)}], "Input"],

Cell[BoxData[
    \(Histogram::"rtail1" \(\(:\)\(\ \)\) 
      "Warning: One point from the right tail of the data, greater than or \
equal to \!\(9568.33538975`\), is not included in histogram."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-6.13174 0.000745348 0.0147151 0.0787655 [
[.12918 -0.0125 -21.125 -18 ]
[.12918 -0.0125 21.125 0 ]
[.27825 -0.0125 -21.125 -18 ]
[.27825 -0.0125 21.125 0 ]
[.42732 -0.0125 -21.125 -18 ]
[.42732 -0.0125 21.125 0 ]
[.57639 -0.0125 -21.125 -18 ]
[.57639 -0.0125 21.125 0 ]
[.72546 -0.0125 -21.125 -18 ]
[.72546 -0.0125 21.125 0 ]
[.87453 -0.0125 -21.125 -18 ]
[.87453 -0.0125 21.125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -116.75 -36 ]
[.5 -0.0125 116.75 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .09348 -13.5625 -9 ]
[-0.0125 .09348 0 9 ]
[-0.0125 .17225 -13.5625 -9 ]
[-0.0125 .17225 0 9 ]
[-0.0125 .25101 -13.5625 -9 ]
[-0.0125 .25101 0 9 ]
[-0.0125 .32978 -13.5625 -9 ]
[-0.0125 .32978 0 9 ]
[-0.0125 .40854 -13.5625 -9 ]
[-0.0125 .40854 0 9 ]
[-0.0125 .48731 -13.5625 -9 ]
[-0.0125 .48731 0 9 ]
[-0.0125 .56607 -13.5625 -9 ]
[-0.0125 .56607 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -55.8125 -9 ]
[-0.01875 .30902 -13.5625 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12918 0 m
.12918 .00625 L
s
gsave
.12918 -0.0125 -82.125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8400) show
1.000 setlinewidth
grestore
.27825 0 m
.27825 .00625 L
s
gsave
.27825 -0.0125 -82.125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8600) show
1.000 setlinewidth
grestore
.42732 0 m
.42732 .00625 L
s
gsave
.42732 -0.0125 -82.125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8800) show
1.000 setlinewidth
grestore
.57639 0 m
.57639 .00625 L
s
gsave
.57639 -0.0125 -82.125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9000) show
1.000 setlinewidth
grestore
.72546 0 m
.72546 .00625 L
s
gsave
.72546 -0.0125 -82.125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9200) show
1.000 setlinewidth
grestore
.87453 0 m
.87453 .00625 L
s
gsave
.87453 -0.0125 -82.125 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9400) show
1.000 setlinewidth
grestore
.125 Mabswid
.16645 0 m
.16645 .00375 L
s
.20372 0 m
.20372 .00375 L
s
.24099 0 m
.24099 .00375 L
s
.31552 0 m
.31552 .00375 L
s
.35279 0 m
.35279 .00375 L
s
.39006 0 m
.39006 .00375 L
s
.46459 0 m
.46459 .00375 L
s
.50186 0 m
.50186 .00375 L
s
.53912 0 m
.53912 .00375 L
s
.61366 0 m
.61366 .00375 L
s
.65093 0 m
.65093 .00375 L
s
.68819 0 m
.68819 .00375 L
s
.76273 0 m
.76273 .00375 L
s
.8 0 m
.8 .00375 L
s
.83726 0 m
.83726 .00375 L
s
.09192 0 m
.09192 .00375 L
s
.05465 0 m
.05465 .00375 L
s
.01738 0 m
.01738 .00375 L
s
.9118 0 m
.9118 .00375 L
s
.94907 0 m
.94907 .00375 L
s
.98633 0 m
.98633 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -177.75 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
72.562 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
82.125 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1370919909931995300000) show
292.500 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .09348 m
.00625 .09348 L
s
gsave
-0.0125 .09348 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .17225 m
.00625 .17225 L
s
gsave
-0.0125 .17225 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .25101 m
.00625 .25101 L
s
gsave
-0.0125 .25101 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 .32978 m
.00625 .32978 L
s
gsave
-0.0125 .32978 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .40854 m
.00625 .40854 L
s
gsave
-0.0125 .40854 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .48731 m
.00625 .48731 L
s
gsave
-0.0125 .48731 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
0 .56607 m
.00625 .56607 L
s
gsave
-0.0125 .56607 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03047 m
.00375 .03047 L
s
0 .04622 m
.00375 .04622 L
s
0 .06197 m
.00375 .06197 L
s
0 .07773 m
.00375 .07773 L
s
0 .10923 m
.00375 .10923 L
s
0 .12499 m
.00375 .12499 L
s
0 .14074 m
.00375 .14074 L
s
0 .15649 m
.00375 .15649 L
s
0 .188 m
.00375 .188 L
s
0 .20375 m
.00375 .20375 L
s
0 .21951 m
.00375 .21951 L
s
0 .23526 m
.00375 .23526 L
s
0 .26676 m
.00375 .26676 L
s
0 .28252 m
.00375 .28252 L
s
0 .29827 m
.00375 .29827 L
s
0 .31402 m
.00375 .31402 L
s
0 .34553 m
.00375 .34553 L
s
0 .36128 m
.00375 .36128 L
s
0 .37704 m
.00375 .37704 L
s
0 .39279 m
.00375 .39279 L
s
0 .4243 m
.00375 .4243 L
s
0 .44005 m
.00375 .44005 L
s
0 .4558 m
.00375 .4558 L
s
0 .47156 m
.00375 .47156 L
s
0 .50306 m
.00375 .50306 L
s
0 .51881 m
.00375 .51881 L
s
0 .53457 m
.00375 .53457 L
s
0 .55032 m
.00375 .55032 L
s
0 .58183 m
.00375 .58183 L
s
0 .59758 m
.00375 .59758 L
s
0 .61333 m
.00375 .61333 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -116.812 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.12918 .61178 m
.12918 .61803 L
s
.27825 .61178 m
.27825 .61803 L
s
.42732 .61178 m
.42732 .61803 L
s
.57639 .61178 m
.57639 .61803 L
s
.72546 .61178 m
.72546 .61803 L
s
.87453 .61178 m
.87453 .61803 L
s
.125 Mabswid
.16645 .61428 m
.16645 .61803 L
s
.20372 .61428 m
.20372 .61803 L
s
.24099 .61428 m
.24099 .61803 L
s
.31552 .61428 m
.31552 .61803 L
s
.35279 .61428 m
.35279 .61803 L
s
.39006 .61428 m
.39006 .61803 L
s
.46459 .61428 m
.46459 .61803 L
s
.50186 .61428 m
.50186 .61803 L
s
.53912 .61428 m
.53912 .61803 L
s
.61366 .61428 m
.61366 .61803 L
s
.65093 .61428 m
.65093 .61803 L
s
.68819 .61428 m
.68819 .61803 L
s
.76273 .61428 m
.76273 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.83726 .61428 m
.83726 .61803 L
s
.09192 .61428 m
.09192 .61803 L
s
.05465 .61428 m
.05465 .61803 L
s
.01738 .61428 m
.01738 .61803 L
s
.9118 .61428 m
.9118 .61803 L
s
.94907 .61428 m
.94907 .61803 L
s
.98633 .61428 m
.98633 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09348 m
1 .09348 L
s
.99375 .17225 m
1 .17225 L
s
.99375 .25101 m
1 .25101 L
s
.99375 .32978 m
1 .32978 L
s
.99375 .40854 m
1 .40854 L
s
.99375 .48731 m
1 .48731 L
s
.99375 .56607 m
1 .56607 L
s
.125 Mabswid
.99625 .03047 m
1 .03047 L
s
.99625 .04622 m
1 .04622 L
s
.99625 .06197 m
1 .06197 L
s
.99625 .07773 m
1 .07773 L
s
.99625 .10923 m
1 .10923 L
s
.99625 .12499 m
1 .12499 L
s
.99625 .14074 m
1 .14074 L
s
.99625 .15649 m
1 .15649 L
s
.99625 .188 m
1 .188 L
s
.99625 .20375 m
1 .20375 L
s
.99625 .21951 m
1 .21951 L
s
.99625 .23526 m
1 .23526 L
s
.99625 .26676 m
1 .26676 L
s
.99625 .28252 m
1 .28252 L
s
.99625 .29827 m
1 .29827 L
s
.99625 .31402 m
1 .31402 L
s
.99625 .34553 m
1 .34553 L
s
.99625 .36128 m
1 .36128 L
s
.99625 .37704 m
1 .37704 L
s
.99625 .39279 m
1 .39279 L
s
.99625 .4243 m
1 .4243 L
s
.99625 .44005 m
1 .44005 L
s
.99625 .4558 m
1 .4558 L
s
.99625 .47156 m
1 .47156 L
s
.99625 .50306 m
1 .50306 L
s
.99625 .51881 m
1 .51881 L
s
.99625 .53457 m
1 .53457 L
s
.99625 .55032 m
1 .55032 L
s
.99625 .58183 m
1 .58183 L
s
.99625 .59758 m
1 .59758 L
s
.99625 .61333 m
1 .61333 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .60185 L
.04 .60185 L
.04 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .60185 L
.04 .60185 L
.04 .01472 L
0 .01472 L
s
1 0 0 r
.04 .01472 m
.04 .60185 L
.08 .60185 L
.08 .01472 L
F
0 g
.04 .01472 m
.04 .60185 L
.08 .60185 L
.08 .01472 L
.04 .01472 L
s
1 0 0 r
.08 .01472 m
.08 .60332 L
.12 .60332 L
.12 .01472 L
F
0 g
.08 .01472 m
.08 .60332 L
.12 .60332 L
.12 .01472 L
.08 .01472 L
s
1 0 0 r
.12 .01472 m
.12 .60038 L
.16 .60038 L
.16 .01472 L
F
0 g
.12 .01472 m
.12 .60038 L
.16 .60038 L
.16 .01472 L
.12 .01472 L
s
1 0 0 r
.16 .01472 m
.16 .60185 L
.2 .60185 L
.2 .01472 L
F
0 g
.16 .01472 m
.16 .60185 L
.2 .60185 L
.2 .01472 L
.16 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .60038 L
.24 .60038 L
.24 .01472 L
F
0 g
.2 .01472 m
.2 .60038 L
.24 .60038 L
.24 .01472 L
.2 .01472 L
s
1 0 0 r
.24 .01472 m
.24 .60332 L
.28 .60332 L
.28 .01472 L
F
0 g
.24 .01472 m
.24 .60332 L
.28 .60332 L
.28 .01472 L
.24 .01472 L
s
1 0 0 r
.28 .01472 m
.28 .60185 L
.32 .60185 L
.32 .01472 L
F
0 g
.28 .01472 m
.28 .60185 L
.32 .60185 L
.32 .01472 L
.28 .01472 L
s
1 0 0 r
.32 .01472 m
.32 .60185 L
.36 .60185 L
.36 .01472 L
F
0 g
.32 .01472 m
.32 .60185 L
.36 .60185 L
.36 .01472 L
.32 .01472 L
s
1 0 0 r
.36 .01472 m
.36 .60038 L
.4 .60038 L
.4 .01472 L
F
0 g
.36 .01472 m
.36 .60038 L
.4 .60038 L
.4 .01472 L
.36 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .60185 L
.44 .60185 L
.44 .01472 L
F
0 g
.4 .01472 m
.4 .60185 L
.44 .60185 L
.44 .01472 L
.4 .01472 L
s
1 0 0 r
.44 .01472 m
.44 .60332 L
.48 .60332 L
.48 .01472 L
F
0 g
.44 .01472 m
.44 .60332 L
.48 .60332 L
.48 .01472 L
.44 .01472 L
s
1 0 0 r
.48 .01472 m
.48 .60038 L
.52 .60038 L
.52 .01472 L
F
0 g
.48 .01472 m
.48 .60038 L
.52 .60038 L
.52 .01472 L
.48 .01472 L
s
1 0 0 r
.52 .01472 m
.52 .60332 L
.56 .60332 L
.56 .01472 L
F
0 g
.52 .01472 m
.52 .60332 L
.56 .60332 L
.56 .01472 L
.52 .01472 L
s
1 0 0 r
.56 .01472 m
.56 .60185 L
.6 .60185 L
.6 .01472 L
F
0 g
.56 .01472 m
.56 .60185 L
.6 .60185 L
.6 .01472 L
.56 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .60332 L
.64 .60332 L
.64 .01472 L
F
0 g
.6 .01472 m
.6 .60332 L
.64 .60332 L
.64 .01472 L
.6 .01472 L
s
1 0 0 r
.64 .01472 m
.64 .60038 L
.68 .60038 L
.68 .01472 L
F
0 g
.64 .01472 m
.64 .60038 L
.68 .60038 L
.68 .01472 L
.64 .01472 L
s
1 0 0 r
.68 .01472 m
.68 .60185 L
.72 .60185 L
.72 .01472 L
F
0 g
.68 .01472 m
.68 .60185 L
.72 .60185 L
.72 .01472 L
.68 .01472 L
s
1 0 0 r
.72 .01472 m
.72 .60185 L
.76 .60185 L
.76 .01472 L
F
0 g
.72 .01472 m
.72 .60185 L
.76 .60185 L
.76 .01472 L
.72 .01472 L
s
1 0 0 r
.76 .01472 m
.76 .60185 L
.8 .60185 L
.8 .01472 L
F
0 g
.76 .01472 m
.76 .60185 L
.8 .60185 L
.8 .01472 L
.76 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .60038 L
.84 .60038 L
.84 .01472 L
F
0 g
.8 .01472 m
.8 .60038 L
.84 .60038 L
.84 .01472 L
.8 .01472 L
s
1 0 0 r
.84 .01472 m
.84 .60185 L
.88 .60185 L
.88 .01472 L
F
0 g
.84 .01472 m
.84 .60185 L
.88 .60185 L
.88 .01472 L
.84 .01472 L
s
1 0 0 r
.88 .01472 m
.88 .60332 L
.92 .60332 L
.92 .01472 L
F
0 g
.88 .01472 m
.88 .60332 L
.92 .60332 L
.92 .01472 L
.88 .01472 L
s
1 0 0 r
.92 .01472 m
.92 .60185 L
.96 .60185 L
.96 .01472 L
F
0 g
.92 .01472 m
.92 .60185 L
.96 .60185 L
.96 .01472 L
.92 .01472 L
s
1 0 0 r
.96 .01472 m
.96 .60038 L
1 .60038 L
1 .01472 L
F
0 g
.96 .01472 m
.96 .60038 L
1 .60038 L
1 .01472 L
.96 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo0005ooooo`03ob4Q8Ol0003oc<c<0>?ooooo0005oooo
o`03o`000?nj^[[o8B4Q0>?ooooo0005ooooo`03odA4A?o<c<co000000oooooo1?l000000ol@413o
ooooooooo`03ooooo`05ojVYZOlQ8B7o0000o`000?mVIVH01oooool00ol0003oZJVYooooo`06oooo
o`04oiRHV?l0003o0000oiRHV0Gooooo00Co8B4Qo`000?lQ8B7oV9RH1_ooool4o`000003oa0@4?oo
oooooooo00?ooooo00Co8B4Qo`000?lQ8B7oV9RH1_ooool01?lQ8B7o0000ob4Q8OnHV9P7ooooo`04
oiRHV?l0003o0000oiRHV0Gooooo00Co8B4Qo`000?lQ8B7oV9RH1_ooool01?lQ8B7o0000ob4Q8OnH
V9P6ooooo`05ojVYZOlQ8B7o0000o`000?mVIVH01Oooool4o`000003oa0@4?oooooooooo00?ooooo
00Co8B4Qo`000?lQ8B7oV9RH1_ooool01?lQ8B7o0000ob4Q8OnHV9P6ooooo`05oiRHV?l@413o0000
o`000?mVIVH01Oooool01OnYZJWo8B4Qo`000?l0003oIVIV00Kooooo00CoV9RHo`000?l0003oV9RH
1_ooool01?nHV9So0000o`000?nHV9P6ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00CoV9RHo`00
0?l0003oV9RH1_ooool1oiRHV0001Oooool00onHV9SoMgMgo`00000Aooooo`03o`000?oooooooooo
00Gooooo00Ko410@olc<c?ooooooooooogMgMomVIVH6ooooo`;oEEEE1_ooool01_nj^[[o8B4QomgM
gOoMgMgo8B4QokZj^PKooooo00?ogMgMoc8b<_mEEED01oooool00ol0003oooooooooo`07ooooo`03
omgMgOlb<S;oEEEE00Oooooo00?ogMgMoc8b<_mEEED01Oooool01_nj^[[o8B4QomgMgOoMgMgo8B4Q
okZj^PKooooo00?ogMgMoc8b<_mEEED01oooool00ooMgMgo<S8boeEEE@05ooooo`06oa0@4?o<c<co
oooooooooomgMgOoIVIV1_ooool00ol0003oooooooooo`07ooooo`03omgMgOlb<S;oEEEE00Oooooo
00?ogMgMoc8b<_mEEED01Oooool01_l@413oQhN7ooooooooooooMgMgofIVIPCooooo00Ko410@olc<
c?ooooooooooogMgMomVIVH4ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_nj^[[o
8B4QomgMgOoMgMgo8B4QokZj^PCooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`06okZj
^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool1okZj^P7o8B4Q0006ooooo`03oc8b<_m4A4Cooooo013o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03ojVYZOl0003ooooo00Go
oooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@8ooooo`03ob4Q8OnYZJWooooo00Gooooo00?o0000
ooooooooool02Oooool00olQ8B7oZJVYooooo`07ooooo`03ob4Q8OnYZJWooooo00?ooooo00KoA4A4
oiRHV?oooooooooooiRHV?m4A4@8ooooo`03ob4Q8OnYZJWooooo00Oooooo00?o8B4QojVYZOooool0
2?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o8B4QojVYZOooool0
1oooool00olQ8B7oZJVYooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo00KoA4A4oiRHV?oooooooooooiRHV?m4
A4@4ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41?ooool01_m4A4CoV9RHooooooooooooV9RH
odA4A0Cooooo0Om4A4@1oiRHV0001_ooool00olQ8B7o<S8bolc<c005ooooo`Ko00001Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000olc<c?ooool01?ooool01_l0
003ok^k^ooooooooooook^k^o`0000Sooooo00?oV9RHodA4A?ooool01Oooool00ol0003ooooooooo
o`09ooooo`03oiRHV?m4A4Cooooo00Oooooo00?oV9RHodA4A?ooool00oooool01_l0003ok^k^oooo
ooooooook^k^o`0000Sooooo00?oV9RHodA4A?ooool01oooool00onHV9SoA4A4ooooo`08ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00onHV9SoA4A4ooooo`07ooooo`03
oiRHV?m4A4Cooooo00Oooooo00?ok^k^o`000?ooool02?ooool00ol0003oooooooooo`02ooooo`06
o`000?o^k^koooooooooooo^k^ko00001?ooool01_l0003ok^k^ooooooooooook^k^o`0000Cooooo
00Ko0000onk^k_ooooooooooonk^k_l00004ooooo`06o`000?o^k^koooooooooooo^k^ko00001?oo
ool1o`00007ok^k^0005ooooo`05ofIVI_nYZJWok^k^ob4Q8Oo^k^h03oooool00ol0003ooooooooo
o`09ooooo`03ojVYZOm4A4Cooooo00Kooooo00?oEEEEofIVI_ooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00Kok^k^oeEEEOl0003o0000ofIVI_l00006ooooo`03
o`000?oooooooooo00Gooooo00Kok^k^oeEEEOl0003o0000ofIVI_l00004ooooo`06onk^k_mEEEGo
0000o`000?mVIVKo00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00Kok^k^oeEEEOl0003o0000ofIVI_l00004ooooo`06onk^k_mEEEGo0000o`000?mVIVKo00002?oo
ool00onYZJWoA4A4ooooo`05ooooo`03o`000?oooooooooo00Gooooo00Kok^k^oeEEEOl0003o0000
ofIVI_l00004ooooo`06onk^k_mEEEGo0000o`000?mVIVKo00001?ooool01_l@413oV9RHoooooooo
ooooMgMgofIVIPSooooo00?oZJVYodA4A?ooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo0Ol00001ooooo`000oooool00oo^k^koIVIVoiRHV002ooooo`03olc<c?lb
<S;ok^k^00kooooo00?o0000ooooooooool01oooool01?lQ8B7o0000o`000?oMgMd7ooooo`03ojVY
ZOl@413ooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`06oeEE
EOmgMgOoooooonk^k_mEEEGo00001_ooool00ol0003oooooooooo`05ooooo`06oeEEEOmgMgOooooo
onk^k_mEEEGo00001?ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00001?ooool0
1_mEEEGoMgMgooooooo^k^koEEEEo`0000Kooooo00Co8B4Qo`000?l0003ogMgM1_ooool00ol0003o
ooooooooo`05ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00001?ooool01_mEEEGoMgMgooooooo^
k^koEEEEo`0000Cooooo00Go0000ob4Q8Ol0003o0000ofIVIP07ooooo`04ob4Q8Ol0003o0000omgM
g@Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`7o00000Oooool000;o
oooo0_mVIVH00oo<c<coooooooooo`02ooooo`03olc<c?mEEEGooooo00gooooo00?o0000oooooooo
ool02Oooool00onYZJWo<S8booooo`07ooooo`03o`000?oMgMgooooo00?ooooo00Ko0000onk^k_oo
ooooooooonk^k_l00004ooooo`06o`000?ooooooooooooooooo^k^ko00001_ooool00ol0003ooooo
ooooo`05ooooo`06o`000?ooooooooooooooooo^k^ko00001?ooool01_l0003ooooooooooooooooo
k^k^o`0000Cooooo00Ko0000onk^k_ooooooooooonk^k_l00004ooooo`06o`000?oooooooooooooo
ooo^k^ko00001?ooool01_l0003oooooooooooooooook^k^o`0000Sooooo00?oZJVYoc8b<_ooool0
1Oooool00ol0003oooooooooo`05ooooo`06o`000?ooooooooooooooooo^k^ko00001?ooool01_l0
003oooooooooooooooook^k^o`0000Cooooo00?o0000ooooooooool02oooool00onYZJWo<S8boooo
o`03ooooo`06o`000?o^k^koooooooooooo^k^ko00001?ooool01_l0003ok^k^ooooooooooook^k^
o`0000Cooooo00Ko0000onk^k_ooooooooooonk^k_l00004ooooo`06o`000?o^k^koooooooooooo^
k^ko00001?ooool1o`00007ok^k^000Iooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01_ooool00omEEEGoQhN7ooooo`03ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41?ooool0
0ol0003oooooooooo`02ooooo`03ob4Q8Ooooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03ob4Q8Ooooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0olQ8B7oooooooooo`02ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41?ooool00ol0003ooooo
ooooo`02ooooo`03ob4Q8Ooooooooooo00;ooooo00?o0000ooooooooool00_ooool00olQ8B7ooooo
ooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03ob4Q8Ooooooooooo00;ooooo00?o0000ooooooooool00_ooool00olQ8B7ooooo
ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool01_m4A4CoV9RH
ooooooooooooV9RHodA4A0Cooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@4ooooo`06odA4A?nH
V9SooooooooooonHV9SoA4A41?ooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Cooooo0Om4A4@1
oiRHV0005oooool00ol0003oA4A4o`000007ooooo`06ob4Q8Onj^[[ooooooooooomVIVKo<S8b1?oo
ool01_l@413oooooooooooooooooZJVYoc8b<PCooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4
ooooo`04oeEEEOn7QhOoooooooooo`;oMgMg1?ooool00ol0003oA4A4o`000007ooooo`04oeEEEOn7
QhOoooooooooo`;oMgMg1?ooool01?mEEEGoQhN7ooooooooool2ogMgM`Cooooo00Ko^[Zjob4Q8OoM
gMgogMgMob4Q8Onj^[X4ooooo`04oeEEEOn7QhOoooooooooo`;oMgMg1?ooool01?mEEEGoQhN7oooo
ooooool2ogMgM`Cooooo00Ko8B4QokZj^_ooooooooooofIVI_lb<S84ooooo`03o`000?m4A4Co0000
00Oooooo00CoEEEEohN7Qooooooooooo0_mgMgL4ooooo`04oeEEEOn7QhOoooooooooo`;oMgMg1?oo
ool00ol0003oooooooooo`07ooooo`06ob4Q8Onj^[[ooooooooooomVIVKo<S8b1?ooool01_nj^[[o
8B4QomgMgOoMgMgo8B4QokZj^PCooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`06okZj
^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1?ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PCooooo0Onj
^[X1ob4Q8@005oooool00oo<c<coEEEEo`000007ooooo`06okZj^_m4A4Co0000o`000?m4A4Cok^k^
1?ooool6o`0000Gooooo00CoV9RHo`000?l0003oV9RH1Oooool01_o^k^koA4A4o`000?l0003oEEEE
onk^kPCooooo00?oc<c<oeEEEOl000001oooool01_o^k^koA4A4o`000?l0003oEEEEonk^kPCooooo
00Kok^k^odA4A?l0003o0000oeEEEOo^k^h5ooooo`04oiRHV?l0003o0000oiRHV0Gooooo00Kok^k^
odA4A?l0003o0000oeEEEOo^k^h4ooooo`06onk^k_m4A4Co0000o`000?mEEEGok^k^1?ooool01_nj
^[[oA4A4o`000?l0003oA4A4onk^kPCooooo00?oc<c<oeEEEOl000001oooool01_o^k^koA4A4o`00
0?l0003oEEEEonk^kPCooooo00Kok^k^odA4A?l0003o0000oeEEEOo^k^h4ooooo`Go00001Oooool0
1_nj^[[oA4A4o`000?l0003oA4A4onk^kPGooooo00CoV9RHo`000?l0003oV9RH1_ooool01?nHV9So
0000o`000?nHV9P6ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00CoV9RHo`000?l0003oV9RH1_oo
ool1oiRHV000joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo000hooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^1oooool2o`000004oa0@4?ooooook^k^
oeEEE@;o000000Co<S8bo`000?l0003oV9RH0_ooool01Oo^k^koEEEEo`000?l0003o<S8b00;o0000
00?oV9RHonk^k_mEEED01?l000001_nHV9Soooooooooooooooook^k^oeEEE@Co000000KoV9RHoooo
oolQ8B7o0000ob4Q8OnHV9P2o`000003oiRHV?oooooooooo00;ooooo00?oV9RHo`000?l000000_l0
00001?nHV9So8B4Qo`000?lQ8B42oiRHV0;o000000?oV9RHooooool000001ol000001OnHV9So8B4Q
o`000?lQ8B7oV9RH00;o000000?oV9RHooooooooool01?ooool3o`000003oiRHV?oooooooooo00;o
oooo00CoV9RHo`000?l0003oV9RH1_ooool01?nHV9So0000o`000?nHV9Phooooo`00>?ooool01_mE
EEGoMgMgooooooooooooMgMgoeEEE@Sooooo00go0000ooooooooooooEEEEogMgMooooooo^[Zjo`l?
3om9BDWogMgMob4Q8Onj^[[ooooo00;oMgMg00kooooookZj^_l?3`ooBDU9omgMgOlQ8B7o?ShnogMg
Monj^[[o8B4QofMWIom9BDWo8B4QokZj^P;ooooo00SoEEEEogMgMonj^[[o8B4QofMWIom9BDWo8B4Q
okZj^P;ooooo00KoXJ6Qo`H61_m9BDWogMgMob4Q8Onj^[X2ooooo`0<okZj^_lQ8B7oXJ6Qoa`L7?lM
7AgoXZ:Rob4Q8Onj^[[oooooomgMgOlU9BGo2`/;0_oMgMd02?lQ8B7o^[ZjoiRHV?l0003ogMgMoooo
oonj^[[o0P820_oMgMd02OlQ8B7o^[ZjoooooonQXJ7o1PH6odU9BOoMgMgo8B4QokZj^P04ooooo`06
okZj^_lQ8B7o0000omgMgOlQ8B7o^[Zj0_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PCooooo
00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[Xgooooo`00>?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo1_l000003?oooooo0000ooooooooooooA4A4oiRHV?l0003ooooooiRH
V?m4A4Coooooob4Q8@;ooooo00goA4A4oiRHV?l0003ooooooiRHV?l0003oooooodA4A?nHV9Sooooo
o`000?nHV9SoA4A400;ooooo00So0000oooooom4A4CoV9RHooooool0003oV9RHodA4A0;ooooo00Ko
A4A4oiRHV?lQ8B7oZJVYoiRHV?m4A4@2ooooo`03odA4A?nHV9SoA4A400;oV9RH00?oA4A4oiRHV?m4
A4@00_ooool03?m4A4Co51@DojVYZOooooooV9RHodA4A?ooooooQhN7ob4Q8Oo^k^koA4A4oiRHV0;o
oooo00WoV9RHodA4A?ooooooA4A4oiRHV?lQ8B7oZJVYoiRHV?m4A4@00_ooool6o`000006oiRHV?m4
A4Cooooooooooom4A4CoV9RH0_ooool00onHV9SoA4A4ooooo`03ooooo`06odA4A?nHV9Sooooooooo
oonHV9SoA4A4=oooool003Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`05odA4A?nj^[[oooooooooool000000_ooool06_l0003oooooooooool0003ok^k^o`000?oooooo
k^k^o`000?oooooo0000onk^k_oooooo0000onk^k_l0003oooooonk^k_l0003oooooo`000?o^k^ko
ooooo`000?o^k^ko00000_ooool02?l0003oooooo`000?o^k^koooooo`000?o^k^ko00000_ooool0
1_l0003ok^k^oiRHV?m4A4Cok^k^o`0000;ooooo00?o0000onk^k_l000000_o^k^h00ol0003ok^k^
o`000002ooooo`06o`000?n>SXkoA4A4ooooooo^k^ko00000_ooool01?nYZJWo8B4Qo`000?o^k^h2
ooooo`09onk^k_l0003oooooo`000?o^k^koV9RHodA4A?o^k^ko000000;ooooo00SoA4A4okZj^_l0
003ok^k^o`000?ooooook^k^o`0000;ooooo00Ko0000onk^k_ooooooooooonk^k_l00004ooooo`06
o`000?o^k^koooooooooooo^k^ko0000=oooool003Sooooo00KoEEEEogMgMoooooooooooogMgMomE
EED4ooooo`05omgMgOlQ8B7oooooooooool000000_ooool01_mEEEGoMgMgooooool0003oMgMgoeEE
E@;ooooo00So0000ooooool0003oEEEEonk^k_l0003oMgMgoeEEE@;ooooo00So0000ogMgMol0003o
ooooogMgMomEEEGoooooo`0000;ooooo00[oEEEEogMgMol0003oooooogMgMomEEEGoooooo`000?o^
k^koEEEE0_l000001?mVIVKo0000ooooool00002ooooo`03o`000?oooooo000000;ooooo00Co0000
ooooool0003oEEEE0_l000001OmVIVKo0000oooooooooooo000000?ooooo00?oV9RHo`000?ooool0
0oooool02?l0003oEEEEo`000?l0003oIVIVo`000?oooooo00000_ooool01OoMgMgo8B4Qo`000?oo
oooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0=Oooool003Sooooo00?ogMgMo`000?l000000_l0
00000ooMgMgoooooooooo`03ooooo`04ogMgMonHV9Soooooo`0000;ooooo00?ogMgMo`000?l00000
0_l000001ooMgMgoooooooooool0003oooooo`000?mgMgL00_l000001?mEEEGok^k^ooooooooool5
o`000003omgMgOoooooo000000;ooooo00?ogMgMo`000?l000000_l000002ooMgMgoooooo`000?mE
EEGoMgMgo`000?o^k^koEEEEo`000?oooooo000000;ooooo00?o0000ooooool000000_ooool02?l0
003oooooo`000?mgMgOoooooo`000?mEEEGo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?mgMgOooooo00;ooooo00So0000ogMgMol0003ok^k^oeEEEOl0003oooooo`0000?ooooo00CoMgMg
o`000?oooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`00>?ooool01_lb<S;oIVIVonk^
k_o^k^koIVIVoc8b<PGooooo00Cok^k^ob4Q8Ooooooo00000_ooool03olb<S;oIVIVonk^k_l0003o
GemOoc8b<_ooooook^k^o`000?ooooooA4A4oiRHV?oooooo0000onk^kP02ooooo`09onk^k_l0003o
IVIVo`000?o^k^koIVIVoc8b<_o^k^ko000000;ooooo00Oo<S8bofIVI_l0003ok^k^ofIVI_lb<S;o
k^k^00;o000000Ooooooo`000?o^k^kok^k^o`000?o^k^ko000000;ooooo00?o0000onk^k_l00000
0_o^k^h00ol0003ok^k^o`000002ooooo`06o`000?o^k^ko0000ooooooo^k^ko00001?ooool02?l0
003o3`l?ooooooooooook^k^o`000?oooooo00000_o^k^h00ol0003ok^k^o`000003ooooo`07onk^
k_l0003ok^k^o`000?ooooook^k^o`000002ooooo`06o`000?o^k^koooooooooooo^k^ko00001?oo
ool01_l0003ok^k^ooooooooooook^k^o`0003Oooooo000hooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00omgMgOoV9RHo`000002ooooo`0?o`000?ooooooooooodA4A?nH
V9So0000oooooonHV9SoA4A4oooooonj^[[o8B4Qoooooom4A4CoV9RH00;ooooo00WoV9RHo`000?oo
ooooA4A4oiRHV?oooooo0000oiRHV?m4A4@00_ooool04?l0003oooooodA4A?nHV9Soooooo`000?nH
V9SoA4A4o`000?ooooooA4A4oiRHV?oooooo8B4QoiRHV?m4A4@2ooooo`03odA4A?nHV9SoA4A400;o
V9RH00?oA4A4oiRHV?l000000_ooool01_m4A4CoV9RHob4Q8OooooooV9RHodA4A0Cooooo00goA4A4
o`000?oooooooooooiRHV?l0003oooooodA4A?nHV9Soooooob4Q8OnHV9SoA4A400Cooooo00Ko7alO
oiRHV?l0003ooooooiRHV?m4A4@2ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41?ooool01_m4
A4CoV9RHooooooooooooV9RHodA4A3Oooooo000hooooo`06oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b
1_ooool00oo^k^ko<S8bo`000002ooooo`09oc8b<_mVIVKok^k^ojf][Ol=3@go;2`/omgMgOlQ8B7o
^[Zj00;ooooo00CoEEEEoc8b<_nQXJ7o8B4Q0_oMgMd02OlQ8B7o9BDUofIVI_n][Jgo7QhNoeQHF?l/
;2co8B4QokZj^P02ooooo`0<oc8b<_mVIVKo[Jf]oahN7_mHF5So;2`/ob4Q8Onj^[[oEEEEohN7Qonj
^[[o8B4Q0_mWIfL06_lQ8B7o^[Zjoooooooooooo^[Zjob4Q8OnQXJ7o71`LoadM7OnRXZ;o8B4Qochn
?_n7QhOooooookZj^_l?3`ooIfMWomgMgOlQ8B7o^[Zjo`000?n7QhOok^k^oooooom_Kfoo2`/;0_oM
gMd01OlQ8B7o?ShnohN7Qonj^[[o8B4Q00;oIfMW00?o8B4QokZj^_ooool00oooool01_n][Jgo1PH6
o`000?oMgMgo8B4QokZj^P;ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X4ooooo`06okZj^_lQ
8B7ogMgMomgMgOlQ8B7o^[Zj=oooool003Sooooo00Kok^k^odA4A?l0003o0000odA4A?o^k^h7oooo
o`06oiRHV?l@413oooooooooooo^k^koA4A40_l000001?lX:2So0000o`000?nHV9P4ooooo`03oiRH
V?lQ8B7o000000;o000000?oV9RHonk^k_m4A4@01?l000001_nHV9Soooooooooooooooook^k^odA4
A0Co000000CoV9RHooooooo^k^koA4A41?l000000onHV9Soooooooooo`02ooooo`03oiRHV?l0003o
000000;o000000?oV9RHonk^k_m4A4@00_l000001olb<S;o0000o`000?nHV9SoooooojVYZOlb<S80
0_l000001omEEEGoSHf=o`000?l0003oV9RHonk^k_m4A4@01?l000000onHV9Soooooooooo`04oooo
o`04oiRHV?l0003o0000oiRHV0Cooooo00CoV9RHo`000?l0003oV9RH1_ooool01?nHV9So0000o`00
0?nHV9Phooooo`00joooool00>_ooooo000`ooooo`04oiRHV?l0003o0000oiRHV;Oooooo000_oooo
o`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Ooooomgo`0003[ooooo000_ooooo`06odA4A?nHV9So
oooooooooonHV9SoA4A41Oooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool0
0000>_ooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooogOo0000>_ooool002oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0>?ooool0
02oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0>?oo
ool002oooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooo`05o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0>?ooool002oo
oooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`05o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0>?ooool002oooooo00Ko
^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0>?ooool002oooooo1?l000000ol:
2P[oooooooooo`04ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0>?ooool0037ooooo00?o0000ooooooooool01_ooool0
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oooooooooo03Sooooo000aooooo`03o`000?oooooooooo00Kooooo00Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0hooooo`00
<Oooool00ol0003oooooooooo`06ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0>?ooool0037ooooo00?o0000oooooooo
ool01_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oooooooooo03Sooooo000aooooo`03o`000?oooooooooo00Kooooo00Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003ooooooooo
o`0hooooo`00<Oooool00ol0003oooooooooo`06ooooo`05o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0>?ooool0037ooooo00?o
0000ooooooooool01_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oooooooooo03Sooooo000_ooooo`03o`000?m4A4Co000000Sooooo
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oooooooooo`0hooooo`00;oooool00oo<c<coEEEEo`000008ooooo`05o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0>?ooool0
02kooooo1_l00006ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ooooooooool0>?ooool002kooooo00?oV9RHo`000?oMgMd00_ooool0
0ol@413oooooooooo`04ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ooooooooool0>?ooool002oooooo00?oQhN7ob4Q8Oo^k^h02?oo
ool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oooooooooo03Sooooo000`ooooo`03ojVYZOlQ8B7ok^k^00Oooooo00Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0hoooo
o`00<Oooool00onHV9So<S8booooo`06ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0>?ooool003;ooooo00?oA4A4ogMg
Moooool01Oooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oooooooooo03Sooooo000booooo`03omgMgOl@413ooooo00Gooooo00Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`0hooooo`00<oooool00ol0003oooooooooo`04ooooo`05o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0>?ooool002kooooo
00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED6ooooo`05o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0>?ooool002kooooo00?oZJVY
ob4Q8Ol000000_l000000omOGeooooooooooo`04ooooo`05o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0>?ooool002oooooo00Ko
410@olc<c?ooooooooooogMgMomVIVH5ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0>?ooool003Cooooo00?o0000oooo
ooooool00oooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oooooooooo03Sooooo000dooooo`03o`000?oooooooooo00?ooooo00Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003ooooo
ooooo`0hooooo`004?ooool00onj^[[o<S8booooo`0>ooooo`03oc8b<_nj^[[ooooo00oooooo00?o
ZJVYodA4A?ooool01?ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oooooooooo03Sooooo0003ooooo`03o`000?oooooooooo00[ooooo
00?o<S8bokZj^_ooool01Oooool00olQ8B7o0000olc<c006ooooo`03okZj^_lb<S;ooooo00gooooo
00Co8B4Qo`000?l0003ogMgM1Oooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oooooooooo03Sooooo0003ooooo`03oc8b<_nj^[[ooooo
00Wooooo00?oc<c<oc8b<_ooool01_ooool00ol0003o^[Zjob4Q8@07ooooo`03oc8b<_o<c<cooooo
00kooooo00?oZJVYoc8b<_ooool01?ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oooooooooo03Sooooo0003ooooo`03ogMgMon7QhOo
MgMg00;o000000?oA4A4olc<c?ooool01?ooool00omVIVKoZJVYooooo`06ooooo`03odA4A?o<c<co
000000Oooooo00?oV9RHofIVI_ooool03oooool00ol0003oooooooooo`03ooooo`05o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
>?ooool000?ooooo00SoV9RHoa0@4?n7QhOok^k^oooooonHV9So410@olc<c0Cooooo00?o<S8boooo
ooooool01_ooool00onHV9SoMgMgo`000007ooooo`03onk^k_lb<S;ooooo00[ooooo00Ko8B4QokZj
^_ooooooooooofIVI_lb<S85ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ooooooooool0>?ooool000?ooooo00?o^[Zjoc8b<_ooool0
0oooool00onHV9SoA4A4ooooo`03ooooo`03oc8b<_oooooooooo00Oooooo00?o<S8bodA4A?ooool0
1oooool00ol0003oooooooooo`09ooooo`03okZj^_m4A4Co000000;o000000?o3`l?ooooooooool0
0oooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oooooooooo03Sooooo0004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00olb<S;oooooooooo`07ooooo`03ob4Q8Olb<S;oc<c<00Oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`04ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0>?ooool000Cooooo00?oA4A4oiRH
V?ooool00_ooool00oo^k^ko0000ooooo`03ooooo`03ob4Q8Ooooooooooo00Kooooo00GoIVIVojVY
ZOo^k^ko8B4Qonk^kP06ooooo`03o`000?oooooooooo00Wooooo1_l00005ooooo`05o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
>?ooool000Cooooo00Oo^[Zjo`000?nj^[[oooooonk^k_mVIVKoEEEE00Cooooo00?o<S8bonk^k_oo
ool01?ooool00oo^k^koIVIVoiRHV002ooooo`03olc<c?lb<S;ok^k^00Cooooo00?ogMgMoc8b<_oo
ool02_ooool01Om4A4Co^[Zjoooooooooooo000000Kooooo00Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0hooooo`001Oooool0
1_nYZJWo8B4Qo`000?l0003oEEEEonk^kPCooooo00?oIVIVoiRHV?ooool00oooool2ofIVIP03olc<
c?oooooooooo00;ooooo00?oc<c<oeEEEOooool00oooool00onHV9SoIVIVooooo`0:ooooo`05omgM
gOlQ8B7oooooooooool000001_ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oooooooooo03Sooooo000?ooooo`03omgMgOlQ8B7ooooo
013ooooo00?o410@olc<c?ooool02oooool01?mgMgOoV9RHooooool00006ooooo`05o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
>?ooool0013ooooo00?o<S8bokZj^_ooool03_ooool00onj^[[o<S8booooo`0<ooooo`04onk^k_lQ
8B7oooooo`0000Kooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`0hooooo`004?ooool00onj^[[o<S8booooo`0>ooooo`03
oc8b<_nj^[[ooooo00gooooo00?oMgMgoiRHV?l000001_ooool01Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo03Sooooo000aoooo
o`03onk^k_lb<S;o000000Kooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oooooooooo`0hooooo`00<_ooool00onHV9So410@ooooo`05
ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0>?ooool002oooooo00GoV9RHoa0@4?l0003o0000ofIVIP06ooooo`05o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0>?ooool002oooooo00Ko410@ohN7QoooooooooooogMgMomVIVH5ooooo`05o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l00000
1?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0
>?ooool003Cooooo00?o0000ooooooooool00oooool01Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0
003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004
ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo03Sooooo000cooooo`03onk^
k_l0003ooooo00Cooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool0
0?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo0000
0ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool0
0002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oooooooooo`0hooooo`00;oooool01_l@413oV9RHooooooooooooMgMg
ofIVIPGooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`0hooooo`00;oooool01Ol0003o8B4Qo`000?l0003oIVIV00Kooooo
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oooooooooo`0hooooo`00;oooool00ol0003oooooooooo`08ooooo`05o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ooooooooool0>?ooool0
02oooooo00?o0000ooooooooool02?ooool01Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oooooooooo03Sooooo000_ooooo`03o`000?oooooo
oooo00Sooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oooooooooo`0hooooo`00;oooool5o`000003onk^k_oooooooooo00?ooooo00Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003o
o`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
ooooooooo`0hooooo`00;oooool2ogMgM`;ooooo00?oMgMgoeEEEOooool01?ooool01Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo
03Sooooo000_ooooo`03ob4Q8Ooooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oooooo
oooo03Sooooo000_ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool00oooool01Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo
oooooooo03Sooooo000_ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE1Oooool01Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000
ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo
00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00
ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo
03Sooooo000_ooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^1Oooool01Ol0003oo`00ool00?oo
003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l0
00001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo
003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0
003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002
ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo03Sooooo
000_ooooo`03odA4A?nHV9Sooooo00Sooooo00Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool0
0?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo0000
0ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0hooooo`00;oooool00onj^[[o8B4Q
ooooo`08ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`00
00;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000
ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo
00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00
ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003
o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`00
00;oo`0000?o0000ooooooooool0>?ooool0033ooooo00?oEEEEoc8b<_oMgMd01oooool01Ol0003o
o`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003o
o`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go
0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo0000
0_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003o
o`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool0
0005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oooooo
oooo03Sooooo000aooooo`04o`000?lE5AGo0000ob4Q8@Gooooo00Go0000ool00?oo003oo`00o`00
0004ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`00
0?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oooooooooo`0hooooo`00<Ooo
ool2oeEEE@Oooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`00
00?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo
00000_oo00000ol0003oooooooooo`0hooooo`00<Oooool00onYZJWo0000ooooo`06ooooo`05o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`00
0?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;o
o`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000oooo
ooooool0>?ooool003;ooooo00?o0000olc<c?ooool01Oooool01Ol0003oo`00ool00?oo003o0000
00Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000
ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo
00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00
o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00
ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005
o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00
ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo03Sooooo000boooo
o`03oeEEEOmVIVKooooo00Gooooo00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003o
o`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o
0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo0000
0_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003o
o`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool0
0003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o
000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o
0000ool00?oo00000_oo00000ol0003oooooooooo`0hooooo`00<_ooool00onYZJWo410@ooooo`05
ooooo`05o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`000?oo
003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`00
00Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo
00000_oo00001Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0
003oo`00ool00002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002
ool00003o`000?oo003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo
003oo`0000;oo`0000Go0000ool00?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`00
00?o0000ooooooooool0>?ooool003?ooooo00?o0000omgMgOooool01?ooool01Ol0003oo`00ool0
0?oo003o000000Coo`0000?o0000ool00?oo00000_oo00001Ol0003oo`00ool00?oo003o000000Co
o`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool00002ool00005o`000?oo003oo`00ool0
0?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oo003oo`0000;oo`0000Go0000ool0
0?oo003oo`00o`000004ool00003o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000_oo0000
1Ol0003oo`00ool00?oo003o000000Coo`0000?o0000ool00?oo00000_oo00000ol0003oo`00ool0
0002ool00005o`000?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00005o`00
0?oo003oo`00ool00?l000001?oo00000ol0003oo`00ool00002ool00003o`000?oooooooooo03So
oooo000cooooo`03oeEEEOn7QhOooooo00Cooooo2_l00004ool000oo00001?oo000Do`0000?oo`00
1_l00004ool000Ko00000ooo000No`0000?oo`002ol0000jooooo`00;oooool01_l@413ooooooooo
ooooooooZJVYoc8b<PGooooo00?o0000ooooooooool01_ooool6o`0000gooooo1_l0000Booooo`Go
00001?ooool6o`0000Cooooo1Ol0000Looooo`Go00002Oooool00ol0003oooooooooo`0hooooo`00
;oooool6o`0000GoooooMol0000jooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {7569.25, -10.6623, 11.3284, \
0.1072}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The code below generates the level spacing histogram for the zeta zeros",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(10\^22\)\)\)]],
  "+1 to ",
  Cell[BoxData[
      \(TraditionalForm\`10\^22\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`10\^4\)]],
  ".  There is no need to unfold this sequence since the zeta zeros are \
uniformly distributed in this range (see previous plot).  All that is needed \
is to rescale the spacings so that the mean spacing is 1."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ZSpacing5 = 
        Table[ZetaZero5[\([i + 1]\)] - ZetaZero5[\([i]\)], {i, 1, 
            L5 - 1}];\)\), "\n", 
    \(\(ZNorm5 = ZSpacing5/Mean[ZSpacing5];\)\), "\[IndentingNewLine]", 
    \(\(int\  = \ Table[0 + i/8, {i, 0, 40}];\)\), "\n", 
    \(ZHist5 = 
      Histogram[ZNorm5, HistogramCategories \[Rule] int, 
        HistogramScale \[Rule] 1, 
        TextStyle \[Rule] {"\<Times\>", FontSize \[Rule] 16}, 
        Frame \[Rule] True, FrameLabel \[Rule] {"\<s\>", "\<P(s)\>"}, 
        RotateLabel \[Rule] False]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.307692 0.0147151 0.628787 [
[.15385 -0.0125 -16.3438 -18 ]
[.15385 -0.0125 16.3438 0 ]
[.30769 -0.0125 -6.78125 -18 ]
[.30769 -0.0125 6.78125 0 ]
[.46154 -0.0125 -16.3438 -18 ]
[.46154 -0.0125 16.3438 0 ]
[.61538 -0.0125 -6.78125 -18 ]
[.61538 -0.0125 6.78125 0 ]
[.76923 -0.0125 -16.3438 -18 ]
[.76923 -0.0125 16.3438 0 ]
[.92308 -0.0125 -6.78125 -18 ]
[.92308 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .01472 -13.5625 -9 ]
[-0.0125 .01472 0 9 ]
[-0.0125 .14047 -32.6875 -9 ]
[-0.0125 .14047 0 9 ]
[-0.0125 .26623 -32.6875 -9 ]
[-0.0125 .26623 0 9 ]
[-0.0125 .39199 -32.6875 -9 ]
[-0.0125 .39199 0 9 ]
[-0.0125 .51774 -32.6875 -9 ]
[-0.0125 .51774 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -74.9375 -9 ]
[-0.01875 .30902 -32.6875 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15385 0 m
.15385 .00625 L
s
gsave
.15385 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.30769 0 m
.30769 .00625 L
s
gsave
.30769 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.46154 0 m
.46154 .00625 L
s
gsave
.46154 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.61538 0 m
.61538 .00625 L
s
gsave
.61538 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.76923 0 m
.76923 .00625 L
s
gsave
.76923 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.92308 0 m
.92308 .00625 L
s
gsave
.92308 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.03077 0 m
.03077 .00375 L
s
.06154 0 m
.06154 .00375 L
s
.09231 0 m
.09231 .00375 L
s
.12308 0 m
.12308 .00375 L
s
.18462 0 m
.18462 .00375 L
s
.21538 0 m
.21538 .00375 L
s
.24615 0 m
.24615 .00375 L
s
.27692 0 m
.27692 .00375 L
s
.33846 0 m
.33846 .00375 L
s
.36923 0 m
.36923 .00375 L
s
.4 0 m
.4 .00375 L
s
.43077 0 m
.43077 .00375 L
s
.49231 0 m
.49231 .00375 L
s
.52308 0 m
.52308 .00375 L
s
.55385 0 m
.55385 .00375 L
s
.58462 0 m
.58462 .00375 L
s
.64615 0 m
.64615 .00375 L
s
.67692 0 m
.67692 .00375 L
s
.70769 0 m
.70769 .00375 L
s
.73846 0 m
.73846 .00375 L
s
.8 0 m
.8 .00375 L
s
.83077 0 m
.83077 .00375 L
s
.86154 0 m
.86154 .00375 L
s
.89231 0 m
.89231 .00375 L
s
.95385 0 m
.95385 .00375 L
s
.98462 0 m
.98462 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .14047 m
.00625 .14047 L
s
gsave
-0.0125 .14047 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .26623 m
.00625 .26623 L
s
gsave
-0.0125 .26623 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .39199 m
.00625 .39199 L
s
gsave
-0.0125 .39199 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .51774 m
.00625 .51774 L
s
gsave
-0.0125 .51774 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04615 m
.00375 .04615 L
s
0 .07759 m
.00375 .07759 L
s
0 .10903 m
.00375 .10903 L
s
0 .17191 m
.00375 .17191 L
s
0 .20335 m
.00375 .20335 L
s
0 .23479 m
.00375 .23479 L
s
0 .29767 m
.00375 .29767 L
s
0 .32911 m
.00375 .32911 L
s
0 .36055 m
.00375 .36055 L
s
0 .42343 m
.00375 .42343 L
s
0 .45487 m
.00375 .45487 L
s
0 .48631 m
.00375 .48631 L
s
0 .54918 m
.00375 .54918 L
s
0 .58062 m
.00375 .58062 L
s
0 .61206 m
.00375 .61206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.15385 .61178 m
.15385 .61803 L
s
.30769 .61178 m
.30769 .61803 L
s
.46154 .61178 m
.46154 .61803 L
s
.61538 .61178 m
.61538 .61803 L
s
.76923 .61178 m
.76923 .61803 L
s
.92308 .61178 m
.92308 .61803 L
s
.125 Mabswid
.03077 .61428 m
.03077 .61803 L
s
.06154 .61428 m
.06154 .61803 L
s
.09231 .61428 m
.09231 .61803 L
s
.12308 .61428 m
.12308 .61803 L
s
.18462 .61428 m
.18462 .61803 L
s
.21538 .61428 m
.21538 .61803 L
s
.24615 .61428 m
.24615 .61803 L
s
.27692 .61428 m
.27692 .61803 L
s
.33846 .61428 m
.33846 .61803 L
s
.36923 .61428 m
.36923 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.43077 .61428 m
.43077 .61803 L
s
.49231 .61428 m
.49231 .61803 L
s
.52308 .61428 m
.52308 .61803 L
s
.55385 .61428 m
.55385 .61803 L
s
.58462 .61428 m
.58462 .61803 L
s
.64615 .61428 m
.64615 .61803 L
s
.67692 .61428 m
.67692 .61803 L
s
.70769 .61428 m
.70769 .61803 L
s
.73846 .61428 m
.73846 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.83077 .61428 m
.83077 .61803 L
s
.86154 .61428 m
.86154 .61803 L
s
.89231 .61428 m
.89231 .61803 L
s
.95385 .61428 m
.95385 .61803 L
s
.98462 .61428 m
.98462 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14047 m
1 .14047 L
s
.99375 .26623 m
1 .26623 L
s
.99375 .39199 m
1 .39199 L
s
.99375 .51774 m
1 .51774 L
s
.125 Mabswid
.99625 .04615 m
1 .04615 L
s
.99625 .07759 m
1 .07759 L
s
.99625 .10903 m
1 .10903 L
s
.99625 .17191 m
1 .17191 L
s
.99625 .20335 m
1 .20335 L
s
.99625 .23479 m
1 .23479 L
s
.99625 .29767 m
1 .29767 L
s
.99625 .32911 m
1 .32911 L
s
.99625 .36055 m
1 .36055 L
s
.99625 .42343 m
1 .42343 L
s
.99625 .45487 m
1 .45487 L
s
.99625 .48631 m
1 .48631 L
s
.99625 .54918 m
1 .54918 L
s
.99625 .58062 m
1 .58062 L
s
.99625 .61206 m
1 .61206 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .02427 L
.03846 .02427 L
.03846 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .02427 L
.03846 .02427 L
.03846 .01472 L
0 .01472 L
s
1 0 0 r
.03846 .01472 m
.03846 .08464 L
.07692 .08464 L
.07692 .01472 L
F
0 g
.03846 .01472 m
.03846 .08464 L
.07692 .08464 L
.07692 .01472 L
.03846 .01472 L
s
1 0 0 r
.07692 .01472 m
.07692 .18224 L
.11538 .18224 L
.11538 .01472 L
F
0 g
.07692 .01472 m
.07692 .18224 L
.11538 .18224 L
.11538 .01472 L
.07692 .01472 L
s
1 0 0 r
.11538 .01472 m
.11538 .33316 L
.15385 .33316 L
.15385 .01472 L
F
0 g
.11538 .01472 m
.11538 .33316 L
.15385 .33316 L
.15385 .01472 L
.11538 .01472 L
s
1 0 0 r
.15385 .01472 m
.15385 .4363 L
.19231 .4363 L
.19231 .01472 L
F
0 g
.15385 .01472 m
.15385 .4363 L
.19231 .4363 L
.19231 .01472 L
.15385 .01472 L
s
1 0 0 r
.19231 .01472 m
.19231 .52685 L
.23077 .52685 L
.23077 .01472 L
F
0 g
.19231 .01472 m
.19231 .52685 L
.23077 .52685 L
.23077 .01472 L
.19231 .01472 L
s
1 0 0 r
.23077 .01472 m
.23077 .6003 L
.26923 .6003 L
.26923 .01472 L
F
0 g
.23077 .01472 m
.23077 .6003 L
.26923 .6003 L
.26923 .01472 L
.23077 .01472 L
s
1 0 0 r
.26923 .01472 m
.26923 .58823 L
.30769 .58823 L
.30769 .01472 L
F
0 g
.26923 .01472 m
.26923 .58823 L
.30769 .58823 L
.30769 .01472 L
.26923 .01472 L
s
1 0 0 r
.30769 .01472 m
.30769 .60332 L
.34615 .60332 L
.34615 .01472 L
F
0 g
.30769 .01472 m
.30769 .60332 L
.34615 .60332 L
.34615 .01472 L
.30769 .01472 L
s
1 0 0 r
.34615 .01472 m
.34615 .469 L
.38462 .469 L
.38462 .01472 L
F
0 g
.34615 .01472 m
.34615 .469 L
.38462 .469 L
.38462 .01472 L
.34615 .01472 L
s
1 0 0 r
.38462 .01472 m
.38462 .42724 L
.42308 .42724 L
.42308 .01472 L
F
0 g
.38462 .01472 m
.38462 .42724 L
.42308 .42724 L
.42308 .01472 L
.38462 .01472 L
s
1 0 0 r
.42308 .01472 m
.42308 .31103 L
.46154 .31103 L
.46154 .01472 L
F
0 g
.42308 .01472 m
.42308 .31103 L
.46154 .31103 L
.46154 .01472 L
.42308 .01472 L
s
1 0 0 r
.46154 .01472 m
.46154 .2401 L
.5 .2401 L
.5 .01472 L
F
0 g
.46154 .01472 m
.46154 .2401 L
.5 .2401 L
.5 .01472 L
.46154 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .16262 L
.53846 .16262 L
.53846 .01472 L
F
0 g
.5 .01472 m
.5 .16262 L
.53846 .16262 L
.53846 .01472 L
.5 .01472 L
s
1 0 0 r
.53846 .01472 m
.53846 .11936 L
.57692 .11936 L
.57692 .01472 L
F
0 g
.53846 .01472 m
.53846 .11936 L
.57692 .11936 L
.57692 .01472 L
.53846 .01472 L
s
1 0 0 r
.57692 .01472 m
.57692 .08112 L
.61538 .08112 L
.61538 .01472 L
F
0 g
.57692 .01472 m
.57692 .08112 L
.61538 .08112 L
.61538 .01472 L
.57692 .01472 L
s
1 0 0 r
.61538 .01472 m
.61538 .04641 L
.65385 .04641 L
.65385 .01472 L
F
0 g
.61538 .01472 m
.61538 .04641 L
.65385 .04641 L
.65385 .01472 L
.61538 .01472 L
s
1 0 0 r
.65385 .01472 m
.65385 .03283 L
.69231 .03283 L
.69231 .01472 L
F
0 g
.65385 .01472 m
.65385 .03283 L
.69231 .03283 L
.69231 .01472 L
.65385 .01472 L
s
1 0 0 r
.69231 .01472 m
.69231 .02629 L
.73077 .02629 L
.73077 .01472 L
F
0 g
.69231 .01472 m
.69231 .02629 L
.73077 .02629 L
.73077 .01472 L
.69231 .01472 L
s
1 0 0 r
.73077 .01472 m
.73077 .02226 L
.76923 .02226 L
.76923 .01472 L
F
0 g
.73077 .01472 m
.73077 .02226 L
.76923 .02226 L
.76923 .01472 L
.73077 .01472 L
s
1 0 0 r
.76923 .01472 m
.76923 .01824 L
.80769 .01824 L
.80769 .01472 L
F
0 g
.76923 .01472 m
.76923 .01824 L
.80769 .01824 L
.80769 .01472 L
.76923 .01472 L
s
1 0 0 r
.80769 .01472 m
.80769 .01622 L
.84615 .01622 L
.84615 .01472 L
F
0 g
.80769 .01472 m
.80769 .01622 L
.84615 .01622 L
.84615 .01472 L
.80769 .01472 L
s
1 0 0 r
.84615 .01472 m
.84615 .01572 L
.88462 .01572 L
.88462 .01472 L
F
0 g
.84615 .01472 m
.84615 .01572 L
.88462 .01572 L
.88462 .01472 L
.84615 .01472 L
s
1 0 0 r
.88462 .01472 m
.88462 .01522 L
.92308 .01522 L
.92308 .01472 L
F
0 g
.88462 .01472 m
.88462 .01522 L
.92308 .01522 L
.92308 .01472 L
.88462 .01472 L
s
1 0 0 r
.92308 .01472 m
.92308 .01472 L
.96154 .01472 L
.96154 .01472 L
F
0 g
.92308 .01472 m
.92308 .01472 L
.96154 .01472 L
.96154 .01472 L
.92308 .01472 L
s
1 0 0 r
.96154 .01472 m
.96154 .01522 L
1 .01522 L
1 .01472 L
F
0 g
.96154 .01472 m
.96154 .01522 L
1 .01522 L
1 .01472 L
.96154 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo002Hooooo`03oa0@4?lb<S;o410@00;o000000?oA4A4olc<
c?ooool0Boooool009Sooooo00?o0000oiRHV?o^k^h00_ooool00on7QhOo410@ooooo`1;ooooo`00
WOooool00onj^[[o0000ooooo`1;ooooo`00V?ooool00oo<c<coA4A4o`000003o`000003oiRHV?oo
oooooooo04[ooooo002Hooooo`05o`000?n7QhOo^[ZjokZj^_o<c<`0C_ooool009Sooooo00?o0000
oiRHV?ooool00_ooool00oo<c<co410@ooooo`1;ooooo`00V?ooool01oo<c<coA4A4o`000?l0003o
410@oc8b<_l00000C?ooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00F_ooool01?nHV9So0000o`000?nHV9P6
ooooo`03oeEEEOl0003oEEEE00Kooooo00GoV9RHoa0@4?l0003o0000ofIVIP09ooooo`Co000000?o
410@ooooooooool01oooool4o`000003oa0@4?oooooooooo00Cooooo00?oEEEEo`000?mEEED01_oo
ool01OnHV9So410@o`000?l0003oIVIV00Sooooo1_l00008ooooo`Ko00001_ooool00omEEEGo0000
oeEEE@06ooooo`05oiRHV?l@413o0000o`000?mVIVH02Oooool01OnYZJWo8B4Qo`000?l0003oIVIV
00_ooooo001Iooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo00Ko410@
ohN7QoooooooooooogMgMomVIVH:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1_ooool3o`0000Kooooo00Ko410@ohN7QoooooooooooogMgMomVIVH7ooooo`03oiRHV?l0003ogMgM
00;ooooo00?o410@ooooooooool01_ooool00onHV9So0000omgMg@02ooooo`03oa0@4?oooooooooo
00Cooooo0ol00006ooooo`06oa0@4?n7QhOooooooooooomgMgOoIVIV2?ooool01_l@413oc<c<oooo
ooooooooMgMgofIVIP[ooooo001Iooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omE
EEGo0000oeEEE@0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`06ooooo`03oeEEEOl0003oEEEE00_ooooo00?o0000ooooooooool01_ooool00on7
QhOo8B4Qonk^kP0;ooooo`03ohN7QolQ8B7ok^k^00Sooooo00?oEEEEo`000?mEEED02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo001Iooooo`06o`000?o^k^kooooooooo
ooo^k^ko00004_ooool00oo^k^ko0000ooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04oooool00oo^k^ko0000ooooo`08ooooo`03ojVYZOlQ8B7ok^k^00_ooooo00?oZJVY
ob4Q8Oo^k^h05?ooool00oo^k^ko0000ooooo`0<ooooo`03o`000?oooooooooo00Sooooo001Ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01_l@413oV9RHoooooooooooo
MgMgofIVIP[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`06oa0@4?nH
V9SooooooooooomgMgOoIVIV2_ooool00onHV9So<S8booooo`0;ooooo`03oiRHV?lb<S;ooooo00oo
oooo00Ko410@oiRHV?ooooooooooogMgMomVIVH<ooooo`03ojVYZOm4A4Cooooo00Wooooo001Ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01Ol0003o8B4Qo`000?l0003o
IVIV00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`05o`000?lQ8B7o
0000o`000?mVIVH03?ooool00om4A4CoMgMgooooo`0;ooooo`03odA4A?mgMgOooooo00kooooo00Go
0000ob4Q8Ol0003o0000ofIVIP0;ooooo`04ob4Q8Ol0003o0000omgMg@[ooooo001Iooooo`06o`00
0?o^k^koooooooooooo^k^ko00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03omgMgOl@413ooooo
00_ooooo00?ogMgMoa0@4?ooool03_ooool00ol0003oooooooooo`0?ooooo`03ojVYZOlb<S;ooooo
00Wooooo001Iooooo`06odA4A?nHV9SooooooooooonHV9SoA4A43_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Sooooo001Iooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?m4A4Co000000_ooooo00?o0000odA4A?l000004Ooo
ool00ol0003oooooooooo`0:ooooo`06o`000?n7QhOok^k^oooooonHV9SoEEEE2?ooool01_l0003o
QhN7onk^k_ooooooV9RHoeEEE@oooooo00?o0000ooooooooool02oooool01_lQ8B7o^[Zjoooooooo
ooooIVIVoc8b<P[ooooo001Jooooo`04oiRHV?l0003o0000oiRHV0oooooo1Ol00009ooooo`03olc<
c?mEEEGo000000_ooooo00?oc<c<oeEEEOl000004Oooool5o`0000Sooooo00KoZJVYoc8b<_l0003o
0000oeEEEOo^k^h8ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^3oooool5o`0000Wooooo00Ko
^[ZjodA4A?l0003o0000odA4A?o^k^h:ooooo`00joooool00>_ooooo003[ooooo`00joooool004?o
oooo00CoV9RHo`000?l0003oV9RH1_oooonMo`00007ooooo0012ooooo`06okZj^_lQ8B7ogMgMomgM
gOlQ8B7o^[Zj1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000Ooo
ool004;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03o`000?oooooooooo08kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`7o00000Oooool004;ooooo00Ko
0000onk^k_ooooooooooonk^k_l00005oooooigo00000Oooool004;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`Oo00001Ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000go0000
8oooool1o`00007ooooo0012ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001ol0000_ooooo`7o00000Ooo
ool004;ooooo00Ko0000onk^k_ooooooooooonk^k_l00005ooooo`03o`000?oooooooooo00?ooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`0cooooo`7o00000Oooool004;ooooo00Ko
A4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`;o00001?ooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oooooooooo03?ooooo0Ol00001ooooo`00@_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj
^PGooooo00?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo0007o`0003Gooooo0Ol00001ooooo`00@oooool01?nHV9So
0000o`000?nHV9P6ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0>Oooool1o`00
007ooooo001=ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0>Oooool1o`00007o
oooo001=ooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0>Oooool1o`00007ooooo
001=ooooo`;o00001?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oooooooooo`0iooooo`7o00000Oooool004gooooo00?o0000
ooooooooool00oooool7o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`001ol0000kooooo`7o00000Oooool004gooooo00?o0000oooo
ooooool02Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo03oooooo0Ol00001oooo
o`00COooool00ol0003oooooooooo`09ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0?oooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00Wooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`0oooooo`7o00000Oooool004gooooo0_l0000:ooooo`03o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ooooooooool0?oooool1o`00007ooooo001=ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`0oooooo`7o00000Oooool0
033ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@05ooooo`Ko00001Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool000Oo0000@Oooool1o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgM
omgMgOlQ8B7o^[Zj1Oooool3o`0000Gooooo00?oV9RHo`000?oMgMd00_ooool00ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0AOooool1o`00007ooooo000_
ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`03ohN7
QolQ8B7ok^k^00Oooooo00?o0000ooooooooool02Oooool00ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`15ooooo`7o0000
0Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000?ooooo`03ojVYZOlQ8B7ok^k^00Ko
oooo0_l0000:ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo04Cooooo0_l00001ooooo`00;oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00kooooo00?oV9RHoc8b<_ooool01Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oooooooooo04Gooooo0Ol00001ooooo`00;oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00oooooo00?oA4A4ogMgMoooool01?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oooooooooo04Gooooo0Ol00001ooooo`00;oooool01_l0003ok^k^oooooooo
ooook^k^o`00017ooooo00?ogMgMoa0@4?ooool01?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo04Gooooo0Ol00001ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A1;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo0007o`0004Oooooo0Ol00001ooooo`00;oooool01_nj^[[o8B4Q
omgMgOoMgMgo8B4QokZj^Pgooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED5ooooo`;o00002_oo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Booo
ool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0kooooo00KoZJVYoc8b<_l0003o0000
oeEEEOo^k^h5ooooo`03o`000?oooooooooo00Wooooo00?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo04_ooooo0Ol00001ooooo`00COooool00ol0003ooooo
ooooo`09ooooo`Oo00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oooooooooo`1;ooooo`7o00000Oooool004gooooo00?o
0000ooooooooool03oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo04_ooooo0Ol0
0001ooooo`00COooool00ol0003oooooooooo`0?ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ooooooooool0Boooool1o`00007ooooo001=ooooo`;o00004?ooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo04_ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0?ooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Boooool1o`00007ooooo001=ooooo`03o`00
0?oooooooooo00oooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1;ooooo`7o0000
0Oooool004gooooo00?o0000ooooooooool03oooool00ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
oooooooo04_ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0?ooooo`03o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0Boooool1o`00007ooooo001=ooooo`;o00004?ooool00ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oooooooooo04_ooooo0Ol00001ooooo`00COooool00ol0003o
ooooooooo`0?ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool000Oo0000COooool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Ko
oooo00?oEEEEo`000?mEEED02Oooool2o`000003oa0@4?oooooooooo00;ooooo00?o0000oooooooo
ool03oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`1Aooooo`7o00000Oooool002oooooo00Ko^[Zjob4Q8OoMgMgo
gMgMob4Q8Onj^[X5ooooo`?o00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00oooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ooooooooool0DOooool1o`00007ooooo000_ooooo`06odA4A?nHV9Sooooooooo
oonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`Ko00001?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo057ooooo0Ol00001ooooo`004?ooool00onj^[[o<S8booooo`0>oooo
o`03oc8b<_nj^[[ooooo00_ooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`05odA4A?nj
^[[oooooooooool000001Oooool2o`00013ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0D?ooool2o`00007ooooo
000@ooooo`03oc8b<_nj^[[ooooo00kooooo00?o^[Zjoc8b<_ooool02oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00cooooo00GogMgMob4Q8Oooooooooooo`000005ooooo`03o`00
0?oooooooooo00oooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool0DOooool1o`00007ooooo000?ooooo`03olc<c?lb
<S;ooooo013ooooo00?o<S8bolc<c?ooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00gooooo00CoMgMgoiRHV?oooooo00001Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oooooooooo057ooooo0Ol00001ooooo`000_ooool01Ol@413o0000o`000?l0003o410@00Sooooo
00?oIVIVojVYZOooool01?ooool00ol@413o<S8boa0@4002o`000003odA4A?o<c<cooooo00Cooooo
00?oV9RHofIVI_ooool02_ooool01_l0003ok^k^ooooooooooook^k^o`0000oooooo00Cok^k^ob4Q
8Ooooooo00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo057ooooo0Ol00001
ooooo`001?ooool00ol0003oooooooooo`08ooooo`03oc8b<_oooooooooo00Cooooo00?o0000oiRH
V?o^k^h00_ooool00on7QhOo410@ooooo`04ooooo`03onk^k_lb<S;ooooo00[ooooo00KoA4A4oiRH
V?oooooooooooiRHV?m4A4@@ooooo`03ogMgMonHV9So000000Gooooo00?o0000ooooooooool03ooo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`1Aooooo`7o00000Oooool000Cooooo00?o0000ooooooooool02?ooool0
0olb<S;oooooooooo`09ooooo`03okZj^_l0003ooooo00Gooooo00?o0000ooooooooool02Oooool0
1_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Q3ooooo00?ok^k^oc8b<_l000001Oooool2o`00013ooooo
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0DOooool1o`00007ooooo0004ooooo`?o000000?o410@ogMgMoo^k^h01Ooo
ool00olb<S;oooooooooo`04ooooo`03olc<c?m4A4Co000000?o000000?oV9RHooooooooool01?oo
ool00ol0003oooooooooo`0:ooooo`04oiRHV?l0003o0000oiRHV1;ooooo00?oV9RHoa0@4?ooool0
1?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo057ooooo0Ol00001ooooo`001?oo
ool01_l0003oooooooooooo^k^koMgMgoeEEE@Gooooo00?o8B4Qooooooooool01?ooool01Ol0003o
QhN7okZj^_nj^[[oc<c<00Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0?oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0007o`0005?ooooo0Ol00001oooo
o`001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o<S8bonk^k_oo
ool01?ooool00ol0003oV9RHooooo`02ooooo`03olc<c?l@413ooooo00Cooooo00?ogMgMoc8b<_oo
ool0:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`1Gooooo`7o00000Oooool000Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03ofIVI_nHV9Sooooo00Cooooo00Ooc<c<odA4A?l0003o
0000oa0@4?lb<S;o000000Gooooo00?oV9RHofIVI_ooool0:?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Goooo
o`7o00000Oooool000Cooooo00Ko0000ooooooooooook^k^ogMgMomEEED5ooooo`03omgMgOlQ8B7o
oooo013ooooo00?o410@olc<c?ooool0:?ooool2o`00013ooooo1ol00005ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo
oooo05Oooooo0Ol00001ooooo`000_ooool00ol@413o0000o`000002o`000003oa0@4?mgMgOok^k^
00Kooooo00?o<S8bokZj^_ooool03_ooool00onj^[[o<S8booooo`0Yooooo`03o`000?oooooooooo
01Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Gooooo`7o00000Oooool0013o
oooo00?o^[Zjoc8b<_ooool03_ooool00olb<S;o^[Zjooooo`0Yooooo`03o`000?oooooooooo01Go
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Gooooo`7o00000Oooool004gooooo
00?o0000ooooooooool05Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo05Oooooo
0Ol00001ooooo`00COooool00ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ooooooooool0Eoooool1o`00007ooooo001=ooooo`;o00005_ooool00ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo05Oooooo0Ol00001ooooo`00<?ooool01?nHV9So0000o`000?nHV9P6
ooooo`03oeEEEOl0003oEEEE00Kooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h4ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Gooooo`7o0000
0Oooool002oooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q8Onj^[X5ooooo`?o00001_ooool2ogMgM`;o
oooo00?oMgMgoeEEEOooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0Eoooool1o`00007ooooo000_ooooo`06odA4A?nHV9SooooooooooonH
V9SoA4A41Oooool00omEEEGo0000oeEEE@06ooooo`03ob4Q8Ooooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooo
ooooool0Eoooool1o`00007ooooo000_ooooo`06o`000?o^k^koooooooooooo^k^ko00003_ooool0
0ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l0000Fooooo`03o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ooooooooool0E_ooool2o`00007ooooo000_ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03?ooool01_l0003oEEEEonk^k_ooooooMgMgoeEEE@Cooooo00?o
0000ooooooooool05Oooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo05Oooooo0Ol0
0001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Ko0000
ogMgMol0003o0000oeEEEOo^k^h4ooooo`03o`000?oooooooooo01Gooooo00?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oooooooooo`1Gooooo`7o00000Oooool002oooooo00Ko0000onk^k_oooooooooo
onk^k_l0000>ooooo`03odA4A?nHV9Sooooo00Oooooo00?o0000ooooooooool05Oooool00ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo05Oooooo0Ol00001ooooo`00;oooool01_m4A4CoV9RH
ooooooooooooV9RHodA4A0kooooo00?o^[Zjob4Q8Oooool01oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Eoooool1o`00007ooooo000_ooooo`06
okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj3oooool00omEEEGo<S8bomgMg@06ooooo`;o00005_ooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oooooooooo05Oooooo0Ol00001ooooo`00<?ooool01?nH
V9So0000o`000?nHV9PAooooo`04oiRHV?lQ8B7o0000ob4Q8@Cooooo00?o0000ooooooooool05Ooo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
0007o`0005Wooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Eooooo`Oo00001Ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oooooooooo05gooooo0Ol00001ooooo`00COooool00ol0
003oooooooooo`0Kooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`1Mooooo`7o00000Oooool004gooooo00?o0000ooooooooool06oooool00ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0GOooool1o`00007o
oooo001=ooooo`;o00007?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ooooooooool0GOooool1o`00007ooooo001=ooooo`03o`000?oooooooooo01_ooooo00?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo05gooooo0Ol0
0001ooooo`00COooool00ol0003oooooooooo`0Kooooo`03o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001ol0001O
ooooo`7o00000Oooool004gooooo00?o0000ooooooooool06oooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oooooooooo06?ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Kooooo`03
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Hoooool1o`00007ooooo001=ooooo`;o0000
7?ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo06?ooooo0Ol00001ooooo`00COoo
ool00ol0003oooooooooo`0Kooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Hooo
ool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01_oo
ool01_o^k^koEEEEo`000?l0003oEEEEonk^kPCooooo00?o0000ooooooooool06oooool00ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oooooooooo06?ooooo0Ol00001ooooo`00;oooool01_nj^[[o8B4Q
omgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE1?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Hooo
ool1o`00007ooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000
oeEEE@06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool0Hoooool1o`00007ooooo
000_ooooo`06o`000?o^k^koooooooooooo^k^ko00003_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo0_l0000Looooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000oooooooo
ool0H_ooool2o`00007ooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3?ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Cooooo00?o0000ooooooooool06oooool7o`00
00Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo
06?ooooo0Ol00001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00co
oooo00?ogMgMo`000?l000000_l000000ooMgMgoooooooooo`02ooooo`03o`000?oooooooooo027o
oooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ooooooooool0Hoooool1o`00007ooooo000_ooooo`06o`000?o^k^koooooooooooo^
k^ko00003_ooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<PCooooo00?o0000ooooooooool08Ooo
ool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oooooooooo`1Sooooo`7o00000Oooool002oooooo00KoA4A4oiRHV?oooooooooooiRH
V?m4A4@>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oooooooooo06?ooooo0Ol00001ooooo`00;oooool01_nj^[[o8B4QomgM
gOoMgMgo8B4QokZj^Pkooooo00Ko<S8bofIVI_o^k^kok^k^ofIVI_lb<S84ooooo`;o00008_ooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oooooooooo`1Sooooo`7o00000Oooool0033ooooo00CoV9RHo`000?l0003oV9RH3oooool0
1_o^k^koA4A4o`000?l0003oA4A4onk^kPCooooo00?o0000ooooooooool08Oooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooo
ooooo`1Sooooo`7o00000Oooool004gooooo00?o0000ooooooooool08Oooool00ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003ooooooooo
o`1Sooooo`7o00000Oooool004gooooo00?o0000ooooooooool08Oooool00ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1S
ooooo`7o00000Oooool004gooooo00?o0000ooooooooool08Oooool00ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`1Soooo
o`7o00000Oooool004gooooo0_l0000Rooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo06?ooooo0Ol00001ooooo`00
COooool00ol0003oooooooooo`0Qooooo`03o`000?oo003oo`0000?oo`001ol00005ool00003o`00
0?oooooooooo06?ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Qooooo`03o`000?oo
003oo`0000?oo`0000?o0000ooooooooool00oooool00ol0003oo`00ool00003ool00003o`000?oo
oooooooo06?ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Qooooo`Oo00001Oooool7
o`0006Gooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`2Iooooo`7o00000Oooool004go
oooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooool000000Oooool004goooooWOl00001ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo
003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_o
oooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00001\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-1.62205, -0.918078, 0.0208319, \
0.0101939}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The plot below compares the level spacing histogram for these zeta \
zeros that are high up the critical line to the theoretical GUE distribution. \
 The fit is quite good, indicating that the spacings between the zeta zeros \
more closely follow GUE statistics as we go farther up the critical line.  \
This implies that the limiting distribution (i.e. the distribution for the \
entire infinite set) for the spacings between zeta zeros is the GUE \
distribution.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[ZHist5, GUE, AspectRatio \[Rule] 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.307692 0.0238095 1.01664 [
[.15385 -0.0125 -16.3438 -18 ]
[.15385 -0.0125 16.3438 0 ]
[.30769 -0.0125 -6.78125 -18 ]
[.30769 -0.0125 6.78125 0 ]
[.46154 -0.0125 -16.3438 -18 ]
[.46154 -0.0125 16.3438 0 ]
[.61538 -0.0125 -6.78125 -18 ]
[.61538 -0.0125 6.78125 0 ]
[.76923 -0.0125 -16.3438 -18 ]
[.76923 -0.0125 16.3438 0 ]
[.92308 -0.0125 -6.78125 -18 ]
[.92308 -0.0125 6.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -6.78125 -36 ]
[.5 -0.0125 6.78125 -18 ]
[-0.0125 .02381 -13.5625 -9 ]
[-0.0125 .02381 0 9 ]
[-0.0125 .22714 -32.6875 -9 ]
[-0.0125 .22714 0 9 ]
[-0.0125 .43047 -32.6875 -9 ]
[-0.0125 .43047 0 9 ]
[-0.0125 .63379 -32.6875 -9 ]
[-0.0125 .63379 0 9 ]
[-0.0125 .83712 -32.6875 -9 ]
[-0.0125 .83712 0 9 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -74.9375 -9 ]
[-0.01875 .5 -32.6875 9 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15385 0 m
.15385 .00625 L
s
gsave
.15385 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.30769 0 m
.30769 .00625 L
s
gsave
.30769 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.46154 0 m
.46154 .00625 L
s
gsave
.46154 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.61538 0 m
.61538 .00625 L
s
gsave
.61538 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.76923 0 m
.76923 .00625 L
s
gsave
.76923 -0.0125 -77.3438 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.92308 0 m
.92308 .00625 L
s
gsave
.92308 -0.0125 -67.7812 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.03077 0 m
.03077 .00375 L
s
.06154 0 m
.06154 .00375 L
s
.09231 0 m
.09231 .00375 L
s
.12308 0 m
.12308 .00375 L
s
.18462 0 m
.18462 .00375 L
s
.21538 0 m
.21538 .00375 L
s
.24615 0 m
.24615 .00375 L
s
.27692 0 m
.27692 .00375 L
s
.33846 0 m
.33846 .00375 L
s
.36923 0 m
.36923 .00375 L
s
.4 0 m
.4 .00375 L
s
.43077 0 m
.43077 .00375 L
s
.49231 0 m
.49231 .00375 L
s
.52308 0 m
.52308 .00375 L
s
.55385 0 m
.55385 .00375 L
s
.58462 0 m
.58462 .00375 L
s
.64615 0 m
.64615 .00375 L
s
.67692 0 m
.67692 .00375 L
s
.70769 0 m
.70769 .00375 L
s
.73846 0 m
.73846 .00375 L
s
.8 0 m
.8 .00375 L
s
.83077 0 m
.83077 .00375 L
s
.86154 0 m
.86154 .00375 L
s
.89231 0 m
.89231 .00375 L
s
.95385 0 m
.95385 .00375 L
s
.98462 0 m
.98462 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -67.7812 -40 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
72.562 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02381 m
.00625 .02381 L
s
gsave
-0.0125 .02381 -74.5625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .22714 m
.00625 .22714 L
s
gsave
-0.0125 .22714 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .43047 m
.00625 .43047 L
s
gsave
-0.0125 .43047 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .63379 m
.00625 .63379 L
s
gsave
-0.0125 .63379 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .83712 m
.00625 .83712 L
s
gsave
-0.0125 .83712 -93.6875 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07464 m
.00375 .07464 L
s
0 .12547 m
.00375 .12547 L
s
0 .17631 m
.00375 .17631 L
s
0 .27797 m
.00375 .27797 L
s
0 .3288 m
.00375 .3288 L
s
0 .37963 m
.00375 .37963 L
s
0 .4813 m
.00375 .4813 L
s
0 .53213 m
.00375 .53213 L
s
0 .58296 m
.00375 .58296 L
s
0 .68463 m
.00375 .68463 L
s
0 .73546 m
.00375 .73546 L
s
0 .78629 m
.00375 .78629 L
s
0 .88796 m
.00375 .88796 L
s
0 .93879 m
.00375 .93879 L
s
0 .98962 m
.00375 .98962 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -135.938 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 26 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
72.562 17.000 moveto
(H) show
82.125 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 17.000 moveto
(L) show
101.250 17.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.15385 .99375 m
.15385 1 L
s
.30769 .99375 m
.30769 1 L
s
.46154 .99375 m
.46154 1 L
s
.61538 .99375 m
.61538 1 L
s
.76923 .99375 m
.76923 1 L
s
.92308 .99375 m
.92308 1 L
s
.125 Mabswid
.03077 .99625 m
.03077 1 L
s
.06154 .99625 m
.06154 1 L
s
.09231 .99625 m
.09231 1 L
s
.12308 .99625 m
.12308 1 L
s
.18462 .99625 m
.18462 1 L
s
.21538 .99625 m
.21538 1 L
s
.24615 .99625 m
.24615 1 L
s
.27692 .99625 m
.27692 1 L
s
.33846 .99625 m
.33846 1 L
s
.36923 .99625 m
.36923 1 L
s
.4 .99625 m
.4 1 L
s
.43077 .99625 m
.43077 1 L
s
.49231 .99625 m
.49231 1 L
s
.52308 .99625 m
.52308 1 L
s
.55385 .99625 m
.55385 1 L
s
.58462 .99625 m
.58462 1 L
s
.64615 .99625 m
.64615 1 L
s
.67692 .99625 m
.67692 1 L
s
.70769 .99625 m
.70769 1 L
s
.73846 .99625 m
.73846 1 L
s
.8 .99625 m
.8 1 L
s
.83077 .99625 m
.83077 1 L
s
.86154 .99625 m
.86154 1 L
s
.89231 .99625 m
.89231 1 L
s
.95385 .99625 m
.95385 1 L
s
.98462 .99625 m
.98462 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .22714 m
1 .22714 L
s
.99375 .43047 m
1 .43047 L
s
.99375 .63379 m
1 .63379 L
s
.99375 .83712 m
1 .83712 L
s
.125 Mabswid
.99625 .07464 m
1 .07464 L
s
.99625 .12547 m
1 .12547 L
s
.99625 .17631 m
1 .17631 L
s
.99625 .27797 m
1 .27797 L
s
.99625 .3288 m
1 .3288 L
s
.99625 .37963 m
1 .37963 L
s
.99625 .4813 m
1 .4813 L
s
.99625 .53213 m
1 .53213 L
s
.99625 .58296 m
1 .58296 L
s
.99625 .68463 m
1 .68463 L
s
.99625 .73546 m
1 .73546 L
s
.99625 .78629 m
1 .78629 L
s
.99625 .88796 m
1 .88796 L
s
.99625 .93879 m
1 .93879 L
s
.99625 .98962 m
1 .98962 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 .02381 m
1 .02381 L
s
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
0 .02381 m
0 .03926 L
.03846 .03926 L
.03846 .02381 L
F
0 g
.5 Mabswid
0 .02381 m
0 .03926 L
.03846 .03926 L
.03846 .02381 L
0 .02381 L
s
1 0 0 r
.03846 .02381 m
.03846 .13687 L
.07692 .13687 L
.07692 .02381 L
F
0 g
.03846 .02381 m
.03846 .13687 L
.07692 .13687 L
.07692 .02381 L
.03846 .02381 L
s
1 0 0 r
.07692 .02381 m
.07692 .29467 L
.11538 .29467 L
.11538 .02381 L
F
0 g
.07692 .02381 m
.07692 .29467 L
.11538 .29467 L
.11538 .02381 L
.07692 .02381 L
s
1 0 0 r
.11538 .02381 m
.11538 .53869 L
.15385 .53869 L
.15385 .02381 L
F
0 g
.11538 .02381 m
.11538 .53869 L
.15385 .53869 L
.15385 .02381 L
.11538 .02381 L
s
1 0 0 r
.15385 .02381 m
.15385 .70543 L
.19231 .70543 L
.19231 .02381 L
F
0 g
.15385 .02381 m
.15385 .70543 L
.19231 .70543 L
.19231 .02381 L
.15385 .02381 L
s
1 0 0 r
.19231 .02381 m
.19231 .85185 L
.23077 .85185 L
.23077 .02381 L
F
0 g
.19231 .02381 m
.19231 .85185 L
.23077 .85185 L
.23077 .02381 L
.19231 .02381 L
s
1 0 0 r
.23077 .02381 m
.23077 .9706 L
.26923 .9706 L
.26923 .02381 L
F
0 g
.23077 .02381 m
.23077 .9706 L
.26923 .9706 L
.26923 .02381 L
.23077 .02381 L
s
1 0 0 r
.26923 .02381 m
.26923 .95108 L
.30769 .95108 L
.30769 .02381 L
F
0 g
.26923 .02381 m
.26923 .95108 L
.30769 .95108 L
.30769 .02381 L
.26923 .02381 L
s
1 0 0 r
.30769 .02381 m
.30769 .97548 L
.34615 .97548 L
.34615 .02381 L
F
0 g
.30769 .02381 m
.30769 .97548 L
.34615 .97548 L
.34615 .02381 L
.30769 .02381 L
s
1 0 0 r
.34615 .02381 m
.34615 .75831 L
.38462 .75831 L
.38462 .02381 L
F
0 g
.34615 .02381 m
.34615 .75831 L
.38462 .75831 L
.38462 .02381 L
.34615 .02381 L
s
1 0 0 r
.38462 .02381 m
.38462 .69079 L
.42308 .69079 L
.42308 .02381 L
F
0 g
.38462 .02381 m
.38462 .69079 L
.42308 .69079 L
.42308 .02381 L
.38462 .02381 L
s
1 0 0 r
.42308 .02381 m
.42308 .5029 L
.46154 .5029 L
.46154 .02381 L
F
0 g
.42308 .02381 m
.42308 .5029 L
.46154 .5029 L
.46154 .02381 L
.42308 .02381 L
s
1 0 0 r
.46154 .02381 m
.46154 .38821 L
.5 .38821 L
.5 .02381 L
F
0 g
.46154 .02381 m
.46154 .38821 L
.5 .38821 L
.5 .02381 L
.46154 .02381 L
s
1 0 0 r
.5 .02381 m
.5 .26295 L
.53846 .26295 L
.53846 .02381 L
F
0 g
.5 .02381 m
.5 .26295 L
.53846 .26295 L
.53846 .02381 L
.5 .02381 L
s
1 0 0 r
.53846 .02381 m
.53846 .193 L
.57692 .193 L
.57692 .02381 L
F
0 g
.53846 .02381 m
.53846 .193 L
.57692 .193 L
.57692 .02381 L
.53846 .02381 L
s
1 0 0 r
.57692 .02381 m
.57692 .13118 L
.61538 .13118 L
.61538 .02381 L
F
0 g
.57692 .02381 m
.57692 .13118 L
.61538 .13118 L
.61538 .02381 L
.57692 .02381 L
s
1 0 0 r
.61538 .02381 m
.61538 .07505 L
.65385 .07505 L
.65385 .02381 L
F
0 g
.61538 .02381 m
.61538 .07505 L
.65385 .07505 L
.65385 .02381 L
.61538 .02381 L
s
1 0 0 r
.65385 .02381 m
.65385 .05309 L
.69231 .05309 L
.69231 .02381 L
F
0 g
.65385 .02381 m
.65385 .05309 L
.69231 .05309 L
.69231 .02381 L
.65385 .02381 L
s
1 0 0 r
.69231 .02381 m
.69231 .04252 L
.73077 .04252 L
.73077 .02381 L
F
0 g
.69231 .02381 m
.69231 .04252 L
.73077 .04252 L
.73077 .02381 L
.69231 .02381 L
s
1 0 0 r
.73077 .02381 m
.73077 .03601 L
.76923 .03601 L
.76923 .02381 L
F
0 g
.73077 .02381 m
.73077 .03601 L
.76923 .03601 L
.76923 .02381 L
.73077 .02381 L
s
1 0 0 r
.76923 .02381 m
.76923 .0295 L
.80769 .0295 L
.80769 .02381 L
F
0 g
.76923 .02381 m
.76923 .0295 L
.80769 .0295 L
.80769 .02381 L
.76923 .02381 L
s
1 0 0 r
.80769 .02381 m
.80769 .02625 L
.84615 .02625 L
.84615 .02381 L
F
0 g
.80769 .02381 m
.80769 .02625 L
.84615 .02625 L
.84615 .02381 L
.80769 .02381 L
s
1 0 0 r
.84615 .02381 m
.84615 .02544 L
.88462 .02544 L
.88462 .02381 L
F
0 g
.84615 .02381 m
.84615 .02544 L
.88462 .02544 L
.88462 .02381 L
.84615 .02381 L
s
1 0 0 r
.88462 .02381 m
.88462 .02462 L
.92308 .02462 L
.92308 .02381 L
F
0 g
.88462 .02381 m
.88462 .02462 L
.92308 .02462 L
.92308 .02381 L
.88462 .02381 L
s
1 0 0 r
.92308 .02381 m
.92308 .02381 L
.96154 .02381 L
.96154 .02381 L
F
0 g
.92308 .02381 m
.92308 .02381 L
.96154 .02381 L
.96154 .02381 L
.92308 .02381 L
s
1 0 0 r
.96154 .02381 m
.96154 .02462 L
1 .02462 L
1 .02381 L
F
0 g
.96154 .02381 m
.96154 .02462 L
1 .02462 L
1 .02381 L
.96154 .02381 L
s
.015 w
0 .02381 m
.0019 .02394 L
.00363 .02427 L
.00562 .02491 L
.00751 .02577 L
.01086 .02791 L
.0145 .03111 L
.01851 .03568 L
.02276 .04172 L
.03038 .05555 L
.04562 .09428 L
.06241 .1525 L
.09755 .31534 L
.13048 .49523 L
.16042 .65767 L
.19311 .8101 L
.21081 .87496 L
.22725 .92157 L
.23533 .93937 L
.24295 .95295 L
.24717 .95912 L
.25174 .96472 L
.25558 .96857 L
.2597 .97182 L
.26183 .97314 L
.26385 .97418 L
.26567 .97493 L
.26764 .97554 L
.26951 .97594 L
.27149 .97616 L
.27319 .97619 L
.27505 .97605 L
.27612 .9759 L
.27724 .97567 L
.27924 .97511 L
.28139 .97428 L
.28375 .97311 L
.28798 .97033 L
.29191 .96699 L
.30053 .95716 L
.30836 .9454 L
.32594 .91009 L
.35693 .82339 L
.39052 .70667 L
.45662 .46346 L
.48951 .35631 L
.52027 .27114 L
.55167 .20066 L
.58148 .14856 L
.61425 .106 L
Mistroke
.64419 .07827 L
.65972 .06731 L
.67625 .05777 L
.70597 .04511 L
.72263 .04002 L
.74062 .03576 L
.75762 .03269 L
.77323 .03051 L
.789 .02882 L
.8037 .02761 L
.81983 .02659 L
.8371 .02578 L
.85358 .02522 L
.87147 .02478 L
.88838 .02448 L
.904 .02429 L
.91959 .02415 L
.93421 .02405 L
.95025 .02398 L
.95926 .02394 L
.96751 .02392 L
.97519 .0239 L
.98339 .02389 L
.99814 .02386 L
Mfstroke
.99814 .02386 m
1 .02386 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{235, 235},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0000jb000`400?l00000o`00003ojoooool0
0>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00jooo
ool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00
joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00V?ooool00ol@413o<S8boa0@4002o`000003odA4A?o<c<cooooo04_ooooo002Hooooo`03o`00
0?nHV9Sok^k^00;ooooo00?oQhN7oa0@4?ooool0Boooool009gooooo00?o^[Zjo`000?ooool0Booo
ool009Sooooo00?oc<c<odA4A?l000000ol000000onHV9Soooooooooo`1:ooooo`00V?ooool01Ol0
003oQhN7okZj^_nj^[[oc<c<04kooooo002Hooooo`03o`000?nHV9Sooooo00;ooooo00?oc<c<oa0@
4?ooool0Boooool009Sooooo00Ooc<c<odA4A?l0003o0000oa0@4?lb<S;o000004cooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool005[ooooo00CoV9RHo`000?l0003oV9RH1_ooool00omEEEGo0000oeEEE@06oooo
o`05oiRHV?l@413o0000o`000?mVIVH02Oooool4o`000003oa0@4?oooooooooo00Oooooo1?l00000
0ol@413oooooooooo`04ooooo`03oeEEEOl0003oEEEE00Kooooo00GoV9RHoa0@4?l0003o0000ofIV
IP08ooooo`Ko00002?ooool6o`0000Kooooo00?oEEEEo`000?mEEED01_ooool01OnHV9So410@o`00
0?l0003oIVIV00Wooooo00GoZJVYob4Q8Ol0003o0000ofIVIP0;ooooo`00FOooool01_nj^[[o8B4Q
omgMgOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`06oa0@4?n7QhOooooooooooomgMgOoIVIV2_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0ol00006ooooo`06oa0@4?n7
QhOooooooooooomgMgOoIVIV1oooool00onHV9So0000omgMg@02ooooo`03oa0@4?oooooooooo00Ko
oooo00?oV9RHo`000?oMgMd00_ooool00ol@413oooooooooo`04ooooo`?o00001_ooool01_l@413o
QhN7ooooooooooooMgMgofIVIPSooooo00Ko410@olc<c?ooooooooooogMgMomVIVH:ooooo`00FOoo
ool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED02oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00omEEEGo
0000oeEEE@0;ooooo`03o`000?oooooooooo00Kooooo00?oQhN7ob4Q8Oo^k^h02oooool00on7QhOo
8B4Qonk^kP08ooooo`03oeEEEOl0003oEEEE00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`08ooooo`00FOooool01_l0003ok^k^ooooooooooook^k^o`0001;ooooo00?ok^k^o`00
0?ooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00?ok^k^o`00
0?ooool02?ooool00onYZJWo8B4Qonk^kP0;ooooo`03ojVYZOlQ8B7ok^k^01Cooooo00?ok^k^o`00
0?ooool03?ooool00ol0003oooooooooo`08ooooo`00FOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00cooooo00Ko410@oiRHV?ooooooooooogMgMomVIVH:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03oooool01_l@413oV9RHooooooooooooMgMgofIVIP[ooooo
00?oV9RHoc8b<_ooool02oooool00onHV9So<S8booooo`0?ooooo`06oa0@4?nHV9Sooooooooooomg
MgOoIVIV3?ooool00onYZJWoA4A4ooooo`09ooooo`00FOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00cooooo00Go0000ob4Q8Ol0003o0000ofIVIP0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03oooool01Ol0003o8B4Qo`000?l0003oIVIV00cooooo00?oA4A4
ogMgMoooool02oooool00om4A4CoMgMgooooo`0>ooooo`05o`000?lQ8B7o0000o`000?mVIVH02ooo
ool01?lQ8B7o0000o`000?oMgMd:ooooo`00FOooool01_l0003ok^k^ooooooooooook^k^o`0000ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03_ooool00ooMgMgo410@ooooo`0;ooooo`03omgMgOl@413ooooo00ko
oooo00?o0000ooooooooool03oooool00onYZJWo<S8booooo`09ooooo`00FOooool01_m4A4CoV9RH
ooooooooooooV9RHodA4A0kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08oooo
o`00FOooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^Pkooooo00?o0000ooooooooool02oooool0
0ol0003oA4A4o`00000;ooooo`03o`000?m4A4Co0000017ooooo00?o0000ooooooooool02_ooool0
1_l0003oQhN7onk^k_ooooooV9RHoeEEE@Sooooo00Ko0000ohN7Qoo^k^kooooooiRHV?mEEED?oooo
o`03o`000?oooooooooo00_ooooo00Ko8B4QokZj^_ooooooooooofIVI_lb<S8:ooooo`00F_ooool0
1?nHV9So0000o`000?nHV9P?ooooo`Go00002Oooool00oo<c<coEEEEo`00000;ooooo`03olc<c?mE
EEGo0000017ooooo1Ol00008ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^2?ooool01_nYZJWo
<S8bo`000?l0003oEEEEonk^kPoooooo1Ol00009ooooo`06okZj^_m4A4Co0000o`000?m4A4Cok^k^
2_ooool00>_ooooo003[ooooo`00joooool004goooooWOl00001ooooo`00@oooool01?nHV9So0000
o`000?nHV9P6ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000001oooo
o`00@_ooool01_nj^[[o8B4QomgMgOoMgMgo8B4QokZj^PGooooo00?o0000ooooooooool0VOooool1
o`00007ooooo0012ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00ol0003ooooooooo
o`2Iooooo`7o00000Oooool004;ooooo00Ko0000onk^k_ooooooooooonk^k_l00005oooooigo0000
0Oooool004;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Co00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00002ool002Ko00000Oooool004;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`Co00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo000@o`0001[ooooo0Ol00001ooooo`00@_ooool01_l0
003ok^k^ooooooooooook^k^o`0000Gooooo1ol00005ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`003?l0
000Tooooo`7o00000Oooool004;ooooo00KoA4A4oiRHV?oooooooooooiRHV?m4A4@5ooooo`03o`00
0?oooooooooo00;o000000?oooooo`000?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000Oo0000
:Oooool1o`00007ooooo0012ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool00ol0003o
ooooooooo`04o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`002_l0000/ooooo`7o00000Oooool004?ooooo00CoV9RHo`000?l0003o
V9RH1_ooool01?l0003oooooooooooooool3o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001ol0000_ooooo`7o00000Oooool004go
oooo00Co0000oooooooooooooooo0ol00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool000?o0000<oooool1o`00007ooooo001=ooooo`;o
00000oooool2o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000So
0000=?ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00;ooooo0_l00005ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oooooooooo`04o`0003Gooooo
0Ol00001ooooo`00COooool00ol0003oooooooooo`02ooooo`?o00001?oo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooool000000ol0000fooooo`7o00000Ooo
ool004gooooo00?o0000ooooooooool00oooool2o`0000Coo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool000Co0000>?ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo
00?ooooo0_l00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0003o`00
03Wooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`03ooooo`?o00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000;oo`000ol0000jooooo`7o00000Oooool004gooooo
00?o0000ooooooooool00oooool3o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00002ool000;o0000>oooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00?ooooo0ol0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`0000Co0000ool00?oo003oo`000ol0000kooooo`7o0000
0Oooool004gooooo0_l00004ooooo`Co00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Co0000>oooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00?ooooo00Co0000
ool00?l0003o00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000Oo0000>oooool1o`00007ooooo001=
ooooo`03o`000?oooooooooo00?ooooo1ol00005ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?oooooo0000o`0003kooooo0Ol0
0001ooooo`00COooool00ol0003oooooooooo`05ooooo`?o000000?oooooo`000?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0004
o`0003kooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`00
0?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo0003o`0003oooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`06ooooo`;o
000000?oooooo`000?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo0002o`00043ooooo0Ol00001ooooo`00COooool00ol0003ooooo
ooooo`06ooooo`;o000000?oooooo`000?oo00001?oo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0003o`00043ooooo0Ol00001ooooo`00COoo
ool00ol0003oooooooooo`06ooooo`Co00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000Co0000ool00?oo003oo`000ol00011ooooo`7o00000Oooool004gooooo0_l0
0008ooooo`?o00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co
0000ool00?oo003oo`000ol00011ooooo`7o00000Oooool004gooooo00?o0000ooooooooool01ooo
ool3o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000Co0000@Oooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00Oooooo0ol00005
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
o`000003ool00?l0003ooooo043ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`07oooo
o`?o00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`001ol00011oooo
o`7o00000Oooool004gooooo00?o0000ooooooooool02?ooool2o`0000Goo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool000Co0000A?ooool1o`00007ooooo000`ooooo`04oiRH
V?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01Oooool6o`0000Gooooo00?o0000oooooooo
ool02?ooool2o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000?o
0000AOooool1o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`00
00Gooooo00?oV9RHo`000?oMgMd00_ooool00ol@413oooooooooo`03ooooo`03o`000?oooooooooo
00Sooooo0_l00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0003o`00
04Gooooo0Ol00001ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEE
o`000?mEEED01_ooool00on7QhOo8B4Qonk^kP07ooooo`03o`000?oooooooooo00Sooooo0_l00005
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0002o`0004Kooooo0Ol00001
ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000oooooo00?oZJVYob4Q8Oo^k^h01_oo
ool2o`0000Wooooo0ol00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
0002o`0004Gooooo0_l00001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00kooooo00?oV9RHoc8b<_ooool01Oooool00ol0003oooooooooo`09ooooo`;o00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`000ol00016ooooo`7o00000Oooool0
02oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03odA4A?mgMgOooooo
00Cooooo00?o0000ooooooooool02Oooool2o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00002ool000;o0000Aoooool1o`00007ooooo000_ooooo`06o`000?o^k^kooooooooo
ooo^k^ko00004Oooool00ooMgMgo410@ooooo`04ooooo`03o`000?oooooooooo00Wooooo0_l00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0002o`0004Oooooo0Ol00001
ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A1;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`?o00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?oo
003oo`00ool000?o0000Aoooool1o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o
^[Zj3Oooool01_l0003oQhN7onk^k_ooooooV9RHoeEEE@Gooooo00?o0000ooooooooool02Oooool3
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo0007o`0004Oooooo0Ol00001ooooo`00<?ooool01?nH
V9So0000o`000?nHV9P>ooooo`06ojVYZOlb<S;o0000o`000?mEEEGok^k^1Oooool00ol0003ooooo
ooooo`09ooooo`?o00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?ooooooooooooooo`;o
0000B?ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00Wooooo0ol00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ooooooooool00ol00018ooooo`7o00000Oooool004gooooo0_l0
000:ooooo`Co00000_oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooooooo00;o0000BOoo
ool1o`00007ooooo001=ooooo`03o`000?oooooooooo00Wooooo00Co0000ool00?l0003o00000_oo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oooooo000000;o0000BOooool1o`00007ooooo001=
ooooo`03o`000?oooooooooo00Wooooo1ol00005ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?oooooo0000o`0004[ooooo0Ol0
0001ooooo`00COooool00ol0003oooooooooo`0;ooooo`;o00000_ooool00ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00004o`000?oooooo0000o`0004[ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0;
ooooo`;o00000_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool000Co0000B_ooool1o`00007ooooo001=oooo
o`03o`000?oooooooooo00_ooooo0ol000000ooooooo0000ool00004ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000?o0000Boooool1o`00
007ooooo001=ooooo`03o`000?oooooooooo00cooooo0_l000000ooooooo0000ool00004ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000?o
0000Boooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00cooooo0_l000000ooooooo0000
ool00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool000;o0000C?ooool1o`00007ooooo001=ooooo`;o00003Oooool2o`000003ooooool0
003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`000_l0001<ooooo`7o00000Oooool004gooooo00?o0000ooooooooool03?ooool2
o`000003ooooool0003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000;oo`000ol0001<ooooo`7o00000Oooool004gooooo00?o0000oooo
ooooool03?ooool4o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000;oo`000_l0001=ooooo`7o00000Oooool004gooooo00?o0000oooooooo
ool03Oooool3o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`000_l0001=ooooo`7o00000Oooool004gooooo00?o0000ooooooooool0
3Oooool3o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`00
0?oo003oo`00ool000?o0000COooool1o`00007ooooo001=ooooo`03o`000?oooooooooo00gooooo
0ol00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003oo`00
ool00?oo0003o`0004gooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0=ooooo`?o0000
1Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000ool00?oo003o
o`000ol0001=ooooo`7o00000Oooool004gooooo00?o0000ooooooooool03Oooool3o`0000Goo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000Co0000
COooool1o`00007ooooo001=ooooo`;o00003oooool2o`0000Goo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;o000000?oo`00o`000?ooool0C?oo
ool1o`00007ooooo001=ooooo`03o`000?oooooooooo00kooooo0_l00005ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo0007o`0004gooooo0Ol00001ooooo`00COooool00ol0
003oooooooooo`0>ooooo`;o00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ooooool000000_l0001?ooooo`7o00000Oooool004gooooo00?o0000oooooooo
ool03_ooool2o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00004
o`000?oooooo0000o`00053ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0>ooooo`;o
00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000ooooool0
003o0000D?ooool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`00
0?mEEED02Oooool2o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool03_ooool3o`00
00Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000Co0000D?ooool1o`00
007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0?ooooo`;o00001?oo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`000ol0001Aooooo`7o00000Oooool002oooooo00KoA4A4oiRH
V?oooooooooooiRHV?m4A4@5ooooo`03oeEEEOl0003oEEEE00Kooooo1_l00004ooooo`03o`000?oo
oooooooo00oooooo0_l00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
0003o`00057ooooo0Ol00001ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000kooooo
00GoA4A4okZj^_ooooooooooo`000005ooooo`;o00004?ooool2o`0000Coo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool000?o0000D?ooool2o`00007ooooo000_ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03?ooool01OoMgMgo8B4Qoooooooooooo000000Go
oooo00?o0000ooooooooool03oooool2o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool000?o0000DOooool1o`00007ooooo000_ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03Oooool01?mgMgOoV9RHooooool00005ooooo`03o`000?oooooooooo00oo
oooo0_l00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0002o`0005;o
oooo0Ol00001ooooo`00;oooool01_l0003ok^k^ooooooooooook^k^o`0000oooooo00Cok^k^ob4Q
8Ooooooo00001Oooool00ol0003oooooooooo`0?ooooo`?o00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`000_l0001Booooo`7o00000Oooool0013ooooo00?o^[Zjoc8b
<_ooool03_ooool00olb<S;o^[Zjooooo`0;ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A44?oo
ool00omgMgOoV9RHo`000005ooooo`03o`000?oooooooooo00oooooo0ol00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000_oo0003o`0005;ooooo0Ol00001ooooo`004?ooool0
0olb<S;o^[Zjooooo`0>ooooo`03okZj^_lb<S;ooooo00_ooooo00Ko^[Zjob4Q8OoMgMgogMgMob4Q
8Onj^[X@ooooo`03onk^k_lb<S;o000000Gooooo00?o0000ooooooooool03oooool3o`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool000;o0000Doooool1o`00007ooooo
000?ooooo`03olc<c?lb<S;ooooo013ooooo00?o<S8bolc<c?ooool02oooool01?nHV9So0000o`00
0?nHV9PBooooo`03oiRHV?l@413ooooo00Cooooo00?o0000ooooooooool03oooool3o`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00002ool000;o0000Doooool1o`00007ooooo
0002ooooo`05oa0@4?l0003o0000o`000?l@41002?ooool00omVIVKoZJVYooooo`04ooooo`03oa0@
4?lb<S;o410@00;o000000?oA4A4olc<c?ooool01?ooool00onHV9SoIVIVooooo`0Xooooo`03o`00
0?oooooooooo00oooooo0ol00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0_oo0002o`0005?ooooo0Ol00001ooooo`001?ooool00ol0003oooooooooo`08ooooo`03oc8b<_oo
oooooooo00Cooooo00?o0000oiRHV?o^k^h00_ooool00on7QhOo410@ooooo`04ooooo`03onk^k_lb
<S;ooooo02Sooooo0_l0000@ooooo`Co00000_oo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo
003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?oo
003oo`00ool000?o0000Doooool1o`00007ooooo0004ooooo`03o`000?oooooooooo00Sooooo00?o
<S8booooooooool02Oooool00onj^[[o0000ooooo`05ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool03oooool01?l0003oo`00o`000?l00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00Co0000ool00?oo003oo`000ol0001Cooooo`7o00000Oooool000Cooooo0ol000000ol@413oMgMg
onk^kP05ooooo`03oc8b<_oooooooooo00Cooooo00?oc<c<odA4A?l000000ol000000onHV9Sooooo
ooooo`04ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool01?l0003oo`00
o`000?l00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000ool00?oo003oo`000ol0001Coooo
o`7o00000Oooool000Cooooo00Ko0000ooooooooooook^k^ogMgMomEEED5ooooo`03ob4Q8Ooooooo
oooo00Cooooo00Go0000ohN7Qonj^[[o^[Zjolc<c008ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool03oooool01?l0003oo`00o`000?l00002ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
1ol0001Cooooo`7o00000Oooool000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03oc8b<_o^k^kooooo00Cooooo00?o0000oiRHV?ooool00_ooool00oo<c<co410@oooo
o`04ooooo`03omgMgOlb<S;ooooo02Sooooo00?o0000ooooooooool03oooool01?l0003oo`00o`00
0?l00002ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ooooooooool00_l0001Eooooo`7o0000
0Oooool000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03ofIVI_nH
V9Sooooo00Cooooo00Ooc<c<odA4A?l0003o0000oa0@4?lb<S;o000000Gooooo00?oV9RHofIVI_oo
ool0:?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo003o0000o`0000;oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oooooooooo`02o`0005Gooooo0Ol00001ooooo`001?ooool01_l0003o
ooooooooooo^k^koMgMgoeEEE@Gooooo00?ogMgMob4Q8Oooool04?ooool00ol@413oc<c<ooooo`0X
ooooo`03o`000?oooooooooo00oooooo00?o0000ool00?l000000_l000000ooo003o0000ool00004
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oooooooooo00;o0000EOooool1o`00007ooooo0002ooooo`03oa0@4?l0003o0000
00;o000000?o410@ogMgMoo^k^h01_ooool00olb<S;o^[Zjooooo`0>ooooo`03okZj^_lb<S;ooooo
02Wooooo0_l0000@ooooo`03o`000?oo003oo`0000;o000000?oo`00o`000?oo00001?oo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooo`000002o`0005Gooooo0Ol00001ooooo`004?ooool00onj^[[o<S8booooo`0>ooooo`03
oc8b<_nj^[[ooooo02Wooooo00?o0000ooooooooool03oooool00ol0003oo`00ool00002o`000003
ool00?l0003oo`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000Co0000ooooool0003o0000E_ooool1o`00007ooooo001=ooooo`03
o`000?oooooooooo00oooooo1ol00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00004o`000?oooooo0000o`0005Kooooo0Ol00001oooo
o`00COooool00ol0003oooooooooo`0Booooo`;o000000?oooooo`000?oo00001?oo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0004o`0005Ko
oooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Booooo`;o000000?oooooo`000?oo0000
1?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo0003o`0005Oooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Booooo`Co00001Ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
0003o`0005Oooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Cooooo`?o00001Ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0003
o`0005Oooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Cooooo`?o00001Ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0003o`00
05Oooooo0Ol00001ooooo`00COooool2o`0001Cooooo0ol00005ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000;o0000F?ooool1o`00007o
oooo001=ooooo`03o`000?oooooooooo01?ooooo0ol00005ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000;o0000F?ooool1o`00007ooooo
001=ooooo`03o`000?oooooooooo01?ooooo0ol00005ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00002ool000?o0000F?ooool1o`00007ooooo001=
ooooo`03o`000?oooooooooo01?ooooo0ol00005ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00002ool000;o0000FOooool1o`00007ooooo001=oooo
o`03o`000?oooooooooo01?ooooo0ol00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool0
0?oo00000ooo00000ol0003oo`00ool00002ool000;o0000FOooool1o`00007ooooo000`ooooo`04
oiRHV?l0003o0000oiRHV0Kooooo00?oEEEEo`000?mEEED01_ooool01_o^k^koEEEEo`000?l0003o
EEEEonk^kPCooooo00?o0000ooooooooool05?ooool2o`0000Goo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00004o`000?oo003oo`00ool000?o0000FOooool1o`00007ooooo
000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj1Oooool3o`0000Kooooo0_mgMgL2ooooo`03
ogMgMomEEEGooooo00?ooooo00?o0000ooooooooool05?ooool2o`0000Goo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oo`00ool00003ool00004o`000?oo003oo`00ool000?o0000FOooool1o`00
007ooooo000_ooooo`06odA4A?nHV9SooooooooooonHV9SoA4A41Oooool00omEEEGo0000oeEEE@06
ooooo`03ob4Q8Ooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0D
ooooo`;o00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000
ool00?oo003oo`000ol0001Iooooo`7o00000Oooool002oooooo00Ko0000onk^k_ooooooooooonk^
k_l0000>ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool00_ooool2o`0001Gooooo
0_l00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003oo`00
ool00?oo0003o`0005Sooooo0_l00001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00cooooo00Ko0000oeEEEOo^k^koooooogMgMomEEED4ooooo`03o`000?oooooooooo
01Cooooo0_l00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00004o`0005Wooooo0Ol00001ooooo`00;oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00cooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^h4ooooo`03o`000?oooooo
oooo01Cooooo0ol00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00002o`000003ool00?l0003ooooo05Sooooo0Ol00001ooooo`00;oooool01_l0
003ok^k^ooooooooooook^k^o`0000kooooo00?oA4A4oiRHV?ooool01oooool00ol0003ooooooooo
o`0Eooooo`;o00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_l000000ooo003o0000ooooo`1Hooooo`7o00000Oooool002oooooo00KoA4A4
oiRHV?oooooooooooiRHV?m4A4@>ooooo`03okZj^_lQ8B7ooooo00Oooooo00?o0000ooooooooool0
5Oooool2o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`00
0?oo003o000000;o000000?oo`00o`000?ooool0F?ooool1o`00007ooooo000_ooooo`06okZj^_lQ
8B7ogMgMomgMgOlQ8B7o^[Zj3oooool00omEEEGo<S8bomgMg@06ooooo`03o`000?oooooooooo01Go
oooo0_l00004ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003o
o`00o`000?l00002ool00003o`000?oooooooooo05Oooooo0Ol00001ooooo`00<?ooool01?nHV9So
0000o`000?nHV9PAooooo`04oiRHV?lQ8B7o0000ob4Q8@Cooooo00?o0000ooooooooool05Oooool2
o`0000Coo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?oo003o
0000o`0000;oo`0000?o0000ooooooooool0Eoooool1o`00007ooooo001=ooooo`03o`000?oooooo
oooo01Gooooo0ol00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
1?l0003oo`00o`000?l00002ool00003o`000?oooooooooo05Oooooo0Ol00001ooooo`00COooool2
o`0001Kooooo0ol00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0004
o`0000;oo`0000?o0000ooooooooool0Eoooool1o`00007ooooo001=ooooo`03o`000?oooooooooo
01Gooooo0ol00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0007o`00
05Wooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Eooooo`?o00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003o
o`00ool00003ool00003o`000?oo003oo`0000?oo`000ol0001Mooooo`7o00000Oooool004gooooo
00?o0000ooooooooool05Oooool3o`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool000?o0000GOooool1o`00007ooooo001=ooooo`03o`000?oooooooooo01Gooooo1ol0
0005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0003ool00003o`000?oo003oo`0000?oo`000_l0001Nooooo`7o00000Oooool004gooooo00?o0000
ooooooooool05oooool2o`0000;ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003
ool000;o0000G_ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo01Oooooo0_l00002oooo
o`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0002o`0005kooooo0Ol00001oooo
o`00COooool00ol0003oooooooooo`0Gooooo`;o00000_ooool00ol0003oo`00ool00003ool00003
o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003
o`000?oo003oo`0000;oo`000ol0001Nooooo`7o00000Oooool004gooooo0_l0000Hooooo`;o0000
0_ooool00ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo0000
0ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000;oo`000_l0001Oooooo`7o0000
0Oooool004gooooo00?o0000ooooooooool05oooool3o`000003ooooool0003oo`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_oo0002o`0005oooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0H
ooooo`;o000000?oooooo`000?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003oo`00ool00?oo0003o`0005oooooo0Ol0
0001ooooo`00COooool00ol0003oooooooooo`0Hooooo`;o000000?oooooo`000?oo00001?oo0000
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo0000
1?l0003oo`00ool00?oo0003o`0005oooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0H
ooooo`;o000000?oooooo`000?oo00001?oo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo0007o`0005oooooo0Ol00001ooooo`00COooool00ol0
003oooooooooo`0Hooooo`;o000000?oooooo`000?oo00001?oo00000ol0003oo`00ool00003ool0
0003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003oooooooooooooool2
o`00063ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Hooooo`Co00001Ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0
003oooooooooo`03o`00063ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Iooooo`?o
00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo
00000ooo00000ol0003oooooooooo`02o`00067ooooo0Ol00001ooooo`00COooool2o`0001[ooooo
0ol00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00
ool00003ool00003o`000?oooooooooo00;o0000HOooool1o`00007ooooo001=ooooo`03o`000?oo
oooooooo01Wooooo0ol00005ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo
00000ol0003oo`00ool00003ool00003o`000?oooooooooo00;o0000HOooool1o`00007ooooo001=
ooooo`03o`000?oooooooooo01Wooooo0ol00005ool00003o`000?oo003oo`0000?oo`0000?o0000
ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oooooo000000;o0000HOooool1
o`00007ooooo001=ooooo`03o`000?oooooooooo01Wooooo0ol00005ool00003o`000?oo003oo`00
00?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?oooooo0000
o`0006;ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Jooooo`;o00001Ooo00000ol0
003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0
003oooooo`000?l0001Rooooo`7o00000Oooool0033ooooo00CoV9RHo`000?l0003oV9RH1_ooool0
0omEEEGo0000oeEEE@06ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^1?ooool00ol0003ooooo
ooooo`0Jooooo`;o00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
00?o0000ool00?oo00000ooo0004o`0006;ooooo0Ol00001ooooo`00;oooool01_nj^[[o8B4QomgM
gOoMgMgo8B4QokZj^PGooooo0ol00006ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE1?ooool0
0ol0003oooooooooo`0Jooooo`;o00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003o
o`0000?oo`0000?o0000ool00?oo00000ooo0003o`0006?ooooo0Ol00001ooooo`00;oooool01_m4
A4CoV9RHooooooooooooV9RHodA4A0Gooooo00?oEEEEo`000?mEEED01_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool3o`0000Coo`0000?o
0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`000ol0
001Sooooo`7o00000Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0001cooooo0_l00004ool00003o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool000?o0000
H_ooool2o`00007ooooo000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?oo
ool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Cooooo00?o0000ooooooooool06oooool2o`0000Co
o`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?o
o`000_l0001Tooooo`7o00000Oooool002oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0<ooooo`03omgMgOl0003o000000;o000000?ogMgMooooooooool00_ooool00ol0003ooooo
ooooo`0Kooooo`Oo00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`00
0_l0001Tooooo`7o00000Oooool002oooooo00Ko0000onk^k_ooooooooooonk^k_l0000>ooooo`06
oc8b<_mVIVKok^k^onk^k_mVIVKo<S8b1?ooool00ol0003oooooooooo`0Looooo`;o00000oooool0
0ol0003oo`00ool00003ool00003o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000_oo0003
o`0006Cooooo0Ol00001ooooo`00;oooool01_m4A4CoV9RHooooooooooooV9RHodA4A0kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo0_l0
0003ooooo`03o`000?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool0
0002ool000;o0000IOooool1o`00007ooooo000_ooooo`06okZj^_lQ8B7ogMgMomgMgOlQ8B7o^[Zj
3_ooool01_lb<S;oIVIVonk^k_o^k^koIVIVoc8b<PCooooo00?o0000ooooooooool07?ooool3o`00
00;ooooo00?o0000ool00?oo00000ooo00000ol0003oo`00ool00003ool00004o`000?oo003oo`00
ool000?o0000IOooool1o`00007ooooo000`ooooo`04oiRHV?l0003o0000oiRHV0oooooo00Kok^k^
odA4A?l0003o0000odA4A?o^k^h4ooooo`03o`000?oooooooooo01gooooo0_l00002ooooo`03o`00
0?oo003oo`0000?oo`0000?o0000ool00?oo00000ooo00001?l0003oo`00ool00?oo0003o`0006Go
oooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Mooooo`;o00000_ooool00ol0003oo`00
ool00003ool00003o`000?oo003oo`0000?oo`0000Co0000ool00?oo003oo`000ol0001Uooooo`7o
00000Oooool004gooooo0_l0000Nooooo`?o000000?oooooo`000?oo00001?oo00000ol0003oo`00
ool00003ool00003o`000?oo003oo`0000Co0000IOooool1o`00007ooooo001=ooooo`03o`000?oo
oooooooo01kooooo0_l000000ooooooo0000ool00004ool00003o`000?oo003oo`0000?oo`0000?o
0000ool00?oo00000_l000000ooo003o0000ooooo`1Tooooo`7o00000Oooool004gooooo00?o0000
ooooooooool07_ooool4o`0000Goo`0000?o0000ool00?oo00000ooo00000ol0003oo`00ool00002
o`000003ool00?l0003ooooo06Cooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Ooooo
o`?o00001Ooo00000ol0003oo`00ool00003ool00003o`000?oo003o000000;o000000?oo`00o`00
0?ooool0I?ooool1o`00007ooooo001=ooooo`03o`000?oooooooooo01oooooo0ol00005ool00003
o`000?oo003oo`0000?oo`0000Co0000ool00?l0003o00000_oo00000ol0003oooooooooo`1Soooo
o`7o00000Oooool004gooooo00?o0000ooooooooool07oooool3o`0000Goo`0000?o0000ool00?oo
00000ooo0004o`0000;oo`0000?o0000ooooooooool0Hoooool1o`00007ooooo001=ooooo`03o`00
0?oooooooooo023ooooo0_l00005ool00003o`000?oo003oo`0000?oo`000ol00003ool00003o`00
0?oooooooooo06?ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`0Pooooo`?o00001?oo
00000ol0003oo`00ool00003ool000?o00000ooo00000ol0003oooooooooo`1Sooooo`7o00000Ooo
ool004gooooo0_l0000Rooooo`;o00001?oo00000ol0003oo`00ool00003ool000;o00001?oo0000
0ol0003oooooooooo`1Sooooo`7o00000Oooool004gooooo00?o0000ooooooooool08Oooool2o`00
00Coo`0000?o0000ool00?oo00000_oo0003o`0000Coo`0000?o0000ooooooooool0Hoooool1o`00
007ooooo001=ooooo`03o`000?oooooooooo027ooooo0ol00003ool000Oo00001Ooo00000ol0003o
ooooooooo`1Sooooo`7o00000Oooool004gooooo00?o0000ooooooooool08Oooool4o`0000;oo`00
00Co0000oooooooooooooooo0ol00005ool00003o`000?oooooooooo06?ooooo0Ol00001ooooo`00
COooool00ol0003oooooooooo`0Qooooo`03o`000?oo003o000000;o000000Coo`00o`000?oooooo
oooo1?l00005ool00003o`000?oooooooooo06?ooooo0Ol00001ooooo`00COooool00ol0003ooooo
ooooo`0Qooooo`_o000000?oooooo`000?oo00001?oo00000ol0003oooooooooo`1Sooooo`7o0000
0Oooool004gooooo00?o0000ooooooooool09?ooool7o`0000;ooooo1ol0001Uooooo`7o00000Ooo
ool004gooooo00?o0000ooooooooool09_ooool4o`0006oooooo0Ol00001ooooo`00COooool2o`00
09[ooooo0Ol00001ooooo`00COoooonMo`00007ooooo003[ooooo`00joooool00>_ooooo003[oooo
o`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[
ooooo`00joooool00>_ooooo003[ooooo`00joooool00>_ooooo003[ooooo`00joooool00001\
\>"],
  ImageRangeCache->{{{0, 234}, {234, 0}} -> {-1.62205, -0.388913, 0.0208319, \
0.0063049}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 998}},
WindowSize->{588, 689},
WindowMargins->{{194, Automatic}, {Automatic, 74}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 52, 0, 136, "Title"],
Cell[1831, 55, 59, 0, 52, "Subtitle"],

Cell[CellGroupData[{
Cell[1915, 59, 31, 0, 69, "Section"],
Cell[1949, 61, 1097, 21, 180, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3083, 87, 57, 0, 69, "Section"],
Cell[3143, 89, 372, 6, 78, "Text"],
Cell[3518, 97, 58, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[3601, 101, 125, 3, 43, "Input"],
Cell[3729, 106, 13894, 375, 243, 3419, 241, "GraphicsData", "PostScript", \
"Graphics"],
Cell[17626, 483, 130, 3, 27, "Output"]
}, Open  ]],
Cell[17771, 489, 364, 8, 64, "Text"],

Cell[CellGroupData[{
Cell[18160, 501, 154, 3, 43, "Input"],
Cell[18317, 506, 19012, 512, 243, 4569, 329, "GraphicsData", "PostScript", \
"Graphics"],
Cell[37332, 1020, 130, 3, 27, "Output"]
}, Open  ]],
Cell[37477, 1026, 165, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[37667, 1034, 134, 3, 43, "Input"],
Cell[37804, 1039, 17840, 528, 243, 5251, 368, "GraphicsData", "PostScript", \
"Graphics"],
Cell[55647, 1569, 130, 3, 27, "Output"]
}, Open  ]],
Cell[55792, 1575, 89, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[55906, 1582, 193, 4, 75, "Input"],
Cell[56102, 1588, 15750, 459, 243, 4493, 315, "GraphicsData", "PostScript", \
"Graphics"],
Cell[71855, 2049, 130, 3, 27, "Output"]
}, Open  ]],
Cell[72000, 2055, 238, 5, 68, "Text"],

Cell[CellGroupData[{
Cell[72263, 2064, 208, 4, 75, "Input"],
Cell[72474, 2070, 17346, 494, 243, 4915, 336, "GraphicsData", "PostScript", \
"Graphics"],
Cell[89823, 2566, 130, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[89990, 2574, 279, 6, 123, "Input"],
Cell[90272, 2582, 15797, 454, 243, 4499, 310, "GraphicsData", "PostScript", \
"Graphics"],
Cell[106072, 3038, 130, 3, 27, "Output"]
}, Open  ]],
Cell[106217, 3044, 174, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[106416, 3052, 140, 3, 43, "Input"],
Cell[106559, 3057, 17258, 505, 243, 5133, 351, "GraphicsData", "PostScript", \
"Graphics"],
Cell[123820, 3564, 130, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[123999, 3573, 33, 0, 69, "Section"],
Cell[124035, 3575, 539, 10, 104, "Text"],
Cell[124577, 3587, 45, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[124647, 3592, 600, 11, 155, "Input"],
Cell[125250, 3605, 203, 3, 49, "Message"],
Cell[125456, 3610, 49275, 1687, 243, 21616, 1341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[174734, 5299, 130, 3, 27, "Output"]
}, Open  ]],
Cell[174879, 5305, 208, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[175112, 5313, 76, 1, 27, "Input"],
Cell[175191, 5316, 58033, 1849, 243, 22846, 1410, "GraphicsData", \
"PostScript", "Graphics"],
Cell[233227, 7167, 130, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[233406, 7176, 38, 0, 69, "Section"],
Cell[233447, 7178, 361, 6, 86, "Text"],
Cell[233811, 7186, 255, 6, 50, "Text"],
Cell[234069, 7194, 71, 1, 27, "Input"],
Cell[234143, 7197, 424, 7, 104, "Text"],
Cell[234570, 7206, 478, 10, 123, "Input"],
Cell[235051, 7218, 475, 8, 104, "Text"],
Cell[235529, 7228, 45, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[235599, 7233, 311, 6, 75, "Input"],
Cell[235913, 7241, 99953, 2405, 243, 27071, 1501, "GraphicsData", \
"PostScript", "Graphics"],
Cell[335869, 9648, 130, 3, 27, "Output"]
}, Open  ]],
Cell[336014, 9654, 364, 8, 68, "Text"],

Cell[CellGroupData[{
Cell[336403, 9666, 154, 3, 43, "Input"],
Cell[336560, 9671, 19029, 512, 243, 4569, 329, "GraphicsData", "PostScript", \
"Graphics"],
Cell[355592, 10185, 130, 3, 27, "Output"]
}, Open  ]],
Cell[355737, 10191, 151, 3, 50, "Text"],

Cell[CellGroupData[{
Cell[355913, 10198, 77, 1, 27, "Input"],
Cell[355993, 10201, 133733, 2887, 243, 28036, 1577, "GraphicsData", \
"PostScript", "Graphics"],
Cell[489729, 13090, 130, 3, 27, "Output"]
}, Open  ]],
Cell[489874, 13096, 413, 7, 86, "Text"],
Cell[490290, 13105, 167, 3, 38, "DisplayFormula"],
Cell[490460, 13110, 432, 9, 86, "Text"],

Cell[CellGroupData[{
Cell[490917, 13123, 480, 9, 155, "Input"],
Cell[491400, 13134, 84760, 2098, 243, 23720, 1340, "GraphicsData", \
"PostScript", "Graphics"],
Cell[576163, 15234, 130, 3, 27, "Output"]
}, Open  ]],
Cell[576308, 15240, 138, 3, 50, "Text"],

Cell[CellGroupData[{
Cell[576471, 15247, 481, 10, 107, "Input"],
Cell[576955, 15259, 69811, 2002, 243, 24924, 1443, "GraphicsData", \
"PostScript", "Graphics"],
Cell[646769, 17263, 130, 3, 27, "Output"]
}, Open  ]],
Cell[646914, 17269, 194, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[647133, 17277, 74, 1, 27, "Input"],
Cell[647210, 17280, 89666, 2295, 243, 25564, 1499, "GraphicsData", \
"PostScript", "Graphics"],
Cell[736879, 19577, 130, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[737058, 19586, 41, 0, 69, "Section"],
Cell[737102, 19588, 896, 14, 158, "Text"],
Cell[738001, 19604, 71, 1, 27, "Input"],
Cell[738075, 19607, 45, 1, 27, "Input"],
Cell[738123, 19610, 1366, 27, 411, "Input"],

Cell[CellGroupData[{
Cell[739514, 19641, 457, 10, 107, "Input"],
Cell[739974, 19653, 70675, 1611, 243, 16568, 939, "GraphicsData", \
"PostScript", "Graphics"],
Cell[810652, 21266, 130, 3, 27, "Output"]
}, Open  ]],
Cell[810797, 21272, 175, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[810997, 21280, 76, 1, 27, "Input"],
Cell[811076, 21283, 99931, 2021, 243, 17406, 998, "GraphicsData", \
"PostScript", "Graphics"],
Cell[911010, 23306, 130, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[911189, 23315, 38, 0, 69, "Section"],
Cell[911230, 23317, 364, 6, 86, "Text"],
Cell[911597, 23325, 255, 6, 50, "Text"],
Cell[911855, 23333, 71, 1, 27, "Input"],
Cell[911929, 23336, 463, 7, 104, "Text"],
Cell[912395, 23345, 552, 11, 171, "Input"],
Cell[912950, 23358, 507, 8, 104, "Text"],
Cell[913460, 23368, 45, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[913530, 23373, 387, 7, 91, "Input"],
Cell[913920, 23382, 99848, 2404, 243, 27079, 1501, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1013771, 25788, 130, 3, 27, "Output"]
}, Open  ]],
Cell[1013916, 25794, 364, 8, 68, "Text"],

Cell[CellGroupData[{
Cell[1014305, 25806, 154, 3, 43, "Input"],
Cell[1014462, 25811, 19012, 512, 243, 4569, 329, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1033477, 26325, 130, 3, 27, "Output"]
}, Open  ]],
Cell[1033622, 26331, 140, 3, 50, "Text"],

Cell[CellGroupData[{
Cell[1033787, 26338, 74, 1, 27, "Input"],
Cell[1033864, 26341, 133733, 2887, 243, 28036, 1577, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1167600, 29230, 130, 3, 27, "Output"]
}, Open  ]],
Cell[1167745, 29236, 424, 9, 86, "Text"],

Cell[CellGroupData[{
Cell[1168194, 29249, 640, 12, 203, "Input"],
Cell[1168837, 29263, 359, 5, 35, "Message"],
Cell[1169199, 29270, 64496, 1832, 243, 22733, 1312, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1233698, 31104, 130, 3, 27, "Output"]
}, Open  ]],
Cell[1233843, 31110, 184, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[1234052, 31118, 74, 1, 27, "Input"],
Cell[1234129, 31121, 81113, 2104, 243, 23708, 1391, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1315245, 33227, 130, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1315424, 33236, 41, 0, 69, "Section"],
Cell[1315468, 33238, 471, 10, 86, "Text"],

Cell[CellGroupData[{
Cell[1315964, 33252, 792, 16, 235, "Input"],
Cell[1316759, 33270, 455201, 19251, 243, 322310, 17606, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1771963, 52523, 130, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1772142, 52532, 39, 0, 69, "Section"],
Cell[1772184, 52534, 600, 9, 122, "Text"],
Cell[1772787, 52545, 301, 6, 155, "Input"],
Cell[1773091, 52553, 281, 5, 68, "Text"],

Cell[CellGroupData[{
Cell[1773397, 52562, 130, 2, 43, "Input"],
Cell[1773530, 52566, 31168, 935, 243, 11982, 694, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1804701, 53503, 130, 3, 27, "Output"]
}, Open  ]],
Cell[1804846, 53509, 705, 11, 140, "Text"],
Cell[1805554, 53522, 45, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[1805624, 53527, 508, 9, 123, "Input"],
Cell[1806135, 53538, 118758, 2557, 186, 24032, 1383, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1924896, 56097, 130, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1925063, 56105, 768, 15, 171, "Input"],
Cell[1925834, 56122, 357, 5, 35, "Message"],
Cell[1926194, 56129, 358, 5, 35, "Message"],
Cell[1926555, 56136, 61049, 1843, 243, 23522, 1375, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1987607, 57981, 130, 3, 27, "Output"]
}, Open  ]],
Cell[1987752, 57987, 355, 6, 86, "Text"],

Cell[CellGroupData[{
Cell[1988132, 57997, 77, 1, 27, "Input"],
Cell[1988212, 58000, 63726, 1857, 243, 22915, 1349, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2051941, 59859, 130, 3, 27, "Output"]
}, Open  ]],
Cell[2052086, 59865, 1083, 17, 194, "Text"],
Cell[2053172, 59884, 419, 8, 107, "Input"],

Cell[CellGroupData[{
Cell[2053616, 59896, 1245, 23, 315, "Input"],
Cell[2054864, 59921, 63922, 1761, 243, 22190, 1241, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2118789, 61684, 130, 3, 27, "Output"]
}, Open  ]],
Cell[2118934, 61690, 529, 8, 104, "Text"],

Cell[CellGroupData[{
Cell[2119488, 61702, 77, 1, 27, "Input"],
Cell[2119568, 61705, 77150, 2040, 243, 24347, 1384, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2196721, 63747, 130, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2196900, 63756, 32, 0, 69, "Section"],
Cell[2196935, 63758, 192, 4, 50, "Text"],
Cell[2197130, 63764, 45, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2197200, 63769, 498, 10, 123, "Input"],
Cell[2197701, 63781, 202, 3, 49, "Message"],
Cell[2197906, 63786, 77990, 1976, 243, 23505, 1299, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2275899, 65764, 130, 3, 27, "Output"]
}, Open  ]],
Cell[2276044, 65770, 164, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[2276233, 65778, 131, 3, 43, "Input"],
Cell[2276367, 65783, 17069, 451, 243, 4128, 287, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2293439, 66236, 130, 3, 27, "Output"]
}, Open  ]],
Cell[2293584, 66242, 152, 3, 50, "Text"],

Cell[CellGroupData[{
Cell[2293761, 66249, 123, 2, 43, "Input"],
Cell[2293887, 66253, 90318, 2140, 243, 22444, 1297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2384208, 68395, 130, 3, 27, "Output"]
}, Open  ]],
Cell[2384353, 68401, 465, 8, 104, "Text"],

Cell[CellGroupData[{
Cell[2384843, 68413, 530, 11, 123, "Input"],
Cell[2385376, 68426, 359, 5, 35, "Message"],
Cell[2385738, 68433, 222, 4, 49, "Message"],
Cell[2385963, 68439, 89026, 2027, 243, 21213, 1185, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2474992, 70468, 130, 3, 27, "Output"]
}, Open  ]],
Cell[2475137, 70474, 317, 6, 68, "Text"],

Cell[CellGroupData[{
Cell[2475479, 70484, 518, 10, 123, "Input"],
Cell[2476000, 70496, 203, 3, 49, "Message"],
Cell[2476206, 70501, 48774, 1507, 243, 19464, 1140, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2524983, 72010, 130, 3, 27, "Output"]
}, Open  ]],
Cell[2525128, 72016, 348, 6, 86, "Text"],

Cell[CellGroupData[{
Cell[2525501, 72026, 76, 1, 27, "Input"],
Cell[2525580, 72029, 58027, 1680, 243, 20716, 1215, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2583610, 73711, 130, 3, 27, "Output"]
}, Open  ]],
Cell[2583755, 73717, 591, 10, 104, "Text"],

Cell[CellGroupData[{
Cell[2584371, 73731, 585, 12, 136, "Input"],
Cell[2584959, 73745, 202, 3, 49, "Message"],
Cell[2585164, 73750, 79367, 2119, 243, 26123, 1457, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2664534, 75871, 130, 3, 27, "Output"]
}, Open  ]],
Cell[2664679, 75877, 473, 9, 86, "Text"],

Cell[CellGroupData[{
Cell[2665177, 75890, 620, 12, 155, "Input"],
Cell[2665800, 75904, 359, 5, 35, "Message"],
Cell[2666162, 75911, 203, 3, 49, "Message"],
Cell[2666368, 75916, 47868, 1490, 243, 19406, 1134, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2714239, 77408, 130, 3, 27, "Output"]
}, Open  ]],
Cell[2714384, 77414, 337, 7, 68, "Text"],

Cell[CellGroupData[{
Cell[2714746, 77425, 77, 1, 27, "Input"],
Cell[2714826, 77428, 55889, 1654, 243, 20720, 1215, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2770718, 79084, 130, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2770897, 79093, 49, 0, 69, "Section"],
Cell[2770949, 79095, 1049, 17, 194, "Text"],

Cell[CellGroupData[{
Cell[2772023, 79116, 103, 2, 43, "Input"],
Cell[2772129, 79120, 83, 1, 27, "Output"]
}, Open  ]],
Cell[2772227, 79124, 100, 3, 32, "Text"],
Cell[2772330, 79129, 45, 1, 27, "Input"],
Cell[2772378, 79132, 168, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[2772571, 79140, 632, 13, 155, "Input"],
Cell[2773206, 79155, 212, 3, 49, "Message"],
Cell[2773421, 79160, 97708, 2381, 243, 27205, 1506, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2871132, 81543, 130, 3, 27, "Output"]
}, Open  ]],
Cell[2871277, 81549, 409, 12, 50, "Text"],

Cell[CellGroupData[{
Cell[2871711, 81565, 141, 3, 43, "Input"],
Cell[2871855, 81570, 16052, 416, 243, 3763, 260, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2887910, 81988, 130, 3, 27, "Output"]
}, Open  ]],
Cell[2888055, 81994, 153, 3, 50, "Text"],

Cell[CellGroupData[{
Cell[2888233, 82001, 72, 1, 27, "Input"],
Cell[2888308, 82004, 128014, 2792, 243, 27572, 1547, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3016325, 84798, 130, 3, 27, "Output"]
}, Open  ]],
Cell[3016470, 84804, 61, 2, 32, "Text"],
Cell[3016534, 84808, 139, 2, 23, "DisplayFormula"],
Cell[3016676, 84812, 145, 3, 50, "Text"],

Cell[CellGroupData[{
Cell[3016846, 84819, 695, 15, 187, "Input"],
Cell[3017544, 84836, 216, 4, 49, "Message"],
Cell[3017763, 84842, 97489, 2099, 243, 19963, 1137, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3115255, 86943, 130, 3, 27, "Output"]
}, Open  ]],
Cell[3115400, 86949, 119, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[3115544, 86956, 481, 10, 107, "Input"],
Cell[3116028, 86968, 59237, 1654, 243, 21467, 1183, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3175268, 88624, 130, 3, 27, "Output"]
}, Open  ]],
Cell[3175413, 88630, 300, 5, 68, "Text"],

Cell[CellGroupData[{
Cell[3175738, 88639, 120, 2, 43, "Input"],
Cell[3175861, 88643, 70095, 1931, 243, 23216, 1348, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3245959, 90576, 130, 3, 27, "Output"]
}, Open  ]],
Cell[3246104, 90582, 906, 19, 140, "Text"],

Cell[CellGroupData[{
Cell[3247035, 90605, 648, 13, 171, "Input"],
Cell[3247686, 90620, 210, 3, 49, "Message"],
Cell[3247899, 90625, 87811, 2234, 243, 26445, 1472, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3335713, 92861, 130, 3, 27, "Output"]
}, Open  ]],
Cell[3335858, 92867, 507, 13, 68, "Text"],

Cell[CellGroupData[{
Cell[3336390, 92884, 559, 11, 139, "Input"],
Cell[3336952, 92897, 61051, 1725, 243, 22119, 1240, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3398006, 94624, 130, 3, 27, "Output"]
}, Open  ]],
Cell[3398151, 94630, 488, 8, 104, "Text"],

Cell[CellGroupData[{
Cell[3398664, 94642, 73, 1, 27, "Input"],
Cell[3398740, 94645, 76304, 1981, 243, 23100, 1320, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3475047, 96628, 130, 3, 27, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

